@@ -1,26 +1,23 @@
 var searchData=
 [
+  ['abstractpersistentbase',['AbstractPersistentBase',['../class_std_obj_mgt___shared_object_1_1_abstract_persistent_base.html',1,'StdObjMgt_SharedObject']]],
   ['adaptor2d_5fcurve2d',['Adaptor2d_Curve2d',['../class_adaptor2d___curve2d.html',1,'']]],
   ['adaptor2d_5fhcurve2d',['Adaptor2d_HCurve2d',['../class_adaptor2d___h_curve2d.html',1,'']]],
   ['adaptor2d_5fhline2d',['Adaptor2d_HLine2d',['../class_adaptor2d___h_line2d.html',1,'']]],
+  ['adaptor2d_5fhoffsetcurve',['Adaptor2d_HOffsetCurve',['../class_adaptor2d___h_offset_curve.html',1,'']]],
   ['adaptor2d_5fline2d',['Adaptor2d_Line2d',['../class_adaptor2d___line2d.html',1,'']]],
+  ['adaptor2d_5foffsetcurve',['Adaptor2d_OffsetCurve',['../class_adaptor2d___offset_curve.html',1,'']]],
   ['adaptor3d_5fcurve',['Adaptor3d_Curve',['../class_adaptor3d___curve.html',1,'']]],
   ['adaptor3d_5fcurveonsurface',['Adaptor3d_CurveOnSurface',['../class_adaptor3d___curve_on_surface.html',1,'']]],
   ['adaptor3d_5fhcurve',['Adaptor3d_HCurve',['../class_adaptor3d___h_curve.html',1,'']]],
   ['adaptor3d_5fhcurveonsurface',['Adaptor3d_HCurveOnSurface',['../class_adaptor3d___h_curve_on_surface.html',1,'']]],
   ['adaptor3d_5fhisocurve',['Adaptor3d_HIsoCurve',['../class_adaptor3d___h_iso_curve.html',1,'']]],
-  ['adaptor3d_5fhoffsetcurve',['Adaptor3d_HOffsetCurve',['../class_adaptor3d___h_offset_curve.html',1,'']]],
   ['adaptor3d_5fhsurface',['Adaptor3d_HSurface',['../class_adaptor3d___h_surface.html',1,'']]],
-  ['adaptor3d_5fhsurfaceoflinearextrusion',['Adaptor3d_HSurfaceOfLinearExtrusion',['../class_adaptor3d___h_surface_of_linear_extrusion.html',1,'']]],
-  ['adaptor3d_5fhsurfaceofrevolution',['Adaptor3d_HSurfaceOfRevolution',['../class_adaptor3d___h_surface_of_revolution.html',1,'']]],
   ['adaptor3d_5fhsurfacetool',['Adaptor3d_HSurfaceTool',['../class_adaptor3d___h_surface_tool.html',1,'']]],
   ['adaptor3d_5fhvertex',['Adaptor3d_HVertex',['../class_adaptor3d___h_vertex.html',1,'']]],
   ['adaptor3d_5finterfunc',['Adaptor3d_InterFunc',['../class_adaptor3d___inter_func.html',1,'']]],
   ['adaptor3d_5fisocurve',['Adaptor3d_IsoCurve',['../class_adaptor3d___iso_curve.html',1,'']]],
-  ['adaptor3d_5foffsetcurve',['Adaptor3d_OffsetCurve',['../class_adaptor3d___offset_curve.html',1,'']]],
   ['adaptor3d_5fsurface',['Adaptor3d_Surface',['../class_adaptor3d___surface.html',1,'']]],
-  ['adaptor3d_5fsurfaceoflinearextrusion',['Adaptor3d_SurfaceOfLinearExtrusion',['../class_adaptor3d___surface_of_linear_extrusion.html',1,'']]],
-  ['adaptor3d_5fsurfaceofrevolution',['Adaptor3d_SurfaceOfRevolution',['../class_adaptor3d___surface_of_revolution.html',1,'']]],
   ['adaptor3d_5ftopoltool',['Adaptor3d_TopolTool',['../class_adaptor3d___topol_tool.html',1,'']]],
   ['advapp2var_5fapproxafunc2var',['AdvApp2Var_ApproxAFunc2Var',['../class_adv_app2_var___approx_a_func2_var.html',1,'']]],
   ['advapp2var_5fapproxf2var',['AdvApp2Var_ApproxF2var',['../class_adv_app2_var___approx_f2var.html',1,'']]],
@@ -34,14 +31,6 @@ var searchData=
   ['advapp2var_5fnetwork',['AdvApp2Var_Network',['../class_adv_app2_var___network.html',1,'']]],
   ['advapp2var_5fnode',['AdvApp2Var_Node',['../class_adv_app2_var___node.html',1,'']]],
   ['advapp2var_5fpatch',['AdvApp2Var_Patch',['../class_adv_app2_var___patch.html',1,'']]],
-  ['advapp2var_5fsequencenodeofsequenceofnode',['AdvApp2Var_SequenceNodeOfSequenceOfNode',['../class_adv_app2_var___sequence_node_of_sequence_of_node.html',1,'']]],
-  ['advapp2var_5fsequencenodeofsequenceofpatch',['AdvApp2Var_SequenceNodeOfSequenceOfPatch',['../class_adv_app2_var___sequence_node_of_sequence_of_patch.html',1,'']]],
-  ['advapp2var_5fsequencenodeofsequenceofstrip',['AdvApp2Var_SequenceNodeOfSequenceOfStrip',['../class_adv_app2_var___sequence_node_of_sequence_of_strip.html',1,'']]],
-  ['advapp2var_5fsequencenodeofstrip',['AdvApp2Var_SequenceNodeOfStrip',['../class_adv_app2_var___sequence_node_of_strip.html',1,'']]],
-  ['advapp2var_5fsequenceofnode',['AdvApp2Var_SequenceOfNode',['../class_adv_app2_var___sequence_of_node.html',1,'']]],
-  ['advapp2var_5fsequenceofpatch',['AdvApp2Var_SequenceOfPatch',['../class_adv_app2_var___sequence_of_patch.html',1,'']]],
-  ['advapp2var_5fsequenceofstrip',['AdvApp2Var_SequenceOfStrip',['../class_adv_app2_var___sequence_of_strip.html',1,'']]],
-  ['advapp2var_5fstrip',['AdvApp2Var_Strip',['../class_adv_app2_var___strip.html',1,'']]],
   ['advapp2var_5fsysbase',['AdvApp2Var_SysBase',['../class_adv_app2_var___sys_base.html',1,'']]],
   ['advapprox_5fapproxafunction',['AdvApprox_ApproxAFunction',['../class_adv_approx___approx_a_function.html',1,'']]],
   ['advapprox_5fcutting',['AdvApprox_Cutting',['../class_adv_approx___cutting.html',1,'']]],
@@ -52,6 +41,11 @@ var searchData=
   ['advapprox_5fsimpleapprox',['AdvApprox_SimpleApprox',['../class_adv_approx___simple_approx.html',1,'']]],
   ['ais',['AIS',['../class_a_i_s.html',1,'']]],
   ['ais_5fangledimension',['AIS_AngleDimension',['../class_a_i_s___angle_dimension.html',1,'']]],
+  ['ais_5fanimation',['AIS_Animation',['../class_a_i_s___animation.html',1,'']]],
+  ['ais_5fanimationcamera',['AIS_AnimationCamera',['../class_a_i_s___animation_camera.html',1,'']]],
+  ['ais_5fanimationobject',['AIS_AnimationObject',['../class_a_i_s___animation_object.html',1,'']]],
+  ['ais_5fanimationprogress',['AIS_AnimationProgress',['../struct_a_i_s___animation_progress.html',1,'']]],
+  ['ais_5fanimationtimer',['AIS_AnimationTimer',['../class_a_i_s___animation_timer.html',1,'']]],
   ['ais_5fattributefilter',['AIS_AttributeFilter',['../class_a_i_s___attribute_filter.html',1,'']]],
   ['ais_5faxis',['AIS_Axis',['../class_a_i_s___axis.html',1,'']]],
   ['ais_5fbadedgefilter',['AIS_BadEdgeFilter',['../class_a_i_s___bad_edge_filter.html',1,'']]],
@@ -61,20 +55,9 @@ var searchData=
   ['ais_5fcircle',['AIS_Circle',['../class_a_i_s___circle.html',1,'']]],
   ['ais_5fcoloreddrawer',['AIS_ColoredDrawer',['../class_a_i_s___colored_drawer.html',1,'']]],
   ['ais_5fcoloredshape',['AIS_ColoredShape',['../class_a_i_s___colored_shape.html',1,'']]],
+  ['ais_5fcolorscale',['AIS_ColorScale',['../class_a_i_s___color_scale.html',1,'']]],
   ['ais_5fconcentricrelation',['AIS_ConcentricRelation',['../class_a_i_s___concentric_relation.html',1,'']]],
   ['ais_5fconnectedinteractive',['AIS_ConnectedInteractive',['../class_a_i_s___connected_interactive.html',1,'']]],
-  ['ais_5fdatamapiteratorofdatamapofilc',['AIS_DataMapIteratorOfDataMapOfILC',['../class_a_i_s___data_map_iterator_of_data_map_of_i_l_c.html',1,'']]],
-  ['ais_5fdatamapiteratorofdatamapofintegerlistofinteractive',['AIS_DataMapIteratorOfDataMapofIntegerListOfinteractive',['../class_a_i_s___data_map_iterator_of_data_mapof_integer_list_ofinteractive.html',1,'']]],
-  ['ais_5fdatamapiteratorofdatamapofiostatus',['AIS_DataMapIteratorOfDataMapOfIOStatus',['../class_a_i_s___data_map_iterator_of_data_map_of_i_o_status.html',1,'']]],
-  ['ais_5fdatamapiteratorofdatamapofselstat',['AIS_DataMapIteratorOfDataMapOfSelStat',['../class_a_i_s___data_map_iterator_of_data_map_of_sel_stat.html',1,'']]],
-  ['ais_5fdatamapnodeofdatamapofilc',['AIS_DataMapNodeOfDataMapOfILC',['../class_a_i_s___data_map_node_of_data_map_of_i_l_c.html',1,'']]],
-  ['ais_5fdatamapnodeofdatamapofintegerlistofinteractive',['AIS_DataMapNodeOfDataMapofIntegerListOfinteractive',['../class_a_i_s___data_map_node_of_data_mapof_integer_list_ofinteractive.html',1,'']]],
-  ['ais_5fdatamapnodeofdatamapofiostatus',['AIS_DataMapNodeOfDataMapOfIOStatus',['../class_a_i_s___data_map_node_of_data_map_of_i_o_status.html',1,'']]],
-  ['ais_5fdatamapnodeofdatamapofselstat',['AIS_DataMapNodeOfDataMapOfSelStat',['../class_a_i_s___data_map_node_of_data_map_of_sel_stat.html',1,'']]],
-  ['ais_5fdatamapofilc',['AIS_DataMapOfILC',['../class_a_i_s___data_map_of_i_l_c.html',1,'']]],
-  ['ais_5fdatamapofintegerlistofinteractive',['AIS_DataMapofIntegerListOfinteractive',['../class_a_i_s___data_mapof_integer_list_ofinteractive.html',1,'']]],
-  ['ais_5fdatamapofiostatus',['AIS_DataMapOfIOStatus',['../class_a_i_s___data_map_of_i_o_status.html',1,'']]],
-  ['ais_5fdatamapofselstat',['AIS_DataMapOfSelStat',['../class_a_i_s___data_map_of_sel_stat.html',1,'']]],
   ['ais_5fdiameterdimension',['AIS_DiameterDimension',['../class_a_i_s___diameter_dimension.html',1,'']]],
   ['ais_5fdimension',['AIS_Dimension',['../class_a_i_s___dimension.html',1,'']]],
   ['ais_5fdimensionowner',['AIS_DimensionOwner',['../class_a_i_s___dimension_owner.html',1,'']]],
@@ -86,19 +69,14 @@ var searchData=
   ['ais_5fglobalstatus',['AIS_GlobalStatus',['../class_a_i_s___global_status.html',1,'']]],
   ['ais_5fgraphictool',['AIS_GraphicTool',['../class_a_i_s___graphic_tool.html',1,'']]],
   ['ais_5fidenticrelation',['AIS_IdenticRelation',['../class_a_i_s___identic_relation.html',1,'']]],
-  ['ais_5findexeddatamapnodeofindexeddatamapofownerprs',['AIS_IndexedDataMapNodeOfIndexedDataMapOfOwnerPrs',['../class_a_i_s___indexed_data_map_node_of_indexed_data_map_of_owner_prs.html',1,'']]],
-  ['ais_5findexeddatamapofownerprs',['AIS_IndexedDataMapOfOwnerPrs',['../class_a_i_s___indexed_data_map_of_owner_prs.html',1,'']]],
   ['ais_5finteractivecontext',['AIS_InteractiveContext',['../class_a_i_s___interactive_context.html',1,'']]],
   ['ais_5finteractiveobject',['AIS_InteractiveObject',['../class_a_i_s___interactive_object.html',1,'']]],
   ['ais_5flengthdimension',['AIS_LengthDimension',['../class_a_i_s___length_dimension.html',1,'']]],
   ['ais_5fline',['AIS_Line',['../class_a_i_s___line.html',1,'']]],
-  ['ais_5flistiteratoroflistofinteractive',['AIS_ListIteratorOfListOfInteractive',['../class_a_i_s___list_iterator_of_list_of_interactive.html',1,'']]],
-  ['ais_5flistnodeoflistofinteractive',['AIS_ListNodeOfListOfInteractive',['../class_a_i_s___list_node_of_list_of_interactive.html',1,'']]],
-  ['ais_5flistofinteractive',['AIS_ListOfInteractive',['../class_a_i_s___list_of_interactive.html',1,'']]],
   ['ais_5flocalcontext',['AIS_LocalContext',['../class_a_i_s___local_context.html',1,'']]],
   ['ais_5flocalstatus',['AIS_LocalStatus',['../class_a_i_s___local_status.html',1,'']]],
-  ['ais_5fmapiteratorofmapofinteractive',['AIS_MapIteratorOfMapOfInteractive',['../class_a_i_s___map_iterator_of_map_of_interactive.html',1,'']]],
-  ['ais_5fmapofinteractive',['AIS_MapOfInteractive',['../class_a_i_s___map_of_interactive.html',1,'']]],
+  ['ais_5fmanipulator',['AIS_Manipulator',['../class_a_i_s___manipulator.html',1,'']]],
+  ['ais_5fmanipulatorowner',['AIS_ManipulatorOwner',['../class_a_i_s___manipulator_owner.html',1,'']]],
   ['ais_5fmaxradiusdimension',['AIS_MaxRadiusDimension',['../class_a_i_s___max_radius_dimension.html',1,'']]],
   ['ais_5fmidpointrelation',['AIS_MidPointRelation',['../class_a_i_s___mid_point_relation.html',1,'']]],
   ['ais_5fminradiusdimension',['AIS_MinRadiusDimension',['../class_a_i_s___min_radius_dimension.html',1,'']]],
@@ -112,14 +90,10 @@ var searchData=
   ['ais_5fpointcloud',['AIS_PointCloud',['../class_a_i_s___point_cloud.html',1,'']]],
   ['ais_5fradiusdimension',['AIS_RadiusDimension',['../class_a_i_s___radius_dimension.html',1,'']]],
   ['ais_5frelation',['AIS_Relation',['../class_a_i_s___relation.html',1,'']]],
+  ['ais_5frubberband',['AIS_RubberBand',['../class_a_i_s___rubber_band.html',1,'']]],
   ['ais_5fselection',['AIS_Selection',['../class_a_i_s___selection.html',1,'']]],
-  ['ais_5fsequencenodeofsequenceofdimension',['AIS_SequenceNodeOfSequenceOfDimension',['../class_a_i_s___sequence_node_of_sequence_of_dimension.html',1,'']]],
-  ['ais_5fsequencenodeofsequenceofinteractive',['AIS_SequenceNodeOfSequenceOfInteractive',['../class_a_i_s___sequence_node_of_sequence_of_interactive.html',1,'']]],
-  ['ais_5fsequenceofdimension',['AIS_SequenceOfDimension',['../class_a_i_s___sequence_of_dimension.html',1,'']]],
-  ['ais_5fsequenceofinteractive',['AIS_SequenceOfInteractive',['../class_a_i_s___sequence_of_interactive.html',1,'']]],
   ['ais_5fshape',['AIS_Shape',['../class_a_i_s___shape.html',1,'']]],
   ['ais_5fsignaturefilter',['AIS_SignatureFilter',['../class_a_i_s___signature_filter.html',1,'']]],
-  ['ais_5fstdmapnodeofmapofinteractive',['AIS_StdMapNodeOfMapOfInteractive',['../class_a_i_s___std_map_node_of_map_of_interactive.html',1,'']]],
   ['ais_5fsymmetricrelation',['AIS_SymmetricRelation',['../class_a_i_s___symmetric_relation.html',1,'']]],
   ['ais_5ftangentrelation',['AIS_TangentRelation',['../class_a_i_s___tangent_relation.html',1,'']]],
   ['ais_5ftextlabel',['AIS_TextLabel',['../class_a_i_s___text_label.html',1,'']]],
@@ -127,6 +101,8 @@ var searchData=
   ['ais_5ftriangulation',['AIS_Triangulation',['../class_a_i_s___triangulation.html',1,'']]],
   ['ais_5ftrihedron',['AIS_Trihedron',['../class_a_i_s___trihedron.html',1,'']]],
   ['ais_5ftypefilter',['AIS_TypeFilter',['../class_a_i_s___type_filter.html',1,'']]],
+  ['aispresentation',['AISPresentation',['../class_std_persistent___p_prs_std_1_1_a_i_s_presentation.html',1,'StdPersistent_PPrsStd']]],
+  ['aispresentation_5f1',['AISPresentation_1',['../class_std_persistent___p_prs_std_1_1_a_i_s_presentation__1.html',1,'StdPersistent_PPrsStd']]],
   ['alignedptr',['AlignedPtr',['../class_n_collection___acc_allocator_1_1_aligned_ptr.html',1,'NCollection_AccAllocator']]],
   ['alignedsize',['AlignedSize',['../class_n_collection___acc_allocator_1_1_aligned_size.html',1,'NCollection_AccAllocator']]],
   ['alist',['alist',['../structalist.html',1,'']]],
@@ -135,7 +111,6 @@ var searchData=
   ['appblend_5fapprox',['AppBlend_Approx',['../class_app_blend___approx.html',1,'']]],
   ['appcont_5ffunction',['AppCont_Function',['../class_app_cont___function.html',1,'']]],
   ['appcont_5fleastsquare',['AppCont_LeastSquare',['../class_app_cont___least_square.html',1,'']]],
-  ['appdef_5farray1ofmultipointconstraint',['AppDef_Array1OfMultiPointConstraint',['../class_app_def___array1_of_multi_point_constraint.html',1,'']]],
   ['appdef_5fbspgradient_5fbfgsofmybsplgradientofbsplinecompute',['AppDef_BSpGradient_BFGSOfMyBSplGradientOfBSplineCompute',['../class_app_def___b_sp_gradient___b_f_g_s_of_my_b_spl_gradient_of_b_spline_compute.html',1,'']]],
   ['appdef_5fbsplinecompute',['AppDef_BSplineCompute',['../class_app_def___b_spline_compute.html',1,'']]],
   ['appdef_5fbspparfunctionofmybsplgradientofbsplinecompute',['AppDef_BSpParFunctionOfMyBSplGradientOfBSplineCompute',['../class_app_def___b_sp_par_function_of_my_b_spl_gradient_of_b_spline_compute.html',1,'']]],
@@ -144,7 +119,6 @@ var searchData=
   ['appdef_5fgradient_5fbfgsofmygradientbisofbsplinecompute',['AppDef_Gradient_BFGSOfMyGradientbisOfBSplineCompute',['../class_app_def___gradient___b_f_g_s_of_my_gradientbis_of_b_spline_compute.html',1,'']]],
   ['appdef_5fgradient_5fbfgsofmygradientofcompute',['AppDef_Gradient_BFGSOfMyGradientOfCompute',['../class_app_def___gradient___b_f_g_s_of_my_gradient_of_compute.html',1,'']]],
   ['appdef_5fgradient_5fbfgsofthegradient',['AppDef_Gradient_BFGSOfTheGradient',['../class_app_def___gradient___b_f_g_s_of_the_gradient.html',1,'']]],
-  ['appdef_5fharray1ofmultipointconstraint',['AppDef_HArray1OfMultiPointConstraint',['../class_app_def___h_array1_of_multi_point_constraint.html',1,'']]],
   ['appdef_5flinearcriteria',['AppDef_LinearCriteria',['../class_app_def___linear_criteria.html',1,'']]],
   ['appdef_5fmultiline',['AppDef_MultiLine',['../class_app_def___multi_line.html',1,'']]],
   ['appdef_5fmultipointconstraint',['AppDef_MultiPointConstraint',['../class_app_def___multi_point_constraint.html',1,'']]],
@@ -168,39 +142,23 @@ var searchData=
   ['appdef_5ftheresol',['AppDef_TheResol',['../class_app_def___the_resol.html',1,'']]],
   ['appdef_5fvariational',['AppDef_Variational',['../class_app_def___variational.html',1,'']]],
   ['appparcurves',['AppParCurves',['../class_app_par_curves.html',1,'']]],
-  ['appparcurves_5farray1ofconstraintcouple',['AppParCurves_Array1OfConstraintCouple',['../class_app_par_curves___array1_of_constraint_couple.html',1,'']]],
-  ['appparcurves_5farray1ofmultibspcurve',['AppParCurves_Array1OfMultiBSpCurve',['../class_app_par_curves___array1_of_multi_b_sp_curve.html',1,'']]],
-  ['appparcurves_5farray1ofmulticurve',['AppParCurves_Array1OfMultiCurve',['../class_app_par_curves___array1_of_multi_curve.html',1,'']]],
-  ['appparcurves_5farray1ofmultipoint',['AppParCurves_Array1OfMultiPoint',['../class_app_par_curves___array1_of_multi_point.html',1,'']]],
   ['appparcurves_5fconstraintcouple',['AppParCurves_ConstraintCouple',['../class_app_par_curves___constraint_couple.html',1,'']]],
-  ['appparcurves_5fharray1ofconstraintcouple',['AppParCurves_HArray1OfConstraintCouple',['../class_app_par_curves___h_array1_of_constraint_couple.html',1,'']]],
-  ['appparcurves_5fharray1ofmultibspcurve',['AppParCurves_HArray1OfMultiBSpCurve',['../class_app_par_curves___h_array1_of_multi_b_sp_curve.html',1,'']]],
-  ['appparcurves_5fharray1ofmulticurve',['AppParCurves_HArray1OfMultiCurve',['../class_app_par_curves___h_array1_of_multi_curve.html',1,'']]],
-  ['appparcurves_5fharray1ofmultipoint',['AppParCurves_HArray1OfMultiPoint',['../class_app_par_curves___h_array1_of_multi_point.html',1,'']]],
   ['appparcurves_5fmultibspcurve',['AppParCurves_MultiBSpCurve',['../class_app_par_curves___multi_b_sp_curve.html',1,'']]],
   ['appparcurves_5fmulticurve',['AppParCurves_MultiCurve',['../class_app_par_curves___multi_curve.html',1,'']]],
   ['appparcurves_5fmultipoint',['AppParCurves_MultiPoint',['../class_app_par_curves___multi_point.html',1,'']]],
-  ['appparcurves_5fsequencenodeofsequenceofmultibspcurve',['AppParCurves_SequenceNodeOfSequenceOfMultiBSpCurve',['../class_app_par_curves___sequence_node_of_sequence_of_multi_b_sp_curve.html',1,'']]],
-  ['appparcurves_5fsequencenodeofsequenceofmulticurve',['AppParCurves_SequenceNodeOfSequenceOfMultiCurve',['../class_app_par_curves___sequence_node_of_sequence_of_multi_curve.html',1,'']]],
-  ['appparcurves_5fsequenceofmultibspcurve',['AppParCurves_SequenceOfMultiBSpCurve',['../class_app_par_curves___sequence_of_multi_b_sp_curve.html',1,'']]],
-  ['appparcurves_5fsequenceofmulticurve',['AppParCurves_SequenceOfMultiCurve',['../class_app_par_curves___sequence_of_multi_curve.html',1,'']]],
-  ['approx_5farray1ofadhsurface',['Approx_Array1OfAdHSurface',['../class_approx___array1_of_ad_h_surface.html',1,'']]],
-  ['approx_5farray1ofgtrsf2d',['Approx_Array1OfGTrsf2d',['../class_approx___array1_of_g_trsf2d.html',1,'']]],
   ['approx_5fcurve2d',['Approx_Curve2d',['../class_approx___curve2d.html',1,'']]],
   ['approx_5fcurve3d',['Approx_Curve3d',['../class_approx___curve3d.html',1,'']]],
   ['approx_5fcurveonsurface',['Approx_CurveOnSurface',['../class_approx___curve_on_surface.html',1,'']]],
   ['approx_5fcurvilinearparameter',['Approx_CurvilinearParameter',['../class_approx___curvilinear_parameter.html',1,'']]],
   ['approx_5fcurvlinfunc',['Approx_CurvlinFunc',['../class_approx___curvlin_func.html',1,'']]],
+  ['approx_5fdata',['Approx_Data',['../struct_approx___data.html',1,'']]],
   ['approx_5ffitanddivide',['Approx_FitAndDivide',['../class_approx___fit_and_divide.html',1,'']]],
   ['approx_5ffitanddivide2d',['Approx_FitAndDivide2d',['../class_approx___fit_and_divide2d.html',1,'']]],
-  ['approx_5fharray1ofadhsurface',['Approx_HArray1OfAdHSurface',['../class_approx___h_array1_of_ad_h_surface.html',1,'']]],
-  ['approx_5fharray1ofgtrsf2d',['Approx_HArray1OfGTrsf2d',['../class_approx___h_array1_of_g_trsf2d.html',1,'']]],
   ['approx_5fmcurvestobspcurve',['Approx_MCurvesToBSpCurve',['../class_approx___m_curves_to_b_sp_curve.html',1,'']]],
   ['approx_5fsameparameter',['Approx_SameParameter',['../class_approx___same_parameter.html',1,'']]],
-  ['approx_5fsequencenodeofsequenceofharray1ofreal',['Approx_SequenceNodeOfSequenceOfHArray1OfReal',['../class_approx___sequence_node_of_sequence_of_h_array1_of_real.html',1,'']]],
-  ['approx_5fsequenceofharray1ofreal',['Approx_SequenceOfHArray1OfReal',['../class_approx___sequence_of_h_array1_of_real.html',1,'']]],
   ['approx_5fsweepapproximation',['Approx_SweepApproximation',['../class_approx___sweep_approximation.html',1,'']]],
   ['approx_5fsweepfunction',['Approx_SweepFunction',['../class_approx___sweep_function.html',1,'']]],
+  ['approxint_5fknottools',['ApproxInt_KnotTools',['../class_approx_int___knot_tools.html',1,'']]],
   ['approxint_5fsvsurfaces',['ApproxInt_SvSurfaces',['../class_approx_int___sv_surfaces.html',1,'']]],
   ['appstd_5fapplication',['AppStd_Application',['../class_app_std___application.html',1,'']]],
   ['appstdl_5fapplication',['AppStdL_Application',['../class_app_std_l___application.html',1,'']]],
@@ -213,19 +171,16 @@ var searchData=
   ['arraytype_3c_20standard_5fshortreal_2c_203_20_3e',['ArrayType&lt; Standard_ShortReal, 3 &gt;',['../struct_b_v_h_1_1_array_type.html',1,'BVH']]],
   ['arraytype_3c_20standard_5fshortreal_2c_20n_20_3e',['ArrayType&lt; Standard_ShortReal, N &gt;',['../struct_b_v_h_1_1_array_type.html',1,'BVH']]],
   ['arrow',['Arrow',['../struct_a_i_s___dimension_1_1_selection_geometry_1_1_arrow.html',1,'AIS_Dimension::SelectionGeometry']]],
-  ['aspect_5faspectfillarea',['Aspect_AspectFillArea',['../class_aspect___aspect_fill_area.html',1,'']]],
-  ['aspect_5faspectline',['Aspect_AspectLine',['../class_aspect___aspect_line.html',1,'']]],
-  ['aspect_5faspectmarker',['Aspect_AspectMarker',['../class_aspect___aspect_marker.html',1,'']]],
+  ['ascii',['Ascii',['../class_std_l_persistent___h_string_1_1_ascii.html',1,'StdLPersistent_HString']]],
+  ['asciistring',['AsciiString',['../class_std_l_persistent___value_1_1_ascii_string.html',1,'StdLPersistent_Value']]],
   ['aspect_5fbackground',['Aspect_Background',['../class_aspect___background.html',1,'']]],
   ['aspect_5fcirculargrid',['Aspect_CircularGrid',['../class_aspect___circular_grid.html',1,'']]],
-  ['aspect_5fcolorscale',['Aspect_ColorScale',['../class_aspect___color_scale.html',1,'']]],
   ['aspect_5fdisplayconnection',['Aspect_DisplayConnection',['../class_aspect___display_connection.html',1,'']]],
   ['aspect_5fgenid',['Aspect_GenId',['../class_aspect___gen_id.html',1,'']]],
   ['aspect_5fgradientbackground',['Aspect_GradientBackground',['../class_aspect___gradient_background.html',1,'']]],
-  ['aspect_5fgraphiccallbackstruct',['Aspect_GraphicCallbackStruct',['../struct_aspect___graphic_callback_struct.html',1,'']]],
   ['aspect_5fgrid',['Aspect_Grid',['../class_aspect___grid.html',1,'']]],
+  ['aspect_5fneutralwindow',['Aspect_NeutralWindow',['../class_aspect___neutral_window.html',1,'']]],
   ['aspect_5frectangulargrid',['Aspect_RectangularGrid',['../class_aspect___rectangular_grid.html',1,'']]],
-  ['aspect_5fsequencenodeofsequenceofcolor',['Aspect_SequenceNodeOfSequenceOfColor',['../class_aspect___sequence_node_of_sequence_of_color.html',1,'']]],
-  ['aspect_5fsequenceofcolor',['Aspect_SequenceOfColor',['../class_aspect___sequence_of_color.html',1,'']]],
-  ['aspect_5fwindow',['Aspect_Window',['../class_aspect___window.html',1,'']]]
+  ['aspect_5fwindow',['Aspect_Window',['../class_aspect___window.html',1,'']]],
+  ['axis',['Axis',['../class_a_i_s___manipulator_1_1_axis.html',1,'AIS_Manipulator']]]
 ];
