@@ -3,22 +3,14 @@ var searchData=
   ['raytracingparams',['RaytracingParams',['../struct_open_gl___view_1_1_raytracing_params.html',1,'OpenGl_View']]],
   ['rebind',['rebind',['../struct_n_collection___std_allocator_1_1rebind.html',1,'NCollection_StdAllocator']]],
   ['rebind',['rebind',['../struct_n_collection___std_allocator_3_01void_01_4_1_1rebind.html',1,'NCollection_StdAllocator&lt; void &gt;']]],
-  ['rect',['Rect',['../struct_font___f_t_font_1_1_rect.html',1,'Font_FTFont']]],
   ['recti',['RectI',['../struct_open_gl___font_1_1_rect_i.html',1,'OpenGl_Font']]],
-  ['resource_5fdatamapiteratorofdatamapofasciistringasciistring',['Resource_DataMapIteratorOfDataMapOfAsciiStringAsciiString',['../class_resource___data_map_iterator_of_data_map_of_ascii_string_ascii_string.html',1,'']]],
-  ['resource_5fdatamapiteratorofdatamapofasciistringextendedstring',['Resource_DataMapIteratorOfDataMapOfAsciiStringExtendedString',['../class_resource___data_map_iterator_of_data_map_of_ascii_string_extended_string.html',1,'']]],
-  ['resource_5fdatamapnodeofdatamapofasciistringasciistring',['Resource_DataMapNodeOfDataMapOfAsciiStringAsciiString',['../class_resource___data_map_node_of_data_map_of_ascii_string_ascii_string.html',1,'']]],
-  ['resource_5fdatamapnodeofdatamapofasciistringextendedstring',['Resource_DataMapNodeOfDataMapOfAsciiStringExtendedString',['../class_resource___data_map_node_of_data_map_of_ascii_string_extended_string.html',1,'']]],
-  ['resource_5fdatamapofasciistringasciistring',['Resource_DataMapOfAsciiStringAsciiString',['../class_resource___data_map_of_ascii_string_ascii_string.html',1,'']]],
-  ['resource_5fdatamapofasciistringextendedstring',['Resource_DataMapOfAsciiStringExtendedString',['../class_resource___data_map_of_ascii_string_extended_string.html',1,'']]],
   ['resource_5flexicalcompare',['Resource_LexicalCompare',['../class_resource___lexical_compare.html',1,'']]],
   ['resource_5fmanager',['Resource_Manager',['../class_resource___manager.html',1,'']]],
-  ['resource_5fquicksortofarray1',['Resource_QuickSortOfArray1',['../class_resource___quick_sort_of_array1.html',1,'']]],
   ['resource_5funicode',['Resource_Unicode',['../class_resource___unicode.html',1,'']]],
+  ['resources',['Resources',['../struct_open_gl___aspect_face_1_1_resources.html',1,'OpenGl_AspectFace']]],
+  ['resources',['Resources',['../struct_open_gl___aspect_line_1_1_resources.html',1,'OpenGl_AspectLine']]],
   ['resources',['Resources',['../struct_open_gl___aspect_marker_1_1_resources.html',1,'OpenGl_AspectMarker']]],
   ['resources',['Resources',['../struct_open_gl___aspect_text_1_1_resources.html',1,'OpenGl_AspectText']]],
-  ['resources',['Resources',['../struct_open_gl___aspect_line_1_1_resources.html',1,'OpenGl_AspectLine']]],
-  ['resources',['Resources',['../struct_open_gl___aspect_face_1_1_resources.html',1,'OpenGl_AspectFace']]],
   ['rwheadersection',['RWHeaderSection',['../class_r_w_header_section.html',1,'']]],
   ['rwheadersection_5fgeneralmodule',['RWHeaderSection_GeneralModule',['../class_r_w_header_section___general_module.html',1,'']]],
   ['rwheadersection_5freadwritemodule',['RWHeaderSection_ReadWriteModule',['../class_r_w_header_section___read_write_module.html',1,'']]],
@@ -65,6 +57,10 @@ var searchData=
   ['rwstepap214_5frwexternallydefinedclass',['RWStepAP214_RWExternallyDefinedClass',['../class_r_w_step_a_p214___r_w_externally_defined_class.html',1,'']]],
   ['rwstepap214_5frwexternallydefinedgeneralproperty',['RWStepAP214_RWExternallyDefinedGeneralProperty',['../class_r_w_step_a_p214___r_w_externally_defined_general_property.html',1,'']]],
   ['rwstepap214_5frwrepitemgroup',['RWStepAP214_RWRepItemGroup',['../class_r_w_step_a_p214___r_w_rep_item_group.html',1,'']]],
+  ['rwstepap242_5frwdraughtingmodelitemassociation',['RWStepAP242_RWDraughtingModelItemAssociation',['../class_r_w_step_a_p242___r_w_draughting_model_item_association.html',1,'']]],
+  ['rwstepap242_5frwgeometricitemspecificusage',['RWStepAP242_RWGeometricItemSpecificUsage',['../class_r_w_step_a_p242___r_w_geometric_item_specific_usage.html',1,'']]],
+  ['rwstepap242_5frwidattribute',['RWStepAP242_RWIdAttribute',['../class_r_w_step_a_p242___r_w_id_attribute.html',1,'']]],
+  ['rwstepap242_5frwitemidentifiedrepresentationusage',['RWStepAP242_RWItemIdentifiedRepresentationUsage',['../class_r_w_step_a_p242___r_w_item_identified_representation_usage.html',1,'']]],
   ['rwstepbasic_5frwaction',['RWStepBasic_RWAction',['../class_r_w_step_basic___r_w_action.html',1,'']]],
   ['rwstepbasic_5frwactionassignment',['RWStepBasic_RWActionAssignment',['../class_r_w_step_basic___r_w_action_assignment.html',1,'']]],
   ['rwstepbasic_5frwactionmethod',['RWStepBasic_RWActionMethod',['../class_r_w_step_basic___r_w_action_method.html',1,'']]],
@@ -156,6 +152,8 @@ var searchData=
   ['rwstepbasic_5frwproductdefinitionformation',['RWStepBasic_RWProductDefinitionFormation',['../class_r_w_step_basic___r_w_product_definition_formation.html',1,'']]],
   ['rwstepbasic_5frwproductdefinitionformationrelationship',['RWStepBasic_RWProductDefinitionFormationRelationship',['../class_r_w_step_basic___r_w_product_definition_formation_relationship.html',1,'']]],
   ['rwstepbasic_5frwproductdefinitionformationwithspecifiedsource',['RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource',['../class_r_w_step_basic___r_w_product_definition_formation_with_specified_source.html',1,'']]],
+  ['rwstepbasic_5frwproductdefinitionreference',['RWStepBasic_RWProductDefinitionReference',['../class_r_w_step_basic___r_w_product_definition_reference.html',1,'']]],
+  ['rwstepbasic_5frwproductdefinitionreferencewithlocalrepresentation',['RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation',['../class_r_w_step_basic___r_w_product_definition_reference_with_local_representation.html',1,'']]],
   ['rwstepbasic_5frwproductdefinitionrelationship',['RWStepBasic_RWProductDefinitionRelationship',['../class_r_w_step_basic___r_w_product_definition_relationship.html',1,'']]],
   ['rwstepbasic_5frwproductdefinitionwithassociateddocuments',['RWStepBasic_RWProductDefinitionWithAssociatedDocuments',['../class_r_w_step_basic___r_w_product_definition_with_associated_documents.html',1,'']]],
   ['rwstepbasic_5frwproductrelatedproductcategory',['RWStepBasic_RWProductRelatedProductCategory',['../class_r_w_step_basic___r_w_product_related_product_category.html',1,'']]],
@@ -189,23 +187,46 @@ var searchData=
   ['rwstepdimtol_5frwdatum',['RWStepDimTol_RWDatum',['../class_r_w_step_dim_tol___r_w_datum.html',1,'']]],
   ['rwstepdimtol_5frwdatumfeature',['RWStepDimTol_RWDatumFeature',['../class_r_w_step_dim_tol___r_w_datum_feature.html',1,'']]],
   ['rwstepdimtol_5frwdatumreference',['RWStepDimTol_RWDatumReference',['../class_r_w_step_dim_tol___r_w_datum_reference.html',1,'']]],
+  ['rwstepdimtol_5frwdatumreferencecompartment',['RWStepDimTol_RWDatumReferenceCompartment',['../class_r_w_step_dim_tol___r_w_datum_reference_compartment.html',1,'']]],
+  ['rwstepdimtol_5frwdatumreferenceelement',['RWStepDimTol_RWDatumReferenceElement',['../class_r_w_step_dim_tol___r_w_datum_reference_element.html',1,'']]],
+  ['rwstepdimtol_5frwdatumreferencemodifierwithvalue',['RWStepDimTol_RWDatumReferenceModifierWithValue',['../class_r_w_step_dim_tol___r_w_datum_reference_modifier_with_value.html',1,'']]],
+  ['rwstepdimtol_5frwdatumsystem',['RWStepDimTol_RWDatumSystem',['../class_r_w_step_dim_tol___r_w_datum_system.html',1,'']]],
   ['rwstepdimtol_5frwdatumtarget',['RWStepDimTol_RWDatumTarget',['../class_r_w_step_dim_tol___r_w_datum_target.html',1,'']]],
   ['rwstepdimtol_5frwflatnesstolerance',['RWStepDimTol_RWFlatnessTolerance',['../class_r_w_step_dim_tol___r_w_flatness_tolerance.html',1,'']]],
+  ['rwstepdimtol_5frwgeneraldatumreference',['RWStepDimTol_RWGeneralDatumReference',['../class_r_w_step_dim_tol___r_w_general_datum_reference.html',1,'']]],
   ['rwstepdimtol_5frwgeometrictolerance',['RWStepDimTol_RWGeometricTolerance',['../class_r_w_step_dim_tol___r_w_geometric_tolerance.html',1,'']]],
   ['rwstepdimtol_5frwgeometrictolerancerelationship',['RWStepDimTol_RWGeometricToleranceRelationship',['../class_r_w_step_dim_tol___r_w_geometric_tolerance_relationship.html',1,'']]],
   ['rwstepdimtol_5frwgeometrictolerancewithdatumreference',['RWStepDimTol_RWGeometricToleranceWithDatumReference',['../class_r_w_step_dim_tol___r_w_geometric_tolerance_with_datum_reference.html',1,'']]],
+  ['rwstepdimtol_5frwgeometrictolerancewithdefinedareaunit',['RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit',['../class_r_w_step_dim_tol___r_w_geometric_tolerance_with_defined_area_unit.html',1,'']]],
+  ['rwstepdimtol_5frwgeometrictolerancewithdefinedunit',['RWStepDimTol_RWGeometricToleranceWithDefinedUnit',['../class_r_w_step_dim_tol___r_w_geometric_tolerance_with_defined_unit.html',1,'']]],
+  ['rwstepdimtol_5frwgeometrictolerancewithmaximumtolerance',['RWStepDimTol_RWGeometricToleranceWithMaximumTolerance',['../class_r_w_step_dim_tol___r_w_geometric_tolerance_with_maximum_tolerance.html',1,'']]],
+  ['rwstepdimtol_5frwgeometrictolerancewithmodifiers',['RWStepDimTol_RWGeometricToleranceWithModifiers',['../class_r_w_step_dim_tol___r_w_geometric_tolerance_with_modifiers.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthdatref',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRef',['../class_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthdatrefandgeotolwthmaxtol',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol',['../class_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_and_geo_tol_wth_max_tol.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthdatrefandgeotolwthmod',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod',['../class_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_and_geo_tol_wth_mod.html',1,'']]],
   ['rwstepdimtol_5frwgeotolandgeotolwthdatrefandmodgeotolandpostol',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol',['../class_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_and_mod_geo_tol_and_pos_tol.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthdatrefanduneqdisgeotol',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol',['../class_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_and_uneq_dis_geo_tol.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthmaxtol',['RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol',['../class_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_max_tol.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthmod',['RWStepDimTol_RWGeoTolAndGeoTolWthMod',['../class_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_mod.html',1,'']]],
   ['rwstepdimtol_5frwlineprofiletolerance',['RWStepDimTol_RWLineProfileTolerance',['../class_r_w_step_dim_tol___r_w_line_profile_tolerance.html',1,'']]],
   ['rwstepdimtol_5frwmodifiedgeometrictolerance',['RWStepDimTol_RWModifiedGeometricTolerance',['../class_r_w_step_dim_tol___r_w_modified_geometric_tolerance.html',1,'']]],
+  ['rwstepdimtol_5frwnonuniformzonedefinition',['RWStepDimTol_RWNonUniformZoneDefinition',['../class_r_w_step_dim_tol___r_w_non_uniform_zone_definition.html',1,'']]],
   ['rwstepdimtol_5frwparallelismtolerance',['RWStepDimTol_RWParallelismTolerance',['../class_r_w_step_dim_tol___r_w_parallelism_tolerance.html',1,'']]],
   ['rwstepdimtol_5frwperpendicularitytolerance',['RWStepDimTol_RWPerpendicularityTolerance',['../class_r_w_step_dim_tol___r_w_perpendicularity_tolerance.html',1,'']]],
   ['rwstepdimtol_5frwplaceddatumtargetfeature',['RWStepDimTol_RWPlacedDatumTargetFeature',['../class_r_w_step_dim_tol___r_w_placed_datum_target_feature.html',1,'']]],
   ['rwstepdimtol_5frwpositiontolerance',['RWStepDimTol_RWPositionTolerance',['../class_r_w_step_dim_tol___r_w_position_tolerance.html',1,'']]],
+  ['rwstepdimtol_5frwprojectedzonedefinition',['RWStepDimTol_RWProjectedZoneDefinition',['../class_r_w_step_dim_tol___r_w_projected_zone_definition.html',1,'']]],
   ['rwstepdimtol_5frwroundnesstolerance',['RWStepDimTol_RWRoundnessTolerance',['../class_r_w_step_dim_tol___r_w_roundness_tolerance.html',1,'']]],
+  ['rwstepdimtol_5frwrunoutzonedefinition',['RWStepDimTol_RWRunoutZoneDefinition',['../class_r_w_step_dim_tol___r_w_runout_zone_definition.html',1,'']]],
+  ['rwstepdimtol_5frwrunoutzoneorientation',['RWStepDimTol_RWRunoutZoneOrientation',['../class_r_w_step_dim_tol___r_w_runout_zone_orientation.html',1,'']]],
   ['rwstepdimtol_5frwstraightnesstolerance',['RWStepDimTol_RWStraightnessTolerance',['../class_r_w_step_dim_tol___r_w_straightness_tolerance.html',1,'']]],
   ['rwstepdimtol_5frwsurfaceprofiletolerance',['RWStepDimTol_RWSurfaceProfileTolerance',['../class_r_w_step_dim_tol___r_w_surface_profile_tolerance.html',1,'']]],
   ['rwstepdimtol_5frwsymmetrytolerance',['RWStepDimTol_RWSymmetryTolerance',['../class_r_w_step_dim_tol___r_w_symmetry_tolerance.html',1,'']]],
+  ['rwstepdimtol_5frwtolerancezone',['RWStepDimTol_RWToleranceZone',['../class_r_w_step_dim_tol___r_w_tolerance_zone.html',1,'']]],
+  ['rwstepdimtol_5frwtolerancezonedefinition',['RWStepDimTol_RWToleranceZoneDefinition',['../class_r_w_step_dim_tol___r_w_tolerance_zone_definition.html',1,'']]],
+  ['rwstepdimtol_5frwtolerancezoneform',['RWStepDimTol_RWToleranceZoneForm',['../class_r_w_step_dim_tol___r_w_tolerance_zone_form.html',1,'']]],
   ['rwstepdimtol_5frwtotalrunouttolerance',['RWStepDimTol_RWTotalRunoutTolerance',['../class_r_w_step_dim_tol___r_w_total_runout_tolerance.html',1,'']]],
+  ['rwstepdimtol_5frwunequallydisposedgeometrictolerance',['RWStepDimTol_RWUnequallyDisposedGeometricTolerance',['../class_r_w_step_dim_tol___r_w_unequally_disposed_geometric_tolerance.html',1,'']]],
   ['rwstepelement_5frwanalysisitemwithinrepresentation',['RWStepElement_RWAnalysisItemWithinRepresentation',['../class_r_w_step_element___r_w_analysis_item_within_representation.html',1,'']]],
   ['rwstepelement_5frwcurve3delementdescriptor',['RWStepElement_RWCurve3dElementDescriptor',['../class_r_w_step_element___r_w_curve3d_element_descriptor.html',1,'']]],
   ['rwstepelement_5frwcurveelementendreleasepacket',['RWStepElement_RWCurveElementEndReleasePacket',['../class_r_w_step_element___r_w_curve_element_end_release_packet.html',1,'']]],
@@ -355,21 +376,35 @@ var searchData=
   ['rwstepgeom_5frwuniformsurface',['RWStepGeom_RWUniformSurface',['../class_r_w_step_geom___r_w_uniform_surface.html',1,'']]],
   ['rwstepgeom_5frwuniformsurfaceandrationalbsplinesurface',['RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface',['../class_r_w_step_geom___r_w_uniform_surface_and_rational_b_spline_surface.html',1,'']]],
   ['rwstepgeom_5frwvector',['RWStepGeom_RWVector',['../class_r_w_step_geom___r_w_vector.html',1,'']]],
+  ['rwsteprepr_5frwallaroundshapeaspect',['RWStepRepr_RWAllAroundShapeAspect',['../class_r_w_step_repr___r_w_all_around_shape_aspect.html',1,'']]],
+  ['rwsteprepr_5frwapex',['RWStepRepr_RWApex',['../class_r_w_step_repr___r_w_apex.html',1,'']]],
   ['rwsteprepr_5frwassemblycomponentusage',['RWStepRepr_RWAssemblyComponentUsage',['../class_r_w_step_repr___r_w_assembly_component_usage.html',1,'']]],
   ['rwsteprepr_5frwassemblycomponentusagesubstitute',['RWStepRepr_RWAssemblyComponentUsageSubstitute',['../class_r_w_step_repr___r_w_assembly_component_usage_substitute.html',1,'']]],
+  ['rwsteprepr_5frwbetweenshapeaspect',['RWStepRepr_RWBetweenShapeAspect',['../class_r_w_step_repr___r_w_between_shape_aspect.html',1,'']]],
+  ['rwsteprepr_5frwcentreofsymmetry',['RWStepRepr_RWCentreOfSymmetry',['../class_r_w_step_repr___r_w_centre_of_symmetry.html',1,'']]],
+  ['rwsteprepr_5frwcharacterizedrepresentation',['RWStepRepr_RWCharacterizedRepresentation',['../class_r_w_step_repr___r_w_characterized_representation.html',1,'']]],
+  ['rwsteprepr_5frwcompgroupshaspandcompshaspanddatumfeatandshasp',['RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp',['../class_r_w_step_repr___r_w_comp_group_sh_asp_and_comp_sh_asp_and_datum_feat_and_sh_asp.html',1,'']]],
+  ['rwsteprepr_5frwcompositegroupshapeaspect',['RWStepRepr_RWCompositeGroupShapeAspect',['../class_r_w_step_repr___r_w_composite_group_shape_aspect.html',1,'']]],
   ['rwsteprepr_5frwcompositeshapeaspect',['RWStepRepr_RWCompositeShapeAspect',['../class_r_w_step_repr___r_w_composite_shape_aspect.html',1,'']]],
   ['rwsteprepr_5frwcompoundrepresentationitem',['RWStepRepr_RWCompoundRepresentationItem',['../class_r_w_step_repr___r_w_compound_representation_item.html',1,'']]],
+  ['rwsteprepr_5frwcompshaspanddatumfeatandshasp',['RWStepRepr_RWCompShAspAndDatumFeatAndShAsp',['../class_r_w_step_repr___r_w_comp_sh_asp_and_datum_feat_and_sh_asp.html',1,'']]],
   ['rwsteprepr_5frwconfigurationdesign',['RWStepRepr_RWConfigurationDesign',['../class_r_w_step_repr___r_w_configuration_design.html',1,'']]],
   ['rwsteprepr_5frwconfigurationeffectivity',['RWStepRepr_RWConfigurationEffectivity',['../class_r_w_step_repr___r_w_configuration_effectivity.html',1,'']]],
   ['rwsteprepr_5frwconfigurationitem',['RWStepRepr_RWConfigurationItem',['../class_r_w_step_repr___r_w_configuration_item.html',1,'']]],
+  ['rwsteprepr_5frwconstructivegeometryrepresentation',['RWStepRepr_RWConstructiveGeometryRepresentation',['../class_r_w_step_repr___r_w_constructive_geometry_representation.html',1,'']]],
+  ['rwsteprepr_5frwconstructivegeometryrepresentationrelationship',['RWStepRepr_RWConstructiveGeometryRepresentationRelationship',['../class_r_w_step_repr___r_w_constructive_geometry_representation_relationship.html',1,'']]],
+  ['rwsteprepr_5frwcontinuosshapeaspect',['RWStepRepr_RWContinuosShapeAspect',['../class_r_w_step_repr___r_w_continuos_shape_aspect.html',1,'']]],
   ['rwsteprepr_5frwdataenvironment',['RWStepRepr_RWDataEnvironment',['../class_r_w_step_repr___r_w_data_environment.html',1,'']]],
   ['rwsteprepr_5frwdefinitionalrepresentation',['RWStepRepr_RWDefinitionalRepresentation',['../class_r_w_step_repr___r_w_definitional_representation.html',1,'']]],
   ['rwsteprepr_5frwderivedshapeaspect',['RWStepRepr_RWDerivedShapeAspect',['../class_r_w_step_repr___r_w_derived_shape_aspect.html',1,'']]],
   ['rwsteprepr_5frwdescriptiverepresentationitem',['RWStepRepr_RWDescriptiveRepresentationItem',['../class_r_w_step_repr___r_w_descriptive_representation_item.html',1,'']]],
   ['rwsteprepr_5frwextension',['RWStepRepr_RWExtension',['../class_r_w_step_repr___r_w_extension.html',1,'']]],
+  ['rwsteprepr_5frwfeaturefordatumtargetrelationship',['RWStepRepr_RWFeatureForDatumTargetRelationship',['../class_r_w_step_repr___r_w_feature_for_datum_target_relationship.html',1,'']]],
   ['rwsteprepr_5frwfunctionallydefinedtransformation',['RWStepRepr_RWFunctionallyDefinedTransformation',['../class_r_w_step_repr___r_w_functionally_defined_transformation.html',1,'']]],
+  ['rwsteprepr_5frwgeometricalignment',['RWStepRepr_RWGeometricAlignment',['../class_r_w_step_repr___r_w_geometric_alignment.html',1,'']]],
   ['rwsteprepr_5frwglobaluncertaintyassignedcontext',['RWStepRepr_RWGlobalUncertaintyAssignedContext',['../class_r_w_step_repr___r_w_global_uncertainty_assigned_context.html',1,'']]],
   ['rwsteprepr_5frwglobalunitassignedcontext',['RWStepRepr_RWGlobalUnitAssignedContext',['../class_r_w_step_repr___r_w_global_unit_assigned_context.html',1,'']]],
+  ['rwsteprepr_5frwintegerrepresentationitem',['RWStepRepr_RWIntegerRepresentationItem',['../class_r_w_step_repr___r_w_integer_representation_item.html',1,'']]],
   ['rwsteprepr_5frwitemdefinedtransformation',['RWStepRepr_RWItemDefinedTransformation',['../class_r_w_step_repr___r_w_item_defined_transformation.html',1,'']]],
   ['rwsteprepr_5frwmakefromusageoption',['RWStepRepr_RWMakeFromUsageOption',['../class_r_w_step_repr___r_w_make_from_usage_option.html',1,'']]],
   ['rwsteprepr_5frwmappeditem',['RWStepRepr_RWMappedItem',['../class_r_w_step_repr___r_w_mapped_item.html',1,'']]],
@@ -377,7 +412,9 @@ var searchData=
   ['rwsteprepr_5frwmaterialproperty',['RWStepRepr_RWMaterialProperty',['../class_r_w_step_repr___r_w_material_property.html',1,'']]],
   ['rwsteprepr_5frwmaterialpropertyrepresentation',['RWStepRepr_RWMaterialPropertyRepresentation',['../class_r_w_step_repr___r_w_material_property_representation.html',1,'']]],
   ['rwsteprepr_5frwmeasurerepresentationitem',['RWStepRepr_RWMeasureRepresentationItem',['../class_r_w_step_repr___r_w_measure_representation_item.html',1,'']]],
+  ['rwsteprepr_5frwparalleloffset',['RWStepRepr_RWParallelOffset',['../class_r_w_step_repr___r_w_parallel_offset.html',1,'']]],
   ['rwsteprepr_5frwparametricrepresentationcontext',['RWStepRepr_RWParametricRepresentationContext',['../class_r_w_step_repr___r_w_parametric_representation_context.html',1,'']]],
+  ['rwsteprepr_5frwperpendicularto',['RWStepRepr_RWPerpendicularTo',['../class_r_w_step_repr___r_w_perpendicular_to.html',1,'']]],
   ['rwsteprepr_5frwproductconcept',['RWStepRepr_RWProductConcept',['../class_r_w_step_repr___r_w_product_concept.html',1,'']]],
   ['rwsteprepr_5frwproductdefinitionshape',['RWStepRepr_RWProductDefinitionShape',['../class_r_w_step_repr___r_w_product_definition_shape.html',1,'']]],
   ['rwsteprepr_5frwpropertydefinition',['RWStepRepr_RWPropertyDefinition',['../class_r_w_step_repr___r_w_property_definition.html',1,'']]],
@@ -391,6 +428,9 @@ var searchData=
   ['rwsteprepr_5frwrepresentationrelationship',['RWStepRepr_RWRepresentationRelationship',['../class_r_w_step_repr___r_w_representation_relationship.html',1,'']]],
   ['rwsteprepr_5frwrepresentationrelationshipwithtransformation',['RWStepRepr_RWRepresentationRelationshipWithTransformation',['../class_r_w_step_repr___r_w_representation_relationship_with_transformation.html',1,'']]],
   ['rwsteprepr_5frwrepritemandlengthmeasurewithunit',['RWStepRepr_RWReprItemAndLengthMeasureWithUnit',['../class_r_w_step_repr___r_w_repr_item_and_length_measure_with_unit.html',1,'']]],
+  ['rwsteprepr_5frwrepritemandlengthmeasurewithunitandqri',['RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI',['../class_r_w_step_repr___r_w_repr_item_and_length_measure_with_unit_and_q_r_i.html',1,'']]],
+  ['rwsteprepr_5frwrepritemandplaneanglemeasurewithunit',['RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit',['../class_r_w_step_repr___r_w_repr_item_and_plane_angle_measure_with_unit.html',1,'']]],
+  ['rwsteprepr_5frwrepritemandplaneanglemeasurewithunitandqri',['RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI',['../class_r_w_step_repr___r_w_repr_item_and_plane_angle_measure_with_unit_and_q_r_i.html',1,'']]],
   ['rwsteprepr_5frwshapeaspect',['RWStepRepr_RWShapeAspect',['../class_r_w_step_repr___r_w_shape_aspect.html',1,'']]],
   ['rwsteprepr_5frwshapeaspectderivingrelationship',['RWStepRepr_RWShapeAspectDerivingRelationship',['../class_r_w_step_repr___r_w_shape_aspect_deriving_relationship.html',1,'']]],
   ['rwsteprepr_5frwshapeaspectrelationship',['RWStepRepr_RWShapeAspectRelationship',['../class_r_w_step_repr___r_w_shape_aspect_relationship.html',1,'']]],
@@ -399,6 +439,8 @@ var searchData=
   ['rwsteprepr_5frwspecifiedhigherusageoccurrence',['RWStepRepr_RWSpecifiedHigherUsageOccurrence',['../class_r_w_step_repr___r_w_specified_higher_usage_occurrence.html',1,'']]],
   ['rwsteprepr_5frwstructuralresponseproperty',['RWStepRepr_RWStructuralResponseProperty',['../class_r_w_step_repr___r_w_structural_response_property.html',1,'']]],
   ['rwsteprepr_5frwstructuralresponsepropertydefinitionrepresentation',['RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation',['../class_r_w_step_repr___r_w_structural_response_property_definition_representation.html',1,'']]],
+  ['rwsteprepr_5frwtangent',['RWStepRepr_RWTangent',['../class_r_w_step_repr___r_w_tangent.html',1,'']]],
+  ['rwsteprepr_5frwvaluerepresentationitem',['RWStepRepr_RWValueRepresentationItem',['../class_r_w_step_repr___r_w_value_representation_item.html',1,'']]],
   ['rwstepshape_5frwadvancedbrepshaperepresentation',['RWStepShape_RWAdvancedBrepShapeRepresentation',['../class_r_w_step_shape___r_w_advanced_brep_shape_representation.html',1,'']]],
   ['rwstepshape_5frwadvancedface',['RWStepShape_RWAdvancedFace',['../class_r_w_step_shape___r_w_advanced_face.html',1,'']]],
   ['rwstepshape_5frwangularlocation',['RWStepShape_RWAngularLocation',['../class_r_w_step_shape___r_w_angular_location.html',1,'']]],
@@ -486,9 +528,13 @@ var searchData=
   ['rwstepshape_5frwtorus',['RWStepShape_RWTorus',['../class_r_w_step_shape___r_w_torus.html',1,'']]],
   ['rwstepshape_5frwtransitionalshaperepresentation',['RWStepShape_RWTransitionalShapeRepresentation',['../class_r_w_step_shape___r_w_transitional_shape_representation.html',1,'']]],
   ['rwstepshape_5frwtypequalifier',['RWStepShape_RWTypeQualifier',['../class_r_w_step_shape___r_w_type_qualifier.html',1,'']]],
+  ['rwstepshape_5frwvalueformattypequalifier',['RWStepShape_RWValueFormatTypeQualifier',['../class_r_w_step_shape___r_w_value_format_type_qualifier.html',1,'']]],
   ['rwstepshape_5frwvertex',['RWStepShape_RWVertex',['../class_r_w_step_shape___r_w_vertex.html',1,'']]],
   ['rwstepshape_5frwvertexloop',['RWStepShape_RWVertexLoop',['../class_r_w_step_shape___r_w_vertex_loop.html',1,'']]],
   ['rwstepshape_5frwvertexpoint',['RWStepShape_RWVertexPoint',['../class_r_w_step_shape___r_w_vertex_point.html',1,'']]],
+  ['rwstepvisual_5frwannotationcurveoccurrence',['RWStepVisual_RWAnnotationCurveOccurrence',['../class_r_w_step_visual___r_w_annotation_curve_occurrence.html',1,'']]],
+  ['rwstepvisual_5frwannotationoccurrence',['RWStepVisual_RWAnnotationOccurrence',['../class_r_w_step_visual___r_w_annotation_occurrence.html',1,'']]],
+  ['rwstepvisual_5frwannotationplane',['RWStepVisual_RWAnnotationPlane',['../class_r_w_step_visual___r_w_annotation_plane.html',1,'']]],
   ['rwstepvisual_5frwareainset',['RWStepVisual_RWAreaInSet',['../class_r_w_step_visual___r_w_area_in_set.html',1,'']]],
   ['rwstepvisual_5frwbackgroundcolour',['RWStepVisual_RWBackgroundColour',['../class_r_w_step_visual___r_w_background_colour.html',1,'']]],
   ['rwstepvisual_5frwcameraimage',['RWStepVisual_RWCameraImage',['../class_r_w_step_visual___r_w_camera_image.html',1,'']]],
@@ -496,6 +542,7 @@ var searchData=
   ['rwstepvisual_5frwcameramodeld2',['RWStepVisual_RWCameraModelD2',['../class_r_w_step_visual___r_w_camera_model_d2.html',1,'']]],
   ['rwstepvisual_5frwcameramodeld3',['RWStepVisual_RWCameraModelD3',['../class_r_w_step_visual___r_w_camera_model_d3.html',1,'']]],
   ['rwstepvisual_5frwcamerausage',['RWStepVisual_RWCameraUsage',['../class_r_w_step_visual___r_w_camera_usage.html',1,'']]],
+  ['rwstepvisual_5frwcharacterizedobjectandcharacterizedrepresentationanddraughtingmodelandrepresentation',['RWStepVisual_RWCharacterizedObjectAndCharacterizedRepresentationAndDraughtingModelAndRepresentation',['../class_r_w_step_visual___r_w_characterized_object_and_characterized_representation_and_draughting_model_and_representation.html',1,'']]],
   ['rwstepvisual_5frwcolour',['RWStepVisual_RWColour',['../class_r_w_step_visual___r_w_colour.html',1,'']]],
   ['rwstepvisual_5frwcolourrgb',['RWStepVisual_RWColourRgb',['../class_r_w_step_visual___r_w_colour_rgb.html',1,'']]],
   ['rwstepvisual_5frwcolourspecification',['RWStepVisual_RWColourSpecification',['../class_r_w_step_visual___r_w_colour_specification.html',1,'']]],
@@ -503,9 +550,11 @@ var searchData=
   ['rwstepvisual_5frwcompositetextwithextent',['RWStepVisual_RWCompositeTextWithExtent',['../class_r_w_step_visual___r_w_composite_text_with_extent.html',1,'']]],
   ['rwstepvisual_5frwcontextdependentinvisibility',['RWStepVisual_RWContextDependentInvisibility',['../class_r_w_step_visual___r_w_context_dependent_invisibility.html',1,'']]],
   ['rwstepvisual_5frwcontextdependentoverridingstyleditem',['RWStepVisual_RWContextDependentOverRidingStyledItem',['../class_r_w_step_visual___r_w_context_dependent_over_riding_styled_item.html',1,'']]],
+  ['rwstepvisual_5frwcoordinateslist',['RWStepVisual_RWCoordinatesList',['../class_r_w_step_visual___r_w_coordinates_list.html',1,'']]],
   ['rwstepvisual_5frwcurvestyle',['RWStepVisual_RWCurveStyle',['../class_r_w_step_visual___r_w_curve_style.html',1,'']]],
   ['rwstepvisual_5frwcurvestylefont',['RWStepVisual_RWCurveStyleFont',['../class_r_w_step_visual___r_w_curve_style_font.html',1,'']]],
   ['rwstepvisual_5frwcurvestylefontpattern',['RWStepVisual_RWCurveStyleFontPattern',['../class_r_w_step_visual___r_w_curve_style_font_pattern.html',1,'']]],
+  ['rwstepvisual_5frwdraughtingcallout',['RWStepVisual_RWDraughtingCallout',['../class_r_w_step_visual___r_w_draughting_callout.html',1,'']]],
   ['rwstepvisual_5frwdraughtingmodel',['RWStepVisual_RWDraughtingModel',['../class_r_w_step_visual___r_w_draughting_model.html',1,'']]],
   ['rwstepvisual_5frwdraughtingpredefinedcolour',['RWStepVisual_RWDraughtingPreDefinedColour',['../class_r_w_step_visual___r_w_draughting_pre_defined_colour.html',1,'']]],
   ['rwstepvisual_5frwdraughtingpredefinedcurvefont',['RWStepVisual_RWDraughtingPreDefinedCurveFont',['../class_r_w_step_visual___r_w_draughting_pre_defined_curve_font.html',1,'']]],
@@ -543,6 +592,10 @@ var searchData=
   ['rwstepvisual_5frwsurfacestyleusage',['RWStepVisual_RWSurfaceStyleUsage',['../class_r_w_step_visual___r_w_surface_style_usage.html',1,'']]],
   ['rwstepvisual_5frwtemplate',['RWStepVisual_RWTemplate',['../class_r_w_step_visual___r_w_template.html',1,'']]],
   ['rwstepvisual_5frwtemplateinstance',['RWStepVisual_RWTemplateInstance',['../class_r_w_step_visual___r_w_template_instance.html',1,'']]],
+  ['rwstepvisual_5frwtessellatedannotationoccurrence',['RWStepVisual_RWTessellatedAnnotationOccurrence',['../class_r_w_step_visual___r_w_tessellated_annotation_occurrence.html',1,'']]],
+  ['rwstepvisual_5frwtessellatedcurveset',['RWStepVisual_RWTessellatedCurveSet',['../class_r_w_step_visual___r_w_tessellated_curve_set.html',1,'']]],
+  ['rwstepvisual_5frwtessellatedgeometricset',['RWStepVisual_RWTessellatedGeometricSet',['../class_r_w_step_visual___r_w_tessellated_geometric_set.html',1,'']]],
+  ['rwstepvisual_5frwtessellateditem',['RWStepVisual_RWTessellatedItem',['../class_r_w_step_visual___r_w_tessellated_item.html',1,'']]],
   ['rwstepvisual_5frwtextliteral',['RWStepVisual_RWTextLiteral',['../class_r_w_step_visual___r_w_text_literal.html',1,'']]],
   ['rwstepvisual_5frwtextstyle',['RWStepVisual_RWTextStyle',['../class_r_w_step_visual___r_w_text_style.html',1,'']]],
   ['rwstepvisual_5frwtextstylefordefinedfont',['RWStepVisual_RWTextStyleForDefinedFont',['../class_r_w_step_visual___r_w_text_style_for_defined_font.html',1,'']]],
