@@ -35,7 +35,6 @@ var searchData=
   ['gccana_5flinpnt2dbisec',['GccAna_LinPnt2dBisec',['../class_gcc_ana___lin_pnt2d_bisec.html',1,'']]],
   ['gccana_5fpnt2dbisec',['GccAna_Pnt2dBisec',['../class_gcc_ana___pnt2d_bisec.html',1,'']]],
   ['gccent',['GccEnt',['../class_gcc_ent.html',1,'']]],
-  ['gccent_5farray1ofposition',['GccEnt_Array1OfPosition',['../class_gcc_ent___array1_of_position.html',1,'']]],
   ['gccent_5fqualifiedcirc',['GccEnt_QualifiedCirc',['../class_gcc_ent___qualified_circ.html',1,'']]],
   ['gccent_5fqualifiedlin',['GccEnt_QualifiedLin',['../class_gcc_ent___qualified_lin.html',1,'']]],
   ['gccint_5fbcirc',['GccInt_BCirc',['../class_gcc_int___b_circ.html',1,'']]],
@@ -85,11 +84,16 @@ var searchData=
   ['gce_5fmaketranslation2d',['gce_MakeTranslation2d',['../classgce___make_translation2d.html',1,'']]],
   ['gce_5froot',['gce_Root',['../classgce___root.html',1,'']]],
   ['gcpnts_5fabscissapoint',['GCPnts_AbscissaPoint',['../class_g_c_pnts___abscissa_point.html',1,'']]],
+  ['gcpnts_5fdistfunction',['GCPnts_DistFunction',['../class_g_c_pnts___dist_function.html',1,'']]],
+  ['gcpnts_5fdistfunction2d',['GCPnts_DistFunction2d',['../class_g_c_pnts___dist_function2d.html',1,'']]],
+  ['gcpnts_5fdistfunction2dmv',['GCPnts_DistFunction2dMV',['../class_g_c_pnts___dist_function2d_m_v.html',1,'']]],
+  ['gcpnts_5fdistfunctionmv',['GCPnts_DistFunctionMV',['../class_g_c_pnts___dist_function_m_v.html',1,'']]],
   ['gcpnts_5fquasiuniformabscissa',['GCPnts_QuasiUniformAbscissa',['../class_g_c_pnts___quasi_uniform_abscissa.html',1,'']]],
   ['gcpnts_5fquasiuniformdeflection',['GCPnts_QuasiUniformDeflection',['../class_g_c_pnts___quasi_uniform_deflection.html',1,'']]],
   ['gcpnts_5ftangentialdeflection',['GCPnts_TangentialDeflection',['../class_g_c_pnts___tangential_deflection.html',1,'']]],
   ['gcpnts_5funiformabscissa',['GCPnts_UniformAbscissa',['../class_g_c_pnts___uniform_abscissa.html',1,'']]],
   ['gcpnts_5funiformdeflection',['GCPnts_UniformDeflection',['../class_g_c_pnts___uniform_deflection.html',1,'']]],
+  ['gcurve',['GCurve',['../class_shape_persistent___b_rep_1_1_g_curve.html',1,'ShapePersistent_BRep']]],
   ['geom2d_5faxisplacement',['Geom2d_AxisPlacement',['../class_geom2d___axis_placement.html',1,'']]],
   ['geom2d_5fbeziercurve',['Geom2d_BezierCurve',['../class_geom2d___bezier_curve.html',1,'']]],
   ['geom2d_5fboundedcurve',['Geom2d_BoundedCurve',['../class_geom2d___bounded_curve.html',1,'']]],
@@ -124,6 +128,8 @@ var searchData=
   ['geom2dconvert_5fbsplinecurveknotsplitting',['Geom2dConvert_BSplineCurveKnotSplitting',['../class_geom2d_convert___b_spline_curve_knot_splitting.html',1,'']]],
   ['geom2dconvert_5fbsplinecurvetobeziercurve',['Geom2dConvert_BSplineCurveToBezierCurve',['../class_geom2d_convert___b_spline_curve_to_bezier_curve.html',1,'']]],
   ['geom2dconvert_5fcompcurvetobsplinecurve',['Geom2dConvert_CompCurveToBSplineCurve',['../class_geom2d_convert___comp_curve_to_b_spline_curve.html',1,'']]],
+  ['geom2devaluator_5fcurve',['Geom2dEvaluator_Curve',['../class_geom2d_evaluator___curve.html',1,'']]],
+  ['geom2devaluator_5foffsetcurve',['Geom2dEvaluator_OffsetCurve',['../class_geom2d_evaluator___offset_curve.html',1,'']]],
   ['geom2dgcc',['Geom2dGcc',['../class_geom2d_gcc.html',1,'']]],
   ['geom2dgcc_5fcirc2d2tanon',['Geom2dGcc_Circ2d2TanOn',['../class_geom2d_gcc___circ2d2_tan_on.html',1,'']]],
   ['geom2dgcc_5fcirc2d2tanongeo',['Geom2dGcc_Circ2d2TanOnGeo',['../class_geom2d_gcc___circ2d2_tan_on_geo.html',1,'']]],
@@ -137,7 +143,6 @@ var searchData=
   ['geom2dgcc_5fcirc2dtanonrad',['Geom2dGcc_Circ2dTanOnRad',['../class_geom2d_gcc___circ2d_tan_on_rad.html',1,'']]],
   ['geom2dgcc_5fcirc2dtanonradgeo',['Geom2dGcc_Circ2dTanOnRadGeo',['../class_geom2d_gcc___circ2d_tan_on_rad_geo.html',1,'']]],
   ['geom2dgcc_5fcurvetool',['Geom2dGcc_CurveTool',['../class_geom2d_gcc___curve_tool.html',1,'']]],
-  ['geom2dgcc_5fcurvetoolgeo',['Geom2dGcc_CurveToolGeo',['../class_geom2d_gcc___curve_tool_geo.html',1,'']]],
   ['geom2dgcc_5ffunctiontancircu',['Geom2dGcc_FunctionTanCirCu',['../class_geom2d_gcc___function_tan_cir_cu.html',1,'']]],
   ['geom2dgcc_5ffunctiontancucu',['Geom2dGcc_FunctionTanCuCu',['../class_geom2d_gcc___function_tan_cu_cu.html',1,'']]],
   ['geom2dgcc_5ffunctiontancucucu',['Geom2dGcc_FunctionTanCuCuCu',['../class_geom2d_gcc___function_tan_cu_cu_cu.html',1,'']]],
@@ -151,26 +156,18 @@ var searchData=
   ['geom2dgcc_5fqcurve',['Geom2dGcc_QCurve',['../class_geom2d_gcc___q_curve.html',1,'']]],
   ['geom2dgcc_5fqualifiedcurve',['Geom2dGcc_QualifiedCurve',['../class_geom2d_gcc___qualified_curve.html',1,'']]],
   ['geom2dhatch_5fclassifier',['Geom2dHatch_Classifier',['../class_geom2d_hatch___classifier.html',1,'']]],
-  ['geom2dhatch_5fdatamapiteratorofhatchings',['Geom2dHatch_DataMapIteratorOfHatchings',['../class_geom2d_hatch___data_map_iterator_of_hatchings.html',1,'']]],
-  ['geom2dhatch_5fdatamapiteratorofmapofelements',['Geom2dHatch_DataMapIteratorOfMapOfElements',['../class_geom2d_hatch___data_map_iterator_of_map_of_elements.html',1,'']]],
-  ['geom2dhatch_5fdatamapnodeofhatchings',['Geom2dHatch_DataMapNodeOfHatchings',['../class_geom2d_hatch___data_map_node_of_hatchings.html',1,'']]],
-  ['geom2dhatch_5fdatamapnodeofmapofelements',['Geom2dHatch_DataMapNodeOfMapOfElements',['../class_geom2d_hatch___data_map_node_of_map_of_elements.html',1,'']]],
   ['geom2dhatch_5felement',['Geom2dHatch_Element',['../class_geom2d_hatch___element.html',1,'']]],
   ['geom2dhatch_5felements',['Geom2dHatch_Elements',['../class_geom2d_hatch___elements.html',1,'']]],
   ['geom2dhatch_5ffclass2dofclassifier',['Geom2dHatch_FClass2dOfClassifier',['../class_geom2d_hatch___f_class2d_of_classifier.html',1,'']]],
   ['geom2dhatch_5fhatcher',['Geom2dHatch_Hatcher',['../class_geom2d_hatch___hatcher.html',1,'']]],
   ['geom2dhatch_5fhatching',['Geom2dHatch_Hatching',['../class_geom2d_hatch___hatching.html',1,'']]],
-  ['geom2dhatch_5fhatchings',['Geom2dHatch_Hatchings',['../class_geom2d_hatch___hatchings.html',1,'']]],
   ['geom2dhatch_5fintersector',['Geom2dHatch_Intersector',['../class_geom2d_hatch___intersector.html',1,'']]],
-  ['geom2dhatch_5fmapofelements',['Geom2dHatch_MapOfElements',['../class_geom2d_hatch___map_of_elements.html',1,'']]],
   ['geom2dint_5fexactintersectionpointoftheintpcurvepcurveofginter',['Geom2dInt_ExactIntersectionPointOfTheIntPCurvePCurveOfGInter',['../class_geom2d_int___exact_intersection_point_of_the_int_p_curve_p_curve_of_g_inter.html',1,'']]],
   ['geom2dint_5fgeom2dcurvetool',['Geom2dInt_Geom2dCurveTool',['../class_geom2d_int___geom2d_curve_tool.html',1,'']]],
   ['geom2dint_5fginter',['Geom2dInt_GInter',['../class_geom2d_int___g_inter.html',1,'']]],
   ['geom2dint_5fintconiccurveofginter',['Geom2dInt_IntConicCurveOfGInter',['../class_geom2d_int___int_conic_curve_of_g_inter.html',1,'']]],
   ['geom2dint_5fmyimppartooloftheintersectoroftheintconiccurveofginter',['Geom2dInt_MyImpParToolOfTheIntersectorOfTheIntConicCurveOfGInter',['../class_geom2d_int___my_imp_par_tool_of_the_intersector_of_the_int_conic_curve_of_g_inter.html',1,'']]],
   ['geom2dint_5fpclocfofthelocateextpcoftheprojpcurofginter',['Geom2dInt_PCLocFOfTheLocateExtPCOfTheProjPCurOfGInter',['../class_geom2d_int___p_c_loc_f_of_the_locate_ext_p_c_of_the_proj_p_cur_of_g_inter.html',1,'']]],
-  ['geom2dint_5fseqpcofpclocfofthelocateextpcoftheprojpcurofginter',['Geom2dInt_SeqPCOfPCLocFOfTheLocateExtPCOfTheProjPCurOfGInter',['../class_geom2d_int___seq_p_c_of_p_c_loc_f_of_the_locate_ext_p_c_of_the_proj_p_cur_of_g_inter.html',1,'']]],
-  ['geom2dint_5fsequencenodeofseqpcofpclocfofthelocateextpcoftheprojpcurofginter',['Geom2dInt_SequenceNodeOfSeqPCOfPCLocFOfTheLocateExtPCOfTheProjPCurOfGInter',['../class_geom2d_int___sequence_node_of_seq_p_c_of_p_c_loc_f_of_the_locate_ext_p_c_of_the_proj_p_cur_of_g_inter.html',1,'']]],
   ['geom2dint_5fthecurvelocatoroftheprojpcurofginter',['Geom2dInt_TheCurveLocatorOfTheProjPCurOfGInter',['../class_geom2d_int___the_curve_locator_of_the_proj_p_cur_of_g_inter.html',1,'']]],
   ['geom2dint_5fthedistbetweenpcurvesoftheintpcurvepcurveofginter',['Geom2dInt_TheDistBetweenPCurvesOfTheIntPCurvePCurveOfGInter',['../class_geom2d_int___the_dist_between_p_curves_of_the_int_p_curve_p_curve_of_g_inter.html',1,'']]],
   ['geom2dint_5ftheintconiccurveofginter',['Geom2dInt_TheIntConicCurveOfGInter',['../class_geom2d_int___the_int_conic_curve_of_g_inter.html',1,'']]],
@@ -208,7 +205,6 @@ var searchData=
   ['geom_5felementarysurface',['Geom_ElementarySurface',['../class_geom___elementary_surface.html',1,'']]],
   ['geom_5fellipse',['Geom_Ellipse',['../class_geom___ellipse.html',1,'']]],
   ['geom_5fgeometry',['Geom_Geometry',['../class_geom___geometry.html',1,'']]],
-  ['geom_5fhsequenceofbsplinesurface',['Geom_HSequenceOfBSplineSurface',['../class_geom___h_sequence_of_b_spline_surface.html',1,'']]],
   ['geom_5fhyperbola',['Geom_Hyperbola',['../class_geom___hyperbola.html',1,'']]],
   ['geom_5fline',['Geom_Line',['../class_geom___line.html',1,'']]],
   ['geom_5foffsetcurve',['Geom_OffsetCurve',['../class_geom___offset_curve.html',1,'']]],
@@ -218,8 +214,6 @@ var searchData=
   ['geom_5fplane',['Geom_Plane',['../class_geom___plane.html',1,'']]],
   ['geom_5fpoint',['Geom_Point',['../class_geom___point.html',1,'']]],
   ['geom_5frectangulartrimmedsurface',['Geom_RectangularTrimmedSurface',['../class_geom___rectangular_trimmed_surface.html',1,'']]],
-  ['geom_5fsequencenodeofsequenceofbsplinesurface',['Geom_SequenceNodeOfSequenceOfBSplineSurface',['../class_geom___sequence_node_of_sequence_of_b_spline_surface.html',1,'']]],
-  ['geom_5fsequenceofbsplinesurface',['Geom_SequenceOfBSplineSurface',['../class_geom___sequence_of_b_spline_surface.html',1,'']]],
   ['geom_5fsphericalsurface',['Geom_SphericalSurface',['../class_geom___spherical_surface.html',1,'']]],
   ['geom_5fsurface',['Geom_Surface',['../class_geom___surface.html',1,'']]],
   ['geom_5fsurfaceoflinearextrusion',['Geom_SurfaceOfLinearExtrusion',['../class_geom___surface_of_linear_extrusion.html',1,'']]],
@@ -236,7 +230,11 @@ var searchData=
   ['geomadaptor_5fghsurface',['GeomAdaptor_GHSurface',['../class_geom_adaptor___g_h_surface.html',1,'']]],
   ['geomadaptor_5fhcurve',['GeomAdaptor_HCurve',['../class_geom_adaptor___h_curve.html',1,'']]],
   ['geomadaptor_5fhsurface',['GeomAdaptor_HSurface',['../class_geom_adaptor___h_surface.html',1,'']]],
+  ['geomadaptor_5fhsurfaceoflinearextrusion',['GeomAdaptor_HSurfaceOfLinearExtrusion',['../class_geom_adaptor___h_surface_of_linear_extrusion.html',1,'']]],
+  ['geomadaptor_5fhsurfaceofrevolution',['GeomAdaptor_HSurfaceOfRevolution',['../class_geom_adaptor___h_surface_of_revolution.html',1,'']]],
   ['geomadaptor_5fsurface',['GeomAdaptor_Surface',['../class_geom_adaptor___surface.html',1,'']]],
+  ['geomadaptor_5fsurfaceoflinearextrusion',['GeomAdaptor_SurfaceOfLinearExtrusion',['../class_geom_adaptor___surface_of_linear_extrusion.html',1,'']]],
+  ['geomadaptor_5fsurfaceofrevolution',['GeomAdaptor_SurfaceOfRevolution',['../class_geom_adaptor___surface_of_revolution.html',1,'']]],
   ['geomapi',['GeomAPI',['../class_geom_a_p_i.html',1,'']]],
   ['geomapi_5fextremacurvecurve',['GeomAPI_ExtremaCurveCurve',['../class_geom_a_p_i___extrema_curve_curve.html',1,'']]],
   ['geomapi_5fextremacurvesurface',['GeomAPI_ExtremaCurveSurface',['../class_geom_a_p_i___extrema_curve_surface.html',1,'']]],
@@ -257,12 +255,19 @@ var searchData=
   ['geomconvert_5fbsplinesurfacetobeziersurface',['GeomConvert_BSplineSurfaceToBezierSurface',['../class_geom_convert___b_spline_surface_to_bezier_surface.html',1,'']]],
   ['geomconvert_5fcompbeziersurfacestobsplinesurface',['GeomConvert_CompBezierSurfacesToBSplineSurface',['../class_geom_convert___comp_bezier_surfaces_to_b_spline_surface.html',1,'']]],
   ['geomconvert_5fcompcurvetobsplinecurve',['GeomConvert_CompCurveToBSplineCurve',['../class_geom_convert___comp_curve_to_b_spline_curve.html',1,'']]],
+  ['geometry',['Geometry',['../class_std_persistent___data_xtd_1_1_geometry.html',1,'StdPersistent_DataXtd']]],
+  ['geometry',['Geometry',['../class_shape_persistent___geom_1_1_geometry.html',1,'ShapePersistent_Geom']]],
+  ['geometrybase',['geometryBase',['../struct_shape_persistent___geom_1_1geometry_base.html',1,'ShapePersistent_Geom']]],
   ['geometrytest',['GeometryTest',['../class_geometry_test.html',1,'']]],
+  ['geomevaluator_5fcurve',['GeomEvaluator_Curve',['../class_geom_evaluator___curve.html',1,'']]],
+  ['geomevaluator_5foffsetcurve',['GeomEvaluator_OffsetCurve',['../class_geom_evaluator___offset_curve.html',1,'']]],
+  ['geomevaluator_5foffsetsurface',['GeomEvaluator_OffsetSurface',['../class_geom_evaluator___offset_surface.html',1,'']]],
+  ['geomevaluator_5fsurface',['GeomEvaluator_Surface',['../class_geom_evaluator___surface.html',1,'']]],
+  ['geomevaluator_5fsurfaceofextrusion',['GeomEvaluator_SurfaceOfExtrusion',['../class_geom_evaluator___surface_of_extrusion.html',1,'']]],
+  ['geomevaluator_5fsurfaceofrevolution',['GeomEvaluator_SurfaceOfRevolution',['../class_geom_evaluator___surface_of_revolution.html',1,'']]],
   ['geomfill',['GeomFill',['../class_geom_fill.html',1,'']]],
   ['geomfill_5fappsurf',['GeomFill_AppSurf',['../class_geom_fill___app_surf.html',1,'']]],
   ['geomfill_5fappsweep',['GeomFill_AppSweep',['../class_geom_fill___app_sweep.html',1,'']]],
-  ['geomfill_5farray1oflocationlaw',['GeomFill_Array1OfLocationLaw',['../class_geom_fill___array1_of_location_law.html',1,'']]],
-  ['geomfill_5farray1ofsectionlaw',['GeomFill_Array1OfSectionLaw',['../class_geom_fill___array1_of_section_law.html',1,'']]],
   ['geomfill_5fbeziercurves',['GeomFill_BezierCurves',['../class_geom_fill___bezier_curves.html',1,'']]],
   ['geomfill_5fboundary',['GeomFill_Boundary',['../class_geom_fill___boundary.html',1,'']]],
   ['geomfill_5fboundwithsurf',['GeomFill_BoundWithSurf',['../class_geom_fill___bound_with_surf.html',1,'']]],
@@ -289,9 +294,6 @@ var searchData=
   ['geomfill_5fgenerator',['GeomFill_Generator',['../class_geom_fill___generator.html',1,'']]],
   ['geomfill_5fguidetrihedronac',['GeomFill_GuideTrihedronAC',['../class_geom_fill___guide_trihedron_a_c.html',1,'']]],
   ['geomfill_5fguidetrihedronplan',['GeomFill_GuideTrihedronPlan',['../class_geom_fill___guide_trihedron_plan.html',1,'']]],
-  ['geomfill_5fharray1oflocationlaw',['GeomFill_HArray1OfLocationLaw',['../class_geom_fill___h_array1_of_location_law.html',1,'']]],
-  ['geomfill_5fharray1ofsectionlaw',['GeomFill_HArray1OfSectionLaw',['../class_geom_fill___h_array1_of_section_law.html',1,'']]],
-  ['geomfill_5fhsequenceofax2',['GeomFill_HSequenceOfAx2',['../class_geom_fill___h_sequence_of_ax2.html',1,'']]],
   ['geomfill_5fline',['GeomFill_Line',['../class_geom_fill___line.html',1,'']]],
   ['geomfill_5flocationdraft',['GeomFill_LocationDraft',['../class_geom_fill___location_draft.html',1,'']]],
   ['geomfill_5flocationguide',['GeomFill_LocationGuide',['../class_geom_fill___location_guide.html',1,'']]],
@@ -306,10 +308,6 @@ var searchData=
   ['geomfill_5fsectiongenerator',['GeomFill_SectionGenerator',['../class_geom_fill___section_generator.html',1,'']]],
   ['geomfill_5fsectionlaw',['GeomFill_SectionLaw',['../class_geom_fill___section_law.html',1,'']]],
   ['geomfill_5fsectionplacement',['GeomFill_SectionPlacement',['../class_geom_fill___section_placement.html',1,'']]],
-  ['geomfill_5fsequencenodeofsequenceofax2',['GeomFill_SequenceNodeOfSequenceOfAx2',['../class_geom_fill___sequence_node_of_sequence_of_ax2.html',1,'']]],
-  ['geomfill_5fsequencenodeofsequenceoftrsf',['GeomFill_SequenceNodeOfSequenceOfTrsf',['../class_geom_fill___sequence_node_of_sequence_of_trsf.html',1,'']]],
-  ['geomfill_5fsequenceofax2',['GeomFill_SequenceOfAx2',['../class_geom_fill___sequence_of_ax2.html',1,'']]],
-  ['geomfill_5fsequenceoftrsf',['GeomFill_SequenceOfTrsf',['../class_geom_fill___sequence_of_trsf.html',1,'']]],
   ['geomfill_5fsimplebound',['GeomFill_SimpleBound',['../class_geom_fill___simple_bound.html',1,'']]],
   ['geomfill_5fsnglrfunc',['GeomFill_SnglrFunc',['../class_geom_fill___snglr_func.html',1,'']]],
   ['geomfill_5fstretch',['GeomFill_Stretch',['../class_geom_fill___stretch.html',1,'']]],
@@ -341,8 +339,6 @@ var searchData=
   ['geomint_5fparleastsquareofmygradientofthecomputelinebezierofwlapprox',['GeomInt_ParLeastSquareOfMyGradientOfTheComputeLineBezierOfWLApprox',['../class_geom_int___par_least_square_of_my_gradient_of_the_compute_line_bezier_of_w_l_approx.html',1,'']]],
   ['geomint_5fresconstraintofmygradientbisofthecomputelineofwlapprox',['GeomInt_ResConstraintOfMyGradientbisOfTheComputeLineOfWLApprox',['../class_geom_int___res_constraint_of_my_gradientbis_of_the_compute_line_of_w_l_approx.html',1,'']]],
   ['geomint_5fresconstraintofmygradientofthecomputelinebezierofwlapprox',['GeomInt_ResConstraintOfMyGradientOfTheComputeLineBezierOfWLApprox',['../class_geom_int___res_constraint_of_my_gradient_of_the_compute_line_bezier_of_w_l_approx.html',1,'']]],
-  ['geomint_5fsequencenodeofsequenceofparameterandorientation',['GeomInt_SequenceNodeOfSequenceOfParameterAndOrientation',['../class_geom_int___sequence_node_of_sequence_of_parameter_and_orientation.html',1,'']]],
-  ['geomint_5fsequenceofparameterandorientation',['GeomInt_SequenceOfParameterAndOrientation',['../class_geom_int___sequence_of_parameter_and_orientation.html',1,'']]],
   ['geomint_5fthecomputelinebezierofwlapprox',['GeomInt_TheComputeLineBezierOfWLApprox',['../class_geom_int___the_compute_line_bezier_of_w_l_approx.html',1,'']]],
   ['geomint_5fthecomputelineofwlapprox',['GeomInt_TheComputeLineOfWLApprox',['../class_geom_int___the_compute_line_of_w_l_approx.html',1,'']]],
   ['geomint_5fthefunctionoftheint2softheprmprmsvsurfacesofwlapprox',['GeomInt_TheFunctionOfTheInt2SOfThePrmPrmSvSurfacesOfWLApprox',['../class_geom_int___the_function_of_the_int2_s_of_the_prm_prm_sv_surfaces_of_w_l_approx.html',1,'']]],
@@ -354,9 +350,9 @@ var searchData=
   ['geomint_5fthezerimpfuncoftheimpprmsvsurfacesofwlapprox',['GeomInt_TheZerImpFuncOfTheImpPrmSvSurfacesOfWLApprox',['../class_geom_int___the_zer_imp_func_of_the_imp_prm_sv_surfaces_of_w_l_approx.html',1,'']]],
   ['geomint_5fwlapprox',['GeomInt_WLApprox',['../class_geom_int___w_l_approx.html',1,'']]],
   ['geomlib',['GeomLib',['../class_geom_lib.html',1,'']]],
-  ['geomlib_5farray1ofmat',['GeomLib_Array1OfMat',['../class_geom_lib___array1_of_mat.html',1,'']]],
   ['geomlib_5fcheck2dbsplinecurve',['GeomLib_Check2dBSplineCurve',['../class_geom_lib___check2d_b_spline_curve.html',1,'']]],
   ['geomlib_5fcheckbsplinecurve',['GeomLib_CheckBSplineCurve',['../class_geom_lib___check_b_spline_curve.html',1,'']]],
+  ['geomlib_5fcheckcurveonsurface',['GeomLib_CheckCurveOnSurface',['../class_geom_lib___check_curve_on_surface.html',1,'']]],
   ['geomlib_5fdenominatormultiplier',['GeomLib_DenominatorMultiplier',['../class_geom_lib___denominator_multiplier.html',1,'']]],
   ['geomlib_5finterpolate',['GeomLib_Interpolate',['../class_geom_lib___interpolate.html',1,'']]],
   ['geomlib_5fisplanarsurface',['GeomLib_IsPlanarSurface',['../class_geom_lib___is_planar_surface.html',1,'']]],
@@ -371,25 +367,13 @@ var searchData=
   ['geomlprop_5fslprops',['GeomLProp_SLProps',['../class_geom_l_prop___s_l_props.html',1,'']]],
   ['geomlprop_5fsurfacetool',['GeomLProp_SurfaceTool',['../class_geom_l_prop___surface_tool.html',1,'']]],
   ['geomplate_5faij',['GeomPlate_Aij',['../class_geom_plate___aij.html',1,'']]],
-  ['geomplate_5farray1ofhcurveonsurface',['GeomPlate_Array1OfHCurveOnSurface',['../class_geom_plate___array1_of_h_curve_on_surface.html',1,'']]],
-  ['geomplate_5farray1ofsequenceofreal',['GeomPlate_Array1OfSequenceOfReal',['../class_geom_plate___array1_of_sequence_of_real.html',1,'']]],
   ['geomplate_5fbuildaverageplane',['GeomPlate_BuildAveragePlane',['../class_geom_plate___build_average_plane.html',1,'']]],
   ['geomplate_5fbuildplatesurface',['GeomPlate_BuildPlateSurface',['../class_geom_plate___build_plate_surface.html',1,'']]],
   ['geomplate_5fcurveconstraint',['GeomPlate_CurveConstraint',['../class_geom_plate___curve_constraint.html',1,'']]],
-  ['geomplate_5fharray1ofhcurveonsurface',['GeomPlate_HArray1OfHCurveOnSurface',['../class_geom_plate___h_array1_of_h_curve_on_surface.html',1,'']]],
-  ['geomplate_5fharray1ofsequenceofreal',['GeomPlate_HArray1OfSequenceOfReal',['../class_geom_plate___h_array1_of_sequence_of_real.html',1,'']]],
-  ['geomplate_5fhsequenceofcurveconstraint',['GeomPlate_HSequenceOfCurveConstraint',['../class_geom_plate___h_sequence_of_curve_constraint.html',1,'']]],
-  ['geomplate_5fhsequenceofpointconstraint',['GeomPlate_HSequenceOfPointConstraint',['../class_geom_plate___h_sequence_of_point_constraint.html',1,'']]],
   ['geomplate_5fmakeapprox',['GeomPlate_MakeApprox',['../class_geom_plate___make_approx.html',1,'']]],
   ['geomplate_5fplateg0criterion',['GeomPlate_PlateG0Criterion',['../class_geom_plate___plate_g0_criterion.html',1,'']]],
   ['geomplate_5fplateg1criterion',['GeomPlate_PlateG1Criterion',['../class_geom_plate___plate_g1_criterion.html',1,'']]],
   ['geomplate_5fpointconstraint',['GeomPlate_PointConstraint',['../class_geom_plate___point_constraint.html',1,'']]],
-  ['geomplate_5fsequencenodeofsequenceofaij',['GeomPlate_SequenceNodeOfSequenceOfAij',['../class_geom_plate___sequence_node_of_sequence_of_aij.html',1,'']]],
-  ['geomplate_5fsequencenodeofsequenceofcurveconstraint',['GeomPlate_SequenceNodeOfSequenceOfCurveConstraint',['../class_geom_plate___sequence_node_of_sequence_of_curve_constraint.html',1,'']]],
-  ['geomplate_5fsequencenodeofsequenceofpointconstraint',['GeomPlate_SequenceNodeOfSequenceOfPointConstraint',['../class_geom_plate___sequence_node_of_sequence_of_point_constraint.html',1,'']]],
-  ['geomplate_5fsequenceofaij',['GeomPlate_SequenceOfAij',['../class_geom_plate___sequence_of_aij.html',1,'']]],
-  ['geomplate_5fsequenceofcurveconstraint',['GeomPlate_SequenceOfCurveConstraint',['../class_geom_plate___sequence_of_curve_constraint.html',1,'']]],
-  ['geomplate_5fsequenceofpointconstraint',['GeomPlate_SequenceOfPointConstraint',['../class_geom_plate___sequence_of_point_constraint.html',1,'']]],
   ['geomplate_5fsurface',['GeomPlate_Surface',['../class_geom_plate___surface.html',1,'']]],
   ['geomprojlib',['GeomProjLib',['../class_geom_proj_lib.html',1,'']]],
   ['geomtoiges_5fgeomcurve',['GeomToIGES_GeomCurve',['../class_geom_to_i_g_e_s___geom_curve.html',1,'']]],
@@ -480,9 +464,6 @@ var searchData=
   ['gprop_5fprincipalprops',['GProp_PrincipalProps',['../class_g_prop___principal_props.html',1,'']]],
   ['gprop_5fselgprops',['GProp_SelGProps',['../class_g_prop___sel_g_props.html',1,'']]],
   ['gprop_5fvelgprops',['GProp_VelGProps',['../class_g_prop___vel_g_props.html',1,'']]],
-  ['graphic3d_5farray1ofvector',['Graphic3d_Array1OfVector',['../class_graphic3d___array1_of_vector.html',1,'']]],
-  ['graphic3d_5farray1ofvertex',['Graphic3d_Array1OfVertex',['../class_graphic3d___array1_of_vertex.html',1,'']]],
-  ['graphic3d_5farray2ofvertex',['Graphic3d_Array2OfVertex',['../class_graphic3d___array2_of_vertex.html',1,'']]],
   ['graphic3d_5farrayofpoints',['Graphic3d_ArrayOfPoints',['../class_graphic3d___array_of_points.html',1,'']]],
   ['graphic3d_5farrayofpolygons',['Graphic3d_ArrayOfPolygons',['../class_graphic3d___array_of_polygons.html',1,'']]],
   ['graphic3d_5farrayofpolylines',['Graphic3d_ArrayOfPolylines',['../class_graphic3d___array_of_polylines.html',1,'']]],
@@ -500,35 +481,28 @@ var searchData=
   ['graphic3d_5fattribute',['Graphic3d_Attribute',['../struct_graphic3d___attribute.html',1,'']]],
   ['graphic3d_5faxisaspect',['Graphic3d_AxisAspect',['../class_graphic3d___axis_aspect.html',1,'']]],
   ['graphic3d_5fboundbuffer',['Graphic3d_BoundBuffer',['../class_graphic3d___bound_buffer.html',1,'']]],
+  ['graphic3d_5fbsdf',['Graphic3d_BSDF',['../class_graphic3d___b_s_d_f.html',1,'']]],
   ['graphic3d_5fbuffer',['Graphic3d_Buffer',['../class_graphic3d___buffer.html',1,'']]],
   ['graphic3d_5fcamera',['Graphic3d_Camera',['../class_graphic3d___camera.html',1,'']]],
-  ['graphic3d_5fcaspectfillarea',['Graphic3d_CAspectFillArea',['../class_graphic3d___c_aspect_fill_area.html',1,'']]],
-  ['graphic3d_5fcaspectline',['Graphic3d_CAspectLine',['../class_graphic3d___c_aspect_line.html',1,'']]],
-  ['graphic3d_5fcaspectmarker',['Graphic3d_CAspectMarker',['../class_graphic3d___c_aspect_marker.html',1,'']]],
-  ['graphic3d_5fcaspecttext',['Graphic3d_CAspectText',['../class_graphic3d___c_aspect_text.html',1,'']]],
-  ['graphic3d_5fcbitfields16',['Graphic3d_CBitFields16',['../struct_graphic3d___c_bit_fields16.html',1,'']]],
-  ['graphic3d_5fcbitfields20',['Graphic3d_CBitFields20',['../struct_graphic3d___c_bit_fields20.html',1,'']]],
-  ['graphic3d_5fcbitfields4',['Graphic3d_CBitFields4',['../struct_graphic3d___c_bit_fields4.html',1,'']]],
-  ['graphic3d_5fcbitfields8',['Graphic3d_CBitFields8',['../struct_graphic3d___c_bit_fields8.html',1,'']]],
+  ['graphic3d_5fcameratile',['Graphic3d_CameraTile',['../class_graphic3d___camera_tile.html',1,'']]],
   ['graphic3d_5fclight',['Graphic3d_CLight',['../struct_graphic3d___c_light.html',1,'']]],
   ['graphic3d_5fclipplane',['Graphic3d_ClipPlane',['../class_graphic3d___clip_plane.html',1,'']]],
   ['graphic3d_5fcstructure',['Graphic3d_CStructure',['../class_graphic3d___c_structure.html',1,'']]],
   ['graphic3d_5fctexture',['Graphic3d_CTexture',['../class_graphic3d___c_texture.html',1,'']]],
   ['graphic3d_5fcview',['Graphic3d_CView',['../class_graphic3d___c_view.html',1,'']]],
   ['graphic3d_5fdatastructuremanager',['Graphic3d_DataStructureManager',['../class_graphic3d___data_structure_manager.html',1,'']]],
+  ['graphic3d_5ffresnel',['Graphic3d_Fresnel',['../class_graphic3d___fresnel.html',1,'']]],
   ['graphic3d_5fgraduatedtrihedron',['Graphic3d_GraduatedTrihedron',['../class_graphic3d___graduated_trihedron.html',1,'']]],
   ['graphic3d_5fgraphicdriver',['Graphic3d_GraphicDriver',['../class_graphic3d___graphic_driver.html',1,'']]],
   ['graphic3d_5fgroup',['Graphic3d_Group',['../class_graphic3d___group.html',1,'']]],
-  ['graphic3d_5fhsequenceofstructure',['Graphic3d_HSequenceOfStructure',['../class_graphic3d___h_sequence_of_structure.html',1,'']]],
+  ['graphic3d_5fhighlightstyle',['Graphic3d_HighlightStyle',['../class_graphic3d___highlight_style.html',1,'']]],
   ['graphic3d_5findexbuffer',['Graphic3d_IndexBuffer',['../class_graphic3d___index_buffer.html',1,'']]],
-  ['graphic3d_5flistiteratoroflistofshortreal',['Graphic3d_ListIteratorOfListOfShortReal',['../class_graphic3d___list_iterator_of_list_of_short_real.html',1,'']]],
-  ['graphic3d_5flistnodeoflistofshortreal',['Graphic3d_ListNodeOfListOfShortReal',['../class_graphic3d___list_node_of_list_of_short_real.html',1,'']]],
-  ['graphic3d_5flistofshortreal',['Graphic3d_ListOfShortReal',['../class_graphic3d___list_of_short_real.html',1,'']]],
   ['graphic3d_5fmarkerimage',['Graphic3d_MarkerImage',['../class_graphic3d___marker_image.html',1,'']]],
   ['graphic3d_5fmaterialaspect',['Graphic3d_MaterialAspect',['../class_graphic3d___material_aspect.html',1,'']]],
+  ['graphic3d_5fpolygonoffset',['Graphic3d_PolygonOffset',['../struct_graphic3d___polygon_offset.html',1,'']]],
   ['graphic3d_5frenderingparams',['Graphic3d_RenderingParams',['../class_graphic3d___rendering_params.html',1,'']]],
-  ['graphic3d_5fsequencenodeofsequenceofstructure',['Graphic3d_SequenceNodeOfSequenceOfStructure',['../class_graphic3d___sequence_node_of_sequence_of_structure.html',1,'']]],
-  ['graphic3d_5fsequenceofstructure',['Graphic3d_SequenceOfStructure',['../class_graphic3d___sequence_of_structure.html',1,'']]],
+  ['graphic3d_5fsequenceofhclipplane',['Graphic3d_SequenceOfHClipPlane',['../class_graphic3d___sequence_of_h_clip_plane.html',1,'']]],
+  ['graphic3d_5fshaderattribute',['Graphic3d_ShaderAttribute',['../class_graphic3d___shader_attribute.html',1,'']]],
   ['graphic3d_5fshaderobject',['Graphic3d_ShaderObject',['../class_graphic3d___shader_object.html',1,'']]],
   ['graphic3d_5fshaderprogram',['Graphic3d_ShaderProgram',['../class_graphic3d___shader_program.html',1,'']]],
   ['graphic3d_5fshadervariable',['Graphic3d_ShaderVariable',['../class_graphic3d___shader_variable.html',1,'']]],
@@ -544,6 +518,7 @@ var searchData=
   ['graphic3d_5ftexturemap',['Graphic3d_TextureMap',['../class_graphic3d___texture_map.html',1,'']]],
   ['graphic3d_5ftextureparams',['Graphic3d_TextureParams',['../class_graphic3d___texture_params.html',1,'']]],
   ['graphic3d_5ftextureroot',['Graphic3d_TextureRoot',['../class_graphic3d___texture_root.html',1,'']]],
+  ['graphic3d_5ftransformpers',['Graphic3d_TransformPers',['../class_graphic3d___transform_pers.html',1,'']]],
   ['graphic3d_5funiformvalue',['Graphic3d_UniformValue',['../struct_graphic3d___uniform_value.html',1,'']]],
   ['graphic3d_5funiformvaluetypeid',['Graphic3d_UniformValueTypeID',['../struct_graphic3d___uniform_value_type_i_d.html',1,'']]],
   ['graphic3d_5funiformvaluetypeid_3c_20graphic3d_5fvec2_20_3e',['Graphic3d_UniformValueTypeID&lt; Graphic3d_Vec2 &gt;',['../struct_graphic3d___uniform_value_type_i_d_3_01_graphic3d___vec2_01_4.html',1,'']]],
@@ -558,6 +533,7 @@ var searchData=
   ['graphic3d_5fvector',['Graphic3d_Vector',['../class_graphic3d___vector.html',1,'']]],
   ['graphic3d_5fvertex',['Graphic3d_Vertex',['../class_graphic3d___vertex.html',1,'']]],
   ['graphic3d_5fviewaffinity',['Graphic3d_ViewAffinity',['../class_graphic3d___view_affinity.html',1,'']]],
+  ['graphic3d_5fworldviewprojstate',['Graphic3d_WorldViewProjState',['../class_graphic3d___world_view_proj_state.html',1,'']]],
   ['graphic3d_5fzlayersettings',['Graphic3d_ZLayerSettings',['../struct_graphic3d___z_layer_settings.html',1,'']]],
   ['groupiterator',['GroupIterator',['../class_open_gl___structure_1_1_group_iterator.html',1,'OpenGl_Structure']]],
   ['guid',['GUID',['../struct_g_u_i_d.html',1,'']]]
