@@ -1,8 +1,6 @@
 var searchData=
 [
   ['xml_5fbuffer_5fsize',['XML_BUFFER_SIZE',['../_l_d_o_m___xml_reader_8hxx.html#a0203786a56eaa95a79e327b43faeff6d',1,'LDOM_XmlReader.hxx']]],
-  ['xmlobjmgt_5frrelocationtable_5ftype_5f',['XmlObjMgt_RRelocationTable_Type_',['../_xml_obj_mgt___r_relocation_table_8hxx.html#a296784551cc66a2dc04a0d21b6086cb4',1,'XmlObjMgt_RRelocationTable.hxx']]],
-  ['xmlobjmgt_5fsrelocationtable_5ftype_5f',['XmlObjMgt_SRelocationTable_Type_',['../_xml_obj_mgt___s_relocation_table_8hxx.html#a97943150389b50802786d59440f3a177',1,'XmlObjMgt_SRelocationTable.hxx']]],
   ['xstep_5fconfig',['XSTEP_Config',['../_interface___version_8hxx.html#a8236df3e6032bd330c69568cb472d747',1,'Interface_Version.hxx']]],
   ['xstep_5fprocessor_5fversion',['XSTEP_PROCESSOR_VERSION',['../_interface___version_8hxx.html#a4b77c34eba20ea36329799d8eb5ac40b',1,'Interface_Version.hxx']]],
   ['xstep_5fsystem_5fversion',['XSTEP_SYSTEM_VERSION',['../_interface___version_8hxx.html#ab20b9b55c4511d018cb4462e6a3e2ffb',1,'Interface_Version.hxx']]],
