@@ -2,10 +2,9 @@ var searchData=
 [
   ['datatag',['DataTag',['../class_t_obj___model.html#a7a5b8ce81e1739912831e429311eba90',1,'TObj_Model::DataTag()'],['../class_t_obj___object.html#a30c78687c24f229cc06aa623b34c33c9',1,'TObj_Object::DataTag()'],['../class_t_obj___partition.html#af3a1cbc86a031df07fdea6794663e5e0',1,'TObj_Partition::DataTag()']]],
   ['dir_5fresponse',['DIR_RESPONSE',['../_o_s_d___w_n_t__1_8hxx.html#a6ae3a396e8d6c9cb2eb3aae2d6095606',1,'OSD_WNT_1.hxx']]],
-  ['displaymode',['DisplayMode',['../class_a_i_s___point_cloud.html#a29b92f41c132593d89b34df1075eea18',1,'AIS_PointCloud::DisplayMode()'],['../class_n_i_s___surface.html#a2dfd6821729144771f465ca448ff73b8',1,'NIS_Surface::DisplayMode()']]],
+  ['displaymode',['DisplayMode',['../class_a_i_s___point_cloud.html#a29b92f41c132593d89b34df1075eea18',1,'AIS_PointCloud']]],
   ['draft_5ferrorstatus',['Draft_ErrorStatus',['../_draft___error_status_8hxx.html#ae4cfaa2311e053102fec1574e13f9b40',1,'Draft_ErrorStatus.hxx']]],
   ['draw_5fcolorkind',['Draw_ColorKind',['../_draw___color_kind_8hxx.html#a8bac32a8bae2daeee20644a6489639f6',1,'Draw_ColorKind.hxx']]],
   ['draw_5fmarkershape',['Draw_MarkerShape',['../_draw___marker_shape_8hxx.html#a0005592e28027aaabe73691e7ac643c8',1,'Draw_MarkerShape.hxx']]],
-  ['drawtype',['DrawType',['../class_n_i_s___drawer.html#ad35f414075b8ae6fc917ecede2172bf7',1,'NIS_Drawer']]],
   ['dsgprs_5farrowside',['DsgPrs_ArrowSide',['../_dsg_prs___arrow_side_8hxx.html#a58cbd6262932ea7ab33b7f2f89c580ed',1,'DsgPrs_ArrowSide.hxx']]]
 ];
