@@ -13,7 +13,6 @@ var searchData=
   ['cdf_5fstorelist_2ehxx',['CDF_StoreList.hxx',['../_c_d_f___store_list_8hxx.html',1,'']]],
   ['cdf_5fstoresetnamestatus_2ehxx',['CDF_StoreSetNameStatus.hxx',['../_c_d_f___store_set_name_status_8hxx.html',1,'']]],
   ['cdf_5fsubcomponentstatus_2ehxx',['CDF_SubComponentStatus.hxx',['../_c_d_f___sub_component_status_8hxx.html',1,'']]],
-  ['cdf_5ftimer_2ehxx',['CDF_Timer.hxx',['../_c_d_f___timer_8hxx.html',1,'']]],
   ['cdf_5ftrystorestatus_2ehxx',['CDF_TryStoreStatus.hxx',['../_c_d_f___try_store_status_8hxx.html',1,'']]],
   ['cdf_5ftypeofactivation_2ehxx',['CDF_TypeOfActivation.hxx',['../_c_d_f___type_of_activation_8hxx.html',1,'']]],
   ['cdm_5fapplication_2ehxx',['CDM_Application.hxx',['../_c_d_m___application_8hxx.html',1,'']]],
@@ -21,15 +20,11 @@ var searchData=
   ['cdm_5fcoutmessagedriver_2ehxx',['CDM_COutMessageDriver.hxx',['../_c_d_m___c_out_message_driver_8hxx.html',1,'']]],
   ['cdm_5fdatamapiteratorofmetadatalookuptable_2ehxx',['CDM_DataMapIteratorOfMetaDataLookUpTable.hxx',['../_c_d_m___data_map_iterator_of_meta_data_look_up_table_8hxx.html',1,'']]],
   ['cdm_5fdatamapiteratorofpresentationdirectory_2ehxx',['CDM_DataMapIteratorOfPresentationDirectory.hxx',['../_c_d_m___data_map_iterator_of_presentation_directory_8hxx.html',1,'']]],
-  ['cdm_5fdatamapnodeofmetadatalookuptable_2ehxx',['CDM_DataMapNodeOfMetaDataLookUpTable.hxx',['../_c_d_m___data_map_node_of_meta_data_look_up_table_8hxx.html',1,'']]],
-  ['cdm_5fdatamapnodeofpresentationdirectory_2ehxx',['CDM_DataMapNodeOfPresentationDirectory.hxx',['../_c_d_m___data_map_node_of_presentation_directory_8hxx.html',1,'']]],
   ['cdm_5fdocument_2ehxx',['CDM_Document.hxx',['../_c_d_m___document_8hxx.html',1,'']]],
   ['cdm_5fdocumenthasher_2ehxx',['CDM_DocumentHasher.hxx',['../_c_d_m___document_hasher_8hxx.html',1,'']]],
   ['cdm_5fdocumentpointer_2ehxx',['CDM_DocumentPointer.hxx',['../_c_d_m___document_pointer_8hxx.html',1,'']]],
   ['cdm_5flistiteratoroflistofdocument_2ehxx',['CDM_ListIteratorOfListOfDocument.hxx',['../_c_d_m___list_iterator_of_list_of_document_8hxx.html',1,'']]],
   ['cdm_5flistiteratoroflistofreferences_2ehxx',['CDM_ListIteratorOfListOfReferences.hxx',['../_c_d_m___list_iterator_of_list_of_references_8hxx.html',1,'']]],
-  ['cdm_5flistnodeoflistofdocument_2ehxx',['CDM_ListNodeOfListOfDocument.hxx',['../_c_d_m___list_node_of_list_of_document_8hxx.html',1,'']]],
-  ['cdm_5flistnodeoflistofreferences_2ehxx',['CDM_ListNodeOfListOfReferences.hxx',['../_c_d_m___list_node_of_list_of_references_8hxx.html',1,'']]],
   ['cdm_5flistofdocument_2ehxx',['CDM_ListOfDocument.hxx',['../_c_d_m___list_of_document_8hxx.html',1,'']]],
   ['cdm_5flistofreferences_2ehxx',['CDM_ListOfReferences.hxx',['../_c_d_m___list_of_references_8hxx.html',1,'']]],
   ['cdm_5fmapiteratorofmapofdocument_2ehxx',['CDM_MapIteratorOfMapOfDocument.hxx',['../_c_d_m___map_iterator_of_map_of_document_8hxx.html',1,'']]],
@@ -42,7 +37,6 @@ var searchData=
   ['cdm_5fpresentationdirectory_2ehxx',['CDM_PresentationDirectory.hxx',['../_c_d_m___presentation_directory_8hxx.html',1,'']]],
   ['cdm_5freference_2ehxx',['CDM_Reference.hxx',['../_c_d_m___reference_8hxx.html',1,'']]],
   ['cdm_5freferenceiterator_2ehxx',['CDM_ReferenceIterator.hxx',['../_c_d_m___reference_iterator_8hxx.html',1,'']]],
-  ['cdm_5fstdmapnodeofmapofdocument_2ehxx',['CDM_StdMapNodeOfMapOfDocument.hxx',['../_c_d_m___std_map_node_of_map_of_document_8hxx.html',1,'']]],
   ['chfi2d_2ehxx',['ChFi2d.hxx',['../_ch_fi2d_8hxx.html',1,'']]],
   ['chfi2d_5fanafilletalgo_2ehxx',['ChFi2d_AnaFilletAlgo.hxx',['../_ch_fi2d___ana_fillet_algo_8hxx.html',1,'']]],
   ['chfi2d_5fbuilder_2ehxx',['ChFi2d_Builder.hxx',['../_ch_fi2d___builder_8hxx.html',1,'']]],
@@ -67,14 +61,10 @@ var searchData=
   ['chfids_5ffilspine_2ehxx',['ChFiDS_FilSpine.hxx',['../_ch_fi_d_s___fil_spine_8hxx.html',1,'']]],
   ['chfids_5fhdata_2ehxx',['ChFiDS_HData.hxx',['../_ch_fi_d_s___h_data_8hxx.html',1,'']]],
   ['chfids_5fhelspine_2ehxx',['ChFiDS_HElSpine.hxx',['../_ch_fi_d_s___h_el_spine_8hxx.html',1,'']]],
-  ['chfids_5findexeddatamapnodeofindexeddatamapofvertexlistofstripe_2ehxx',['ChFiDS_IndexedDataMapNodeOfIndexedDataMapOfVertexListOfStripe.hxx',['../_ch_fi_d_s___indexed_data_map_node_of_indexed_data_map_of_vertex_list_of_stripe_8hxx.html',1,'']]],
   ['chfids_5findexeddatamapofvertexlistofstripe_2ehxx',['ChFiDS_IndexedDataMapOfVertexListOfStripe.hxx',['../_ch_fi_d_s___indexed_data_map_of_vertex_list_of_stripe_8hxx.html',1,'']]],
   ['chfids_5flistiteratoroflistofhelspine_2ehxx',['ChFiDS_ListIteratorOfListOfHElSpine.hxx',['../_ch_fi_d_s___list_iterator_of_list_of_h_el_spine_8hxx.html',1,'']]],
   ['chfids_5flistiteratoroflistofstripe_2ehxx',['ChFiDS_ListIteratorOfListOfStripe.hxx',['../_ch_fi_d_s___list_iterator_of_list_of_stripe_8hxx.html',1,'']]],
   ['chfids_5flistiteratorofregularities_2ehxx',['ChFiDS_ListIteratorOfRegularities.hxx',['../_ch_fi_d_s___list_iterator_of_regularities_8hxx.html',1,'']]],
-  ['chfids_5flistnodeoflistofhelspine_2ehxx',['ChFiDS_ListNodeOfListOfHElSpine.hxx',['../_ch_fi_d_s___list_node_of_list_of_h_el_spine_8hxx.html',1,'']]],
-  ['chfids_5flistnodeoflistofstripe_2ehxx',['ChFiDS_ListNodeOfListOfStripe.hxx',['../_ch_fi_d_s___list_node_of_list_of_stripe_8hxx.html',1,'']]],
-  ['chfids_5flistnodeofregularities_2ehxx',['ChFiDS_ListNodeOfRegularities.hxx',['../_ch_fi_d_s___list_node_of_regularities_8hxx.html',1,'']]],
   ['chfids_5flistofhelspine_2ehxx',['ChFiDS_ListOfHElSpine.hxx',['../_ch_fi_d_s___list_of_h_el_spine_8hxx.html',1,'']]],
   ['chfids_5flistofstripe_2ehxx',['ChFiDS_ListOfStripe.hxx',['../_ch_fi_d_s___list_of_stripe_8hxx.html',1,'']]],
   ['chfids_5fmap_2ehxx',['ChFiDS_Map.hxx',['../_ch_fi_d_s___map_8hxx.html',1,'']]],
@@ -82,8 +72,6 @@ var searchData=
   ['chfids_5fregularities_2ehxx',['ChFiDS_Regularities.hxx',['../_ch_fi_d_s___regularities_8hxx.html',1,'']]],
   ['chfids_5fsecarray1_2ehxx',['ChFiDS_SecArray1.hxx',['../_ch_fi_d_s___sec_array1_8hxx.html',1,'']]],
   ['chfids_5fsecharray1_2ehxx',['ChFiDS_SecHArray1.hxx',['../_ch_fi_d_s___sec_h_array1_8hxx.html',1,'']]],
-  ['chfids_5fsequencenodeofsequenceofspine_2ehxx',['ChFiDS_SequenceNodeOfSequenceOfSpine.hxx',['../_ch_fi_d_s___sequence_node_of_sequence_of_spine_8hxx.html',1,'']]],
-  ['chfids_5fsequencenodeofsequenceofsurfdata_2ehxx',['ChFiDS_SequenceNodeOfSequenceOfSurfData.hxx',['../_ch_fi_d_s___sequence_node_of_sequence_of_surf_data_8hxx.html',1,'']]],
   ['chfids_5fsequenceofspine_2ehxx',['ChFiDS_SequenceOfSpine.hxx',['../_ch_fi_d_s___sequence_of_spine_8hxx.html',1,'']]],
   ['chfids_5fsequenceofsurfdata_2ehxx',['ChFiDS_SequenceOfSurfData.hxx',['../_ch_fi_d_s___sequence_of_surf_data_8hxx.html',1,'']]],
   ['chfids_5fspine_2ehxx',['ChFiDS_Spine.hxx',['../_ch_fi_d_s___spine_8hxx.html',1,'']]],
@@ -107,7 +95,6 @@ var searchData=
   ['chfikpart_5fcomputedata_5frotule_2ehxx',['ChFiKPart_ComputeData_Rotule.hxx',['../_ch_fi_k_part___compute_data___rotule_8hxx.html',1,'']]],
   ['chfikpart_5fcomputedata_5fsphere_2ehxx',['ChFiKPart_ComputeData_Sphere.hxx',['../_ch_fi_k_part___compute_data___sphere_8hxx.html',1,'']]],
   ['chfikpart_5fdatamapiteratorofrstmap_2ehxx',['ChFiKPart_DataMapIteratorOfRstMap.hxx',['../_ch_fi_k_part___data_map_iterator_of_rst_map_8hxx.html',1,'']]],
-  ['chfikpart_5fdatamapnodeofrstmap_2ehxx',['ChFiKPart_DataMapNodeOfRstMap.hxx',['../_ch_fi_k_part___data_map_node_of_rst_map_8hxx.html',1,'']]],
   ['chfikpart_5frstmap_2ehxx',['ChFiKPart_RstMap.hxx',['../_ch_fi_k_part___rst_map_8hxx.html',1,'']]],
   ['cocoa_5flocalpool_2ehxx',['Cocoa_LocalPool.hxx',['../_cocoa___local_pool_8hxx.html',1,'']]],
   ['cocoa_5fwindow_2ehxx',['Cocoa_Window.hxx',['../_cocoa___window_8hxx.html',1,'']]],
@@ -119,11 +106,6 @@ var searchData=
   ['contap_5fitype_2ehxx',['Contap_IType.hxx',['../_contap___i_type_8hxx.html',1,'']]],
   ['contap_5fline_2ehxx',['Contap_Line.hxx',['../_contap___line_8hxx.html',1,'']]],
   ['contap_5fpoint_2ehxx',['Contap_Point.hxx',['../_contap___point_8hxx.html',1,'']]],
-  ['contap_5fsequencenodeofsequenceofiwlineoftheiwalking_2ehxx',['Contap_SequenceNodeOfSequenceOfIWLineOfTheIWalking.hxx',['../_contap___sequence_node_of_sequence_of_i_w_line_of_the_i_walking_8hxx.html',1,'']]],
-  ['contap_5fsequencenodeofsequenceofpathpointofthesearch_2ehxx',['Contap_SequenceNodeOfSequenceOfPathPointOfTheSearch.hxx',['../_contap___sequence_node_of_sequence_of_path_point_of_the_search_8hxx.html',1,'']]],
-  ['contap_5fsequencenodeofsequenceofsegmentofthesearch_2ehxx',['Contap_SequenceNodeOfSequenceOfSegmentOfTheSearch.hxx',['../_contap___sequence_node_of_sequence_of_segment_of_the_search_8hxx.html',1,'']]],
-  ['contap_5fsequencenodeofthesequenceofline_2ehxx',['Contap_SequenceNodeOfTheSequenceOfLine.hxx',['../_contap___sequence_node_of_the_sequence_of_line_8hxx.html',1,'']]],
-  ['contap_5fsequencenodeofthesequenceofpoint_2ehxx',['Contap_SequenceNodeOfTheSequenceOfPoint.hxx',['../_contap___sequence_node_of_the_sequence_of_point_8hxx.html',1,'']]],
   ['contap_5fsequenceofiwlineoftheiwalking_2ehxx',['Contap_SequenceOfIWLineOfTheIWalking.hxx',['../_contap___sequence_of_i_w_line_of_the_i_walking_8hxx.html',1,'']]],
   ['contap_5fsequenceofpathpointofthesearch_2ehxx',['Contap_SequenceOfPathPointOfTheSearch.hxx',['../_contap___sequence_of_path_point_of_the_search_8hxx.html',1,'']]],
   ['contap_5fsequenceofsegmentofthesearch_2ehxx',['Contap_SequenceOfSegmentOfTheSearch.hxx',['../_contap___sequence_of_segment_of_the_search_8hxx.html',1,'']]],
@@ -154,7 +136,6 @@ var searchData=
   ['convert_5fparabolatobsplinecurve_2ehxx',['Convert_ParabolaToBSplineCurve.hxx',['../_convert___parabola_to_b_spline_curve_8hxx.html',1,'']]],
   ['convert_5fparameterisationtype_2ehxx',['Convert_ParameterisationType.hxx',['../_convert___parameterisation_type_8hxx.html',1,'']]],
   ['convert_5fpolynomialcosandsin_2ehxx',['Convert_PolynomialCosAndSin.hxx',['../_convert___polynomial_cos_and_sin_8hxx.html',1,'']]],
-  ['convert_5fsequencenodeofsequenceofarray1ofpoles_2ehxx',['Convert_SequenceNodeOfSequenceOfArray1OfPoles.hxx',['../_convert___sequence_node_of_sequence_of_array1_of_poles_8hxx.html',1,'']]],
   ['convert_5fsequenceofarray1ofpoles_2ehxx',['Convert_SequenceOfArray1OfPoles.hxx',['../_convert___sequence_of_array1_of_poles_8hxx.html',1,'']]],
   ['convert_5fsequenceofarray1ofpoles2d_2ehxx',['Convert_SequenceOfArray1OfPoles2d.hxx',['../_convert___sequence_of_array1_of_poles2d_8hxx.html',1,'']]],
   ['convert_5fspheretobsplinesurface_2ehxx',['Convert_SphereToBSplineSurface.hxx',['../_convert___sphere_to_b_spline_surface_8hxx.html',1,'']]],
