@@ -1,20 +1,5 @@
 var searchData=
 [
-  ['dbc_5fbasearray_2ehxx',['DBC_BaseArray.hxx',['../_d_b_c___base_array_8hxx.html',1,'']]],
-  ['dbc_5fbasearray_5fobjs_2ehxx',['DBC_BaseArray_objs.hxx',['../_d_b_c___base_array__objs_8hxx.html',1,'']]],
-  ['dbc_5fdbvarray_2ehxx',['DBC_DBVArray.hxx',['../_d_b_c___d_b_v_array_8hxx.html',1,'']]],
-  ['dbc_5fvarraynodeofvarrayofcharacter_2ehxx',['DBC_VArrayNodeOfVArrayOfCharacter.hxx',['../_d_b_c___v_array_node_of_v_array_of_character_8hxx.html',1,'']]],
-  ['dbc_5fvarraynodeofvarrayofextcharacter_2ehxx',['DBC_VArrayNodeOfVArrayOfExtCharacter.hxx',['../_d_b_c___v_array_node_of_v_array_of_ext_character_8hxx.html',1,'']]],
-  ['dbc_5fvarraynodeofvarrayofinteger_2ehxx',['DBC_VArrayNodeOfVArrayOfInteger.hxx',['../_d_b_c___v_array_node_of_v_array_of_integer_8hxx.html',1,'']]],
-  ['dbc_5fvarraynodeofvarrayofreal_2ehxx',['DBC_VArrayNodeOfVArrayOfReal.hxx',['../_d_b_c___v_array_node_of_v_array_of_real_8hxx.html',1,'']]],
-  ['dbc_5fvarrayofcharacter_2ehxx',['DBC_VArrayOfCharacter.hxx',['../_d_b_c___v_array_of_character_8hxx.html',1,'']]],
-  ['dbc_5fvarrayofextcharacter_2ehxx',['DBC_VArrayOfExtCharacter.hxx',['../_d_b_c___v_array_of_ext_character_8hxx.html',1,'']]],
-  ['dbc_5fvarrayofinteger_2ehxx',['DBC_VArrayOfInteger.hxx',['../_d_b_c___v_array_of_integer_8hxx.html',1,'']]],
-  ['dbc_5fvarrayofreal_2ehxx',['DBC_VArrayOfReal.hxx',['../_d_b_c___v_array_of_real_8hxx.html',1,'']]],
-  ['dbc_5fvarraytnodeofvarrayofcharacter_2ehxx',['DBC_VArrayTNodeOfVArrayOfCharacter.hxx',['../_d_b_c___v_array_t_node_of_v_array_of_character_8hxx.html',1,'']]],
-  ['dbc_5fvarraytnodeofvarrayofextcharacter_2ehxx',['DBC_VArrayTNodeOfVArrayOfExtCharacter.hxx',['../_d_b_c___v_array_t_node_of_v_array_of_ext_character_8hxx.html',1,'']]],
-  ['dbc_5fvarraytnodeofvarrayofinteger_2ehxx',['DBC_VArrayTNodeOfVArrayOfInteger.hxx',['../_d_b_c___v_array_t_node_of_v_array_of_integer_8hxx.html',1,'']]],
-  ['dbc_5fvarraytnodeofvarrayofreal_2ehxx',['DBC_VArrayTNodeOfVArrayOfReal.hxx',['../_d_b_c___v_array_t_node_of_v_array_of_real_8hxx.html',1,'']]],
   ['dbrep_2ehxx',['DBRep.hxx',['../_d_b_rep_8hxx.html',1,'']]],
   ['dbrep_5fdrawableshape_2ehxx',['DBRep_DrawableShape.hxx',['../_d_b_rep___drawable_shape_8hxx.html',1,'']]],
   ['dbrep_5fedge_2ehxx',['DBRep_Edge.hxx',['../_d_b_rep___edge_8hxx.html',1,'']]],
@@ -24,9 +9,6 @@ var searchData=
   ['dbrep_5flistiteratoroflistofedge_2ehxx',['DBRep_ListIteratorOfListOfEdge.hxx',['../_d_b_rep___list_iterator_of_list_of_edge_8hxx.html',1,'']]],
   ['dbrep_5flistiteratoroflistofface_2ehxx',['DBRep_ListIteratorOfListOfFace.hxx',['../_d_b_rep___list_iterator_of_list_of_face_8hxx.html',1,'']]],
   ['dbrep_5flistiteratoroflistofhidedata_2ehxx',['DBRep_ListIteratorOfListOfHideData.hxx',['../_d_b_rep___list_iterator_of_list_of_hide_data_8hxx.html',1,'']]],
-  ['dbrep_5flistnodeoflistofedge_2ehxx',['DBRep_ListNodeOfListOfEdge.hxx',['../_d_b_rep___list_node_of_list_of_edge_8hxx.html',1,'']]],
-  ['dbrep_5flistnodeoflistofface_2ehxx',['DBRep_ListNodeOfListOfFace.hxx',['../_d_b_rep___list_node_of_list_of_face_8hxx.html',1,'']]],
-  ['dbrep_5flistnodeoflistofhidedata_2ehxx',['DBRep_ListNodeOfListOfHideData.hxx',['../_d_b_rep___list_node_of_list_of_hide_data_8hxx.html',1,'']]],
   ['dbrep_5flistofedge_2ehxx',['DBRep_ListOfEdge.hxx',['../_d_b_rep___list_of_edge_8hxx.html',1,'']]],
   ['dbrep_5flistofface_2ehxx',['DBRep_ListOfFace.hxx',['../_d_b_rep___list_of_face_8hxx.html',1,'']]],
   ['dbrep_5flistofhidedata_2ehxx',['DBRep_ListOfHideData.hxx',['../_d_b_rep___list_of_hide_data_8hxx.html',1,'']]],
@@ -40,23 +22,15 @@ var searchData=
   ['ddf_5fdata_2ehxx',['DDF_Data.hxx',['../_d_d_f___data_8hxx.html',1,'']]],
   ['ddf_5fiostream_2ehxx',['DDF_IOStream.hxx',['../_d_d_f___i_o_stream_8hxx.html',1,'']]],
   ['ddf_5flistiteratoroftransactionstack_2ehxx',['DDF_ListIteratorOfTransactionStack.hxx',['../_d_d_f___list_iterator_of_transaction_stack_8hxx.html',1,'']]],
-  ['ddf_5flistnodeoftransactionstack_2ehxx',['DDF_ListNodeOfTransactionStack.hxx',['../_d_d_f___list_node_of_transaction_stack_8hxx.html',1,'']]],
   ['ddf_5ftransaction_2ehxx',['DDF_Transaction.hxx',['../_d_d_f___transaction_8hxx.html',1,'']]],
   ['ddf_5ftransactionstack_2ehxx',['DDF_TransactionStack.hxx',['../_d_d_f___transaction_stack_8hxx.html',1,'']]],
   ['ddocstd_2ehxx',['DDocStd.hxx',['../_d_doc_std_8hxx.html',1,'']]],
   ['ddocstd_5fdrawdocument_2ehxx',['DDocStd_DrawDocument.hxx',['../_d_doc_std___draw_document_8hxx.html',1,'']]],
-  ['dico_5fdictionaryofinteger_2ehxx',['Dico_DictionaryOfInteger.hxx',['../_dico___dictionary_of_integer_8hxx.html',1,'']]],
-  ['dico_5fdictionaryoftransient_2ehxx',['Dico_DictionaryOfTransient.hxx',['../_dico___dictionary_of_transient_8hxx.html',1,'']]],
-  ['dico_5fiteratorofdictionaryofinteger_2ehxx',['Dico_IteratorOfDictionaryOfInteger.hxx',['../_dico___iterator_of_dictionary_of_integer_8hxx.html',1,'']]],
-  ['dico_5fiteratorofdictionaryoftransient_2ehxx',['Dico_IteratorOfDictionaryOfTransient.hxx',['../_dico___iterator_of_dictionary_of_transient_8hxx.html',1,'']]],
-  ['dico_5fstackitemofdictionaryofinteger_2ehxx',['Dico_StackItemOfDictionaryOfInteger.hxx',['../_dico___stack_item_of_dictionary_of_integer_8hxx.html',1,'']]],
-  ['dico_5fstackitemofdictionaryoftransient_2ehxx',['Dico_StackItemOfDictionaryOfTransient.hxx',['../_dico___stack_item_of_dictionary_of_transient_8hxx.html',1,'']]],
   ['dnaming_2ehxx',['DNaming.hxx',['../_d_naming_8hxx.html',1,'']]],
   ['dnaming_5fbooleanoperationdriver_2ehxx',['DNaming_BooleanOperationDriver.hxx',['../_d_naming___boolean_operation_driver_8hxx.html',1,'']]],
   ['dnaming_5fboxdriver_2ehxx',['DNaming_BoxDriver.hxx',['../_d_naming___box_driver_8hxx.html',1,'']]],
   ['dnaming_5fcylinderdriver_2ehxx',['DNaming_CylinderDriver.hxx',['../_d_naming___cylinder_driver_8hxx.html',1,'']]],
   ['dnaming_5fdatamapiteratorofdatamapofshapeofname_2ehxx',['DNaming_DataMapIteratorOfDataMapOfShapeOfName.hxx',['../_d_naming___data_map_iterator_of_data_map_of_shape_of_name_8hxx.html',1,'']]],
-  ['dnaming_5fdatamapnodeofdatamapofshapeofname_2ehxx',['DNaming_DataMapNodeOfDataMapOfShapeOfName.hxx',['../_d_naming___data_map_node_of_data_map_of_shape_of_name_8hxx.html',1,'']]],
   ['dnaming_5fdatamapofshapeofname_2ehxx',['DNaming_DataMapOfShapeOfName.hxx',['../_d_naming___data_map_of_shape_of_name_8hxx.html',1,'']]],
   ['dnaming_5ffilletdriver_2ehxx',['DNaming_FilletDriver.hxx',['../_d_naming___fillet_driver_8hxx.html',1,'']]],
   ['dnaming_5fline3ddriver_2ehxx',['DNaming_Line3DDriver.hxx',['../_d_naming___line3_d_driver_8hxx.html',1,'']]],
@@ -68,18 +42,12 @@ var searchData=
   ['dnaming_5ftransformationdriver_2ehxx',['DNaming_TransformationDriver.hxx',['../_d_naming___transformation_driver_8hxx.html',1,'']]],
   ['dprsstd_2ehxx',['DPrsStd.hxx',['../_d_prs_std_8hxx.html',1,'']]],
   ['draft_2ehxx',['Draft.hxx',['../_draft_8hxx.html',1,'']]],
-  ['draft_5fdatamapiteratorofdatamapofedgeedgeinfo_2ehxx',['Draft_DataMapIteratorOfDataMapOfEdgeEdgeInfo.hxx',['../_draft___data_map_iterator_of_data_map_of_edge_edge_info_8hxx.html',1,'']]],
-  ['draft_5fdatamapiteratorofdatamapoffacefaceinfo_2ehxx',['Draft_DataMapIteratorOfDataMapOfFaceFaceInfo.hxx',['../_draft___data_map_iterator_of_data_map_of_face_face_info_8hxx.html',1,'']]],
-  ['draft_5fdatamapiteratorofdatamapofvertexvertexinfo_2ehxx',['Draft_DataMapIteratorOfDataMapOfVertexVertexInfo.hxx',['../_draft___data_map_iterator_of_data_map_of_vertex_vertex_info_8hxx.html',1,'']]],
-  ['draft_5fdatamapnodeofdatamapofedgeedgeinfo_2ehxx',['Draft_DataMapNodeOfDataMapOfEdgeEdgeInfo.hxx',['../_draft___data_map_node_of_data_map_of_edge_edge_info_8hxx.html',1,'']]],
-  ['draft_5fdatamapnodeofdatamapoffacefaceinfo_2ehxx',['Draft_DataMapNodeOfDataMapOfFaceFaceInfo.hxx',['../_draft___data_map_node_of_data_map_of_face_face_info_8hxx.html',1,'']]],
-  ['draft_5fdatamapnodeofdatamapofvertexvertexinfo_2ehxx',['Draft_DataMapNodeOfDataMapOfVertexVertexInfo.hxx',['../_draft___data_map_node_of_data_map_of_vertex_vertex_info_8hxx.html',1,'']]],
-  ['draft_5fdatamapofedgeedgeinfo_2ehxx',['Draft_DataMapOfEdgeEdgeInfo.hxx',['../_draft___data_map_of_edge_edge_info_8hxx.html',1,'']]],
-  ['draft_5fdatamapoffacefaceinfo_2ehxx',['Draft_DataMapOfFaceFaceInfo.hxx',['../_draft___data_map_of_face_face_info_8hxx.html',1,'']]],
-  ['draft_5fdatamapofvertexvertexinfo_2ehxx',['Draft_DataMapOfVertexVertexInfo.hxx',['../_draft___data_map_of_vertex_vertex_info_8hxx.html',1,'']]],
   ['draft_5fedgeinfo_2ehxx',['Draft_EdgeInfo.hxx',['../_draft___edge_info_8hxx.html',1,'']]],
   ['draft_5ferrorstatus_2ehxx',['Draft_ErrorStatus.hxx',['../_draft___error_status_8hxx.html',1,'']]],
   ['draft_5ffaceinfo_2ehxx',['Draft_FaceInfo.hxx',['../_draft___face_info_8hxx.html',1,'']]],
+  ['draft_5findexeddatamapofedgeedgeinfo_2ehxx',['Draft_IndexedDataMapOfEdgeEdgeInfo.hxx',['../_draft___indexed_data_map_of_edge_edge_info_8hxx.html',1,'']]],
+  ['draft_5findexeddatamapoffacefaceinfo_2ehxx',['Draft_IndexedDataMapOfFaceFaceInfo.hxx',['../_draft___indexed_data_map_of_face_face_info_8hxx.html',1,'']]],
+  ['draft_5findexeddatamapofvertexvertexinfo_2ehxx',['Draft_IndexedDataMapOfVertexVertexInfo.hxx',['../_draft___indexed_data_map_of_vertex_vertex_info_8hxx.html',1,'']]],
   ['draft_5fmodification_2ehxx',['Draft_Modification.hxx',['../_draft___modification_8hxx.html',1,'']]],
   ['draft_5fvertexinfo_2ehxx',['Draft_VertexInfo.hxx',['../_draft___vertex_info_8hxx.html',1,'']]],
   ['draw_2ehxx',['Draw.hxx',['../_draw_8hxx.html',1,'']]],
@@ -97,7 +65,6 @@ var searchData=
   ['draw_5fdrawable3d_2ehxx',['Draw_Drawable3D.hxx',['../_draw___drawable3_d_8hxx.html',1,'']]],
   ['draw_5ffailure_2ehxx',['Draw_Failure.hxx',['../_draw___failure_8hxx.html',1,'']]],
   ['draw_5fgrid_2ehxx',['Draw_Grid.hxx',['../_draw___grid_8hxx.html',1,'']]],
-  ['draw_5findexedmapnodeofmapofasciistring_2ehxx',['Draw_IndexedMapNodeOfMapOfAsciiString.hxx',['../_draw___indexed_map_node_of_map_of_ascii_string_8hxx.html',1,'']]],
   ['draw_5finterpretor_2ehxx',['Draw_Interpretor.hxx',['../_draw___interpretor_8hxx.html',1,'']]],
   ['draw_5fmain_2ehxx',['Draw_Main.hxx',['../_draw___main_8hxx.html',1,'']]],
   ['draw_5fmapofasciistring_2ehxx',['Draw_MapOfAsciiString.hxx',['../_draw___map_of_ascii_string_8hxx.html',1,'']]],
@@ -111,7 +78,6 @@ var searchData=
   ['draw_5fprogressindicator_2ehxx',['Draw_ProgressIndicator.hxx',['../_draw___progress_indicator_8hxx.html',1,'']]],
   ['draw_5fsegment2d_2ehxx',['Draw_Segment2D.hxx',['../_draw___segment2_d_8hxx.html',1,'']]],
   ['draw_5fsegment3d_2ehxx',['Draw_Segment3D.hxx',['../_draw___segment3_d_8hxx.html',1,'']]],
-  ['draw_5fsequencenodeofsequenceofdrawable3d_2ehxx',['Draw_SequenceNodeOfSequenceOfDrawable3D.hxx',['../_draw___sequence_node_of_sequence_of_drawable3_d_8hxx.html',1,'']]],
   ['draw_5fsequenceofdrawable3d_2ehxx',['Draw_SequenceOfDrawable3D.hxx',['../_draw___sequence_of_drawable3_d_8hxx.html',1,'']]],
   ['draw_5ftext2d_2ehxx',['Draw_Text2D.hxx',['../_draw___text2_d_8hxx.html',1,'']]],
   ['draw_5ftext3d_2ehxx',['Draw_Text3D.hxx',['../_draw___text3_d_8hxx.html',1,'']]],
