@@ -30,7 +30,6 @@ var searchData=
   ['expr_5fgeneralrelation_2ehxx',['Expr_GeneralRelation.hxx',['../_expr___general_relation_8hxx.html',1,'']]],
   ['expr_5fgreaterthan_2ehxx',['Expr_GreaterThan.hxx',['../_expr___greater_than_8hxx.html',1,'']]],
   ['expr_5fgreaterthanorequal_2ehxx',['Expr_GreaterThanOrEqual.hxx',['../_expr___greater_than_or_equal_8hxx.html',1,'']]],
-  ['expr_5findexedmapnodeofmapofnamedunknown_2ehxx',['Expr_IndexedMapNodeOfMapOfNamedUnknown.hxx',['../_expr___indexed_map_node_of_map_of_named_unknown_8hxx.html',1,'']]],
   ['expr_5finvalidassignment_2ehxx',['Expr_InvalidAssignment.hxx',['../_expr___invalid_assignment_8hxx.html',1,'']]],
   ['expr_5finvalidfunction_2ehxx',['Expr_InvalidFunction.hxx',['../_expr___invalid_function_8hxx.html',1,'']]],
   ['expr_5finvalidoperand_2ehxx',['Expr_InvalidOperand.hxx',['../_expr___invalid_operand_8hxx.html',1,'']]],
@@ -52,8 +51,6 @@ var searchData=
   ['expr_5fproduct_2ehxx',['Expr_Product.hxx',['../_expr___product_8hxx.html',1,'']]],
   ['expr_5frelationiterator_2ehxx',['Expr_RelationIterator.hxx',['../_expr___relation_iterator_8hxx.html',1,'']]],
   ['expr_5fruiterator_2ehxx',['Expr_RUIterator.hxx',['../_expr___r_u_iterator_8hxx.html',1,'']]],
-  ['expr_5fsequencenodeofsequenceofgeneralexpression_2ehxx',['Expr_SequenceNodeOfSequenceOfGeneralExpression.hxx',['../_expr___sequence_node_of_sequence_of_general_expression_8hxx.html',1,'']]],
-  ['expr_5fsequencenodeofsequenceofgeneralrelation_2ehxx',['Expr_SequenceNodeOfSequenceOfGeneralRelation.hxx',['../_expr___sequence_node_of_sequence_of_general_relation_8hxx.html',1,'']]],
   ['expr_5fsequenceofgeneralexpression_2ehxx',['Expr_SequenceOfGeneralExpression.hxx',['../_expr___sequence_of_general_expression_8hxx.html',1,'']]],
   ['expr_5fsequenceofgeneralrelation_2ehxx',['Expr_SequenceOfGeneralRelation.hxx',['../_expr___sequence_of_general_relation_8hxx.html',1,'']]],
   ['expr_5fsign_2ehxx',['Expr_Sign.hxx',['../_expr___sign_8hxx.html',1,'']]],
@@ -79,11 +76,6 @@ var searchData=
   ['exprintrp_5flistiteratorofstackofgeneralexpression_2ehxx',['ExprIntrp_ListIteratorOfStackOfGeneralExpression.hxx',['../_expr_intrp___list_iterator_of_stack_of_general_expression_8hxx.html',1,'']]],
   ['exprintrp_5flistiteratorofstackofgeneralfunction_2ehxx',['ExprIntrp_ListIteratorOfStackOfGeneralFunction.hxx',['../_expr_intrp___list_iterator_of_stack_of_general_function_8hxx.html',1,'']]],
   ['exprintrp_5flistiteratorofstackofgeneralrelation_2ehxx',['ExprIntrp_ListIteratorOfStackOfGeneralRelation.hxx',['../_expr_intrp___list_iterator_of_stack_of_general_relation_8hxx.html',1,'']]],
-  ['exprintrp_5flistnodeofstackofgeneralexpression_2ehxx',['ExprIntrp_ListNodeOfStackOfGeneralExpression.hxx',['../_expr_intrp___list_node_of_stack_of_general_expression_8hxx.html',1,'']]],
-  ['exprintrp_5flistnodeofstackofgeneralfunction_2ehxx',['ExprIntrp_ListNodeOfStackOfGeneralFunction.hxx',['../_expr_intrp___list_node_of_stack_of_general_function_8hxx.html',1,'']]],
-  ['exprintrp_5flistnodeofstackofgeneralrelation_2ehxx',['ExprIntrp_ListNodeOfStackOfGeneralRelation.hxx',['../_expr_intrp___list_node_of_stack_of_general_relation_8hxx.html',1,'']]],
-  ['exprintrp_5fsequencenodeofsequenceofnamedexpression_2ehxx',['ExprIntrp_SequenceNodeOfSequenceOfNamedExpression.hxx',['../_expr_intrp___sequence_node_of_sequence_of_named_expression_8hxx.html',1,'']]],
-  ['exprintrp_5fsequencenodeofsequenceofnamedfunction_2ehxx',['ExprIntrp_SequenceNodeOfSequenceOfNamedFunction.hxx',['../_expr_intrp___sequence_node_of_sequence_of_named_function_8hxx.html',1,'']]],
   ['exprintrp_5fsequenceofnamedexpression_2ehxx',['ExprIntrp_SequenceOfNamedExpression.hxx',['../_expr_intrp___sequence_of_named_expression_8hxx.html',1,'']]],
   ['exprintrp_5fsequenceofnamedfunction_2ehxx',['ExprIntrp_SequenceOfNamedFunction.hxx',['../_expr_intrp___sequence_of_named_function_8hxx.html',1,'']]],
   ['exprintrp_5fstackofgeneralexpression_2ehxx',['ExprIntrp_StackOfGeneralExpression.hxx',['../_expr_intrp___stack_of_general_expression_8hxx.html',1,'']]],
@@ -131,8 +123,9 @@ var searchData=
   ['extrema_5fextps_2ehxx',['Extrema_ExtPS.hxx',['../_extrema___ext_p_s_8hxx.html',1,'']]],
   ['extrema_5fextss_2ehxx',['Extrema_ExtSS.hxx',['../_extrema___ext_s_s_8hxx.html',1,'']]],
   ['extrema_5ffuncextcs_2ehxx',['Extrema_FuncExtCS.hxx',['../_extrema___func_ext_c_s_8hxx.html',1,'']]],
-  ['extrema_5ffuncextps_2ehxx',['Extrema_FuncExtPS.hxx',['../_extrema___func_ext_p_s_8hxx.html',1,'']]],
   ['extrema_5ffuncextss_2ehxx',['Extrema_FuncExtSS.hxx',['../_extrema___func_ext_s_s_8hxx.html',1,'']]],
+  ['extrema_5ffuncpsdist_2ehxx',['Extrema_FuncPSDist.hxx',['../_extrema___func_p_s_dist_8hxx.html',1,'']]],
+  ['extrema_5ffuncpsnorm_2ehxx',['Extrema_FuncPSNorm.hxx',['../_extrema___func_p_s_norm_8hxx.html',1,'']]],
   ['extrema_5fgenextcs_2ehxx',['Extrema_GenExtCS.hxx',['../_extrema___gen_ext_c_s_8hxx.html',1,'']]],
   ['extrema_5fgenextps_2ehxx',['Extrema_GenExtPS.hxx',['../_extrema___gen_ext_p_s_8hxx.html',1,'']]],
   ['extrema_5fgenextss_2ehxx',['Extrema_GenExtSS.hxx',['../_extrema___gen_ext_s_s_8hxx.html',1,'']]],
@@ -167,25 +160,6 @@ var searchData=
   ['extrema_5fponcurv2d_2ehxx',['Extrema_POnCurv2d.hxx',['../_extrema___p_on_curv2d_8hxx.html',1,'']]],
   ['extrema_5fponsurf_2ehxx',['Extrema_POnSurf.hxx',['../_extrema___p_on_surf_8hxx.html',1,'']]],
   ['extrema_5fponsurfparams_2ehxx',['Extrema_POnSurfParams.hxx',['../_extrema___p_on_surf_params_8hxx.html',1,'']]],
-  ['extrema_5fseqpcofpcfofepcofelpcoflocateextpc_2ehxx',['Extrema_SeqPCOfPCFOfEPCOfELPCOfLocateExtPC.hxx',['../_extrema___seq_p_c_of_p_c_f_of_e_p_c_of_e_l_p_c_of_locate_ext_p_c_8hxx.html',1,'']]],
-  ['extrema_5fseqpcofpcfofepcofelpcoflocateextpc2d_2ehxx',['Extrema_SeqPCOfPCFOfEPCOfELPCOfLocateExtPC2d.hxx',['../_extrema___seq_p_c_of_p_c_f_of_e_p_c_of_e_l_p_c_of_locate_ext_p_c2d_8hxx.html',1,'']]],
-  ['extrema_5fseqpcofpcfofepcofextpc_2ehxx',['Extrema_SeqPCOfPCFOfEPCOfExtPC.hxx',['../_extrema___seq_p_c_of_p_c_f_of_e_p_c_of_ext_p_c_8hxx.html',1,'']]],
-  ['extrema_5fseqpcofpcfofepcofextpc2d_2ehxx',['Extrema_SeqPCOfPCFOfEPCOfExtPC2d.hxx',['../_extrema___seq_p_c_of_p_c_f_of_e_p_c_of_ext_p_c2d_8hxx.html',1,'']]],
-  ['extrema_5fseqpcofpclocfoflocepcoflocateextpc_2ehxx',['Extrema_SeqPCOfPCLocFOfLocEPCOfLocateExtPC.hxx',['../_extrema___seq_p_c_of_p_c_loc_f_of_loc_e_p_c_of_locate_ext_p_c_8hxx.html',1,'']]],
-  ['extrema_5fseqpcofpclocfoflocepcoflocateextpc2d_2ehxx',['Extrema_SeqPCOfPCLocFOfLocEPCOfLocateExtPC2d.hxx',['../_extrema___seq_p_c_of_p_c_loc_f_of_loc_e_p_c_of_locate_ext_p_c2d_8hxx.html',1,'']]],
-  ['extrema_5fseqponcofcclocfoflocecc_2ehxx',['Extrema_SeqPOnCOfCCLocFOfLocECC.hxx',['../_extrema___seq_p_on_c_of_c_c_loc_f_of_loc_e_c_c_8hxx.html',1,'']]],
-  ['extrema_5fseqponcofcclocfoflocecc2d_2ehxx',['Extrema_SeqPOnCOfCCLocFOfLocECC2d.hxx',['../_extrema___seq_p_on_c_of_c_c_loc_f_of_loc_e_c_c2d_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofseqpcofpcfofepcofelpcoflocateextpc_2ehxx',['Extrema_SequenceNodeOfSeqPCOfPCFOfEPCOfELPCOfLocateExtPC.hxx',['../_extrema___sequence_node_of_seq_p_c_of_p_c_f_of_e_p_c_of_e_l_p_c_of_locate_ext_p_c_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofseqpcofpcfofepcofelpcoflocateextpc2d_2ehxx',['Extrema_SequenceNodeOfSeqPCOfPCFOfEPCOfELPCOfLocateExtPC2d.hxx',['../_extrema___sequence_node_of_seq_p_c_of_p_c_f_of_e_p_c_of_e_l_p_c_of_locate_ext_p_c2d_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofseqpcofpcfofepcofextpc_2ehxx',['Extrema_SequenceNodeOfSeqPCOfPCFOfEPCOfExtPC.hxx',['../_extrema___sequence_node_of_seq_p_c_of_p_c_f_of_e_p_c_of_ext_p_c_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofseqpcofpcfofepcofextpc2d_2ehxx',['Extrema_SequenceNodeOfSeqPCOfPCFOfEPCOfExtPC2d.hxx',['../_extrema___sequence_node_of_seq_p_c_of_p_c_f_of_e_p_c_of_ext_p_c2d_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofseqpcofpclocfoflocepcoflocateextpc_2ehxx',['Extrema_SequenceNodeOfSeqPCOfPCLocFOfLocEPCOfLocateExtPC.hxx',['../_extrema___sequence_node_of_seq_p_c_of_p_c_loc_f_of_loc_e_p_c_of_locate_ext_p_c_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofseqpcofpclocfoflocepcoflocateextpc2d_2ehxx',['Extrema_SequenceNodeOfSeqPCOfPCLocFOfLocEPCOfLocateExtPC2d.hxx',['../_extrema___sequence_node_of_seq_p_c_of_p_c_loc_f_of_loc_e_p_c_of_locate_ext_p_c2d_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofseqponcofcclocfoflocecc_2ehxx',['Extrema_SequenceNodeOfSeqPOnCOfCCLocFOfLocECC.hxx',['../_extrema___sequence_node_of_seq_p_on_c_of_c_c_loc_f_of_loc_e_c_c_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofseqponcofcclocfoflocecc2d_2ehxx',['Extrema_SequenceNodeOfSeqPOnCOfCCLocFOfLocECC2d.hxx',['../_extrema___sequence_node_of_seq_p_on_c_of_c_c_loc_f_of_loc_e_c_c2d_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofsequenceofponcurv_2ehxx',['Extrema_SequenceNodeOfSequenceOfPOnCurv.hxx',['../_extrema___sequence_node_of_sequence_of_p_on_curv_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofsequenceofponcurv2d_2ehxx',['Extrema_SequenceNodeOfSequenceOfPOnCurv2d.hxx',['../_extrema___sequence_node_of_sequence_of_p_on_curv2d_8hxx.html',1,'']]],
-  ['extrema_5fsequencenodeofsequenceofponsurf_2ehxx',['Extrema_SequenceNodeOfSequenceOfPOnSurf.hxx',['../_extrema___sequence_node_of_sequence_of_p_on_surf_8hxx.html',1,'']]],
   ['extrema_5fsequenceofponcurv_2ehxx',['Extrema_SequenceOfPOnCurv.hxx',['../_extrema___sequence_of_p_on_curv_8hxx.html',1,'']]],
   ['extrema_5fsequenceofponcurv2d_2ehxx',['Extrema_SequenceOfPOnCurv2d.hxx',['../_extrema___sequence_of_p_on_curv2d_8hxx.html',1,'']]],
   ['extrema_5fsequenceofponsurf_2ehxx',['Extrema_SequenceOfPOnSurf.hxx',['../_extrema___sequence_of_p_on_surf_8hxx.html',1,'']]]
