@@ -92,6 +92,8 @@ var searchData=
   ['gcpnts_5fabscissapoint_2ehxx',['GCPnts_AbscissaPoint.hxx',['../_g_c_pnts___abscissa_point_8hxx.html',1,'']]],
   ['gcpnts_5fabscissatype_2ehxx',['GCPnts_AbscissaType.hxx',['../_g_c_pnts___abscissa_type_8hxx.html',1,'']]],
   ['gcpnts_5fdeflectiontype_2ehxx',['GCPnts_DeflectionType.hxx',['../_g_c_pnts___deflection_type_8hxx.html',1,'']]],
+  ['gcpnts_5fdistfunction_2ehxx',['GCPnts_DistFunction.hxx',['../_g_c_pnts___dist_function_8hxx.html',1,'']]],
+  ['gcpnts_5fdistfunction2d_2ehxx',['GCPnts_DistFunction2d.hxx',['../_g_c_pnts___dist_function2d_8hxx.html',1,'']]],
   ['gcpnts_5fquasiuniformabscissa_2ehxx',['GCPnts_QuasiUniformAbscissa.hxx',['../_g_c_pnts___quasi_uniform_abscissa_8hxx.html',1,'']]],
   ['gcpnts_5fquasiuniformdeflection_2ehxx',['GCPnts_QuasiUniformDeflection.hxx',['../_g_c_pnts___quasi_uniform_deflection_8hxx.html',1,'']]],
   ['gcpnts_5ftangentialdeflection_2ehxx',['GCPnts_TangentialDeflection.hxx',['../_g_c_pnts___tangential_deflection_8hxx.html',1,'']]],
@@ -133,6 +135,8 @@ var searchData=
   ['geom2dconvert_5fbsplinecurveknotsplitting_2ehxx',['Geom2dConvert_BSplineCurveKnotSplitting.hxx',['../_geom2d_convert___b_spline_curve_knot_splitting_8hxx.html',1,'']]],
   ['geom2dconvert_5fbsplinecurvetobeziercurve_2ehxx',['Geom2dConvert_BSplineCurveToBezierCurve.hxx',['../_geom2d_convert___b_spline_curve_to_bezier_curve_8hxx.html',1,'']]],
   ['geom2dconvert_5fcompcurvetobsplinecurve_2ehxx',['Geom2dConvert_CompCurveToBSplineCurve.hxx',['../_geom2d_convert___comp_curve_to_b_spline_curve_8hxx.html',1,'']]],
+  ['geom2devaluator_5fcurve_2ehxx',['Geom2dEvaluator_Curve.hxx',['../_geom2d_evaluator___curve_8hxx.html',1,'']]],
+  ['geom2devaluator_5foffsetcurve_2ehxx',['Geom2dEvaluator_OffsetCurve.hxx',['../_geom2d_evaluator___offset_curve_8hxx.html',1,'']]],
   ['geom2dgcc_2ehxx',['Geom2dGcc.hxx',['../_geom2d_gcc_8hxx.html',1,'']]],
   ['geom2dgcc_5fcirc2d2tanon_2ehxx',['Geom2dGcc_Circ2d2TanOn.hxx',['../_geom2d_gcc___circ2d2_tan_on_8hxx.html',1,'']]],
   ['geom2dgcc_5fcirc2d2tanongeo_2ehxx',['Geom2dGcc_Circ2d2TanOnGeo.hxx',['../_geom2d_gcc___circ2d2_tan_on_geo_8hxx.html',1,'']]],
@@ -146,7 +150,6 @@ var searchData=
   ['geom2dgcc_5fcirc2dtanonrad_2ehxx',['Geom2dGcc_Circ2dTanOnRad.hxx',['../_geom2d_gcc___circ2d_tan_on_rad_8hxx.html',1,'']]],
   ['geom2dgcc_5fcirc2dtanonradgeo_2ehxx',['Geom2dGcc_Circ2dTanOnRadGeo.hxx',['../_geom2d_gcc___circ2d_tan_on_rad_geo_8hxx.html',1,'']]],
   ['geom2dgcc_5fcurvetool_2ehxx',['Geom2dGcc_CurveTool.hxx',['../_geom2d_gcc___curve_tool_8hxx.html',1,'']]],
-  ['geom2dgcc_5fcurvetoolgeo_2ehxx',['Geom2dGcc_CurveToolGeo.hxx',['../_geom2d_gcc___curve_tool_geo_8hxx.html',1,'']]],
   ['geom2dgcc_5ffunctiontancircu_2ehxx',['Geom2dGcc_FunctionTanCirCu.hxx',['../_geom2d_gcc___function_tan_cir_cu_8hxx.html',1,'']]],
   ['geom2dgcc_5ffunctiontancucu_2ehxx',['Geom2dGcc_FunctionTanCuCu.hxx',['../_geom2d_gcc___function_tan_cu_cu_8hxx.html',1,'']]],
   ['geom2dgcc_5ffunctiontancucucu_2ehxx',['Geom2dGcc_FunctionTanCuCuCu.hxx',['../_geom2d_gcc___function_tan_cu_cu_cu_8hxx.html',1,'']]],
@@ -166,8 +169,6 @@ var searchData=
   ['geom2dhatch_5fclassifier_2ehxx',['Geom2dHatch_Classifier.hxx',['../_geom2d_hatch___classifier_8hxx.html',1,'']]],
   ['geom2dhatch_5fdatamapiteratorofhatchings_2ehxx',['Geom2dHatch_DataMapIteratorOfHatchings.hxx',['../_geom2d_hatch___data_map_iterator_of_hatchings_8hxx.html',1,'']]],
   ['geom2dhatch_5fdatamapiteratorofmapofelements_2ehxx',['Geom2dHatch_DataMapIteratorOfMapOfElements.hxx',['../_geom2d_hatch___data_map_iterator_of_map_of_elements_8hxx.html',1,'']]],
-  ['geom2dhatch_5fdatamapnodeofhatchings_2ehxx',['Geom2dHatch_DataMapNodeOfHatchings.hxx',['../_geom2d_hatch___data_map_node_of_hatchings_8hxx.html',1,'']]],
-  ['geom2dhatch_5fdatamapnodeofmapofelements_2ehxx',['Geom2dHatch_DataMapNodeOfMapOfElements.hxx',['../_geom2d_hatch___data_map_node_of_map_of_elements_8hxx.html',1,'']]],
   ['geom2dhatch_5felement_2ehxx',['Geom2dHatch_Element.hxx',['../_geom2d_hatch___element_8hxx.html',1,'']]],
   ['geom2dhatch_5felements_2ehxx',['Geom2dHatch_Elements.hxx',['../_geom2d_hatch___elements_8hxx.html',1,'']]],
   ['geom2dhatch_5ffclass2dofclassifier_2ehxx',['Geom2dHatch_FClass2dOfClassifier.hxx',['../_geom2d_hatch___f_class2d_of_classifier_8hxx.html',1,'']]],
@@ -182,8 +183,6 @@ var searchData=
   ['geom2dint_5fintconiccurveofginter_2ehxx',['Geom2dInt_IntConicCurveOfGInter.hxx',['../_geom2d_int___int_conic_curve_of_g_inter_8hxx.html',1,'']]],
   ['geom2dint_5fmyimppartooloftheintersectoroftheintconiccurveofginter_2ehxx',['Geom2dInt_MyImpParToolOfTheIntersectorOfTheIntConicCurveOfGInter.hxx',['../_geom2d_int___my_imp_par_tool_of_the_intersector_of_the_int_conic_curve_of_g_inter_8hxx.html',1,'']]],
   ['geom2dint_5fpclocfofthelocateextpcoftheprojpcurofginter_2ehxx',['Geom2dInt_PCLocFOfTheLocateExtPCOfTheProjPCurOfGInter.hxx',['../_geom2d_int___p_c_loc_f_of_the_locate_ext_p_c_of_the_proj_p_cur_of_g_inter_8hxx.html',1,'']]],
-  ['geom2dint_5fseqpcofpclocfofthelocateextpcoftheprojpcurofginter_2ehxx',['Geom2dInt_SeqPCOfPCLocFOfTheLocateExtPCOfTheProjPCurOfGInter.hxx',['../_geom2d_int___seq_p_c_of_p_c_loc_f_of_the_locate_ext_p_c_of_the_proj_p_cur_of_g_inter_8hxx.html',1,'']]],
-  ['geom2dint_5fsequencenodeofseqpcofpclocfofthelocateextpcoftheprojpcurofginter_2ehxx',['Geom2dInt_SequenceNodeOfSeqPCOfPCLocFOfTheLocateExtPCOfTheProjPCurOfGInter.hxx',['../_geom2d_int___sequence_node_of_seq_p_c_of_p_c_loc_f_of_the_locate_ext_p_c_of_the_proj_p_cur_of_g_inter_8hxx.html',1,'']]],
   ['geom2dint_5fthecurvelocatoroftheprojpcurofginter_2ehxx',['Geom2dInt_TheCurveLocatorOfTheProjPCurOfGInter.hxx',['../_geom2d_int___the_curve_locator_of_the_proj_p_cur_of_g_inter_8hxx.html',1,'']]],
   ['geom2dint_5fthedistbetweenpcurvesoftheintpcurvepcurveofginter_2ehxx',['Geom2dInt_TheDistBetweenPCurvesOfTheIntPCurvePCurveOfGInter.hxx',['../_geom2d_int___the_dist_between_p_curves_of_the_int_p_curve_p_curve_of_g_inter_8hxx.html',1,'']]],
   ['geom2dint_5ftheintconiccurveofginter_2ehxx',['Geom2dInt_TheIntConicCurveOfGInter.hxx',['../_geom2d_int___the_int_conic_curve_of_g_inter_8hxx.html',1,'']]],
@@ -231,7 +230,6 @@ var searchData=
   ['geom_5fplane_2ehxx',['Geom_Plane.hxx',['../_geom___plane_8hxx.html',1,'']]],
   ['geom_5fpoint_2ehxx',['Geom_Point.hxx',['../_geom___point_8hxx.html',1,'']]],
   ['geom_5frectangulartrimmedsurface_2ehxx',['Geom_RectangularTrimmedSurface.hxx',['../_geom___rectangular_trimmed_surface_8hxx.html',1,'']]],
-  ['geom_5fsequencenodeofsequenceofbsplinesurface_2ehxx',['Geom_SequenceNodeOfSequenceOfBSplineSurface.hxx',['../_geom___sequence_node_of_sequence_of_b_spline_surface_8hxx.html',1,'']]],
   ['geom_5fsequenceofbsplinesurface_2ehxx',['Geom_SequenceOfBSplineSurface.hxx',['../_geom___sequence_of_b_spline_surface_8hxx.html',1,'']]],
   ['geom_5fsphericalsurface_2ehxx',['Geom_SphericalSurface.hxx',['../_geom___spherical_surface_8hxx.html',1,'']]],
   ['geom_5fsurface_2ehxx',['Geom_Surface.hxx',['../_geom___surface_8hxx.html',1,'']]],
@@ -260,7 +258,11 @@ var searchData=
   ['geomadaptor_5fghsurface_2ehxx',['GeomAdaptor_GHSurface.hxx',['../_geom_adaptor___g_h_surface_8hxx.html',1,'']]],
   ['geomadaptor_5fhcurve_2ehxx',['GeomAdaptor_HCurve.hxx',['../_geom_adaptor___h_curve_8hxx.html',1,'']]],
   ['geomadaptor_5fhsurface_2ehxx',['GeomAdaptor_HSurface.hxx',['../_geom_adaptor___h_surface_8hxx.html',1,'']]],
+  ['geomadaptor_5fhsurfaceoflinearextrusion_2ehxx',['GeomAdaptor_HSurfaceOfLinearExtrusion.hxx',['../_geom_adaptor___h_surface_of_linear_extrusion_8hxx.html',1,'']]],
+  ['geomadaptor_5fhsurfaceofrevolution_2ehxx',['GeomAdaptor_HSurfaceOfRevolution.hxx',['../_geom_adaptor___h_surface_of_revolution_8hxx.html',1,'']]],
   ['geomadaptor_5fsurface_2ehxx',['GeomAdaptor_Surface.hxx',['../_geom_adaptor___surface_8hxx.html',1,'']]],
+  ['geomadaptor_5fsurfaceoflinearextrusion_2ehxx',['GeomAdaptor_SurfaceOfLinearExtrusion.hxx',['../_geom_adaptor___surface_of_linear_extrusion_8hxx.html',1,'']]],
+  ['geomadaptor_5fsurfaceofrevolution_2ehxx',['GeomAdaptor_SurfaceOfRevolution.hxx',['../_geom_adaptor___surface_of_revolution_8hxx.html',1,'']]],
   ['geomapi_2ehxx',['GeomAPI.hxx',['../_geom_a_p_i_8hxx.html',1,'']]],
   ['geomapi_5fextremacurvecurve_2ehxx',['GeomAPI_ExtremaCurveCurve.hxx',['../_geom_a_p_i___extrema_curve_curve_8hxx.html',1,'']]],
   ['geomapi_5fextremacurvesurface_2ehxx',['GeomAPI_ExtremaCurveSurface.hxx',['../_geom_a_p_i___extrema_curve_surface_8hxx.html',1,'']]],
@@ -282,6 +284,12 @@ var searchData=
   ['geomconvert_5fcompbeziersurfacestobsplinesurface_2ehxx',['GeomConvert_CompBezierSurfacesToBSplineSurface.hxx',['../_geom_convert___comp_bezier_surfaces_to_b_spline_surface_8hxx.html',1,'']]],
   ['geomconvert_5fcompcurvetobsplinecurve_2ehxx',['GeomConvert_CompCurveToBSplineCurve.hxx',['../_geom_convert___comp_curve_to_b_spline_curve_8hxx.html',1,'']]],
   ['geometrytest_2ehxx',['GeometryTest.hxx',['../_geometry_test_8hxx.html',1,'']]],
+  ['geomevaluator_5fcurve_2ehxx',['GeomEvaluator_Curve.hxx',['../_geom_evaluator___curve_8hxx.html',1,'']]],
+  ['geomevaluator_5foffsetcurve_2ehxx',['GeomEvaluator_OffsetCurve.hxx',['../_geom_evaluator___offset_curve_8hxx.html',1,'']]],
+  ['geomevaluator_5foffsetsurface_2ehxx',['GeomEvaluator_OffsetSurface.hxx',['../_geom_evaluator___offset_surface_8hxx.html',1,'']]],
+  ['geomevaluator_5fsurface_2ehxx',['GeomEvaluator_Surface.hxx',['../_geom_evaluator___surface_8hxx.html',1,'']]],
+  ['geomevaluator_5fsurfaceofextrusion_2ehxx',['GeomEvaluator_SurfaceOfExtrusion.hxx',['../_geom_evaluator___surface_of_extrusion_8hxx.html',1,'']]],
+  ['geomevaluator_5fsurfaceofrevolution_2ehxx',['GeomEvaluator_SurfaceOfRevolution.hxx',['../_geom_evaluator___surface_of_revolution_8hxx.html',1,'']]],
   ['geomfill_2ehxx',['GeomFill.hxx',['../_geom_fill_8hxx.html',1,'']]],
   ['geomfill_5fapproxstyle_2ehxx',['GeomFill_ApproxStyle.hxx',['../_geom_fill___approx_style_8hxx.html',1,'']]],
   ['geomfill_5fappsurf_2ehxx',['GeomFill_AppSurf.hxx',['../_geom_fill___app_surf_8hxx.html',1,'']]],
@@ -333,8 +341,6 @@ var searchData=
   ['geomfill_5fsectiongenerator_2ehxx',['GeomFill_SectionGenerator.hxx',['../_geom_fill___section_generator_8hxx.html',1,'']]],
   ['geomfill_5fsectionlaw_2ehxx',['GeomFill_SectionLaw.hxx',['../_geom_fill___section_law_8hxx.html',1,'']]],
   ['geomfill_5fsectionplacement_2ehxx',['GeomFill_SectionPlacement.hxx',['../_geom_fill___section_placement_8hxx.html',1,'']]],
-  ['geomfill_5fsequencenodeofsequenceofax2_2ehxx',['GeomFill_SequenceNodeOfSequenceOfAx2.hxx',['../_geom_fill___sequence_node_of_sequence_of_ax2_8hxx.html',1,'']]],
-  ['geomfill_5fsequencenodeofsequenceoftrsf_2ehxx',['GeomFill_SequenceNodeOfSequenceOfTrsf.hxx',['../_geom_fill___sequence_node_of_sequence_of_trsf_8hxx.html',1,'']]],
   ['geomfill_5fsequenceofax2_2ehxx',['GeomFill_SequenceOfAx2.hxx',['../_geom_fill___sequence_of_ax2_8hxx.html',1,'']]],
   ['geomfill_5fsequenceoftrsf_2ehxx',['GeomFill_SequenceOfTrsf.hxx',['../_geom_fill___sequence_of_trsf_8hxx.html',1,'']]],
   ['geomfill_5fsimplebound_2ehxx',['GeomFill_SimpleBound.hxx',['../_geom_fill___simple_bound_8hxx.html',1,'']]],
@@ -369,7 +375,6 @@ var searchData=
   ['geomint_5fparleastsquareofmygradientofthecomputelinebezierofwlapprox_2ehxx',['GeomInt_ParLeastSquareOfMyGradientOfTheComputeLineBezierOfWLApprox.hxx',['../_geom_int___par_least_square_of_my_gradient_of_the_compute_line_bezier_of_w_l_approx_8hxx.html',1,'']]],
   ['geomint_5fresconstraintofmygradientbisofthecomputelineofwlapprox_2ehxx',['GeomInt_ResConstraintOfMyGradientbisOfTheComputeLineOfWLApprox.hxx',['../_geom_int___res_constraint_of_my_gradientbis_of_the_compute_line_of_w_l_approx_8hxx.html',1,'']]],
   ['geomint_5fresconstraintofmygradientofthecomputelinebezierofwlapprox_2ehxx',['GeomInt_ResConstraintOfMyGradientOfTheComputeLineBezierOfWLApprox.hxx',['../_geom_int___res_constraint_of_my_gradient_of_the_compute_line_bezier_of_w_l_approx_8hxx.html',1,'']]],
-  ['geomint_5fsequencenodeofsequenceofparameterandorientation_2ehxx',['GeomInt_SequenceNodeOfSequenceOfParameterAndOrientation.hxx',['../_geom_int___sequence_node_of_sequence_of_parameter_and_orientation_8hxx.html',1,'']]],
   ['geomint_5fsequenceofparameterandorientation_2ehxx',['GeomInt_SequenceOfParameterAndOrientation.hxx',['../_geom_int___sequence_of_parameter_and_orientation_8hxx.html',1,'']]],
   ['geomint_5fthecomputelinebezierofwlapprox_2ehxx',['GeomInt_TheComputeLineBezierOfWLApprox.hxx',['../_geom_int___the_compute_line_bezier_of_w_l_approx_8hxx.html',1,'']]],
   ['geomint_5fthecomputelineofwlapprox_2ehxx',['GeomInt_TheComputeLineOfWLApprox.hxx',['../_geom_int___the_compute_line_of_w_l_approx_8hxx.html',1,'']]],
@@ -386,6 +391,7 @@ var searchData=
   ['geomlib_5farray1ofmat_2ehxx',['GeomLib_Array1OfMat.hxx',['../_geom_lib___array1_of_mat_8hxx.html',1,'']]],
   ['geomlib_5fcheck2dbsplinecurve_2ehxx',['GeomLib_Check2dBSplineCurve.hxx',['../_geom_lib___check2d_b_spline_curve_8hxx.html',1,'']]],
   ['geomlib_5fcheckbsplinecurve_2ehxx',['GeomLib_CheckBSplineCurve.hxx',['../_geom_lib___check_b_spline_curve_8hxx.html',1,'']]],
+  ['geomlib_5fcheckcurveonsurface_2ehxx',['GeomLib_CheckCurveOnSurface.hxx',['../_geom_lib___check_curve_on_surface_8hxx.html',1,'']]],
   ['geomlib_5fdenominatormultiplier_2ehxx',['GeomLib_DenominatorMultiplier.hxx',['../_geom_lib___denominator_multiplier_8hxx.html',1,'']]],
   ['geomlib_5fdenominatormultiplierptr_2ehxx',['GeomLib_DenominatorMultiplierPtr.hxx',['../_geom_lib___denominator_multiplier_ptr_8hxx.html',1,'']]],
   ['geomlib_5finterpolate_2ehxx',['GeomLib_Interpolate.hxx',['../_geom_lib___interpolate_8hxx.html',1,'']]],
@@ -415,9 +421,6 @@ var searchData=
   ['geomplate_5fplateg0criterion_2ehxx',['GeomPlate_PlateG0Criterion.hxx',['../_geom_plate___plate_g0_criterion_8hxx.html',1,'']]],
   ['geomplate_5fplateg1criterion_2ehxx',['GeomPlate_PlateG1Criterion.hxx',['../_geom_plate___plate_g1_criterion_8hxx.html',1,'']]],
   ['geomplate_5fpointconstraint_2ehxx',['GeomPlate_PointConstraint.hxx',['../_geom_plate___point_constraint_8hxx.html',1,'']]],
-  ['geomplate_5fsequencenodeofsequenceofaij_2ehxx',['GeomPlate_SequenceNodeOfSequenceOfAij.hxx',['../_geom_plate___sequence_node_of_sequence_of_aij_8hxx.html',1,'']]],
-  ['geomplate_5fsequencenodeofsequenceofcurveconstraint_2ehxx',['GeomPlate_SequenceNodeOfSequenceOfCurveConstraint.hxx',['../_geom_plate___sequence_node_of_sequence_of_curve_constraint_8hxx.html',1,'']]],
-  ['geomplate_5fsequencenodeofsequenceofpointconstraint_2ehxx',['GeomPlate_SequenceNodeOfSequenceOfPointConstraint.hxx',['../_geom_plate___sequence_node_of_sequence_of_point_constraint_8hxx.html',1,'']]],
   ['geomplate_5fsequenceofaij_2ehxx',['GeomPlate_SequenceOfAij.hxx',['../_geom_plate___sequence_of_aij_8hxx.html',1,'']]],
   ['geomplate_5fsequenceofcurveconstraint_2ehxx',['GeomPlate_SequenceOfCurveConstraint.hxx',['../_geom_plate___sequence_of_curve_constraint_8hxx.html',1,'']]],
   ['geomplate_5fsequenceofpointconstraint_2ehxx',['GeomPlate_SequenceOfPointConstraint.hxx',['../_geom_plate___sequence_of_point_constraint_8hxx.html',1,'']]],
@@ -501,6 +504,7 @@ var searchData=
   ['gp_5ftrsf_2ehxx',['gp_Trsf.hxx',['../gp___trsf_8hxx.html',1,'']]],
   ['gp_5ftrsf2d_2ehxx',['gp_Trsf2d.hxx',['../gp___trsf2d_8hxx.html',1,'']]],
   ['gp_5ftrsfform_2ehxx',['gp_TrsfForm.hxx',['../gp___trsf_form_8hxx.html',1,'']]],
+  ['gp_5ftrsfnlerp_2ehxx',['gp_TrsfNLerp.hxx',['../gp___trsf_n_lerp_8hxx.html',1,'']]],
   ['gp_5fvec_2ehxx',['gp_Vec.hxx',['../gp___vec_8hxx.html',1,'']]],
   ['gp_5fvec2d_2ehxx',['gp_Vec2d.hxx',['../gp___vec2d_8hxx.html',1,'']]],
   ['gp_5fvectorwithnullmagnitude_2ehxx',['gp_VectorWithNullMagnitude.hxx',['../gp___vector_with_null_magnitude_8hxx.html',1,'']]],
@@ -517,9 +521,6 @@ var searchData=
   ['gprop_5fundefinedaxis_2ehxx',['GProp_UndefinedAxis.hxx',['../_g_prop___undefined_axis_8hxx.html',1,'']]],
   ['gprop_5fvaluetype_2ehxx',['GProp_ValueType.hxx',['../_g_prop___value_type_8hxx.html',1,'']]],
   ['gprop_5fvelgprops_2ehxx',['GProp_VelGProps.hxx',['../_g_prop___vel_g_props_8hxx.html',1,'']]],
-  ['graphic3d_5farray1ofvector_2ehxx',['Graphic3d_Array1OfVector.hxx',['../_graphic3d___array1_of_vector_8hxx.html',1,'']]],
-  ['graphic3d_5farray1ofvertex_2ehxx',['Graphic3d_Array1OfVertex.hxx',['../_graphic3d___array1_of_vertex_8hxx.html',1,'']]],
-  ['graphic3d_5farray2ofvertex_2ehxx',['Graphic3d_Array2OfVertex.hxx',['../_graphic3d___array2_of_vertex_8hxx.html',1,'']]],
   ['graphic3d_5farrayofpoints_2ehxx',['Graphic3d_ArrayOfPoints.hxx',['../_graphic3d___array_of_points_8hxx.html',1,'']]],
   ['graphic3d_5farrayofpolygons_2ehxx',['Graphic3d_ArrayOfPolygons.hxx',['../_graphic3d___array_of_polygons_8hxx.html',1,'']]],
   ['graphic3d_5farrayofpolylines_2ehxx',['Graphic3d_ArrayOfPolylines.hxx',['../_graphic3d___array_of_polylines_8hxx.html',1,'']]],
@@ -535,45 +536,34 @@ var searchData=
   ['graphic3d_5faspectmarker3d_2ehxx',['Graphic3d_AspectMarker3d.hxx',['../_graphic3d___aspect_marker3d_8hxx.html',1,'']]],
   ['graphic3d_5faspecttext3d_2ehxx',['Graphic3d_AspectText3d.hxx',['../_graphic3d___aspect_text3d_8hxx.html',1,'']]],
   ['graphic3d_5faspecttextdefinitionerror_2ehxx',['Graphic3d_AspectTextDefinitionError.hxx',['../_graphic3d___aspect_text_definition_error_8hxx.html',1,'']]],
+  ['graphic3d_5fbndbox3d_2ehxx',['Graphic3d_BndBox3d.hxx',['../_graphic3d___bnd_box3d_8hxx.html',1,'']]],
   ['graphic3d_5fbndbox4d_2ehxx',['Graphic3d_BndBox4d.hxx',['../_graphic3d___bnd_box4d_8hxx.html',1,'']]],
   ['graphic3d_5fbndbox4f_2ehxx',['Graphic3d_BndBox4f.hxx',['../_graphic3d___bnd_box4f_8hxx.html',1,'']]],
   ['graphic3d_5fboundbuffer_2ehxx',['Graphic3d_BoundBuffer.hxx',['../_graphic3d___bound_buffer_8hxx.html',1,'']]],
+  ['graphic3d_5fbsdf_2ehxx',['Graphic3d_BSDF.hxx',['../_graphic3d___b_s_d_f_8hxx.html',1,'']]],
   ['graphic3d_5fbuffer_2ehxx',['Graphic3d_Buffer.hxx',['../_graphic3d___buffer_8hxx.html',1,'']]],
   ['graphic3d_5fbuffertype_2ehxx',['Graphic3d_BufferType.hxx',['../_graphic3d___buffer_type_8hxx.html',1,'']]],
   ['graphic3d_5fcamera_2ehxx',['Graphic3d_Camera.hxx',['../_graphic3d___camera_8hxx.html',1,'']]],
-  ['graphic3d_5fcaspectfillarea_2ehxx',['Graphic3d_CAspectFillArea.hxx',['../_graphic3d___c_aspect_fill_area_8hxx.html',1,'']]],
-  ['graphic3d_5fcaspectline_2ehxx',['Graphic3d_CAspectLine.hxx',['../_graphic3d___c_aspect_line_8hxx.html',1,'']]],
-  ['graphic3d_5fcaspectmarker_2ehxx',['Graphic3d_CAspectMarker.hxx',['../_graphic3d___c_aspect_marker_8hxx.html',1,'']]],
-  ['graphic3d_5fcaspecttext_2ehxx',['Graphic3d_CAspectText.hxx',['../_graphic3d___c_aspect_text_8hxx.html',1,'']]],
-  ['graphic3d_5fcbitfields16_2ehxx',['Graphic3d_CBitFields16.hxx',['../_graphic3d___c_bit_fields16_8hxx.html',1,'']]],
-  ['graphic3d_5fcbitfields20_2ehxx',['Graphic3d_CBitFields20.hxx',['../_graphic3d___c_bit_fields20_8hxx.html',1,'']]],
-  ['graphic3d_5fcbitfields4_2ehxx',['Graphic3d_CBitFields4.hxx',['../_graphic3d___c_bit_fields4_8hxx.html',1,'']]],
-  ['graphic3d_5fcbitfields8_2ehxx',['Graphic3d_CBitFields8.hxx',['../_graphic3d___c_bit_fields8_8hxx.html',1,'']]],
+  ['graphic3d_5fcameratile_2ehxx',['Graphic3d_CameraTile.hxx',['../_graphic3d___camera_tile_8hxx.html',1,'']]],
+  ['graphic3d_5fcappingflags_2ehxx',['Graphic3d_CappingFlags.hxx',['../_graphic3d___capping_flags_8hxx.html',1,'']]],
   ['graphic3d_5fclight_2ehxx',['Graphic3d_CLight.hxx',['../_graphic3d___c_light_8hxx.html',1,'']]],
   ['graphic3d_5fclipplane_2ehxx',['Graphic3d_ClipPlane.hxx',['../_graphic3d___clip_plane_8hxx.html',1,'']]],
   ['graphic3d_5fcstructure_2ehxx',['Graphic3d_CStructure.hxx',['../_graphic3d___c_structure_8hxx.html',1,'']]],
-  ['graphic3d_5fcstructureptr_2ehxx',['Graphic3d_CStructurePtr.hxx',['../_graphic3d___c_structure_ptr_8hxx.html',1,'']]],
   ['graphic3d_5fctexture_2ehxx',['Graphic3d_CTexture.hxx',['../_graphic3d___c_texture_8hxx.html',1,'']]],
-  ['graphic3d_5fctranspersstruct_2ehxx',['Graphic3d_CTransPersStruct.hxx',['../_graphic3d___c_trans_pers_struct_8hxx.html',1,'']]],
-  ['graphic3d_5fcuserdraw_2ehxx',['Graphic3d_CUserDraw.hxx',['../_graphic3d___c_user_draw_8hxx.html',1,'']]],
   ['graphic3d_5fcview_2ehxx',['Graphic3d_CView.hxx',['../_graphic3d___c_view_8hxx.html',1,'']]],
-  ['graphic3d_5fcycleerror_2ehxx',['Graphic3d_CycleError.hxx',['../_graphic3d___cycle_error_8hxx.html',1,'']]],
   ['graphic3d_5fdatastructuremanager_2ehxx',['Graphic3d_DataStructureManager.hxx',['../_graphic3d___data_structure_manager_8hxx.html',1,'']]],
+  ['graphic3d_5fdiagnosticinfo_2ehxx',['Graphic3d_DiagnosticInfo.hxx',['../_graphic3d___diagnostic_info_8hxx.html',1,'']]],
   ['graphic3d_5fexportformat_2ehxx',['Graphic3d_ExportFormat.hxx',['../_graphic3d___export_format_8hxx.html',1,'']]],
   ['graphic3d_5fgraduatedtrihedron_2ehxx',['Graphic3d_GraduatedTrihedron.hxx',['../_graphic3d___graduated_trihedron_8hxx.html',1,'']]],
   ['graphic3d_5fgraphicdriver_2ehxx',['Graphic3d_GraphicDriver.hxx',['../_graphic3d___graphic_driver_8hxx.html',1,'']]],
   ['graphic3d_5fgroup_2ehxx',['Graphic3d_Group.hxx',['../_graphic3d___group_8hxx.html',1,'']]],
   ['graphic3d_5fgroupaspect_2ehxx',['Graphic3d_GroupAspect.hxx',['../_graphic3d___group_aspect_8hxx.html',1,'']]],
   ['graphic3d_5fgroupdefinitionerror_2ehxx',['Graphic3d_GroupDefinitionError.hxx',['../_graphic3d___group_definition_error_8hxx.html',1,'']]],
+  ['graphic3d_5fhighlightstyle_2ehxx',['Graphic3d_HighlightStyle.hxx',['../_graphic3d___highlight_style_8hxx.html',1,'']]],
   ['graphic3d_5fhorizontaltextalignment_2ehxx',['Graphic3d_HorizontalTextAlignment.hxx',['../_graphic3d___horizontal_text_alignment_8hxx.html',1,'']]],
-  ['graphic3d_5fhsequenceofstructure_2ehxx',['Graphic3d_HSequenceOfStructure.hxx',['../_graphic3d___h_sequence_of_structure_8hxx.html',1,'']]],
   ['graphic3d_5findexbuffer_2ehxx',['Graphic3d_IndexBuffer.hxx',['../_graphic3d___index_buffer_8hxx.html',1,'']]],
   ['graphic3d_5findexedmapofaddress_2ehxx',['Graphic3d_IndexedMapOfAddress.hxx',['../_graphic3d___indexed_map_of_address_8hxx.html',1,'']]],
-  ['graphic3d_5finitialisationerror_2ehxx',['Graphic3d_InitialisationError.hxx',['../_graphic3d___initialisation_error_8hxx.html',1,'']]],
   ['graphic3d_5fleveloftextureanisotropy_2ehxx',['Graphic3d_LevelOfTextureAnisotropy.hxx',['../_graphic3d___level_of_texture_anisotropy_8hxx.html',1,'']]],
-  ['graphic3d_5flistiteratoroflistofshortreal_2ehxx',['Graphic3d_ListIteratorOfListOfShortReal.hxx',['../_graphic3d___list_iterator_of_list_of_short_real_8hxx.html',1,'']]],
-  ['graphic3d_5flistnodeoflistofshortreal_2ehxx',['Graphic3d_ListNodeOfListOfShortReal.hxx',['../_graphic3d___list_node_of_list_of_short_real_8hxx.html',1,'']]],
-  ['graphic3d_5flistofshortreal_2ehxx',['Graphic3d_ListOfShortReal.hxx',['../_graphic3d___list_of_short_real_8hxx.html',1,'']]],
   ['graphic3d_5fmapiteratorofmapofstructure_2ehxx',['Graphic3d_MapIteratorOfMapOfStructure.hxx',['../_graphic3d___map_iterator_of_map_of_structure_8hxx.html',1,'']]],
   ['graphic3d_5fmapofobject_2ehxx',['Graphic3d_MapOfObject.hxx',['../_graphic3d___map_of_object_8hxx.html',1,'']]],
   ['graphic3d_5fmapofstructure_2ehxx',['Graphic3d_MapOfStructure.hxx',['../_graphic3d___map_of_structure_8hxx.html',1,'']]],
@@ -587,16 +577,15 @@ var searchData=
   ['graphic3d_5fnameoftexture2d_2ehxx',['Graphic3d_NameOfTexture2D.hxx',['../_graphic3d___name_of_texture2_d_8hxx.html',1,'']]],
   ['graphic3d_5fnameoftextureenv_2ehxx',['Graphic3d_NameOfTextureEnv.hxx',['../_graphic3d___name_of_texture_env_8hxx.html',1,'']]],
   ['graphic3d_5fnameoftextureplane_2ehxx',['Graphic3d_NameOfTexturePlane.hxx',['../_graphic3d___name_of_texture_plane_8hxx.html',1,'']]],
-  ['graphic3d_5fnlistofhasciistring_2ehxx',['Graphic3d_NListOfHAsciiString.hxx',['../_graphic3d___n_list_of_h_ascii_string_8hxx.html',1,'']]],
   ['graphic3d_5fnmapoftransient_2ehxx',['Graphic3d_NMapOfTransient.hxx',['../_graphic3d___n_map_of_transient_8hxx.html',1,'']]],
+  ['graphic3d_5fpolygonoffset_2ehxx',['Graphic3d_PolygonOffset.hxx',['../_graphic3d___polygon_offset_8hxx.html',1,'']]],
   ['graphic3d_5fprioritydefinitionerror_2ehxx',['Graphic3d_PriorityDefinitionError.hxx',['../_graphic3d___priority_definition_error_8hxx.html',1,'']]],
-  ['graphic3d_5fptrframebuffer_2ehxx',['Graphic3d_PtrFrameBuffer.hxx',['../_graphic3d___ptr_frame_buffer_8hxx.html',1,'']]],
   ['graphic3d_5frenderingmode_2ehxx',['Graphic3d_RenderingMode.hxx',['../_graphic3d___rendering_mode_8hxx.html',1,'']]],
   ['graphic3d_5frenderingparams_2ehxx',['Graphic3d_RenderingParams.hxx',['../_graphic3d___rendering_params_8hxx.html',1,'']]],
-  ['graphic3d_5fsequencenodeofsequenceofstructure_2ehxx',['Graphic3d_SequenceNodeOfSequenceOfStructure.hxx',['../_graphic3d___sequence_node_of_sequence_of_structure_8hxx.html',1,'']]],
   ['graphic3d_5fsequenceofgroup_2ehxx',['Graphic3d_SequenceOfGroup.hxx',['../_graphic3d___sequence_of_group_8hxx.html',1,'']]],
   ['graphic3d_5fsequenceofhclipplane_2ehxx',['Graphic3d_SequenceOfHClipPlane.hxx',['../_graphic3d___sequence_of_h_clip_plane_8hxx.html',1,'']]],
   ['graphic3d_5fsequenceofstructure_2ehxx',['Graphic3d_SequenceOfStructure.hxx',['../_graphic3d___sequence_of_structure_8hxx.html',1,'']]],
+  ['graphic3d_5fshaderattribute_2ehxx',['Graphic3d_ShaderAttribute.hxx',['../_graphic3d___shader_attribute_8hxx.html',1,'']]],
   ['graphic3d_5fshaderobject_2ehxx',['Graphic3d_ShaderObject.hxx',['../_graphic3d___shader_object_8hxx.html',1,'']]],
   ['graphic3d_5fshaderprogram_2ehxx',['Graphic3d_ShaderProgram.hxx',['../_graphic3d___shader_program_8hxx.html',1,'']]],
   ['graphic3d_5fshadervariable_2ehxx',['Graphic3d_ShaderVariable.hxx',['../_graphic3d___shader_variable_8hxx.html',1,'']]],
@@ -605,8 +594,6 @@ var searchData=
   ['graphic3d_5fstructure_2ehxx',['Graphic3d_Structure.hxx',['../_graphic3d___structure_8hxx.html',1,'']]],
   ['graphic3d_5fstructuredefinitionerror_2ehxx',['Graphic3d_StructureDefinitionError.hxx',['../_graphic3d___structure_definition_error_8hxx.html',1,'']]],
   ['graphic3d_5fstructuremanager_2ehxx',['Graphic3d_StructureManager.hxx',['../_graphic3d___structure_manager_8hxx.html',1,'']]],
-  ['graphic3d_5fstructuremanagerptr_2ehxx',['Graphic3d_StructureManagerPtr.hxx',['../_graphic3d___structure_manager_ptr_8hxx.html',1,'']]],
-  ['graphic3d_5fstructureptr_2ehxx',['Graphic3d_StructurePtr.hxx',['../_graphic3d___structure_ptr_8hxx.html',1,'']]],
   ['graphic3d_5ftextpath_2ehxx',['Graphic3d_TextPath.hxx',['../_graphic3d___text_path_8hxx.html',1,'']]],
   ['graphic3d_5ftexture1d_2ehxx',['Graphic3d_Texture1D.hxx',['../_graphic3d___texture1_d_8hxx.html',1,'']]],
   ['graphic3d_5ftexture1dmanual_2ehxx',['Graphic3d_Texture1Dmanual.hxx',['../_graphic3d___texture1_dmanual_8hxx.html',1,'']]],
@@ -619,20 +606,26 @@ var searchData=
   ['graphic3d_5ftextureparams_2ehxx',['Graphic3d_TextureParams.hxx',['../_graphic3d___texture_params_8hxx.html',1,'']]],
   ['graphic3d_5ftextureroot_2ehxx',['Graphic3d_TextureRoot.hxx',['../_graphic3d___texture_root_8hxx.html',1,'']]],
   ['graphic3d_5ftransformerror_2ehxx',['Graphic3d_TransformError.hxx',['../_graphic3d___transform_error_8hxx.html',1,'']]],
+  ['graphic3d_5ftransformpers_2ehxx',['Graphic3d_TransformPers.hxx',['../_graphic3d___transform_pers_8hxx.html',1,'']]],
+  ['graphic3d_5ftransformutils_2ehxx',['Graphic3d_TransformUtils.hxx',['../_graphic3d___transform_utils_8hxx.html',1,'']]],
   ['graphic3d_5ftransmodeflags_2ehxx',['Graphic3d_TransModeFlags.hxx',['../_graphic3d___trans_mode_flags_8hxx.html',1,'']]],
+  ['graphic3d_5ftypeofanswer_2ehxx',['Graphic3d_TypeOfAnswer.hxx',['../_graphic3d___type_of_answer_8hxx.html',1,'']]],
+  ['graphic3d_5ftypeofbackfacingmodel_2ehxx',['Graphic3d_TypeOfBackfacingModel.hxx',['../_graphic3d___type_of_backfacing_model_8hxx.html',1,'']]],
   ['graphic3d_5ftypeofbackground_2ehxx',['Graphic3d_TypeOfBackground.hxx',['../_graphic3d___type_of_background_8hxx.html',1,'']]],
   ['graphic3d_5ftypeofcomposition_2ehxx',['Graphic3d_TypeOfComposition.hxx',['../_graphic3d___type_of_composition_8hxx.html',1,'']]],
   ['graphic3d_5ftypeofconnection_2ehxx',['Graphic3d_TypeOfConnection.hxx',['../_graphic3d___type_of_connection_8hxx.html',1,'']]],
+  ['graphic3d_5ftypeoflightsource_2ehxx',['Graphic3d_TypeOfLightSource.hxx',['../_graphic3d___type_of_light_source_8hxx.html',1,'']]],
+  ['graphic3d_5ftypeoflimit_2ehxx',['Graphic3d_TypeOfLimit.hxx',['../_graphic3d___type_of_limit_8hxx.html',1,'']]],
   ['graphic3d_5ftypeofmaterial_2ehxx',['Graphic3d_TypeOfMaterial.hxx',['../_graphic3d___type_of_material_8hxx.html',1,'']]],
-  ['graphic3d_5ftypeofpolygon_2ehxx',['Graphic3d_TypeOfPolygon.hxx',['../_graphic3d___type_of_polygon_8hxx.html',1,'']]],
-  ['graphic3d_5ftypeofprimitive_2ehxx',['Graphic3d_TypeOfPrimitive.hxx',['../_graphic3d___type_of_primitive_8hxx.html',1,'']]],
   ['graphic3d_5ftypeofprimitivearray_2ehxx',['Graphic3d_TypeOfPrimitiveArray.hxx',['../_graphic3d___type_of_primitive_array_8hxx.html',1,'']]],
   ['graphic3d_5ftypeofreflection_2ehxx',['Graphic3d_TypeOfReflection.hxx',['../_graphic3d___type_of_reflection_8hxx.html',1,'']]],
   ['graphic3d_5ftypeofshaderobject_2ehxx',['Graphic3d_TypeOfShaderObject.hxx',['../_graphic3d___type_of_shader_object_8hxx.html',1,'']]],
+  ['graphic3d_5ftypeofshadingmodel_2ehxx',['Graphic3d_TypeOfShadingModel.hxx',['../_graphic3d___type_of_shading_model_8hxx.html',1,'']]],
   ['graphic3d_5ftypeofstructure_2ehxx',['Graphic3d_TypeOfStructure.hxx',['../_graphic3d___type_of_structure_8hxx.html',1,'']]],
   ['graphic3d_5ftypeoftexture_2ehxx',['Graphic3d_TypeOfTexture.hxx',['../_graphic3d___type_of_texture_8hxx.html',1,'']]],
   ['graphic3d_5ftypeoftexturefilter_2ehxx',['Graphic3d_TypeOfTextureFilter.hxx',['../_graphic3d___type_of_texture_filter_8hxx.html',1,'']]],
   ['graphic3d_5ftypeoftexturemode_2ehxx',['Graphic3d_TypeOfTextureMode.hxx',['../_graphic3d___type_of_texture_mode_8hxx.html',1,'']]],
+  ['graphic3d_5ftypeofvisualization_2ehxx',['Graphic3d_TypeOfVisualization.hxx',['../_graphic3d___type_of_visualization_8hxx.html',1,'']]],
   ['graphic3d_5fvec_2ehxx',['Graphic3d_Vec.hxx',['../_graphic3d___vec_8hxx.html',1,'']]],
   ['graphic3d_5fvec2_2ehxx',['Graphic3d_Vec2.hxx',['../_graphic3d___vec2_8hxx.html',1,'']]],
   ['graphic3d_5fvec3_2ehxx',['Graphic3d_Vec3.hxx',['../_graphic3d___vec3_8hxx.html',1,'']]],
@@ -642,6 +635,7 @@ var searchData=
   ['graphic3d_5fvertex_2ehxx',['Graphic3d_Vertex.hxx',['../_graphic3d___vertex_8hxx.html',1,'']]],
   ['graphic3d_5fverticaltextalignment_2ehxx',['Graphic3d_VerticalTextAlignment.hxx',['../_graphic3d___vertical_text_alignment_8hxx.html',1,'']]],
   ['graphic3d_5fviewaffinity_2ehxx',['Graphic3d_ViewAffinity.hxx',['../_graphic3d___view_affinity_8hxx.html',1,'']]],
+  ['graphic3d_5fworldviewprojstate_2ehxx',['Graphic3d_WorldViewProjState.hxx',['../_graphic3d___world_view_proj_state_8hxx.html',1,'']]],
   ['graphic3d_5fzlayerid_2ehxx',['Graphic3d_ZLayerId.hxx',['../_graphic3d___z_layer_id_8hxx.html',1,'']]],
   ['graphic3d_5fzlayersettings_2ehxx',['Graphic3d_ZLayerSettings.hxx',['../_graphic3d___z_layer_settings_8hxx.html',1,'']]]
 ];
