@@ -4,8 +4,6 @@ var searchData=
   ['hatch_5fline_2ehxx',['Hatch_Line.hxx',['../_hatch___line_8hxx.html',1,'']]],
   ['hatch_5flineform_2ehxx',['Hatch_LineForm.hxx',['../_hatch___line_form_8hxx.html',1,'']]],
   ['hatch_5fparameter_2ehxx',['Hatch_Parameter.hxx',['../_hatch___parameter_8hxx.html',1,'']]],
-  ['hatch_5fsequencenodeofsequenceofline_2ehxx',['Hatch_SequenceNodeOfSequenceOfLine.hxx',['../_hatch___sequence_node_of_sequence_of_line_8hxx.html',1,'']]],
-  ['hatch_5fsequencenodeofsequenceofparameter_2ehxx',['Hatch_SequenceNodeOfSequenceOfParameter.hxx',['../_hatch___sequence_node_of_sequence_of_parameter_8hxx.html',1,'']]],
   ['hatch_5fsequenceofline_2ehxx',['Hatch_SequenceOfLine.hxx',['../_hatch___sequence_of_line_8hxx.html',1,'']]],
   ['hatch_5fsequenceofparameter_2ehxx',['Hatch_SequenceOfParameter.hxx',['../_hatch___sequence_of_parameter_8hxx.html',1,'']]],
   ['hatchgen_5fdomain_2ehxx',['HatchGen_Domain.hxx',['../_hatch_gen___domain_8hxx.html',1,'']]],
@@ -17,9 +15,6 @@ var searchData=
   ['hatchgen_5fpointonhatching_2ehxx',['HatchGen_PointOnHatching.hxx',['../_hatch_gen___point_on_hatching_8hxx.html',1,'']]],
   ['hatchgen_5fpointsonelement_2ehxx',['HatchGen_PointsOnElement.hxx',['../_hatch_gen___points_on_element_8hxx.html',1,'']]],
   ['hatchgen_5fpointsonhatching_2ehxx',['HatchGen_PointsOnHatching.hxx',['../_hatch_gen___points_on_hatching_8hxx.html',1,'']]],
-  ['hatchgen_5fsequencenodeofdomains_2ehxx',['HatchGen_SequenceNodeOfDomains.hxx',['../_hatch_gen___sequence_node_of_domains_8hxx.html',1,'']]],
-  ['hatchgen_5fsequencenodeofpointsonelement_2ehxx',['HatchGen_SequenceNodeOfPointsOnElement.hxx',['../_hatch_gen___sequence_node_of_points_on_element_8hxx.html',1,'']]],
-  ['hatchgen_5fsequencenodeofpointsonhatching_2ehxx',['HatchGen_SequenceNodeOfPointsOnHatching.hxx',['../_hatch_gen___sequence_node_of_points_on_hatching_8hxx.html',1,'']]],
   ['headersection_2ehxx',['HeaderSection.hxx',['../_header_section_8hxx.html',1,'']]],
   ['headersection_5ffiledescription_2ehxx',['HeaderSection_FileDescription.hxx',['../_header_section___file_description_8hxx.html',1,'']]],
   ['headersection_5ffilename_2ehxx',['HeaderSection_FileName.hxx',['../_header_section___file_name_8hxx.html',1,'']]],
@@ -46,8 +41,6 @@ var searchData=
   ['hlralgo_5fintersection_2ehxx',['HLRAlgo_Intersection.hxx',['../_h_l_r_algo___intersection_8hxx.html',1,'']]],
   ['hlralgo_5flistiteratorofinterferencelist_2ehxx',['HLRAlgo_ListIteratorOfInterferenceList.hxx',['../_h_l_r_algo___list_iterator_of_interference_list_8hxx.html',1,'']]],
   ['hlralgo_5flistiteratoroflistofbpoint_2ehxx',['HLRAlgo_ListIteratorOfListOfBPoint.hxx',['../_h_l_r_algo___list_iterator_of_list_of_b_point_8hxx.html',1,'']]],
-  ['hlralgo_5flistnodeofinterferencelist_2ehxx',['HLRAlgo_ListNodeOfInterferenceList.hxx',['../_h_l_r_algo___list_node_of_interference_list_8hxx.html',1,'']]],
-  ['hlralgo_5flistnodeoflistofbpoint_2ehxx',['HLRAlgo_ListNodeOfListOfBPoint.hxx',['../_h_l_r_algo___list_node_of_list_of_b_point_8hxx.html',1,'']]],
   ['hlralgo_5flistofbpoint_2ehxx',['HLRAlgo_ListOfBPoint.hxx',['../_h_l_r_algo___list_of_b_point_8hxx.html',1,'']]],
   ['hlralgo_5fpolyalgo_2ehxx',['HLRAlgo_PolyAlgo.hxx',['../_h_l_r_algo___poly_algo_8hxx.html',1,'']]],
   ['hlralgo_5fpolydata_2ehxx',['HLRAlgo_PolyData.hxx',['../_h_l_r_algo___poly_data_8hxx.html',1,'']]],
@@ -55,6 +48,7 @@ var searchData=
   ['hlralgo_5fpolyinternaldata_2ehxx',['HLRAlgo_PolyInternalData.hxx',['../_h_l_r_algo___poly_internal_data_8hxx.html',1,'']]],
   ['hlralgo_5fpolyinternalnode_2ehxx',['HLRAlgo_PolyInternalNode.hxx',['../_h_l_r_algo___poly_internal_node_8hxx.html',1,'']]],
   ['hlralgo_5fpolyinternalsegment_2ehxx',['HLRAlgo_PolyInternalSegment.hxx',['../_h_l_r_algo___poly_internal_segment_8hxx.html',1,'']]],
+  ['hlralgo_5fpolymask_2ehxx',['HLRAlgo_PolyMask.hxx',['../_h_l_r_algo___poly_mask_8hxx.html',1,'']]],
   ['hlralgo_5fpolyshelldata_2ehxx',['HLRAlgo_PolyShellData.hxx',['../_h_l_r_algo___poly_shell_data_8hxx.html',1,'']]],
   ['hlralgo_5fprojector_2ehxx',['HLRAlgo_Projector.hxx',['../_h_l_r_algo___projector_8hxx.html',1,'']]],
   ['hlralgo_5ftriangledata_2ehxx',['HLRAlgo_TriangleData.hxx',['../_h_l_r_algo___triangle_data_8hxx.html',1,'']]],
@@ -92,8 +86,6 @@ var searchData=
   ['hlrbrep_5flinetool_2ehxx',['HLRBRep_LineTool.hxx',['../_h_l_r_b_rep___line_tool_8hxx.html',1,'']]],
   ['hlrbrep_5flistiteratoroflistofbpnt2d_2ehxx',['HLRBRep_ListIteratorOfListOfBPnt2D.hxx',['../_h_l_r_b_rep___list_iterator_of_list_of_b_pnt2_d_8hxx.html',1,'']]],
   ['hlrbrep_5flistiteratoroflistofbpoint_2ehxx',['HLRBRep_ListIteratorOfListOfBPoint.hxx',['../_h_l_r_b_rep___list_iterator_of_list_of_b_point_8hxx.html',1,'']]],
-  ['hlrbrep_5flistnodeoflistofbpnt2d_2ehxx',['HLRBRep_ListNodeOfListOfBPnt2D.hxx',['../_h_l_r_b_rep___list_node_of_list_of_b_pnt2_d_8hxx.html',1,'']]],
-  ['hlrbrep_5flistnodeoflistofbpoint_2ehxx',['HLRBRep_ListNodeOfListOfBPoint.hxx',['../_h_l_r_b_rep___list_node_of_list_of_b_point_8hxx.html',1,'']]],
   ['hlrbrep_5flistofbpnt2d_2ehxx',['HLRBRep_ListOfBPnt2D.hxx',['../_h_l_r_b_rep___list_of_b_pnt2_d_8hxx.html',1,'']]],
   ['hlrbrep_5flistofbpoint_2ehxx',['HLRBRep_ListOfBPoint.hxx',['../_h_l_r_b_rep___list_of_b_point_8hxx.html',1,'']]],
   ['hlrbrep_5fmyimppartooloftheintersectoroftheintconiccurveofcinter_2ehxx',['HLRBRep_MyImpParToolOfTheIntersectorOfTheIntConicCurveOfCInter.hxx',['../_h_l_r_b_rep___my_imp_par_tool_of_the_intersector_of_the_int_conic_curve_of_c_inter_8hxx.html',1,'']]],
@@ -101,9 +93,6 @@ var searchData=
   ['hlrbrep_5fpolyalgo_2ehxx',['HLRBRep_PolyAlgo.hxx',['../_h_l_r_b_rep___poly_algo_8hxx.html',1,'']]],
   ['hlrbrep_5fpolyhlrtoshape_2ehxx',['HLRBRep_PolyHLRToShape.hxx',['../_h_l_r_b_rep___poly_h_l_r_to_shape_8hxx.html',1,'']]],
   ['hlrbrep_5fseqofshapebounds_2ehxx',['HLRBRep_SeqOfShapeBounds.hxx',['../_h_l_r_b_rep___seq_of_shape_bounds_8hxx.html',1,'']]],
-  ['hlrbrep_5fseqpcofpclocfofthelocateextpcoftheprojpcurofcinter_2ehxx',['HLRBRep_SeqPCOfPCLocFOfTheLocateExtPCOfTheProjPCurOfCInter.hxx',['../_h_l_r_b_rep___seq_p_c_of_p_c_loc_f_of_the_locate_ext_p_c_of_the_proj_p_cur_of_c_inter_8hxx.html',1,'']]],
-  ['hlrbrep_5fsequencenodeofseqofshapebounds_2ehxx',['HLRBRep_SequenceNodeOfSeqOfShapeBounds.hxx',['../_h_l_r_b_rep___sequence_node_of_seq_of_shape_bounds_8hxx.html',1,'']]],
-  ['hlrbrep_5fsequencenodeofseqpcofpclocfofthelocateextpcoftheprojpcurofcinter_2ehxx',['HLRBRep_SequenceNodeOfSeqPCOfPCLocFOfTheLocateExtPCOfTheProjPCurOfCInter.hxx',['../_h_l_r_b_rep___sequence_node_of_seq_p_c_of_p_c_loc_f_of_the_locate_ext_p_c_of_the_proj_p_cur_of_c_inter_8hxx.html',1,'']]],
   ['hlrbrep_5fshapebounds_2ehxx',['HLRBRep_ShapeBounds.hxx',['../_h_l_r_b_rep___shape_bounds_8hxx.html',1,'']]],
   ['hlrbrep_5fshapetohlr_2ehxx',['HLRBRep_ShapeToHLR.hxx',['../_h_l_r_b_rep___shape_to_h_l_r_8hxx.html',1,'']]],
   ['hlrbrep_5fslprops_2ehxx',['HLRBRep_SLProps.hxx',['../_h_l_r_b_rep___s_l_props_8hxx.html',1,'']]],
@@ -127,6 +116,7 @@ var searchData=
   ['hlrbrep_5ftheprojpcurofcinter_2ehxx',['HLRBRep_TheProjPCurOfCInter.hxx',['../_h_l_r_b_rep___the_proj_p_cur_of_c_inter_8hxx.html',1,'']]],
   ['hlrbrep_5fthequadcurvexactintercsurf_2ehxx',['HLRBRep_TheQuadCurvExactInterCSurf.hxx',['../_h_l_r_b_rep___the_quad_curv_exact_inter_c_surf_8hxx.html',1,'']]],
   ['hlrbrep_5fthequadcurvfuncofthequadcurvexactintercsurf_2ehxx',['HLRBRep_TheQuadCurvFuncOfTheQuadCurvExactInterCSurf.hxx',['../_h_l_r_b_rep___the_quad_curv_func_of_the_quad_curv_exact_inter_c_surf_8hxx.html',1,'']]],
+  ['hlrbrep_5ftypeofresultingedge_2ehxx',['HLRBRep_TypeOfResultingEdge.hxx',['../_h_l_r_b_rep___type_of_resulting_edge_8hxx.html',1,'']]],
   ['hlrbrep_5fvertexlist_2ehxx',['HLRBRep_VertexList.hxx',['../_h_l_r_b_rep___vertex_list_8hxx.html',1,'']]],
   ['hlrtest_2ehxx',['HLRTest.hxx',['../_h_l_r_test_8hxx.html',1,'']]],
   ['hlrtest_5fdrawableedgetool_2ehxx',['HLRTest_DrawableEdgeTool.hxx',['../_h_l_r_test___drawable_edge_tool_8hxx.html',1,'']]],
@@ -137,14 +127,11 @@ var searchData=
   ['hlrtopobrep_5fdata_2ehxx',['HLRTopoBRep_Data.hxx',['../_h_l_r_topo_b_rep___data_8hxx.html',1,'']]],
   ['hlrtopobrep_5fdatamapiteratorofdatamapofshapefacedata_2ehxx',['HLRTopoBRep_DataMapIteratorOfDataMapOfShapeFaceData.hxx',['../_h_l_r_topo_b_rep___data_map_iterator_of_data_map_of_shape_face_data_8hxx.html',1,'']]],
   ['hlrtopobrep_5fdatamapiteratorofmapofshapelistofvdata_2ehxx',['HLRTopoBRep_DataMapIteratorOfMapOfShapeListOfVData.hxx',['../_h_l_r_topo_b_rep___data_map_iterator_of_map_of_shape_list_of_v_data_8hxx.html',1,'']]],
-  ['hlrtopobrep_5fdatamapnodeofdatamapofshapefacedata_2ehxx',['HLRTopoBRep_DataMapNodeOfDataMapOfShapeFaceData.hxx',['../_h_l_r_topo_b_rep___data_map_node_of_data_map_of_shape_face_data_8hxx.html',1,'']]],
-  ['hlrtopobrep_5fdatamapnodeofmapofshapelistofvdata_2ehxx',['HLRTopoBRep_DataMapNodeOfMapOfShapeListOfVData.hxx',['../_h_l_r_topo_b_rep___data_map_node_of_map_of_shape_list_of_v_data_8hxx.html',1,'']]],
   ['hlrtopobrep_5fdatamapofshapefacedata_2ehxx',['HLRTopoBRep_DataMapOfShapeFaceData.hxx',['../_h_l_r_topo_b_rep___data_map_of_shape_face_data_8hxx.html',1,'']]],
   ['hlrtopobrep_5fdsfiller_2ehxx',['HLRTopoBRep_DSFiller.hxx',['../_h_l_r_topo_b_rep___d_s_filler_8hxx.html',1,'']]],
   ['hlrtopobrep_5ffacedata_2ehxx',['HLRTopoBRep_FaceData.hxx',['../_h_l_r_topo_b_rep___face_data_8hxx.html',1,'']]],
   ['hlrtopobrep_5ffaceisoliner_2ehxx',['HLRTopoBRep_FaceIsoLiner.hxx',['../_h_l_r_topo_b_rep___face_iso_liner_8hxx.html',1,'']]],
   ['hlrtopobrep_5flistiteratoroflistofvdata_2ehxx',['HLRTopoBRep_ListIteratorOfListOfVData.hxx',['../_h_l_r_topo_b_rep___list_iterator_of_list_of_v_data_8hxx.html',1,'']]],
-  ['hlrtopobrep_5flistnodeoflistofvdata_2ehxx',['HLRTopoBRep_ListNodeOfListOfVData.hxx',['../_h_l_r_topo_b_rep___list_node_of_list_of_v_data_8hxx.html',1,'']]],
   ['hlrtopobrep_5flistofvdata_2ehxx',['HLRTopoBRep_ListOfVData.hxx',['../_h_l_r_topo_b_rep___list_of_v_data_8hxx.html',1,'']]],
   ['hlrtopobrep_5fmapofshapelistofvdata_2ehxx',['HLRTopoBRep_MapOfShapeListOfVData.hxx',['../_h_l_r_topo_b_rep___map_of_shape_list_of_v_data_8hxx.html',1,'']]],
   ['hlrtopobrep_5foutliner_2ehxx',['HLRTopoBRep_OutLiner.hxx',['../_h_l_r_topo_b_rep___out_liner_8hxx.html',1,'']]],
