@@ -3,15 +3,12 @@ var searchData=
   ['resource_5fconvertunicode_2ehxx',['Resource_ConvertUnicode.hxx',['../_resource___convert_unicode_8hxx.html',1,'']]],
   ['resource_5fdatamapiteratorofdatamapofasciistringasciistring_2ehxx',['Resource_DataMapIteratorOfDataMapOfAsciiStringAsciiString.hxx',['../_resource___data_map_iterator_of_data_map_of_ascii_string_ascii_string_8hxx.html',1,'']]],
   ['resource_5fdatamapiteratorofdatamapofasciistringextendedstring_2ehxx',['Resource_DataMapIteratorOfDataMapOfAsciiStringExtendedString.hxx',['../_resource___data_map_iterator_of_data_map_of_ascii_string_extended_string_8hxx.html',1,'']]],
-  ['resource_5fdatamapnodeofdatamapofasciistringasciistring_2ehxx',['Resource_DataMapNodeOfDataMapOfAsciiStringAsciiString.hxx',['../_resource___data_map_node_of_data_map_of_ascii_string_ascii_string_8hxx.html',1,'']]],
-  ['resource_5fdatamapnodeofdatamapofasciistringextendedstring_2ehxx',['Resource_DataMapNodeOfDataMapOfAsciiStringExtendedString.hxx',['../_resource___data_map_node_of_data_map_of_ascii_string_extended_string_8hxx.html',1,'']]],
   ['resource_5fdatamapofasciistringasciistring_2ehxx',['Resource_DataMapOfAsciiStringAsciiString.hxx',['../_resource___data_map_of_ascii_string_ascii_string_8hxx.html',1,'']]],
   ['resource_5fdatamapofasciistringextendedstring_2ehxx',['Resource_DataMapOfAsciiStringExtendedString.hxx',['../_resource___data_map_of_ascii_string_extended_string_8hxx.html',1,'']]],
   ['resource_5fformattype_2ehxx',['Resource_FormatType.hxx',['../_resource___format_type_8hxx.html',1,'']]],
   ['resource_5flexicalcompare_2ehxx',['Resource_LexicalCompare.hxx',['../_resource___lexical_compare_8hxx.html',1,'']]],
   ['resource_5fmanager_2ehxx',['Resource_Manager.hxx',['../_resource___manager_8hxx.html',1,'']]],
   ['resource_5fnosuchresource_2ehxx',['Resource_NoSuchResource.hxx',['../_resource___no_such_resource_8hxx.html',1,'']]],
-  ['resource_5fquicksortofarray1_2ehxx',['Resource_QuickSortOfArray1.hxx',['../_resource___quick_sort_of_array1_8hxx.html',1,'']]],
   ['resource_5funicode_2ehxx',['Resource_Unicode.hxx',['../_resource___unicode_8hxx.html',1,'']]],
   ['rwheadersection_2ehxx',['RWHeaderSection.hxx',['../_r_w_header_section_8hxx.html',1,'']]],
   ['rwheadersection_5fgeneralmodule_2ehxx',['RWHeaderSection_GeneralModule.hxx',['../_r_w_header_section___general_module_8hxx.html',1,'']]],
@@ -59,6 +56,10 @@ var searchData=
   ['rwstepap214_5frwexternallydefinedclass_2ehxx',['RWStepAP214_RWExternallyDefinedClass.hxx',['../_r_w_step_a_p214___r_w_externally_defined_class_8hxx.html',1,'']]],
   ['rwstepap214_5frwexternallydefinedgeneralproperty_2ehxx',['RWStepAP214_RWExternallyDefinedGeneralProperty.hxx',['../_r_w_step_a_p214___r_w_externally_defined_general_property_8hxx.html',1,'']]],
   ['rwstepap214_5frwrepitemgroup_2ehxx',['RWStepAP214_RWRepItemGroup.hxx',['../_r_w_step_a_p214___r_w_rep_item_group_8hxx.html',1,'']]],
+  ['rwstepap242_5frwdraughtingmodelitemassociation_2ehxx',['RWStepAP242_RWDraughtingModelItemAssociation.hxx',['../_r_w_step_a_p242___r_w_draughting_model_item_association_8hxx.html',1,'']]],
+  ['rwstepap242_5frwgeometricitemspecificusage_2ehxx',['RWStepAP242_RWGeometricItemSpecificUsage.hxx',['../_r_w_step_a_p242___r_w_geometric_item_specific_usage_8hxx.html',1,'']]],
+  ['rwstepap242_5frwidattribute_2ehxx',['RWStepAP242_RWIdAttribute.hxx',['../_r_w_step_a_p242___r_w_id_attribute_8hxx.html',1,'']]],
+  ['rwstepap242_5frwitemidentifiedrepresentationusage_2ehxx',['RWStepAP242_RWItemIdentifiedRepresentationUsage.hxx',['../_r_w_step_a_p242___r_w_item_identified_representation_usage_8hxx.html',1,'']]],
   ['rwstepbasic_5frwaction_2ehxx',['RWStepBasic_RWAction.hxx',['../_r_w_step_basic___r_w_action_8hxx.html',1,'']]],
   ['rwstepbasic_5frwactionassignment_2ehxx',['RWStepBasic_RWActionAssignment.hxx',['../_r_w_step_basic___r_w_action_assignment_8hxx.html',1,'']]],
   ['rwstepbasic_5frwactionmethod_2ehxx',['RWStepBasic_RWActionMethod.hxx',['../_r_w_step_basic___r_w_action_method_8hxx.html',1,'']]],
@@ -150,6 +151,8 @@ var searchData=
   ['rwstepbasic_5frwproductdefinitionformation_2ehxx',['RWStepBasic_RWProductDefinitionFormation.hxx',['../_r_w_step_basic___r_w_product_definition_formation_8hxx.html',1,'']]],
   ['rwstepbasic_5frwproductdefinitionformationrelationship_2ehxx',['RWStepBasic_RWProductDefinitionFormationRelationship.hxx',['../_r_w_step_basic___r_w_product_definition_formation_relationship_8hxx.html',1,'']]],
   ['rwstepbasic_5frwproductdefinitionformationwithspecifiedsource_2ehxx',['RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource.hxx',['../_r_w_step_basic___r_w_product_definition_formation_with_specified_source_8hxx.html',1,'']]],
+  ['rwstepbasic_5frwproductdefinitionreference_2ehxx',['RWStepBasic_RWProductDefinitionReference.hxx',['../_r_w_step_basic___r_w_product_definition_reference_8hxx.html',1,'']]],
+  ['rwstepbasic_5frwproductdefinitionreferencewithlocalrepresentation_2ehxx',['RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation.hxx',['../_r_w_step_basic___r_w_product_definition_reference_with_local_representation_8hxx.html',1,'']]],
   ['rwstepbasic_5frwproductdefinitionrelationship_2ehxx',['RWStepBasic_RWProductDefinitionRelationship.hxx',['../_r_w_step_basic___r_w_product_definition_relationship_8hxx.html',1,'']]],
   ['rwstepbasic_5frwproductdefinitionwithassociateddocuments_2ehxx',['RWStepBasic_RWProductDefinitionWithAssociatedDocuments.hxx',['../_r_w_step_basic___r_w_product_definition_with_associated_documents_8hxx.html',1,'']]],
   ['rwstepbasic_5frwproductrelatedproductcategory_2ehxx',['RWStepBasic_RWProductRelatedProductCategory.hxx',['../_r_w_step_basic___r_w_product_related_product_category_8hxx.html',1,'']]],
@@ -183,23 +186,46 @@ var searchData=
   ['rwstepdimtol_5frwdatum_2ehxx',['RWStepDimTol_RWDatum.hxx',['../_r_w_step_dim_tol___r_w_datum_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwdatumfeature_2ehxx',['RWStepDimTol_RWDatumFeature.hxx',['../_r_w_step_dim_tol___r_w_datum_feature_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwdatumreference_2ehxx',['RWStepDimTol_RWDatumReference.hxx',['../_r_w_step_dim_tol___r_w_datum_reference_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwdatumreferencecompartment_2ehxx',['RWStepDimTol_RWDatumReferenceCompartment.hxx',['../_r_w_step_dim_tol___r_w_datum_reference_compartment_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwdatumreferenceelement_2ehxx',['RWStepDimTol_RWDatumReferenceElement.hxx',['../_r_w_step_dim_tol___r_w_datum_reference_element_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwdatumreferencemodifierwithvalue_2ehxx',['RWStepDimTol_RWDatumReferenceModifierWithValue.hxx',['../_r_w_step_dim_tol___r_w_datum_reference_modifier_with_value_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwdatumsystem_2ehxx',['RWStepDimTol_RWDatumSystem.hxx',['../_r_w_step_dim_tol___r_w_datum_system_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwdatumtarget_2ehxx',['RWStepDimTol_RWDatumTarget.hxx',['../_r_w_step_dim_tol___r_w_datum_target_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwflatnesstolerance_2ehxx',['RWStepDimTol_RWFlatnessTolerance.hxx',['../_r_w_step_dim_tol___r_w_flatness_tolerance_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeneraldatumreference_2ehxx',['RWStepDimTol_RWGeneralDatumReference.hxx',['../_r_w_step_dim_tol___r_w_general_datum_reference_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwgeometrictolerance_2ehxx',['RWStepDimTol_RWGeometricTolerance.hxx',['../_r_w_step_dim_tol___r_w_geometric_tolerance_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwgeometrictolerancerelationship_2ehxx',['RWStepDimTol_RWGeometricToleranceRelationship.hxx',['../_r_w_step_dim_tol___r_w_geometric_tolerance_relationship_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwgeometrictolerancewithdatumreference_2ehxx',['RWStepDimTol_RWGeometricToleranceWithDatumReference.hxx',['../_r_w_step_dim_tol___r_w_geometric_tolerance_with_datum_reference_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeometrictolerancewithdefinedareaunit_2ehxx',['RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit.hxx',['../_r_w_step_dim_tol___r_w_geometric_tolerance_with_defined_area_unit_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeometrictolerancewithdefinedunit_2ehxx',['RWStepDimTol_RWGeometricToleranceWithDefinedUnit.hxx',['../_r_w_step_dim_tol___r_w_geometric_tolerance_with_defined_unit_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeometrictolerancewithmaximumtolerance_2ehxx',['RWStepDimTol_RWGeometricToleranceWithMaximumTolerance.hxx',['../_r_w_step_dim_tol___r_w_geometric_tolerance_with_maximum_tolerance_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeometrictolerancewithmodifiers_2ehxx',['RWStepDimTol_RWGeometricToleranceWithModifiers.hxx',['../_r_w_step_dim_tol___r_w_geometric_tolerance_with_modifiers_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthdatref_2ehxx',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRef.hxx',['../_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthdatrefandgeotolwthmaxtol_2ehxx',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol.hxx',['../_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_and_geo_tol_wth_max_tol_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthdatrefandgeotolwthmod_2ehxx',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod.hxx',['../_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_and_geo_tol_wth_mod_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwgeotolandgeotolwthdatrefandmodgeotolandpostol_2ehxx',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol.hxx',['../_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_and_mod_geo_tol_and_pos_tol_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthdatrefanduneqdisgeotol_2ehxx',['RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol.hxx',['../_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_dat_ref_and_uneq_dis_geo_tol_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthmaxtol_2ehxx',['RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol.hxx',['../_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_max_tol_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwgeotolandgeotolwthmod_2ehxx',['RWStepDimTol_RWGeoTolAndGeoTolWthMod.hxx',['../_r_w_step_dim_tol___r_w_geo_tol_and_geo_tol_wth_mod_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwlineprofiletolerance_2ehxx',['RWStepDimTol_RWLineProfileTolerance.hxx',['../_r_w_step_dim_tol___r_w_line_profile_tolerance_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwmodifiedgeometrictolerance_2ehxx',['RWStepDimTol_RWModifiedGeometricTolerance.hxx',['../_r_w_step_dim_tol___r_w_modified_geometric_tolerance_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwnonuniformzonedefinition_2ehxx',['RWStepDimTol_RWNonUniformZoneDefinition.hxx',['../_r_w_step_dim_tol___r_w_non_uniform_zone_definition_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwparallelismtolerance_2ehxx',['RWStepDimTol_RWParallelismTolerance.hxx',['../_r_w_step_dim_tol___r_w_parallelism_tolerance_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwperpendicularitytolerance_2ehxx',['RWStepDimTol_RWPerpendicularityTolerance.hxx',['../_r_w_step_dim_tol___r_w_perpendicularity_tolerance_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwplaceddatumtargetfeature_2ehxx',['RWStepDimTol_RWPlacedDatumTargetFeature.hxx',['../_r_w_step_dim_tol___r_w_placed_datum_target_feature_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwpositiontolerance_2ehxx',['RWStepDimTol_RWPositionTolerance.hxx',['../_r_w_step_dim_tol___r_w_position_tolerance_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwprojectedzonedefinition_2ehxx',['RWStepDimTol_RWProjectedZoneDefinition.hxx',['../_r_w_step_dim_tol___r_w_projected_zone_definition_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwroundnesstolerance_2ehxx',['RWStepDimTol_RWRoundnessTolerance.hxx',['../_r_w_step_dim_tol___r_w_roundness_tolerance_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwrunoutzonedefinition_2ehxx',['RWStepDimTol_RWRunoutZoneDefinition.hxx',['../_r_w_step_dim_tol___r_w_runout_zone_definition_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwrunoutzoneorientation_2ehxx',['RWStepDimTol_RWRunoutZoneOrientation.hxx',['../_r_w_step_dim_tol___r_w_runout_zone_orientation_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwstraightnesstolerance_2ehxx',['RWStepDimTol_RWStraightnessTolerance.hxx',['../_r_w_step_dim_tol___r_w_straightness_tolerance_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwsurfaceprofiletolerance_2ehxx',['RWStepDimTol_RWSurfaceProfileTolerance.hxx',['../_r_w_step_dim_tol___r_w_surface_profile_tolerance_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwsymmetrytolerance_2ehxx',['RWStepDimTol_RWSymmetryTolerance.hxx',['../_r_w_step_dim_tol___r_w_symmetry_tolerance_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwtolerancezone_2ehxx',['RWStepDimTol_RWToleranceZone.hxx',['../_r_w_step_dim_tol___r_w_tolerance_zone_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwtolerancezonedefinition_2ehxx',['RWStepDimTol_RWToleranceZoneDefinition.hxx',['../_r_w_step_dim_tol___r_w_tolerance_zone_definition_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwtolerancezoneform_2ehxx',['RWStepDimTol_RWToleranceZoneForm.hxx',['../_r_w_step_dim_tol___r_w_tolerance_zone_form_8hxx.html',1,'']]],
   ['rwstepdimtol_5frwtotalrunouttolerance_2ehxx',['RWStepDimTol_RWTotalRunoutTolerance.hxx',['../_r_w_step_dim_tol___r_w_total_runout_tolerance_8hxx.html',1,'']]],
+  ['rwstepdimtol_5frwunequallydisposedgeometrictolerance_2ehxx',['RWStepDimTol_RWUnequallyDisposedGeometricTolerance.hxx',['../_r_w_step_dim_tol___r_w_unequally_disposed_geometric_tolerance_8hxx.html',1,'']]],
   ['rwstepelement_5frwanalysisitemwithinrepresentation_2ehxx',['RWStepElement_RWAnalysisItemWithinRepresentation.hxx',['../_r_w_step_element___r_w_analysis_item_within_representation_8hxx.html',1,'']]],
   ['rwstepelement_5frwcurve3delementdescriptor_2ehxx',['RWStepElement_RWCurve3dElementDescriptor.hxx',['../_r_w_step_element___r_w_curve3d_element_descriptor_8hxx.html',1,'']]],
   ['rwstepelement_5frwcurveelementendreleasepacket_2ehxx',['RWStepElement_RWCurveElementEndReleasePacket.hxx',['../_r_w_step_element___r_w_curve_element_end_release_packet_8hxx.html',1,'']]],
@@ -349,21 +375,35 @@ var searchData=
   ['rwstepgeom_5frwuniformsurface_2ehxx',['RWStepGeom_RWUniformSurface.hxx',['../_r_w_step_geom___r_w_uniform_surface_8hxx.html',1,'']]],
   ['rwstepgeom_5frwuniformsurfaceandrationalbsplinesurface_2ehxx',['RWStepGeom_RWUniformSurfaceAndRationalBSplineSurface.hxx',['../_r_w_step_geom___r_w_uniform_surface_and_rational_b_spline_surface_8hxx.html',1,'']]],
   ['rwstepgeom_5frwvector_2ehxx',['RWStepGeom_RWVector.hxx',['../_r_w_step_geom___r_w_vector_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwallaroundshapeaspect_2ehxx',['RWStepRepr_RWAllAroundShapeAspect.hxx',['../_r_w_step_repr___r_w_all_around_shape_aspect_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwapex_2ehxx',['RWStepRepr_RWApex.hxx',['../_r_w_step_repr___r_w_apex_8hxx.html',1,'']]],
   ['rwsteprepr_5frwassemblycomponentusage_2ehxx',['RWStepRepr_RWAssemblyComponentUsage.hxx',['../_r_w_step_repr___r_w_assembly_component_usage_8hxx.html',1,'']]],
   ['rwsteprepr_5frwassemblycomponentusagesubstitute_2ehxx',['RWStepRepr_RWAssemblyComponentUsageSubstitute.hxx',['../_r_w_step_repr___r_w_assembly_component_usage_substitute_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwbetweenshapeaspect_2ehxx',['RWStepRepr_RWBetweenShapeAspect.hxx',['../_r_w_step_repr___r_w_between_shape_aspect_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwcentreofsymmetry_2ehxx',['RWStepRepr_RWCentreOfSymmetry.hxx',['../_r_w_step_repr___r_w_centre_of_symmetry_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwcharacterizedrepresentation_2ehxx',['RWStepRepr_RWCharacterizedRepresentation.hxx',['../_r_w_step_repr___r_w_characterized_representation_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwcompgroupshaspandcompshaspanddatumfeatandshasp_2ehxx',['RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp.hxx',['../_r_w_step_repr___r_w_comp_group_sh_asp_and_comp_sh_asp_and_datum_feat_and_sh_asp_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwcompositegroupshapeaspect_2ehxx',['RWStepRepr_RWCompositeGroupShapeAspect.hxx',['../_r_w_step_repr___r_w_composite_group_shape_aspect_8hxx.html',1,'']]],
   ['rwsteprepr_5frwcompositeshapeaspect_2ehxx',['RWStepRepr_RWCompositeShapeAspect.hxx',['../_r_w_step_repr___r_w_composite_shape_aspect_8hxx.html',1,'']]],
   ['rwsteprepr_5frwcompoundrepresentationitem_2ehxx',['RWStepRepr_RWCompoundRepresentationItem.hxx',['../_r_w_step_repr___r_w_compound_representation_item_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwcompshaspanddatumfeatandshasp_2ehxx',['RWStepRepr_RWCompShAspAndDatumFeatAndShAsp.hxx',['../_r_w_step_repr___r_w_comp_sh_asp_and_datum_feat_and_sh_asp_8hxx.html',1,'']]],
   ['rwsteprepr_5frwconfigurationdesign_2ehxx',['RWStepRepr_RWConfigurationDesign.hxx',['../_r_w_step_repr___r_w_configuration_design_8hxx.html',1,'']]],
   ['rwsteprepr_5frwconfigurationeffectivity_2ehxx',['RWStepRepr_RWConfigurationEffectivity.hxx',['../_r_w_step_repr___r_w_configuration_effectivity_8hxx.html',1,'']]],
   ['rwsteprepr_5frwconfigurationitem_2ehxx',['RWStepRepr_RWConfigurationItem.hxx',['../_r_w_step_repr___r_w_configuration_item_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwconstructivegeometryrepresentation_2ehxx',['RWStepRepr_RWConstructiveGeometryRepresentation.hxx',['../_r_w_step_repr___r_w_constructive_geometry_representation_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwconstructivegeometryrepresentationrelationship_2ehxx',['RWStepRepr_RWConstructiveGeometryRepresentationRelationship.hxx',['../_r_w_step_repr___r_w_constructive_geometry_representation_relationship_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwcontinuosshapeaspect_2ehxx',['RWStepRepr_RWContinuosShapeAspect.hxx',['../_r_w_step_repr___r_w_continuos_shape_aspect_8hxx.html',1,'']]],
   ['rwsteprepr_5frwdataenvironment_2ehxx',['RWStepRepr_RWDataEnvironment.hxx',['../_r_w_step_repr___r_w_data_environment_8hxx.html',1,'']]],
   ['rwsteprepr_5frwdefinitionalrepresentation_2ehxx',['RWStepRepr_RWDefinitionalRepresentation.hxx',['../_r_w_step_repr___r_w_definitional_representation_8hxx.html',1,'']]],
   ['rwsteprepr_5frwderivedshapeaspect_2ehxx',['RWStepRepr_RWDerivedShapeAspect.hxx',['../_r_w_step_repr___r_w_derived_shape_aspect_8hxx.html',1,'']]],
   ['rwsteprepr_5frwdescriptiverepresentationitem_2ehxx',['RWStepRepr_RWDescriptiveRepresentationItem.hxx',['../_r_w_step_repr___r_w_descriptive_representation_item_8hxx.html',1,'']]],
   ['rwsteprepr_5frwextension_2ehxx',['RWStepRepr_RWExtension.hxx',['../_r_w_step_repr___r_w_extension_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwfeaturefordatumtargetrelationship_2ehxx',['RWStepRepr_RWFeatureForDatumTargetRelationship.hxx',['../_r_w_step_repr___r_w_feature_for_datum_target_relationship_8hxx.html',1,'']]],
   ['rwsteprepr_5frwfunctionallydefinedtransformation_2ehxx',['RWStepRepr_RWFunctionallyDefinedTransformation.hxx',['../_r_w_step_repr___r_w_functionally_defined_transformation_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwgeometricalignment_2ehxx',['RWStepRepr_RWGeometricAlignment.hxx',['../_r_w_step_repr___r_w_geometric_alignment_8hxx.html',1,'']]],
   ['rwsteprepr_5frwglobaluncertaintyassignedcontext_2ehxx',['RWStepRepr_RWGlobalUncertaintyAssignedContext.hxx',['../_r_w_step_repr___r_w_global_uncertainty_assigned_context_8hxx.html',1,'']]],
   ['rwsteprepr_5frwglobalunitassignedcontext_2ehxx',['RWStepRepr_RWGlobalUnitAssignedContext.hxx',['../_r_w_step_repr___r_w_global_unit_assigned_context_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwintegerrepresentationitem_2ehxx',['RWStepRepr_RWIntegerRepresentationItem.hxx',['../_r_w_step_repr___r_w_integer_representation_item_8hxx.html',1,'']]],
   ['rwsteprepr_5frwitemdefinedtransformation_2ehxx',['RWStepRepr_RWItemDefinedTransformation.hxx',['../_r_w_step_repr___r_w_item_defined_transformation_8hxx.html',1,'']]],
   ['rwsteprepr_5frwmakefromusageoption_2ehxx',['RWStepRepr_RWMakeFromUsageOption.hxx',['../_r_w_step_repr___r_w_make_from_usage_option_8hxx.html',1,'']]],
   ['rwsteprepr_5frwmappeditem_2ehxx',['RWStepRepr_RWMappedItem.hxx',['../_r_w_step_repr___r_w_mapped_item_8hxx.html',1,'']]],
@@ -371,7 +411,9 @@ var searchData=
   ['rwsteprepr_5frwmaterialproperty_2ehxx',['RWStepRepr_RWMaterialProperty.hxx',['../_r_w_step_repr___r_w_material_property_8hxx.html',1,'']]],
   ['rwsteprepr_5frwmaterialpropertyrepresentation_2ehxx',['RWStepRepr_RWMaterialPropertyRepresentation.hxx',['../_r_w_step_repr___r_w_material_property_representation_8hxx.html',1,'']]],
   ['rwsteprepr_5frwmeasurerepresentationitem_2ehxx',['RWStepRepr_RWMeasureRepresentationItem.hxx',['../_r_w_step_repr___r_w_measure_representation_item_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwparalleloffset_2ehxx',['RWStepRepr_RWParallelOffset.hxx',['../_r_w_step_repr___r_w_parallel_offset_8hxx.html',1,'']]],
   ['rwsteprepr_5frwparametricrepresentationcontext_2ehxx',['RWStepRepr_RWParametricRepresentationContext.hxx',['../_r_w_step_repr___r_w_parametric_representation_context_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwperpendicularto_2ehxx',['RWStepRepr_RWPerpendicularTo.hxx',['../_r_w_step_repr___r_w_perpendicular_to_8hxx.html',1,'']]],
   ['rwsteprepr_5frwproductconcept_2ehxx',['RWStepRepr_RWProductConcept.hxx',['../_r_w_step_repr___r_w_product_concept_8hxx.html',1,'']]],
   ['rwsteprepr_5frwproductdefinitionshape_2ehxx',['RWStepRepr_RWProductDefinitionShape.hxx',['../_r_w_step_repr___r_w_product_definition_shape_8hxx.html',1,'']]],
   ['rwsteprepr_5frwpropertydefinition_2ehxx',['RWStepRepr_RWPropertyDefinition.hxx',['../_r_w_step_repr___r_w_property_definition_8hxx.html',1,'']]],
@@ -385,6 +427,9 @@ var searchData=
   ['rwsteprepr_5frwrepresentationrelationship_2ehxx',['RWStepRepr_RWRepresentationRelationship.hxx',['../_r_w_step_repr___r_w_representation_relationship_8hxx.html',1,'']]],
   ['rwsteprepr_5frwrepresentationrelationshipwithtransformation_2ehxx',['RWStepRepr_RWRepresentationRelationshipWithTransformation.hxx',['../_r_w_step_repr___r_w_representation_relationship_with_transformation_8hxx.html',1,'']]],
   ['rwsteprepr_5frwrepritemandlengthmeasurewithunit_2ehxx',['RWStepRepr_RWReprItemAndLengthMeasureWithUnit.hxx',['../_r_w_step_repr___r_w_repr_item_and_length_measure_with_unit_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwrepritemandlengthmeasurewithunitandqri_2ehxx',['RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI.hxx',['../_r_w_step_repr___r_w_repr_item_and_length_measure_with_unit_and_q_r_i_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwrepritemandplaneanglemeasurewithunit_2ehxx',['RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit.hxx',['../_r_w_step_repr___r_w_repr_item_and_plane_angle_measure_with_unit_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwrepritemandplaneanglemeasurewithunitandqri_2ehxx',['RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI.hxx',['../_r_w_step_repr___r_w_repr_item_and_plane_angle_measure_with_unit_and_q_r_i_8hxx.html',1,'']]],
   ['rwsteprepr_5frwshapeaspect_2ehxx',['RWStepRepr_RWShapeAspect.hxx',['../_r_w_step_repr___r_w_shape_aspect_8hxx.html',1,'']]],
   ['rwsteprepr_5frwshapeaspectderivingrelationship_2ehxx',['RWStepRepr_RWShapeAspectDerivingRelationship.hxx',['../_r_w_step_repr___r_w_shape_aspect_deriving_relationship_8hxx.html',1,'']]],
   ['rwsteprepr_5frwshapeaspectrelationship_2ehxx',['RWStepRepr_RWShapeAspectRelationship.hxx',['../_r_w_step_repr___r_w_shape_aspect_relationship_8hxx.html',1,'']]],
@@ -393,6 +438,8 @@ var searchData=
   ['rwsteprepr_5frwspecifiedhigherusageoccurrence_2ehxx',['RWStepRepr_RWSpecifiedHigherUsageOccurrence.hxx',['../_r_w_step_repr___r_w_specified_higher_usage_occurrence_8hxx.html',1,'']]],
   ['rwsteprepr_5frwstructuralresponseproperty_2ehxx',['RWStepRepr_RWStructuralResponseProperty.hxx',['../_r_w_step_repr___r_w_structural_response_property_8hxx.html',1,'']]],
   ['rwsteprepr_5frwstructuralresponsepropertydefinitionrepresentation_2ehxx',['RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation.hxx',['../_r_w_step_repr___r_w_structural_response_property_definition_representation_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwtangent_2ehxx',['RWStepRepr_RWTangent.hxx',['../_r_w_step_repr___r_w_tangent_8hxx.html',1,'']]],
+  ['rwsteprepr_5frwvaluerepresentationitem_2ehxx',['RWStepRepr_RWValueRepresentationItem.hxx',['../_r_w_step_repr___r_w_value_representation_item_8hxx.html',1,'']]],
   ['rwstepshape_5frwadvancedbrepshaperepresentation_2ehxx',['RWStepShape_RWAdvancedBrepShapeRepresentation.hxx',['../_r_w_step_shape___r_w_advanced_brep_shape_representation_8hxx.html',1,'']]],
   ['rwstepshape_5frwadvancedface_2ehxx',['RWStepShape_RWAdvancedFace.hxx',['../_r_w_step_shape___r_w_advanced_face_8hxx.html',1,'']]],
   ['rwstepshape_5frwangularlocation_2ehxx',['RWStepShape_RWAngularLocation.hxx',['../_r_w_step_shape___r_w_angular_location_8hxx.html',1,'']]],
@@ -480,9 +527,13 @@ var searchData=
   ['rwstepshape_5frwtorus_2ehxx',['RWStepShape_RWTorus.hxx',['../_r_w_step_shape___r_w_torus_8hxx.html',1,'']]],
   ['rwstepshape_5frwtransitionalshaperepresentation_2ehxx',['RWStepShape_RWTransitionalShapeRepresentation.hxx',['../_r_w_step_shape___r_w_transitional_shape_representation_8hxx.html',1,'']]],
   ['rwstepshape_5frwtypequalifier_2ehxx',['RWStepShape_RWTypeQualifier.hxx',['../_r_w_step_shape___r_w_type_qualifier_8hxx.html',1,'']]],
+  ['rwstepshape_5frwvalueformattypequalifier_2ehxx',['RWStepShape_RWValueFormatTypeQualifier.hxx',['../_r_w_step_shape___r_w_value_format_type_qualifier_8hxx.html',1,'']]],
   ['rwstepshape_5frwvertex_2ehxx',['RWStepShape_RWVertex.hxx',['../_r_w_step_shape___r_w_vertex_8hxx.html',1,'']]],
   ['rwstepshape_5frwvertexloop_2ehxx',['RWStepShape_RWVertexLoop.hxx',['../_r_w_step_shape___r_w_vertex_loop_8hxx.html',1,'']]],
   ['rwstepshape_5frwvertexpoint_2ehxx',['RWStepShape_RWVertexPoint.hxx',['../_r_w_step_shape___r_w_vertex_point_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwannotationcurveoccurrence_2ehxx',['RWStepVisual_RWAnnotationCurveOccurrence.hxx',['../_r_w_step_visual___r_w_annotation_curve_occurrence_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwannotationoccurrence_2ehxx',['RWStepVisual_RWAnnotationOccurrence.hxx',['../_r_w_step_visual___r_w_annotation_occurrence_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwannotationplane_2ehxx',['RWStepVisual_RWAnnotationPlane.hxx',['../_r_w_step_visual___r_w_annotation_plane_8hxx.html',1,'']]],
   ['rwstepvisual_5frwareainset_2ehxx',['RWStepVisual_RWAreaInSet.hxx',['../_r_w_step_visual___r_w_area_in_set_8hxx.html',1,'']]],
   ['rwstepvisual_5frwbackgroundcolour_2ehxx',['RWStepVisual_RWBackgroundColour.hxx',['../_r_w_step_visual___r_w_background_colour_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcameraimage_2ehxx',['RWStepVisual_RWCameraImage.hxx',['../_r_w_step_visual___r_w_camera_image_8hxx.html',1,'']]],
@@ -490,6 +541,7 @@ var searchData=
   ['rwstepvisual_5frwcameramodeld2_2ehxx',['RWStepVisual_RWCameraModelD2.hxx',['../_r_w_step_visual___r_w_camera_model_d2_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcameramodeld3_2ehxx',['RWStepVisual_RWCameraModelD3.hxx',['../_r_w_step_visual___r_w_camera_model_d3_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcamerausage_2ehxx',['RWStepVisual_RWCameraUsage.hxx',['../_r_w_step_visual___r_w_camera_usage_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwcharacterizedobjectandcharacterizedrepresentationanddraughtingmodelandrepresentation_2ehxx',['RWStepVisual_RWCharacterizedObjectAndCharacterizedRepresentationAndDraughtingModelAndRepresentation.hxx',['../_r_w_step_visual___r_w_characterized_object_and_characterized_representation_and_draughting_model_and_representation_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcolour_2ehxx',['RWStepVisual_RWColour.hxx',['../_r_w_step_visual___r_w_colour_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcolourrgb_2ehxx',['RWStepVisual_RWColourRgb.hxx',['../_r_w_step_visual___r_w_colour_rgb_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcolourspecification_2ehxx',['RWStepVisual_RWColourSpecification.hxx',['../_r_w_step_visual___r_w_colour_specification_8hxx.html',1,'']]],
@@ -497,9 +549,11 @@ var searchData=
   ['rwstepvisual_5frwcompositetextwithextent_2ehxx',['RWStepVisual_RWCompositeTextWithExtent.hxx',['../_r_w_step_visual___r_w_composite_text_with_extent_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcontextdependentinvisibility_2ehxx',['RWStepVisual_RWContextDependentInvisibility.hxx',['../_r_w_step_visual___r_w_context_dependent_invisibility_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcontextdependentoverridingstyleditem_2ehxx',['RWStepVisual_RWContextDependentOverRidingStyledItem.hxx',['../_r_w_step_visual___r_w_context_dependent_over_riding_styled_item_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwcoordinateslist_2ehxx',['RWStepVisual_RWCoordinatesList.hxx',['../_r_w_step_visual___r_w_coordinates_list_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcurvestyle_2ehxx',['RWStepVisual_RWCurveStyle.hxx',['../_r_w_step_visual___r_w_curve_style_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcurvestylefont_2ehxx',['RWStepVisual_RWCurveStyleFont.hxx',['../_r_w_step_visual___r_w_curve_style_font_8hxx.html',1,'']]],
   ['rwstepvisual_5frwcurvestylefontpattern_2ehxx',['RWStepVisual_RWCurveStyleFontPattern.hxx',['../_r_w_step_visual___r_w_curve_style_font_pattern_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwdraughtingcallout_2ehxx',['RWStepVisual_RWDraughtingCallout.hxx',['../_r_w_step_visual___r_w_draughting_callout_8hxx.html',1,'']]],
   ['rwstepvisual_5frwdraughtingmodel_2ehxx',['RWStepVisual_RWDraughtingModel.hxx',['../_r_w_step_visual___r_w_draughting_model_8hxx.html',1,'']]],
   ['rwstepvisual_5frwdraughtingpredefinedcolour_2ehxx',['RWStepVisual_RWDraughtingPreDefinedColour.hxx',['../_r_w_step_visual___r_w_draughting_pre_defined_colour_8hxx.html',1,'']]],
   ['rwstepvisual_5frwdraughtingpredefinedcurvefont_2ehxx',['RWStepVisual_RWDraughtingPreDefinedCurveFont.hxx',['../_r_w_step_visual___r_w_draughting_pre_defined_curve_font_8hxx.html',1,'']]],
@@ -537,6 +591,10 @@ var searchData=
   ['rwstepvisual_5frwsurfacestyleusage_2ehxx',['RWStepVisual_RWSurfaceStyleUsage.hxx',['../_r_w_step_visual___r_w_surface_style_usage_8hxx.html',1,'']]],
   ['rwstepvisual_5frwtemplate_2ehxx',['RWStepVisual_RWTemplate.hxx',['../_r_w_step_visual___r_w_template_8hxx.html',1,'']]],
   ['rwstepvisual_5frwtemplateinstance_2ehxx',['RWStepVisual_RWTemplateInstance.hxx',['../_r_w_step_visual___r_w_template_instance_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwtessellatedannotationoccurrence_2ehxx',['RWStepVisual_RWTessellatedAnnotationOccurrence.hxx',['../_r_w_step_visual___r_w_tessellated_annotation_occurrence_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwtessellatedcurveset_2ehxx',['RWStepVisual_RWTessellatedCurveSet.hxx',['../_r_w_step_visual___r_w_tessellated_curve_set_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwtessellatedgeometricset_2ehxx',['RWStepVisual_RWTessellatedGeometricSet.hxx',['../_r_w_step_visual___r_w_tessellated_geometric_set_8hxx.html',1,'']]],
+  ['rwstepvisual_5frwtessellateditem_2ehxx',['RWStepVisual_RWTessellatedItem.hxx',['../_r_w_step_visual___r_w_tessellated_item_8hxx.html',1,'']]],
   ['rwstepvisual_5frwtextliteral_2ehxx',['RWStepVisual_RWTextLiteral.hxx',['../_r_w_step_visual___r_w_text_literal_8hxx.html',1,'']]],
   ['rwstepvisual_5frwtextstyle_2ehxx',['RWStepVisual_RWTextStyle.hxx',['../_r_w_step_visual___r_w_text_style_8hxx.html',1,'']]],
   ['rwstepvisual_5frwtextstylefordefinedfont_2ehxx',['RWStepVisual_RWTextStyleForDefinedFont.hxx',['../_r_w_step_visual___r_w_text_style_for_defined_font_8hxx.html',1,'']]],
