@@ -1,18 +1,6 @@
 var searchData=
 [
-  ['qabugs_5fmytext',['QABugs_MyText',['../class_q_a_bugs___my_text.html#a64a7c95f2271f75674ae82fd503a8c2a',1,'QABugs_MyText::QABugs_MyText(const TCollection_ExtendedString &amp;aText, const gp_Pnt &amp;aPosition)'],['../class_q_a_bugs___my_text.html#a8de03c4be791a5a053477b32369fa497',1,'QABugs_MyText::QABugs_MyText(const TCollection_ExtendedString &amp;aText, const gp_Pnt &amp;aPosition, const Standard_CString aFont, const Quantity_NameOfColor aColor, const Standard_Real aHeight)']]],
   ['qabugs_5fpresentableobject',['QABugs_PresentableObject',['../class_q_a_bugs___presentable_object.html#af1c739eb0e4d054c0b228d1a445ff24e',1,'QABugs_PresentableObject']]],
-  ['qancollection_5fdatamapiteratorofdatamapofrealpnt',['QANCollection_DataMapIteratorOfDataMapOfRealPnt',['../class_q_a_n_collection___data_map_iterator_of_data_map_of_real_pnt.html#ac6c6672127de4fc69b71aab83569076b',1,'QANCollection_DataMapIteratorOfDataMapOfRealPnt::QANCollection_DataMapIteratorOfDataMapOfRealPnt()'],['../class_q_a_n_collection___data_map_iterator_of_data_map_of_real_pnt.html#aa47fd39f3098d63f6f7d71832c35fa45',1,'QANCollection_DataMapIteratorOfDataMapOfRealPnt::QANCollection_DataMapIteratorOfDataMapOfRealPnt(const QANCollection_DataMapOfRealPnt &amp;aMap)']]],
-  ['qancollection_5fdatamapnodeofdatamapofrealpnt',['QANCollection_DataMapNodeOfDataMapOfRealPnt',['../class_q_a_n_collection___data_map_node_of_data_map_of_real_pnt.html#a3709bfe5dcaa024ab2a84fbffbd3f7ca',1,'QANCollection_DataMapNodeOfDataMapOfRealPnt']]],
-  ['qancollection_5fdatamapofrealpnt',['QANCollection_DataMapOfRealPnt',['../class_q_a_n_collection___data_map_of_real_pnt.html#afb9138156cffb371521ec4d43b014c62',1,'QANCollection_DataMapOfRealPnt']]],
-  ['qancollection_5fdoublemapiteratorofdoublemapofrealinteger',['QANCollection_DoubleMapIteratorOfDoubleMapOfRealInteger',['../class_q_a_n_collection___double_map_iterator_of_double_map_of_real_integer.html#a9c2e26db9d196d7adcfdb64dfd5fbad8',1,'QANCollection_DoubleMapIteratorOfDoubleMapOfRealInteger::QANCollection_DoubleMapIteratorOfDoubleMapOfRealInteger()'],['../class_q_a_n_collection___double_map_iterator_of_double_map_of_real_integer.html#af3879cdb5a0fadbe9d9e9e46b52dbb80',1,'QANCollection_DoubleMapIteratorOfDoubleMapOfRealInteger::QANCollection_DoubleMapIteratorOfDoubleMapOfRealInteger(const QANCollection_DoubleMapOfRealInteger &amp;aMap)']]],
-  ['qancollection_5fdoublemapnodeofdoublemapofrealinteger',['QANCollection_DoubleMapNodeOfDoubleMapOfRealInteger',['../class_q_a_n_collection___double_map_node_of_double_map_of_real_integer.html#a85c3996d25b707abd2200f7a26e0a351',1,'QANCollection_DoubleMapNodeOfDoubleMapOfRealInteger']]],
-  ['qancollection_5fdoublemapofrealinteger',['QANCollection_DoubleMapOfRealInteger',['../class_q_a_n_collection___double_map_of_real_integer.html#a9442c8d29eb83df9b5c56f2d07033d7b',1,'QANCollection_DoubleMapOfRealInteger']]],
-  ['qancollection_5findexeddatamapnodeofindexeddatamapofrealpnt',['QANCollection_IndexedDataMapNodeOfIndexedDataMapOfRealPnt',['../class_q_a_n_collection___indexed_data_map_node_of_indexed_data_map_of_real_pnt.html#aec985f0f3c2773d413ebdddeaf77eee7',1,'QANCollection_IndexedDataMapNodeOfIndexedDataMapOfRealPnt']]],
-  ['qancollection_5findexeddatamapofrealpnt',['QANCollection_IndexedDataMapOfRealPnt',['../class_q_a_n_collection___indexed_data_map_of_real_pnt.html#a738c2d62f40c7bc0977e9a43464c3bf9',1,'QANCollection_IndexedDataMapOfRealPnt']]],
-  ['qancollection_5flistiteratoroflistofpnt',['QANCollection_ListIteratorOfListOfPnt',['../class_q_a_n_collection___list_iterator_of_list_of_pnt.html#abae5c8527f0e78b435f75d22f43454b1',1,'QANCollection_ListIteratorOfListOfPnt::QANCollection_ListIteratorOfListOfPnt()'],['../class_q_a_n_collection___list_iterator_of_list_of_pnt.html#aab4c3f542b980160f7074ffd780afe48',1,'QANCollection_ListIteratorOfListOfPnt::QANCollection_ListIteratorOfListOfPnt(const QANCollection_ListOfPnt &amp;L)']]],
-  ['qancollection_5flistnodeoflistofpnt',['QANCollection_ListNodeOfListOfPnt',['../class_q_a_n_collection___list_node_of_list_of_pnt.html#a8d1ae1c25101bd43a97f498af1f291f0',1,'QANCollection_ListNodeOfListOfPnt']]],
-  ['qancollection_5flistofpnt',['QANCollection_ListOfPnt',['../class_q_a_n_collection___list_of_pnt.html#a081ff43bfc936a54f1ce4e9e52d69291',1,'QANCollection_ListOfPnt::QANCollection_ListOfPnt()'],['../class_q_a_n_collection___list_of_pnt.html#a02b5b2f14fde20b330b5ae8b673ba82a',1,'QANCollection_ListOfPnt::QANCollection_ListOfPnt(const QANCollection_ListOfPnt &amp;Other)']]],
   ['qanewbrepnaming_5fbooleanoperation',['QANewBRepNaming_BooleanOperation',['../class_q_a_new_b_rep_naming___boolean_operation.html#aeefde6f0d87e6c39c4b3985b9c6d566f',1,'QANewBRepNaming_BooleanOperation::QANewBRepNaming_BooleanOperation()'],['../class_q_a_new_b_rep_naming___boolean_operation.html#ab1b381775881fde141f8c50ce4680f64',1,'QANewBRepNaming_BooleanOperation::QANewBRepNaming_BooleanOperation(const TDF_Label &amp;ResultLabel)']]],
   ['qanewbrepnaming_5fbooleanoperationfeat',['QANewBRepNaming_BooleanOperationFeat',['../class_q_a_new_b_rep_naming___boolean_operation_feat.html#acec1a1b0b38c6e9c7bc8a0a46ccc8440',1,'QANewBRepNaming_BooleanOperationFeat::QANewBRepNaming_BooleanOperationFeat()'],['../class_q_a_new_b_rep_naming___boolean_operation_feat.html#af9e45d787844145e2720a6d8e4f4bd12',1,'QANewBRepNaming_BooleanOperationFeat::QANewBRepNaming_BooleanOperationFeat(const TDF_Label &amp;ResultLabel)']]],
   ['qanewbrepnaming_5fbox',['QANewBRepNaming_Box',['../class_q_a_new_b_rep_naming___box.html#af0de35b59c1b0863045e7615210c17d8',1,'QANewBRepNaming_Box::QANewBRepNaming_Box()'],['../class_q_a_new_b_rep_naming___box.html#aec7100b6495e8ddc3a8f98df35f45a4f',1,'QANewBRepNaming_Box::QANewBRepNaming_Box(const TDF_Label &amp;ResultLabel)']]],
@@ -34,6 +22,7 @@ var searchData=
   ['qanewmodtopope_5fintersection',['QANewModTopOpe_Intersection',['../class_q_a_new_mod_top_ope___intersection.html#aa9d2a59dfb543ef5c08ed31138239bbf',1,'QANewModTopOpe_Intersection']]],
   ['qanewmodtopope_5flimitation',['QANewModTopOpe_Limitation',['../class_q_a_new_mod_top_ope___limitation.html#acb64911e6cd0686c4f14d0935b2b2228',1,'QANewModTopOpe_Limitation']]],
   ['qanewmodtopope_5freshaper',['QANewModTopOpe_ReShaper',['../class_q_a_new_mod_top_ope___re_shaper.html#ae206ddd083d07642087c83aa9960363b',1,'QANewModTopOpe_ReShaper::QANewModTopOpe_ReShaper(const TopoDS_Shape &amp;TheInitialShape)'],['../class_q_a_new_mod_top_ope___re_shaper.html#a6d8cdfa3b4e1318b07e71fd70c2f99c2',1,'QANewModTopOpe_ReShaper::QANewModTopOpe_ReShaper(const TopoDS_Shape &amp;TheInitialShape, const TopTools_MapOfShape &amp;TheMap)'],['../class_q_a_new_mod_top_ope___re_shaper.html#a15e4e3a6c16486a5be86da18b9800007',1,'QANewModTopOpe_ReShaper::QANewModTopOpe_ReShaper(const TopoDS_Shape &amp;TheInitialShape, const Handle&lt; TopTools_HSequenceOfShape &gt; &amp;TheShapeToBeRemoved)']]],
+  ['quadbvh',['QuadBVH',['../class_open_gl___triangle_set.html#ab7841e9e410b249ea1e09472a0b3b581',1,'OpenGl_TriangleSet::QuadBVH()'],['../class_open_gl___raytrace_geometry.html#a4db52b0023b6ae0a92fef289e40c8da1',1,'OpenGl_RaytraceGeometry::QuadBVH()']]],
   ['quadraticerror',['QuadraticError',['../class_app_def___variational.html#a55a516dd414fea84b2e0671e06a8414a',1,'AppDef_Variational']]],
   ['quadric',['Quadric',['../class_int_patch___arc_function.html#ad55bbcfadd69f887c3cf0199ede50149',1,'IntPatch_ArcFunction::Quadric()'],['../class_contap___arc_function.html#a7e46591374391d60073b6ddc6054ea10',1,'Contap_ArcFunction::Quadric()']]],
   ['qualified',['Qualified',['../class_gcc_ent___qualified_circ.html#ac3c0842ff93b150b01a8b2221b0f7abc',1,'GccEnt_QualifiedCirc::Qualified()'],['../class_gcc_ent___qualified_lin.html#a6ea8cb626da2d90e9db897003e4dcd5c',1,'GccEnt_QualifiedLin::Qualified()'],['../class_geom2d_gcc___q_curve.html#a8025b2e1ea062dd463c891127f937d6b',1,'Geom2dGcc_QCurve::Qualified()'],['../class_geom2d_gcc___qualified_curve.html#abd1d061fe061cadc5343a1082897289c',1,'Geom2dGcc_QualifiedCurve::Qualified()']]],
@@ -41,17 +30,14 @@ var searchData=
   ['qualifier',['Qualifier',['../class_gcc_ent___qualified_circ.html#a493e257f890c9629f9d5636266b508b8',1,'GccEnt_QualifiedCirc::Qualifier()'],['../class_gcc_ent___qualified_lin.html#a4086b0528c190d707f6f6eef00f011bb',1,'GccEnt_QualifiedLin::Qualifier()'],['../class_geom2d_gcc___q_curve.html#ae114b339395b2aae7388d14f73c8822d',1,'Geom2dGcc_QCurve::Qualifier()'],['../class_geom2d_gcc___qualified_curve.html#a13420da0308a98c32e32fecbfcfaa066',1,'Geom2dGcc_QualifiedCurve::Qualifier()']]],
   ['qualifiers',['Qualifiers',['../class_step_shape___measure_qualification.html#ad58ba482fa0f012d13e0a06476be6dee',1,'StepShape_MeasureQualification::Qualifiers()'],['../class_step_shape___measure_representation_item_and_qualified_representation_item.html#a4d959be85e0f3c23b120009ea90d7155',1,'StepShape_MeasureRepresentationItemAndQualifiedRepresentationItem::Qualifiers()'],['../class_step_shape___qualified_representation_item.html#abec74b0e14104e857e54c21f529f3e51',1,'StepShape_QualifiedRepresentationItem::Qualifiers()']]],
   ['qualifiersvalue',['QualifiersValue',['../class_step_shape___measure_qualification.html#adcef57d009fe0672f121a12149d8c378',1,'StepShape_MeasureQualification::QualifiersValue()'],['../class_step_shape___measure_representation_item_and_qualified_representation_item.html#a10c1775177c660dd84edd32526ab1d0c',1,'StepShape_MeasureRepresentationItemAndQualifiedRepresentationItem::QualifiersValue()'],['../class_step_shape___qualified_representation_item.html#ae13b653dcc1bb76c65e32f89489090c2',1,'StepShape_QualifiedRepresentationItem::QualifiersValue()']]],
-  ['qualityvalues',['QualityValues',['../class_app_def___linear_criteria.html#a604f9617715743d8f0a7ba21f6d6ff5b',1,'AppDef_LinearCriteria::QualityValues()'],['../class_app_def___smooth_criterion.html#a4bb70f0bbafde76c7a3ddc119dbf904c',1,'AppDef_SmoothCriterion::QualityValues()']]],
+  ['qualityvalues',['QualityValues',['../class_app_def___linear_criteria.html#ae7b99f9d085cdda894f194fe324da7ed',1,'AppDef_LinearCriteria::QualityValues()'],['../class_app_def___smooth_criterion.html#a4bb70f0bbafde76c7a3ddc119dbf904c',1,'AppDef_SmoothCriterion::QualityValues()']]],
   ['quantitiessequence',['QuantitiesSequence',['../class_units___units_system.html#a3a80d2ef424c5a172310c66dfc1b87ec',1,'Units_UnitsSystem']]],
   ['quantity',['Quantity',['../class_units.html#a3d065a384ca6d99cf56e2daa5f2867d9',1,'Units::Quantity()'],['../class_units___dimensions.html#acb47eb44c80e55f8327d8831ddbe4116',1,'Units_Dimensions::Quantity()'],['../class_units___explorer.html#a32e3814b38de847165744f7df5792533',1,'Units_Explorer::Quantity()'],['../class_units___unit.html#a9d1b7b0206505706f36e60f6460ce368',1,'Units_Unit::Quantity() const '],['../class_units___unit.html#ab9c893c4a9f8611334f0ab0205e83fb8',1,'Units_Unit::Quantity(const Handle&lt; Units_Quantity &gt; &amp;aquantity)'],['../class_step_repr___make_from_usage_option.html#aadc92813b81f25c620c0c58b2cd1c254',1,'StepRepr_MakeFromUsageOption::Quantity()'],['../class_step_repr___quantified_assembly_component_usage.html#a15f050f167a2a2e2e4bd01a4fa9bed11',1,'StepRepr_QuantifiedAssemblyComponentUsage::Quantity()']]],
-  ['quantity_5farray1ofcoefficient',['Quantity_Array1OfCoefficient',['../class_quantity___array1_of_coefficient.html#acd6c90465ca0e6232b9661353a7b5b2f',1,'Quantity_Array1OfCoefficient::Quantity_Array1OfCoefficient(const Standard_Integer Low, const Standard_Integer Up)'],['../class_quantity___array1_of_coefficient.html#a26e655c215b662291e6c746507406761',1,'Quantity_Array1OfCoefficient::Quantity_Array1OfCoefficient(const Quantity_Coefficient &amp;Item, const Standard_Integer Low, const Standard_Integer Up)']]],
-  ['quantity_5farray1ofcolor',['Quantity_Array1OfColor',['../class_quantity___array1_of_color.html#a9e2f775531bfe48f1b7de4817fe11e1b',1,'Quantity_Array1OfColor::Quantity_Array1OfColor(const Standard_Integer Low, const Standard_Integer Up)'],['../class_quantity___array1_of_color.html#a96931418aab53ecbdcceef3112905862',1,'Quantity_Array1OfColor::Quantity_Array1OfColor(const Quantity_Color &amp;Item, const Standard_Integer Low, const Standard_Integer Up)']]],
-  ['quantity_5farray2ofcolor',['Quantity_Array2OfColor',['../class_quantity___array2_of_color.html#aea3b0d827640d336ee565afa57323994',1,'Quantity_Array2OfColor::Quantity_Array2OfColor(const Standard_Integer R1, const Standard_Integer R2, const Standard_Integer C1, const Standard_Integer C2)'],['../class_quantity___array2_of_color.html#af41972f1be5377a86f61ea1d85c91885',1,'Quantity_Array2OfColor::Quantity_Array2OfColor(const Quantity_Color &amp;Item, const Standard_Integer R1, const Standard_Integer R2, const Standard_Integer C1, const Standard_Integer C2)']]],
-  ['quantity_5fcolor',['Quantity_Color',['../class_quantity___color.html#ae2cb1a257f7889aed9400a57ae57ac6e',1,'Quantity_Color::Quantity_Color()'],['../class_quantity___color.html#a2ee936d9f3b7d2517c56bb7aab80998e',1,'Quantity_Color::Quantity_Color(const Quantity_NameOfColor AName)'],['../class_quantity___color.html#a5a62dcbd7ecf86fdfa5ef17ffa9a4b55',1,'Quantity_Color::Quantity_Color(const Quantity_Parameter R1, const Quantity_Parameter R2, const Quantity_Parameter R3, const Quantity_TypeOfColor AType)']]],
+  ['quantity_5fcolor',['Quantity_Color',['../class_quantity___color.html#ae2cb1a257f7889aed9400a57ae57ac6e',1,'Quantity_Color::Quantity_Color()'],['../class_quantity___color.html#a2ee936d9f3b7d2517c56bb7aab80998e',1,'Quantity_Color::Quantity_Color(const Quantity_NameOfColor AName)'],['../class_quantity___color.html#a6f65dcde0c5f7972a141b900f511ff87',1,'Quantity_Color::Quantity_Color(const Quantity_Parameter theR1, const Quantity_Parameter theR2, const Quantity_Parameter theR3, const Quantity_TypeOfColor theType)'],['../class_quantity___color.html#a2d33c9dbc013675e81fac42e4bb84ae4',1,'Quantity_Color::Quantity_Color(const NCollection_Vec3&lt; float &gt; &amp;theRgb)']]],
+  ['quantity_5fcolorrgba',['Quantity_ColorRGBA',['../class_quantity___color_r_g_b_a.html#a246c2f78565aa982d53cf82fb39551ed',1,'Quantity_ColorRGBA::Quantity_ColorRGBA()'],['../class_quantity___color_r_g_b_a.html#a281ffcacbf7c0fd8356de801c1de0378',1,'Quantity_ColorRGBA::Quantity_ColorRGBA(const Quantity_Color &amp;theRgb)'],['../class_quantity___color_r_g_b_a.html#a62048ec1ce3666281568dd248db5870c',1,'Quantity_ColorRGBA::Quantity_ColorRGBA(const NCollection_Vec4&lt; float &gt; &amp;theRgba)']]],
   ['quantity_5fconvert',['Quantity_Convert',['../class_quantity___convert.html#ae1b4e87d9032a9b1f09a983edfb418a7',1,'Quantity_Convert']]],
   ['quantity_5fdate',['Quantity_Date',['../class_quantity___date.html#af72d1d36e0e680d293412fa62f9613fc',1,'Quantity_Date::Quantity_Date()'],['../class_quantity___date.html#ad38778f9a605f1c0cbe770b00f0f1f22',1,'Quantity_Date::Quantity_Date(const Standard_Integer mm, const Standard_Integer dd, const Standard_Integer yyyy, const Standard_Integer hh, const Standard_Integer mn, const Standard_Integer ss, const Standard_Integer mis=0, const Standard_Integer mics=0)']]],
-  ['quantity_5fharray1ofcolor',['Quantity_HArray1OfColor',['../class_quantity___h_array1_of_color.html#aef34567c5230612fc742189ddc42ab2a',1,'Quantity_HArray1OfColor::Quantity_HArray1OfColor(const Standard_Integer Low, const Standard_Integer Up)'],['../class_quantity___h_array1_of_color.html#ab0884daf4a899678f6583f3a43215891',1,'Quantity_HArray1OfColor::Quantity_HArray1OfColor(const Standard_Integer Low, const Standard_Integer Up, const Quantity_Color &amp;V)']]],
-  ['quantity_5fperiod',['Quantity_Period',['../class_quantity___period.html#a048c13492b0d2c1c2f2452d10291e933',1,'Quantity_Period::Quantity_Period(const Standard_Integer dd, const Standard_Integer hh, const Standard_Integer mn, const Standard_Integer ss, const Standard_Integer mis=0, const Standard_Integer mics=0)'],['../class_quantity___period.html#a874d5be2c896f18ccc3e6be7aba89795',1,'Quantity_Period::Quantity_Period(const Standard_Integer ss, const Standard_Integer mics=0)'],['../class_quantity___period.html#a7c7372cda917ff290acd004a28ccbdd0',1,'Quantity_Period::Quantity_Period()']]],
+  ['quantity_5fperiod',['Quantity_Period',['../class_quantity___period.html#a048c13492b0d2c1c2f2452d10291e933',1,'Quantity_Period::Quantity_Period(const Standard_Integer dd, const Standard_Integer hh, const Standard_Integer mn, const Standard_Integer ss, const Standard_Integer mis=0, const Standard_Integer mics=0)'],['../class_quantity___period.html#a874d5be2c896f18ccc3e6be7aba89795',1,'Quantity_Period::Quantity_Period(const Standard_Integer ss, const Standard_Integer mics=0)']]],
   ['quasiuniformcurve',['QuasiUniformCurve',['../class_step_geom___quasi_uniform_curve_and_rational_b_spline_curve.html#a9ca7a41ba7ec907d1d18d4ec8345e80c',1,'StepGeom_QuasiUniformCurveAndRationalBSplineCurve']]],
   ['quasiuniformsurface',['QuasiUniformSurface',['../class_step_geom___quasi_uniform_surface_and_rational_b_spline_surface.html#a83cd2adc6e47c71142c95c652661ec6d',1,'StepGeom_QuasiUniformSurfaceAndRationalBSplineSurface']]],
   ['querychecklist',['QueryCheckList',['../class_i_f_select___work_session.html#af044ba62fd380efd3135371d4cad14dc',1,'IFSelect_WorkSession']]],
