@@ -1,11 +1,8 @@
 var searchData=
 [
-  ['g',['g',['../class_g_prop___g_props.html#acd9b97a189d86919b98316080e04a724',1,'GProp_GProps::g()'],['../union_multitype.html#a6144d7589398ee0202ee7f4fbfad4f21',1,'Multitype::g()'],['../struct_c_a_l_l___d_e_f___w_i_n_d_o_w.html#a3a05153f6fec569cee4665ee7054aca4',1,'CALL_DEF_WINDOW::g()'],['../struct_c_a_l_l___d_e_f___c_o_l_o_r.html#a64626d536cb61f49f994709adffccab1',1,'CALL_DEF_COLOR::g()']]],
+  ['g',['g',['../class_g_prop___g_props.html#acd9b97a189d86919b98316080e04a724',1,'GProp_GProps::g()'],['../union_multitype.html#a6144d7589398ee0202ee7f4fbfad4f21',1,'Multitype::g()']]],
   ['g1',['g1',['../struct_mesh_v_s___two_colors.html#a9f61cd8d321d072042b0b78b294370d7',1,'MeshVS_TwoColors']]],
   ['g2',['g2',['../struct_mesh_v_s___two_colors.html#a0fa8411d0f36525edb910f46906b6eac',1,'MeshVS_TwoColors']]],
-  ['gclientdata',['GClientData',['../class_graphic3d___c_view.html#a8c80188f2ff64f4446654729a99c2ca5',1,'Graphic3d_CView']]],
-  ['gcontext',['GContext',['../class_graphic3d___c_view.html#a760dd6838b957daaef3e3d878998bd53',1,'Graphic3d_CView']]],
-  ['gdisplaycb',['GDisplayCB',['../class_graphic3d___c_view.html#a4c61606b05ad40d615b1a226055f0d90',1,'Graphic3d_CView']]],
   ['glactiveshaderprogram',['glActiveShaderProgram',['../struct_open_gl___gl_functions.html#af6ac690246a77996d46d1f2aa5e7513b',1,'OpenGl_GlFunctions']]],
   ['glactivetexture',['glActiveTexture',['../struct_open_gl___gl_functions.html#a5d88db62e1b29af3d5d1912c9170825f',1,'OpenGl_GlFunctions']]],
   ['glattachshader',['glAttachShader',['../struct_open_gl___gl_functions.html#a9a67b664490bb0157124c2046bfdc7a9',1,'OpenGl_GlFunctions']]],
@@ -70,7 +67,6 @@ var searchData=
   ['glcompressedtexsubimage1d',['glCompressedTexSubImage1D',['../struct_open_gl___gl_functions.html#a85c96f2469a2e63581e43d064d46555d',1,'OpenGl_GlFunctions']]],
   ['glcompressedtexsubimage2d',['glCompressedTexSubImage2D',['../struct_open_gl___gl_functions.html#a863b1eee652f6812d74f77bdb7332df5',1,'OpenGl_GlFunctions']]],
   ['glcompressedtexsubimage3d',['glCompressedTexSubImage3D',['../struct_open_gl___gl_functions.html#a3af4f63ea83b77b77e6612b186b9ed16',1,'OpenGl_GlFunctions']]],
-  ['glcontext',['glContext',['../struct_aspect___graphic_callback_struct.html#ae6dcc41a96d11241d1c86fa6361f96ea',1,'Aspect_GraphicCallbackStruct']]],
   ['glcopybuffersubdata',['glCopyBufferSubData',['../struct_open_gl___gl_functions.html#a380063273182b970f19195e6749292ea',1,'OpenGl_GlFunctions']]],
   ['glcopyimagesubdata',['glCopyImageSubData',['../struct_open_gl___gl_functions.html#a20dd23e2a71f434019871aa34e22b236',1,'OpenGl_GlFunctions']]],
   ['glcopytexsubimage3d',['glCopyTexSubImage3D',['../struct_open_gl___gl_functions.html#a3d83a04ac593fa52e91cf9f5a76bf8c0',1,'OpenGl_GlFunctions']]],
@@ -78,11 +74,8 @@ var searchData=
   ['glcreateshader',['glCreateShader',['../struct_open_gl___gl_functions.html#a4666f8557ce6c1ef9eb903cbea1931d3',1,'OpenGl_GlFunctions']]],
   ['glcreateshaderprogramv',['glCreateShaderProgramv',['../struct_open_gl___gl_functions.html#abaa15955b2eb5065d939c5c2d0a2621e',1,'OpenGl_GlFunctions']]],
   ['gldebugmessagecallback',['glDebugMessageCallback',['../struct_open_gl___gl_functions.html#ad704814ab52fb2ffeda26cf98578ac1d',1,'OpenGl_GlFunctions']]],
-  ['gldebugmessagecallbackarb',['glDebugMessageCallbackARB',['../struct_open_gl___gl_functions.html#ad6bb81d22b086501135ffd66ead9bf17',1,'OpenGl_GlFunctions']]],
   ['gldebugmessagecontrol',['glDebugMessageControl',['../struct_open_gl___gl_functions.html#a6816c45b969e9fef539b5981a1a2899b',1,'OpenGl_GlFunctions']]],
-  ['gldebugmessagecontrolarb',['glDebugMessageControlARB',['../struct_open_gl___gl_functions.html#ada2b92e75e5e4b7c67ba8c6e38eebdbf',1,'OpenGl_GlFunctions']]],
   ['gldebugmessageinsert',['glDebugMessageInsert',['../struct_open_gl___gl_functions.html#ae21d3fa8a0a0243df33facfd46e13197',1,'OpenGl_GlFunctions']]],
-  ['gldebugmessageinsertarb',['glDebugMessageInsertARB',['../struct_open_gl___gl_functions.html#ada54ca9b4d17e8b99106c5e1965b5b7a',1,'OpenGl_GlFunctions']]],
   ['gldeletebuffers',['glDeleteBuffers',['../struct_open_gl___gl_functions.html#a2c94c161082c919186d8e8ef42535c3e',1,'OpenGl_GlFunctions']]],
   ['gldeleteframebuffers',['glDeleteFramebuffers',['../struct_open_gl___gl_functions.html#a3ef0c4a99ca5b2c9118ebc99c5516e5e',1,'OpenGl_GlFunctions']]],
   ['gldeleteprogram',['glDeleteProgram',['../struct_open_gl___gl_functions.html#ac6cbf60a7b4b57f45efd9185479abf7d',1,'OpenGl_GlFunctions']]],
@@ -161,7 +154,6 @@ var searchData=
   ['glgetbuffersubdata',['glGetBufferSubData',['../struct_open_gl___gl_functions.html#afc7d45c74b506abcc5b1883050d3ae89',1,'OpenGl_GlFunctions']]],
   ['glgetcompressedteximage',['glGetCompressedTexImage',['../struct_open_gl___gl_functions.html#a0462886d44b65d453fb17840cacf2668',1,'OpenGl_GlFunctions']]],
   ['glgetdebugmessagelog',['glGetDebugMessageLog',['../struct_open_gl___gl_functions.html#a67f371cf02b22e7b571dd4b28275e9cc',1,'OpenGl_GlFunctions']]],
-  ['glgetdebugmessagelogarb',['glGetDebugMessageLogARB',['../struct_open_gl___gl_functions.html#a0e38f0f2b631a8b44cc68bae5232f9f1',1,'OpenGl_GlFunctions']]],
   ['glgetdoublei_5fv',['glGetDoublei_v',['../struct_open_gl___gl_functions.html#a67c8640f25c08e38623eeeefb45ff575',1,'OpenGl_GlFunctions']]],
   ['glgetfloati_5fv',['glGetFloati_v',['../struct_open_gl___gl_functions.html#a8cf62a9351d027fa5cdcd094f964f16a',1,'OpenGl_GlFunctions']]],
   ['glgetfragdataindex',['glGetFragDataIndex',['../struct_open_gl___gl_functions.html#a6b835af17dc8cb9daf9055942e2e3a0d',1,'OpenGl_GlFunctions']]],
@@ -309,6 +301,7 @@ var searchData=
   ['glmulttransposematrixf',['glMultTransposeMatrixf',['../struct_open_gl___gl_functions.html#acbc4693831be9a26afcb022a21ab40ba',1,'OpenGl_GlFunctions']]],
   ['glnormalp3ui',['glNormalP3ui',['../struct_open_gl___gl_functions.html#a153310f746ae58836ba22f800452ffa3',1,'OpenGl_GlFunctions']]],
   ['glnormalp3uiv',['glNormalP3uiv',['../struct_open_gl___gl_functions.html#a7d5bac66455adfba16614916c9b436b4',1,'OpenGl_GlFunctions']]],
+  ['globalillumination',['GlobalIllumination',['../struct_open_gl___view_1_1_raytracing_params.html#a6b00cb5c32f684b1cf3e41e1c9100872',1,'OpenGl_View::RaytracingParams']]],
   ['globjectlabel',['glObjectLabel',['../struct_open_gl___gl_functions.html#aaa45456841e996a508fa8f757ac62fe4',1,'OpenGl_GlFunctions']]],
   ['globjectptrlabel',['glObjectPtrLabel',['../struct_open_gl___gl_functions.html#ad73da1f20c7a4109b09fad79b8393be3',1,'OpenGl_GlFunctions']]],
   ['glpatchparameterfv',['glPatchParameterfv',['../struct_open_gl___gl_functions.html#af926f41b87e8b19358bf2d99a657cd32',1,'OpenGl_GlFunctions']]],
@@ -577,6 +570,10 @@ var searchData=
   ['glviewportindexedf',['glViewportIndexedf',['../struct_open_gl___gl_functions.html#a56729d84f58c33a18e70f7f3574c0f03',1,'OpenGl_GlFunctions']]],
   ['glviewportindexedfv',['glViewportIndexedfv',['../struct_open_gl___gl_functions.html#a991e17e9d0a30944748c0861abbe5865',1,'OpenGl_GlFunctions']]],
   ['glwaitsync',['glWaitSync',['../struct_open_gl___gl_functions.html#ac017a72abfebe0c17c146bdcca63d741',1,'OpenGl_GlFunctions']]],
+  ['glxquerycurrentrendererintegermesa',['glXQueryCurrentRendererIntegerMESA',['../struct_open_gl___gl_functions.html#a342ca83c730d974f0fee1238332a5f30',1,'OpenGl_GlFunctions']]],
+  ['glxquerycurrentrendererstringmesa',['glXQueryCurrentRendererStringMESA',['../struct_open_gl___gl_functions.html#acef2f38bcf4f3d6ec5b442edaf76d0c2',1,'OpenGl_GlFunctions']]],
+  ['glxqueryrendererintegermesa',['glXQueryRendererIntegerMESA',['../struct_open_gl___gl_functions.html#ae894dfd04d96dd57ebb5da0a12662ba8',1,'OpenGl_GlFunctions']]],
+  ['glxqueryrendererstringmesa',['glXQueryRendererStringMESA',['../struct_open_gl___gl_functions.html#a4f7f3972b0ccc2b7f13cebb142947df6',1,'OpenGl_GlFunctions']]],
   ['glxswapintervalext',['glXSwapIntervalEXT',['../struct_open_gl___gl_functions.html#a401a35c191fb5f1526ea7a81e5f998da',1,'OpenGl_GlFunctions']]],
   ['glxswapintervalsgi',['glXSwapIntervalSGI',['../struct_open_gl___gl_functions.html#a0d0f26f7c7cac837232050db3bb71601',1,'OpenGl_GlFunctions']]],
   ['gpvec',['gpVec',['../class_geom___vector.html#af10e0398facf46d52f319cd5fa31f0c8',1,'Geom_Vector']]],
