@@ -8,8 +8,6 @@
 #include "OCC_MainFrame.h"
 #include "Viewer3dApp.h"
 #include "Viewer3dDoc.h"
-#include "ZClippingDlg.h"
-#include "ZCueingDlg.h"
 #include "ScaleDlg.h"
 #include "ShadingModelDlg.h"
 #include "ModelClippingDlg.h"
@@ -86,9 +84,7 @@ BEGIN_MESSAGE_MAP(CViewer3dView, CView)
 	ON_COMMAND(ID_SPOT_LIGHT, OnSpotLight)
 	ON_COMMAND(ID_POSITIONAL_LIGHT, OnPositionalLight)
 	ON_COMMAND(ID_AMBIENT_LIGHT, OnAmbientLight)
-	ON_COMMAND(ID_ZCUEING, OnZcueing)
 	ON_COMMAND(ID_SCALE, OnScale)
-	ON_COMMAND(ID_ZCLIPPING, OnZclipping)
 	ON_COMMAND(ID_SHADINGMODEL, OnShadingmodel)
 	ON_COMMAND(ID_ANTIALIASINGONOFF, OnAntialiasingonoff)
 	ON_COMMAND(ID_CLEAR_LIGHTS, OnClearLights)
@@ -111,8 +107,6 @@ CViewer3dView::CViewer3dView()
   myXmax (0),
   myYmax (0),
   myCurZoom (0.0),
-  myWidth  (0),
-  myHeight (0),
   NbActiveLights (2), // There are 2 default active lights
   myHlrModeIsOn (Standard_False),
   m_Pen (NULL),
@@ -131,10 +125,10 @@ CViewer3dView::~CViewer3dView()
 
 BOOL CViewer3dView::PreCreateWindow(CREATESTRUCT& cs)
 {
-	// TODO: Modify the Window class or styles here by modifying
-	//  the CREATESTRUCT cs
-
-	return CView::PreCreateWindow(cs);
+  // TODO: Modify the Window class or styles here by modifying
+  //  the CREATESTRUCT cs
+  cs.lpszClass = ::AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW | CS_DBLCLKS | CS_OWNDC, ::LoadCursor(NULL, IDC_ARROW), NULL, NULL);
+  return CView::PreCreateWindow(cs);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -170,15 +164,7 @@ void CViewer3dView::OnDraw(CDC* /*pDC*/)
 {
 	CViewer3dDoc* pDoc = GetDocument();
 	ASSERT_VALID(pDoc);
-	CRect aRect;
-	GetWindowRect(aRect);
-	if(myWidth != aRect.Width() || myHeight != aRect.Height()) {
-		myWidth = aRect.Width();
-		myHeight = aRect.Height();
-		::PostMessage ( GetSafeHwnd () , WM_SIZE , SW_SHOW , myWidth + myHeight*65536 );
-	}
 	myView->Redraw();
-
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -228,18 +214,19 @@ gp_Pnt ConvertClickToPoint(Standard_Real x, Standard_Real y, Handle(V3d_View) aV
 	return ResultPoint;
 }
 
-void CViewer3dView::OnSize(UINT /*nType*/, int /*cx*/, int /*cy*/) 
+void CViewer3dView::OnSize(UINT nType, int cx, int cy)
 {
+  CView::OnSize (nType, cx, cy);
   if (!myView.IsNull())
    myView->MustBeResized();
 }
 
 void CViewer3dView::OnBUTTONBack() 
 { 
-	myView->SetProj(V3d_Xneg); 
+	myView->SetProj(V3d_Ypos); 
 
 TCollection_AsciiString Message("\
-myView->SetProj(V3d_Xneg);\n\
+myView->SetProj(V3d_Ypos);\n\
   ");
 
   // Update The Result Message Dialog
@@ -247,10 +234,10 @@ GetDocument()->UpdateResultMessageDlg("SetProj",Message);
 } // See the back View
 void CViewer3dView::OnBUTTONFront() 
 { 
-	myView->SetProj(V3d_Xpos); 
+	myView->SetProj(V3d_Yneg); 
 
 TCollection_AsciiString Message("\
-myView->SetProj(V3d_Xpos);\n\
+myView->SetProj(V3d_Yneg);\n\
   ");
 
   // Update The Result Message Dialog
@@ -282,10 +269,10 @@ GetDocument()->UpdateResultMessageDlg("SetProj",Message);
 
 void CViewer3dView::OnBUTTONLeft() 
 { 
-	myView->SetProj(V3d_Ypos); 
+	myView->SetProj(V3d_Xneg); 
 
 TCollection_AsciiString Message("\
-myView->SetProj(V3d_Ypos);\n\
+myView->SetProj(V3d_Xneg);\n\
   ");
 
   // Update The Result Message Dialog
@@ -293,10 +280,10 @@ GetDocument()->UpdateResultMessageDlg("SetProj",Message);
 } // See the left View	
 void CViewer3dView::OnBUTTONRight() 
 { 
-	myView->SetProj(V3d_Yneg); 
+	myView->SetProj(V3d_Xpos); 
 
 TCollection_AsciiString Message("\
-myView->SetProj(V3d_Yneg);\n\
+myView->SetProj(V3d_Xpos);\n\
   ");
 
   // Update The Result Message Dialog
@@ -1010,20 +997,6 @@ void CViewer3dView::OnScale()
 	myView->Redraw();
 }
 
-void CViewer3dView::OnZcueing() 
-{
-	ZCueingDlg Dlg(myView, GetDocument());
-	Dlg.DoModal();
-	myView->Redraw();
-}
-
-void CViewer3dView::OnZclipping() 
-{
-	ZClippingDlg Dlg(myView, GetDocument());
-	Dlg.DoModal();
-	myView->Redraw();
-}
-
 //V3d_View.hxx
 
 void CViewer3dView::OnShadingmodel() 
@@ -1045,18 +1018,13 @@ GetDocument()->UpdateResultMessageDlg("SetShadingModel",Message);
 
 void CViewer3dView::OnAntialiasingonoff() 
 {
-	if(!myView->Antialiasing())
-		myView->SetAntialiasingOn();
-	else
-		myView->SetAntialiasingOff();
-
+  Graphic3d_RenderingParams& aParams = myView->ChangeRenderingParams();
+  aParams.NbMsaaSamples = aParams.NbMsaaSamples == 0 ? 8 : 0;
 	myView->Update();
 
 TCollection_AsciiString Message("\
-if(!myView->Antialiasing())\n\
-	myView->SetAntialiasingOn();\n\
-else\n\
-	myView->SetAntialiasingOff();\n\
+Graphic3d_RenderingParams& aParams = myView->ChangeRenderingParams();\n\
+aParams.NbMsaaSamples = aParams.NbMsaaSamples == 0 ? 8 : 0;\n\
   ");
 
   // Update The Result Message Dialog
