@@ -69,7 +69,7 @@ COcafDoc::~COcafDoc()
  	Handle(TOcaf_Application) OcafApp = ((COcafApp*)AfxGetApp())->GetApp();
  
  	// Create a new Ocaf document
- 	OcafApp->NewDocument("MDTV-Standard",myOcafDoc);
+ 	OcafApp->NewDocument("BinOcaf",myOcafDoc);
  	TPrsStd_AISViewer::New(myOcafDoc->Main(),myViewer);
  
  	Handle(AIS_InteractiveContext) CTX;
@@ -87,7 +87,7 @@ COcafDoc::~COcafDoc()
  Handle(TOcaf_Application) OcafApp= ((COcafApp*)AfxGetApp())->GetApp(); \n\
   \n\
  //  Creating the new document \n\
- OcafApp->NewDocument(\"MDTV-Standard\", myOcafDoc); \n\
+ OcafApp->NewDocument(\"BinOcaf\", myOcafDoc); \n\
   \n\
  //  Creation of a new TPrsStd_AISViewer connected to the current V3d_Viewer\n\
  TPrsStd_AISViewer::New(myOcafDoc->Main(),myViewer); \n\
@@ -213,7 +213,7 @@ void COcafDoc::OnCreatebox()
 
 	// Create a new box using the CNewBoxDlg Dialog parameters as attributes
   TDF_Label L = TSC.CreateBox (Dlg.m_x, Dlg.m_y, Dlg.m_z, Dlg.m_w, Dlg.m_l, Dlg.m_h,
-                               TCollection_ExtendedString ((Standard_ExtString )(const wchar_t* )Dlg.m_Name));
+                               TCollection_ExtendedString ((const wchar_t* )Dlg.m_Name));
 
 	// Get the TPrsStd_AISPresentation of the new box TNaming_NamedShape
 	Handle(TPrsStd_AISPresentation) prs= TPrsStd_AISPresentation::Set(L, TNaming_NamedShape::GetID()); 
@@ -270,7 +270,7 @@ void COcafDoc::OnCreatecyl()
 
 	// Create a new box using the CNewCylDlg Dialog parameters as attributes
   TDF_Label L = TSC.CreateCyl (Dlg.m_x, Dlg.m_y, Dlg.m_z, Dlg.m_r, Dlg.m_h,
-                               TCollection_ExtendedString ((Standard_ExtString )(const wchar_t* )Dlg.m_Name));
+                               TCollection_ExtendedString ((const wchar_t* )Dlg.m_Name));
 
 	// Get the TPrsStd_AISPresentation of the new cylinder TNaming_NamedShape
 	Handle(TPrsStd_AISPresentation) prs= TPrsStd_AISPresentation::Set(L, TNaming_NamedShape::GetID()); 
@@ -336,7 +336,7 @@ void COcafDoc::OnModify()
 	Standard_GUID myDriverID=TFF->GetDriverGUID();
 
 	Handle(TDocStd_Document) D = GetOcafDoc();
-	TFunction_Logbook log;
+	Handle(TFunction_Logbook) log = TFunction_Logbook::Set(D->Main());
 
 	TCollection_AsciiString Message("\
 //  Modification and recomputation of the selected object \n\
@@ -389,7 +389,7 @@ Handle(TFunction_Function) TFF; \n\
 		// Modify the box
 		TOcaf_Commands TSC(LabObject);
 		TSC.ModifyBox (Dlg.m_x, Dlg.m_y, Dlg.m_z, Dlg.m_w, Dlg.m_l, Dlg.m_h,
-                   TCollection_ExtendedString ((Standard_ExtString )(const wchar_t* )Dlg.m_Name), log);
+                   TCollection_ExtendedString ((const wchar_t* )Dlg.m_Name), log);
 
 		// Get the presentation of the box, display it and set it selected
 		Handle(TPrsStd_AISPresentation) prs= TPrsStd_AISPresentation::Set(LabObject, TNaming_NamedShape::GetID()); 
@@ -474,7 +474,7 @@ D->CommitCommand(); \n\
 		// Modify the cylinder
 		TOcaf_Commands TSC(LabObject);
 		TSC.ModifyCyl (Dlg.m_x, Dlg.m_y, Dlg.m_z, Dlg.m_r, Dlg.m_h,
-                   TCollection_ExtendedString ((Standard_ExtString )(const wchar_t* )Dlg.m_Name), log);
+                   TCollection_ExtendedString ((const wchar_t* )Dlg.m_Name), log);
 
 		// Get the presentation of the cylinder, display it and set it selected
 		Handle(TPrsStd_AISPresentation) prs= TPrsStd_AISPresentation::Set(LabObject, TNaming_NamedShape::GetID()); 
@@ -591,7 +591,7 @@ D->CommitCommand(); \n\
 		// Modify the cylinder
 		TOcaf_Commands ToolTSC(ToolLab);
 		ToolTSC.ModifyCyl (Dlg.m_x, Dlg.m_y, Dlg.m_z, Dlg.m_r, Dlg.m_h,
-                       TCollection_ExtendedString ((Standard_ExtString )(const wchar_t* )Dlg.m_Name), log);
+                       TCollection_ExtendedString ((const wchar_t* )Dlg.m_Name), log);
 
 		// Redisplay the modified Tool object
 		TDataStd_Integer::Set(ToolLab, 1);
@@ -600,14 +600,14 @@ D->CommitCommand(); \n\
 		Sleep(1000);
 
 		// Get the TOcafFunction_CutDriver using its Standard_GUID in the TFunction_DriverTable
-		Handle(TOcafFunction_CutDriver) myCutDriver;
+		Handle(TFunction_Driver) myCutDriver;
 		if (TFunction_DriverTable::Get()->FindDriver(myDriverID, myCutDriver))
             myCutDriver->Init(LabObject);
 
 		// Recompute the cut object if it must be (look at the MustExecute function code)
 //		if (myCutDriver->MustExecute(log))
 //		{
-			log.SetTouched(LabObject);
+			log->SetTouched(LabObject);
 			if(myCutDriver->Execute(log))
 				MessageBoxW (AfxGetApp()->m_pMainWnd->m_hWnd, L"Recompute failed", L"Modify cut", MB_ICONEXCLAMATION);
 //		}
@@ -643,7 +643,7 @@ TOcaf_Commands TSC(ToolLab); \n\
 TSC.ModifyBox(m_x, m_y, m_z, m_w, m_l, m_h, Name); \n\
  \n\
 //  Getting the TOcafFunction_CutDriver used to create the cut\n\
-Handle(TOcafFunction_CutDriver) myCutDriver; \n\
+Handle(TFunction_Driver) myCutDriver; \n\
 TFunction_DriverTable::Get()->FindDriver(myDriverID, myCutDriver); \n\
  \n\
 //  Recompute the cut if it must be (if an attribute was modified)\n\
@@ -899,22 +899,18 @@ void COcafDoc::OnCloseDocument()
 void COcafDoc::OnFileSaveAs() 
 {
 	const wchar_t* SPathName = PathName;
-	TCollection_ExtendedString TPathName ((Standard_ExtString )SPathName);
+	TCollection_ExtendedString TPathName (SPathName);
 
 	CString Filter;
 
 	if (TPathName.SearchFromEnd(".xml") > 0){
-		Filter = "OCAFSample(XML) (*.xml)|*.xml|OCAFSample(STD) (*.std)|*.std|OCAFSample(Binary) (*.cbf)|*.cbf||";
-	}
-	else if (TPathName.SearchFromEnd(".cbf") > 0){
-		Filter = "OCAFSample(Binary) (*.cbf)|*.cbf|OCAFSample(STD) (*.std)|*.std|OCAFSample(XML) (*.xml)|*.xml||";
-	}
-	else{
-		Filter = "OCAFSample(STD) (*.std)|*.std|OCAFSample(XML) (*.xml)|*.xml|OCAFSample(Binary) (*.cbf)|*.cbf||";
+		Filter = "OCAFSample(XML) (*.xml)|*.xml|OCAFSample(Binary) (*.cbf)|*.cbf||";
+	} else {
+		Filter = "OCAFSample(Binary) (*.cbf)|*.cbf|OCAFSample(XML) (*.xml)|*.xml||";
 	}
 	
 	CFileDialog dlg(FALSE,
-			L"std",
+			L"cbf",
 			GetTitle(),
 			OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT,
 			Filter,
@@ -932,7 +928,7 @@ void COcafDoc::OnFileSaveAs()
 	cout << "Save As " << CSPath << endl;
 	PathName=CSPath;
         const wchar_t* SPath = CSPath;
-	TCollection_ExtendedString TPath ((Standard_ExtString )SPath);
+	TCollection_ExtendedString TPath (SPath);
 
 	    if (TPath.SearchFromEnd(".xml") > 0)
 		{
@@ -944,11 +940,6 @@ void COcafDoc::OnFileSaveAs()
 			// The document must be saved in binary format
 			myOcafDoc->ChangeStorageFormat("BinOcaf");
 		}
-		else
-		{
-			// The document must be saved in standard format
-			myOcafDoc->ChangeStorageFormat("MDTV-Standard");
-		}
 
 		try
 		{
@@ -993,7 +984,7 @@ void COcafDoc::OnFileSave()
 	if(PathName!="")
 	{
           const wchar_t* SPath = PathName;
-          TCollection_ExtendedString TPath ((Standard_ExtString )SPath);
+          TCollection_ExtendedString TPath (SPath);
 
 	    if (TPath.SearchFromEnd(".xml") > 0)
 		{
@@ -1005,11 +996,6 @@ void COcafDoc::OnFileSave()
 			// The document must be saved in binary format
 			myOcafDoc->ChangeStorageFormat("BinOcaf");
 		}
-		else
-		{
-			// The document must be saved in standard format
-			myOcafDoc->ChangeStorageFormat("MDTV-Standard");
-		}
 
 		try
 		{
@@ -1038,10 +1024,10 @@ m_App->SaveAs(myOcafDoc,(TCollection_ExtendedString) TPath); \n\
 	}
 
 	CFileDialog dlg(FALSE,
-			L"std",
+			L"cbf",
 			GetTitle(),
 			OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT,
-			L"OCAFSample(STD) (*.std)|*.std|OCAFSample(XML) (*.xml)|*.xml|OCAFSample(Binary) (*.cbf)|*.cbf||",
+			L"OCAFSample(Binary) (*.cbf)|*.cbf|OCAFSample(XML) (*.xml)|*.xml||",
 			NULL );
 
 	if (dlg.DoModal() != IDOK) return;
@@ -1052,7 +1038,7 @@ m_App->SaveAs(myOcafDoc,(TCollection_ExtendedString) TPath); \n\
 	CString CSPath = dlg.GetPathName();
 
 	const wchar_t* SPath = CSPath;
-    TCollection_ExtendedString TPath ((Standard_ExtString )SPath);
+    TCollection_ExtendedString TPath (SPath);
 
     // Choose storage format
     if (TPath.SearchFromEnd(".xml") > 0)
@@ -1065,11 +1051,6 @@ m_App->SaveAs(myOcafDoc,(TCollection_ExtendedString) TPath); \n\
 	  // The document must be saved in binary format
 	  myOcafDoc->ChangeStorageFormat("BinOcaf");
 	}
-	else
-	{
-		// The document must be saved in standard format
-		myOcafDoc->ChangeStorageFormat("MDTV-Standard");
-	}
 
    try
    {
@@ -1113,7 +1094,7 @@ BOOL COcafDoc::OnOpenDocument(LPCTSTR lpszPathName)
   PathName = lpszPathName;
 
   const wchar_t* aPathName = lpszPathName;
-  TCollection_ExtendedString anOccPathName ((Standard_ExtString)aPathName);
+  TCollection_ExtendedString anOccPathName (aPathName);
 
   // Open the document in the current application
   //PCDM_ReaderStatus RS = m_App->Open(TPath,myOcafDoc);
