@@ -105,10 +105,10 @@ CAnimationView3D::~CAnimationView3D()
 
 BOOL CAnimationView3D::PreCreateWindow(CREATESTRUCT& cs)
 {
-	// TODO: Modify the Window class or styles here by modifying
-	//  the CREATESTRUCT cs
-
-	return CView::PreCreateWindow(cs);
+  // TODO: Modify the Window class or styles here by modifying
+  //  the CREATESTRUCT cs
+  cs.lpszClass = ::AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW | CS_DBLCLKS | CS_OWNDC, ::LoadCursor(NULL, IDC_ARROW), NULL, NULL);
+  return CView::PreCreateWindow(cs);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -227,18 +227,19 @@ void CAnimationView3D::OnFileExportImage()
   GetDocument()->ExportView (myView);
 }
 
-void CAnimationView3D::OnSize(UINT /*nType*/, int cx, int cy) 
+void CAnimationView3D::OnSize(UINT nType, int cx, int cy)
 {
-	m_cx = cx ;
-	m_cy = cy ;
-	if (!myView.IsNull())
-		myView->MustBeResized();
+  CView::OnSize (nType, cx, cy);
+  m_cx = cx ;
+  m_cy = cy ;
+  if (!myView.IsNull())
+    myView->MustBeResized();
 }
 
 void CAnimationView3D::OnBUTTONBack() 
-{ myView->SetProj(V3d_Xneg); } // See the back View
+{ myView->SetProj(V3d_Ypos); } // See the back View
 void CAnimationView3D::OnBUTTONFront() 
-{ myView->SetProj(V3d_Xpos); } // See the front View
+{ myView->SetProj(V3d_Yneg); } // See the front View
 
 void CAnimationView3D::OnBUTTONBottom() 
 { myView->SetProj(V3d_Zneg); } // See the bottom View
@@ -246,9 +247,9 @@ void CAnimationView3D::OnBUTTONTop()
 { myView->SetProj(V3d_Zpos); } // See the top View	
 
 void CAnimationView3D::OnBUTTONLeft() 
-{ myView->SetProj(V3d_Ypos); } // See the left View	
+{ myView->SetProj(V3d_Xneg); } // See the left View	
 void CAnimationView3D::OnBUTTONRight() 
-{ myView->SetProj(V3d_Yneg); } // See the right View
+{ myView->SetProj(V3d_Xpos); } // See the right View
 
 void CAnimationView3D::OnBUTTONAxo() 
 { myView->SetProj(V3d_XposYnegZpos); } // See the axonometric View
