@@ -28,6 +28,7 @@
 #include <Geom_SurfaceOfRevolution.hxx>
 #include <Geom_ToroidalSurface.hxx>
 #include <Geom_ConicalSurface.hxx>
+#include <Geom_BSplineSurface.hxx>
 
 
 // Initialization of global variable with an instance of this class
@@ -53,11 +54,7 @@ static const Quantity_Color SurfaceColor     (1,1,0, Quantity_TOC_RGB);      //
 static const Quantity_Color BSplineColor     (1,0.647,0, Quantity_TOC_RGB);  // orange
 static const Quantity_Color BSplineSurfaceColor (0,0,1, Quantity_TOC_RGB);   // blue
 
-#ifdef WNT
- #define EOL "\r\n"
-#else
- #define EOL "\n"
-#endif
+#define EOL "\r\n"
 
 //////////////////////////////////////////////////////////////////////
 // Construction/Destruction
@@ -89,7 +86,7 @@ void Convert_Presentation::DoSample()
 // Function : Convert_Presentation::drawSurfaceAndItsBSpline
 // Purpose  : 
 //================================================================
-void Convert_Presentation::drawSurfaceAndItsBSpline(Handle_Geom_Surface theSurface, 
+void Convert_Presentation::drawSurfaceAndItsBSpline(const Handle(Geom_Surface) & theSurface, 
                                                     const Standard_CString theName, 
                                                     TCollection_AsciiString& theText)
 {
@@ -98,7 +95,7 @@ void Convert_Presentation::drawSurfaceAndItsBSpline(Handle_Geom_Surface theSurfa
   aTitle += " to BSpline surface";
 
   theText += EOL
-    "  Handle_Geom_BSplineSurface aBSplineSurface = " EOL
+    "  Handle(Geom_BSplineSurface) aBSplineSurface = " EOL
     "    GeomConvert::SurfaceToBSplineSurface(aSurface);" EOL;
 
   setResultTitle (aTitle.ToCString());
@@ -108,7 +105,7 @@ void Convert_Presentation::drawSurfaceAndItsBSpline(Handle_Geom_Surface theSurfa
 
   if (WAIT_A_LITTLE) return;
 
-  Handle_Geom_BSplineSurface aBSplineSurface = GeomConvert::SurfaceToBSplineSurface(theSurface);
+  Handle(Geom_BSplineSurface) aBSplineSurface = GeomConvert::SurfaceToBSplineSurface(theSurface);
 
   _ASSERTE(!aBSplineSurface.IsNull());
 
@@ -119,7 +116,7 @@ void Convert_Presentation::drawSurfaceAndItsBSpline(Handle_Geom_Surface theSurfa
 // Function : Convert_Presentation::drawCurveAndItsBSpline
 // Purpose  : 
 //================================================================
-void Convert_Presentation::drawCurveAndItsBSpline(Handle_Geom_Curve theCurve, 
+void Convert_Presentation::drawCurveAndItsBSpline(Handle(Geom_Curve) theCurve, 
                                                   const Standard_CString theName, 
                                                   TCollection_AsciiString& theText)
 {
@@ -128,7 +125,7 @@ void Convert_Presentation::drawCurveAndItsBSpline(Handle_Geom_Curve theCurve,
   aTitle += " to BSpline curve";
 
   theText += EOL
-    "  Handle_Geom_BSplineCurve aBSpline = " EOL
+    "  Handle(Geom_BSplineCurve) aBSpline = " EOL
     "    GeomConvert::CurveToBSplineCurve(aCurve);" EOL;
 
   setResultTitle (aTitle.ToCString());
@@ -138,7 +135,7 @@ void Convert_Presentation::drawCurveAndItsBSpline(Handle_Geom_Curve theCurve,
   
   if (WAIT_A_LITTLE) return;
 
-  Handle_Geom_BSplineCurve aBSpline = GeomConvert::CurveToBSplineCurve(theCurve);
+  Handle(Geom_Curve) aBSpline = GeomConvert::CurveToBSplineCurve(theCurve);
 
   drawCurve (aBSpline, BSplineColor);
 }
@@ -158,7 +155,7 @@ void Convert_Presentation::sampleCircle()
   gp_Dir aDir (1,0,0);
   gp_Ax2 aAxis (aOrigin, aDir);
   Standard_Real aRadius = 300;
-  Handle_Geom_Circle aCurve = new Geom_Circle (aAxis, aRadius);
+  Handle(Geom_Circle) aCurve = new Geom_Circle (aAxis, aRadius);
 
   TCollection_AsciiString aText (
     "  gp_Pnt aOrigin (0,0,0);" EOL
@@ -370,7 +367,7 @@ void Convert_Presentation::sampleRevolSurface()
   aPoles(3) = gp_Pnt(350, 150, 0);  aWeights(3) =120;
   aPoles(4) = gp_Pnt(500, 500, 0);  aWeights(4) = 1;
 
-  Handle(Geom_BezierCurve) aBezierCurve = new Geom_BezierCurve(aPoles, aWeights);
+  Handle(Geom_Curve) aBezierCurve = new Geom_BezierCurve(aPoles, aWeights);
   drawCurve(aBezierCurve);
 
   // creating a surface of revolution of the bezier curve around Y axis
