@@ -11,11 +11,9 @@
 #include "RadiusParamsPage.h"
 #include "ParamsFacesPage.h"
 #include <Standard_Macro.hxx>
-#include <AIS_InteractiveContext.hxx>
 #include <TColStd_ListIteratorOfListOfInteger.hxx>
 #include <TColStd_ListOfInteger.hxx>
 #include <AIS_LocalContext.hxx>
-#include <AIS_Selection.hxx>
 #include <Quantity_Color.hxx>
 
 BEGIN_MESSAGE_MAP(CDimensionDlg, CDialog)
@@ -381,10 +379,10 @@ void CDimensionDlg::OnBnClickedDimLength()
 {
   // Update parameters
   UpdateStandardModeForLength ();
-  (CTabCtrl*) GetDlgItem (IDC_LengthTab)->ShowWindow (SW_SHOW);
-  (CTabCtrl*) GetDlgItem (IDC_AngleTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_RadiusTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_DiameterTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_LengthTab)->ShowWindow (SW_SHOW);
+  GetDlgItem (IDC_AngleTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_RadiusTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_DiameterTab)->ShowWindow (SW_HIDE);
 
   UpdateUnitsListForLength ();
   ((CSliderCtrl*)GetDlgItem(IDC_Flyout))->SetPos (15);
@@ -399,10 +397,10 @@ void CDimensionDlg::OnBnClickedDimAngle()
 {
   // Update parameters
   UpdateStandardModeForAngle();
-  (CTabCtrl*) GetDlgItem (IDC_LengthTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_AngleTab)->ShowWindow (SW_SHOW);
-  (CTabCtrl*) GetDlgItem (IDC_RadiusTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_DiameterTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_LengthTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_AngleTab)->ShowWindow (SW_SHOW);
+  GetDlgItem (IDC_RadiusTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_DiameterTab)->ShowWindow (SW_HIDE);
 
   UpdateUnitsListForAngle();
   ((CSliderCtrl*)GetDlgItem(IDC_Flyout))->SetPos (15);
@@ -420,10 +418,10 @@ void CDimensionDlg::OnBnClickedDimDiameter()
   myAISContext->OpenLocalContext();
   myAISContext->ActivateStandardMode (TopAbs_EDGE);
 
-  (CTabCtrl*) GetDlgItem (IDC_LengthTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_AngleTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_RadiusTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_DiameterTab)->ShowWindow (SW_SHOW);
+  GetDlgItem (IDC_LengthTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_AngleTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_RadiusTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_DiameterTab)->ShowWindow (SW_SHOW);
 
   UpdateUnitsListForLength();
   ((CSliderCtrl*)GetDlgItem(IDC_Flyout))->SetPos (0);
@@ -440,10 +438,10 @@ void CDimensionDlg::OnBnClickedDimRadius()
   myAISContext->CloseAllContexts();
   myAISContext->OpenLocalContext();
   myAISContext->ActivateStandardMode (TopAbs_EDGE);
-  (CTabCtrl*) GetDlgItem (IDC_LengthTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_AngleTab)->ShowWindow (SW_HIDE);
-  (CTabCtrl*) GetDlgItem (IDC_RadiusTab)->ShowWindow (SW_SHOW);
-  (CTabCtrl*) GetDlgItem (IDC_DiameterTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_LengthTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_AngleTab)->ShowWindow (SW_HIDE);
+  GetDlgItem (IDC_RadiusTab)->ShowWindow (SW_SHOW);
+  GetDlgItem (IDC_DiameterTab)->ShowWindow (SW_HIDE);
 
   UpdateUnitsListForLength();
   ((CSliderCtrl*)GetDlgItem(IDC_Flyout))->SetPos (0);
@@ -604,7 +602,7 @@ void CDimensionDlg::OnDestroy()
 const Standard_Boolean CDimensionDlg::GetTextType() const
 {
   CButton* a3DButton = (CButton*)GetDlgItem (IDC_3DText);
-  return a3DButton->GetCheck();
+  return a3DButton->GetCheck() != 0;
 }
 
 //=======================================================================
@@ -717,8 +715,7 @@ const TCollection_AsciiString CDimensionDlg::GetUnits() const
     return TCollection_AsciiString();
   CString aStr;
   GetDlgItem (IDC_DisplayUnits)->GetWindowText (aStr);
-  TCollection_ExtendedString aCharsW ((Standard_ExtString )(const wchar_t* )aStr);
-  return TCollection_AsciiString (aCharsW, '?');
+  return TCollection_AsciiString ((const wchar_t* )aStr);
 }
 
 //=======================================================================
@@ -763,11 +760,3 @@ void CDimensionDlg::OnClose()
   }
   CDialog::OnClose();
 }
-
-TopoDS_Shape CDimensionDlg::SelectedShape()
-{
-  Handle(Standard_Transient) aSelection = AIS_Selection::CurrentSelection()->Value();
-  Handle(SelectMgr_EntityOwner) anOwner = *((Handle(SelectMgr_EntityOwner)*)&aSelection);
-  Handle(StdSelect_BRepOwner) aBrepOwner = Handle(StdSelect_BRepOwner)::DownCast(anOwner);
-  return aBrepOwner->Shape().Located (aBrepOwner->Location() * aBrepOwner->Shape().Location());
-}
