@@ -49,9 +49,11 @@
 #include <SelectMgr_Selection.hxx>
 #include <Standard_ProgramError.hxx>
 #include <UnitsAPI.hxx>
+#include <Geom_Line.hxx>
+#include <Geom_Plane.hxx>
 
-IMPLEMENT_STANDARD_HANDLE (AIS_AngleDimension, AIS_Dimension)
-IMPLEMENT_STANDARD_RTTIEXT (AIS_AngleDimension, AIS_Dimension)
+
+IMPLEMENT_STANDARD_RTTIEXT(AIS_AngleDimension,AIS_Dimension)
 
 namespace
 {
@@ -59,7 +61,7 @@ namespace
   static const Standard_Real              THE_EMPTY_LABEL_WIDTH = 0.0;
   static const Standard_ExtCharacter      THE_DEGREE_SYMBOL (0x00B0);
   static const Standard_Real              THE_3D_TEXT_MARGIN = 0.1;
-};
+}
 
 //=======================================================================
 //function : Constructor
@@ -152,7 +154,7 @@ void AIS_AngleDimension::SetMeasuredGeometry (const TopoDS_Edge& theFirstEdge,
 
   if (myIsGeometryValid && !myIsPlaneCustom)
   {
-    ComputePlane();
+    myPlane = aComputedPlane;
   }
 
   SetToUpdate();
@@ -277,6 +279,8 @@ void AIS_AngleDimension::SetMeasuredGeometry (const TopoDS_Face& theFirstFace,
 //=======================================================================
 void AIS_AngleDimension::Init()
 {
+  SetType (AIS_TOA_Interior);
+  SetArrowsVisibility (AIS_TOAV_Both);
   SetSpecialSymbol (THE_DEGREE_SYMBOL);
   SetDisplaySpecialSymbol (AIS_DSS_After);
   SetFlyout (15.0);
@@ -298,6 +302,14 @@ gp_Pnt AIS_AngleDimension::GetCenterOnArc (const gp_Pnt& theFirstAttach,
   }
   
   gp_Pln aPlane = aConstructPlane.Value();
+  // to have an exterior angle presentation, a plane for further constructed circle should be reversed
+  if (myType == AIS_TOA_Exterior)
+  {
+    gp_Ax1 anAxis = aPlane.Axis();
+    gp_Dir aDir = anAxis.Direction();
+    aDir.Reverse();
+    aPlane.SetAxis(gp_Ax1(anAxis.Location(), aDir));
+  }
 
   Standard_Real aRadius = theFirstAttach.Distance (theCenter);
 
@@ -318,6 +330,21 @@ gp_Pnt AIS_AngleDimension::GetCenterOnArc (const gp_Pnt& theFirstAttach,
   return ElCLib::Value ((aParamBeg + aParamEnd) * 0.5, aCircle);
 }
 
+//=======================================================================
+//function : GetNormalForMinAngle
+//purpose  :
+//=======================================================================
+gp_Dir AIS_AngleDimension::GetNormalForMinAngle() const
+{
+  const gp_Dir& aNormal = myPlane.Axis().Direction();
+  gp_Dir aFirst (gp_Vec (myCenterPoint, myFirstPoint) );
+  gp_Dir aSecond (gp_Vec (myCenterPoint, mySecondPoint) );
+
+  return aFirst.AngleWithRef (aSecond, aNormal) < 0.0
+    ? aNormal.Reversed()
+    : aNormal;
+}
+
 //=======================================================================
 //function : DrawArc
 //purpose  : draws the arc between two attach points
@@ -329,14 +356,16 @@ void AIS_AngleDimension::DrawArc (const Handle(Prs3d_Presentation)& thePresentat
                                   const Standard_Real theRadius,
                                   const Standard_Integer theMode)
 {
-  // construct plane where the circle and the arc are located
-  gce_MakePln aConstructPlane (theFirstAttach, theSecondAttach, theCenter);
-  if (!aConstructPlane.IsDone())
-  {
-    return;
-  }
+  gp_Pln aPlane (myCenterPoint, GetNormalForMinAngle());
 
-  gp_Pln aPlane = aConstructPlane.Value();
+  // to have an exterior angle presentation, a plane for further constructed circle should be reversed
+  if (myType == AIS_TOA_Exterior)
+  {
+    gp_Ax1 anAxis = aPlane.Axis();
+    gp_Dir aDir = anAxis.Direction();
+    aDir.Reverse();
+    aPlane.SetAxis(gp_Ax1(anAxis.Location(), aDir));
+  }
 
   // construct circle forming the arc
   gce_MakeCirc aConstructCircle (theCenter, aPlane, theRadius);
@@ -362,7 +391,10 @@ void AIS_AngleDimension::DrawArc (const Handle(Prs3d_Presentation)& thePresentat
   // compute number of discretization elements in old-fanshioned way
   gp_Vec aCenterToFirstVec  (theCenter, theFirstAttach);
   gp_Vec aCenterToSecondVec (theCenter, theSecondAttach);
-  const Standard_Real anAngle = aCenterToFirstVec.Angle (aCenterToSecondVec);
+  Standard_Real anAngle = aCenterToFirstVec.Angle (aCenterToSecondVec);
+  if (myType == AIS_TOA_Exterior)
+    anAngle = 2.0 * M_PI - anAngle;
+  // it sets 50 points on PI, and a part of points if angle is less
   const Standard_Integer aNbPoints = Max (4, Standard_Integer (50.0 * anAngle / M_PI));
 
   GCPnts_UniformAbscissa aMakePnts (anArcAdaptor, aNbPoints);
@@ -413,15 +445,8 @@ void AIS_AngleDimension::DrawArcWithText (const Handle(Prs3d_Presentation)& theP
                                           const Standard_Integer theMode,
                                           const Standard_Integer theLabelPosition)
 {
-  // construct plane where the circle and the arc are located
-  gce_MakePln aConstructPlane (theFirstAttach, theSecondAttach, theCenter);
-  if (!aConstructPlane.IsDone())
-  {
-    return;
-  }
-
-  gp_Pln aPlane = aConstructPlane.Value();
-
+  gp_Pln aPlane (myCenterPoint, GetNormalForMinAngle());
+  
   Standard_Real aRadius = theFirstAttach.Distance (myCenterPoint);
 
   // construct circle forming the arc
@@ -448,7 +473,7 @@ void AIS_AngleDimension::DrawArcWithText (const Handle(Prs3d_Presentation)& theP
     gp_Dir aTextDir = gce_MakeDir (theFirstAttach, theSecondAttach);
 
     // Drawing text
-    DrawText (thePresentation,
+    drawText (thePresentation,
               aTextPos,
               aTextDir,
               theText,
@@ -468,14 +493,21 @@ void AIS_AngleDimension::DrawArcWithText (const Handle(Prs3d_Presentation)& theP
   if (isLineBreak)
   {
     // compute gap for label as parameteric size of sector on circle segment
-    Standard_Real aSectorOnCircle = theTextWidth / aRadius;
-  
-    gp_Pnt aTextPntBeg = ElCLib::Value (aParamMid - aSectorOnCircle * 0.5, aCircle);
-    gp_Pnt aTextPntEnd = ElCLib::Value (aParamMid + aSectorOnCircle * 0.5, aCircle);
+    Standard_Real aSectorOfText = theTextWidth / aRadius;
+    Standard_Real aTextBegin = aParamMid - aSectorOfText * 0.5;
+    Standard_Real aTextEnd = aParamMid + aSectorOfText * 0.5;
+    gp_Pnt aTextPntBeg = ElCLib::Value (aTextBegin, aCircle);
+    gp_Pnt aTextPntEnd = ElCLib::Value (aTextEnd, aCircle);
 
     // Drawing arcs
-    DrawArc (thePresentation, theFirstAttach, aTextPntBeg, theCenter, aRadius, theMode);
-    DrawArc (thePresentation, theSecondAttach, aTextPntEnd, theCenter, aRadius, theMode);
+    if (aTextBegin > aParamBeg)
+    {
+      DrawArc (thePresentation, theFirstAttach, aTextPntBeg, theCenter, aRadius, theMode);
+    }
+    if (aTextEnd < aParamEnd)
+    {
+      DrawArc (thePresentation, aTextPntEnd, theSecondAttach, theCenter, aRadius, theMode);
+    }
   }
   else
   {
@@ -510,11 +542,13 @@ void AIS_AngleDimension::ComputePlane()
     return;
   }
 
-  gp_Vec aFirstVec   = gp_Vec (myCenterPoint, myFirstPoint).Normalized();
-  gp_Vec aSecondVec  = gp_Vec (myCenterPoint, mySecondPoint).Normalized();
-  gp_Vec aDirectionN = aSecondVec.Crossed (aFirstVec).Normalized();
-  gp_Vec aDirectionY = (aFirstVec + aSecondVec).Normalized();
-  gp_Vec aDirectionX = aDirectionY.Crossed (aDirectionN).Normalized();
+  // Compute working plane so that Y axis is codirectional
+  // with Y axis of text coordinate system (necessary for text alignment)
+  gp_Vec aFirstVec   = gp_Vec (myCenterPoint, myFirstPoint);
+  gp_Vec aSecondVec  = gp_Vec (myCenterPoint, mySecondPoint);
+  gp_Vec aDirectionN = aSecondVec ^ aFirstVec;
+  gp_Vec aDirectionY = aFirstVec + aSecondVec;
+  gp_Vec aDirectionX = aDirectionY ^ aDirectionN;
 
   myPlane = gp_Pln (gp_Ax3 (myCenterPoint, gp_Dir (aDirectionN), gp_Dir (aDirectionX)));
 }
@@ -569,7 +603,7 @@ Standard_Real AIS_AngleDimension::ComputeValue() const
   gp_Vec aVec1 (myCenterPoint, myFirstPoint);
   gp_Vec aVec2 (myCenterPoint, mySecondPoint);
 
-  Standard_Real anAngle = aVec2.AngleWithRef (aVec1, GetPlane().Axis().Direction());
+  Standard_Real anAngle = aVec1.AngleWithRef (aVec2, GetNormalForMinAngle());
 
   return anAngle > 0.0 ? anAngle : (2.0 * M_PI + anAngle);
 }
@@ -582,7 +616,6 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
                                   const Handle(Prs3d_Presentation)& thePresentation,
                                   const Standard_Integer theMode)
 {
-  thePresentation->Clear();
   mySelectionGeom.Clear (theMode);
 
   if (!IsValid())
@@ -626,25 +659,25 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
   gp_Pnt aSecondAttach = myCenterPoint.Translated (gp_Vec(myCenterPoint, mySecondPoint).Normalized() * GetFlyout());
 
   //Arrows positions and directions
-  gp_Vec aWPDir = gp_Vec (GetPlane().Axis().Direction());
+  gp_Vec aWorkingPlaneDir (GetNormalForMinAngle());
 
-  gp_Dir aFirstExtensionDir  = aWPDir            ^ gp_Vec (myCenterPoint, aFirstAttach);
-  gp_Dir aSecondExtensionDir = aWPDir.Reversed() ^ gp_Vec (myCenterPoint, aSecondAttach);
+  gp_Dir aFirstExtensionDir  = aWorkingPlaneDir.Reversed() ^ gp_Vec (myCenterPoint, aFirstAttach);
+  gp_Dir aSecondExtensionDir = aWorkingPlaneDir            ^ gp_Vec (myCenterPoint, aSecondAttach);
 
   gp_Vec aFirstArrowVec  = gp_Vec (aFirstExtensionDir)  * anArrowLength;
   gp_Vec aSecondArrowVec = gp_Vec (aSecondExtensionDir) * anArrowLength;
 
-  gp_Pnt aFirstArrowBegin  (0.0, 0.0, 0.0);
-  gp_Pnt aFirstArrowEnd    (0.0, 0.0, 0.0);
-  gp_Pnt aSecondArrowBegin (0.0, 0.0, 0.0);
-  gp_Pnt aSecondArrowEnd   (0.0, 0.0, 0.0);
-
   if (isArrowsExternal)
   {
     aFirstArrowVec.Reverse();
     aSecondArrowVec.Reverse();
   }
 
+  gp_Pnt aFirstArrowBegin  (0.0, 0.0, 0.0);
+  gp_Pnt aFirstArrowEnd    (0.0, 0.0, 0.0);
+  gp_Pnt aSecondArrowBegin (0.0, 0.0, 0.0);
+  gp_Pnt aSecondArrowEnd   (0.0, 0.0, 0.0);
+
   aFirstArrowBegin  = aFirstAttach;
   aSecondArrowBegin = aSecondAttach;
   aFirstArrowEnd    = aFirstAttach.Translated (-aFirstArrowVec);
@@ -684,7 +717,7 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
                                                 : GetCenterOnArc (aFirstAttach, aSecondAttach, myCenterPoint);
         gp_Dir aTextDir = aDimensionDir;
 
-        DrawText (thePresentation,
+        drawText (thePresentation,
                   aTextPos,
                   aTextDir,
                   aLabelString,
@@ -694,8 +727,8 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
       if (theMode == ComputeMode_All || theMode == ComputeMode_Line)
       {
         DrawArc (thePresentation,
-                 isArrowsExternal ? aFirstAttach : aFirstArrowEnd,
-                 isArrowsExternal ? aSecondAttach : aSecondArrowEnd,
+                 (isArrowsExternal || !isArrowVisible(AIS_TOAV_First)) ? aFirstAttach : aFirstArrowEnd,
+                 (isArrowsExternal || !isArrowVisible(AIS_TOAV_Second)) ? aSecondAttach : aSecondArrowEnd,
                  myCenterPoint,
                  Abs (GetFlyout()),
                  theMode);
@@ -707,7 +740,7 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
     {
       DrawExtension (thePresentation,
                      anExtensionSize,
-                     isArrowsExternal ? aFirstArrowEnd : aFirstAttach,
+                     (isArrowsExternal && isArrowVisible(AIS_TOAV_First)) ? aFirstArrowEnd : aFirstAttach,
                      aFirstExtensionDir,
                      aLabelString,
                      aLabelWidth,
@@ -720,7 +753,7 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
     {
       DrawExtension (thePresentation,
                      anExtensionSize,
-                     isArrowsExternal ? aSecondArrowEnd : aSecondAttach,
+                     (isArrowsExternal && isArrowVisible(AIS_TOAV_Second)) ? aSecondArrowEnd : aSecondAttach,
                      aSecondExtensionDir,
                      aLabelString,
                      aLabelWidth,
@@ -736,8 +769,8 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
     Prs3d_Root::NewGroup (thePresentation);
 
     DrawArc (thePresentation,
-             isArrowsExternal ? aFirstAttach  : aFirstArrowEnd,
-             isArrowsExternal ? aSecondAttach : aSecondArrowEnd,
+             (isArrowsExternal || !isArrowVisible(AIS_TOAV_First)) ? aFirstAttach  : aFirstArrowEnd,
+             (isArrowsExternal || !isArrowVisible(AIS_TOAV_Second)) ? aSecondAttach : aSecondArrowEnd,
              myCenterPoint,
              Abs(GetFlyout ()),
              theMode);
@@ -748,15 +781,17 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
   {
     Prs3d_Root::NewGroup (thePresentation);
 
-    DrawArrow (thePresentation, aFirstArrowBegin,  gp_Dir (aFirstArrowVec));
-    DrawArrow (thePresentation, aSecondArrowBegin, gp_Dir (aSecondArrowVec));
+    if (isArrowVisible(AIS_TOAV_First))
+      DrawArrow (thePresentation, aFirstArrowBegin,  gp_Dir (aFirstArrowVec));
+    if (isArrowVisible(AIS_TOAV_Second))
+      DrawArrow (thePresentation, aSecondArrowBegin, gp_Dir (aSecondArrowVec));
   }
 
   if ((theMode == ComputeMode_All || theMode == ComputeMode_Line) && isArrowsExternal)
   {
     Prs3d_Root::NewGroup (thePresentation);
 
-    if (aHPosition != LabelPosition_Left)
+    if (aHPosition != LabelPosition_Left && isArrowVisible(AIS_TOAV_First))
     {
       DrawExtension (thePresentation,
                      aDimensionAspect->ArrowTailSize(),
@@ -768,7 +803,7 @@ void AIS_AngleDimension::Compute (const Handle(PrsMgr_PresentationManager3d)& /*
                      LabelPosition_None);
     }
 
-    if (aHPosition != LabelPosition_Right)
+    if (aHPosition != LabelPosition_Right && isArrowVisible(AIS_TOAV_Second))
     {
       DrawExtension (thePresentation,
                      aDimensionAspect->ArrowTailSize(),
@@ -840,22 +875,17 @@ Standard_Boolean AIS_AngleDimension::InitTwoEdgesAngle (gp_Pln& theComputedPlane
   gp_Lin aFirstLin  = aFirstLine->Lin();
   gp_Lin aSecondLin = aSecondLine->Lin();
 
-  Standard_Boolean isParallelLines = Abs (aFirstLin.Angle (aSecondLin) - M_PI) <= Precision::Angular();
+  Standard_Boolean isParallelLines = aFirstLin.Direction().IsParallel (aSecondLin.Direction(), Precision::Angular());
 
-  gp_Pnt aPoint  = aFirstLine->Value (0.0);
-  gp_Dir aNormal = isParallelLines
-                     ? gp_Vec (aSecondLin.Normal (aPoint).Direction()) ^ gp_Vec (aSecondLin.Direction())
-                     : gp_Vec (aFirstLin.Direction()) ^ gp_Vec (aSecondLin.Direction());
+  theComputedPlane = isParallelLines ? gp_Pln(gp::XOY())
+                                     : gp_Pln (aSecondLin.Location(), gp_Vec (aFirstLin.Direction()) ^ gp_Vec (aSecondLin.Direction()));
 
-  theComputedPlane = gp_Pln (aPoint, aNormal);
-
-    // Compute geometry for this plane and edges
+  // Compute geometry for this plane and edges
   Standard_Boolean isInfinite1,isInfinite2;
   gp_Pnt aFirstPoint1, aLastPoint1, aFirstPoint2, aLastPoint2;
-  gp_Lin2d aFirstLin2d, aSecondLin2d;
-
+  Handle(Geom_Curve) aFirstCurve = aFirstLine, aSecondCurve = aSecondLine;
   if (!AIS::ComputeGeometry (aFirstEdge, aSecondEdge,
-                             aFirstLine, aSecondLine,
+                             aFirstCurve, aSecondCurve,
                              aFirstPoint1, aLastPoint1,
                              aFirstPoint2, aLastPoint2,
                              isInfinite1, isInfinite2))
@@ -863,17 +893,32 @@ Standard_Boolean AIS_AngleDimension::InitTwoEdgesAngle (gp_Pln& theComputedPlane
     return Standard_False;
   }
 
-  if (aFirstLin.Direction().IsParallel (aSecondLin.Direction(), Precision::Angular()))
-  {
-    myFirstPoint  = aFirstLin.Location();
-    mySecondPoint = ElCLib::Value (ElCLib::Parameter (aFirstLin, myFirstPoint), aSecondLin);
+  Standard_Boolean isSameLines = aFirstLin.Direction().IsEqual (aSecondLin.Direction(), Precision::Angular())
+                              && aFirstLin.Location().IsEqual (aSecondLin.Location(),Precision::Confusion());
 
-    if (mySecondPoint.Distance (myFirstPoint) <= Precision::Confusion())
+  // It can be the same gp_Lin geometry but the different begin and end parameters
+  Standard_Boolean isSameEdges =
+    (aFirstPoint1.IsEqual (aFirstPoint2, Precision::Confusion()) && aLastPoint1.IsEqual (aLastPoint2, Precision::Confusion()))
+    || (aFirstPoint1.IsEqual (aLastPoint2, Precision::Confusion()) && aLastPoint1.IsEqual (aFirstPoint2, Precision::Confusion()));
+
+  if (isParallelLines)
+  {
+    // Zero angle, it could not handle this geometry
+    if (isSameLines && isSameEdges)
     {
-      mySecondPoint.Translate (gp_Vec (aSecondLin.Direction()) * Abs (GetFlyout()));
+      return Standard_False;
     }
 
-    myCenterPoint.SetXYZ ((myFirstPoint.XYZ() + mySecondPoint.XYZ()) / 2.0);
+    // Handle the case of Pi angle
+    const Standard_Real aParam11 = ElCLib::Parameter (aFirstLin, aFirstPoint1);
+    const Standard_Real aParam12 = ElCLib::Parameter (aFirstLin, aLastPoint1);
+    const Standard_Real aParam21 = ElCLib::Parameter (aFirstLin, aFirstPoint2);
+    const Standard_Real aParam22 = ElCLib::Parameter (aFirstLin, aLastPoint2);
+    myCenterPoint = ElCLib::Value ( (Min (aParam11, aParam12) + Max (aParam21, aParam22)) * 0.5, aFirstLin);
+    myFirstPoint = myCenterPoint.Translated (gp_Vec (aFirstLin.Direction()) * Abs (GetFlyout()));
+    mySecondPoint = myCenterPoint.XYZ() + (aFirstLin.Direction().IsEqual (aSecondLin.Direction(), Precision::Angular())
+      ? aFirstLin.Direction().Reversed().XYZ() * Abs (GetFlyout())
+      : aSecondLin.Direction().XYZ() * Abs (GetFlyout()));
   }
   else
   {
@@ -924,15 +969,15 @@ Standard_Boolean AIS_AngleDimension::InitTwoFacesAngle()
   TopoDS_Face aSecondFace = TopoDS::Face (mySecondShape);
 
   gp_Dir aFirstDir, aSecondDir;
-  gp_Pln aFirstPlane, aSecondPlane;
+  gp_Pln aFirstPln, aSecondPln;
   Handle(Geom_Surface) aFirstBasisSurf, aSecondBasisSurf;
   AIS_KindOfSurface aFirstSurfType, aSecondSurfType;
   Standard_Real aFirstOffset, aSecondOffset;
 
-  AIS::GetPlaneFromFace (aFirstFace, aFirstPlane,
+  AIS::GetPlaneFromFace (aFirstFace, aFirstPln,
                          aFirstBasisSurf,aFirstSurfType,aFirstOffset);
 
-  AIS::GetPlaneFromFace (aSecondFace, aSecondPlane,
+  AIS::GetPlaneFromFace (aSecondFace, aSecondPln,
                          aSecondBasisSurf, aSecondSurfType, aSecondOffset);
 
   if (aFirstSurfType == AIS_KOS_Plane && aSecondSurfType == AIS_KOS_Plane)
@@ -975,15 +1020,15 @@ Standard_Boolean AIS_AngleDimension::InitTwoFacesAngle (const gp_Pnt thePointOnF
   TopoDS_Face aSecondFace = TopoDS::Face (mySecondShape);
 
   gp_Dir aFirstDir, aSecondDir;
-  gp_Pln aFirstPlane, aSecondPlane;
+  gp_Pln aFirstPln, aSecondPln;
   Handle(Geom_Surface) aFirstBasisSurf, aSecondBasisSurf;
   AIS_KindOfSurface aFirstSurfType, aSecondSurfType;
   Standard_Real aFirstOffset, aSecondOffset;
 
-  AIS::GetPlaneFromFace (aFirstFace, aFirstPlane,
+  AIS::GetPlaneFromFace (aFirstFace, aFirstPln,
                          aFirstBasisSurf,aFirstSurfType,aFirstOffset);
 
-  AIS::GetPlaneFromFace (aSecondFace, aSecondPlane,
+  AIS::GetPlaneFromFace (aSecondFace, aSecondPln,
                          aSecondBasisSurf, aSecondSurfType, aSecondOffset);
 
   myFirstPoint = thePointOnFirstFace;
@@ -1137,6 +1182,26 @@ Standard_Boolean AIS_AngleDimension::IsValidPoints (const gp_Pnt& theFirstPoint,
            gp_Vec (theCenterPoint, theSecondPoint)) > Precision::Angular();
 }
 
+//=======================================================================
+//function : isArrowVisible
+//purpose  : compares given and internal arrows types, returns true if the the type should be shown
+//=======================================================================
+Standard_Boolean AIS_AngleDimension::isArrowVisible(const AIS_TypeOfAngleArrowVisibility& theArrowType) const
+{
+  switch (theArrowType)
+  {
+    case AIS_TOAV_Both:
+      return myArrowsVisibility == AIS_TOAV_Both;
+    case AIS_TOAV_First:
+      return myArrowsVisibility == AIS_TOAV_Both || myArrowsVisibility == AIS_TOAV_First;
+    case AIS_TOAV_Second:
+      return myArrowsVisibility == AIS_TOAV_Both || myArrowsVisibility == AIS_TOAV_Second;
+    case AIS_TOAV_None:
+      return false;
+  }
+  return false;
+}
+
 //=======================================================================
 //function : GetTextPosition
 //purpose  : 
