@@ -13,36 +13,50 @@
 
 #define No_Standard_OutOfRange
 
-#include <Adaptor3d_CurveOnSurface.ixx>
 
+#include <Adaptor2d_HCurve2d.hxx>
+#include <Adaptor3d_CurveOnSurface.hxx>
+#include <Adaptor3d_HCurve.hxx>
 #include <Adaptor3d_HCurveOnSurface.hxx>
-#include <gp_Pnt2d.hxx>
-#include <gp_Vec2d.hxx>
-#include <gp_Ax22d.hxx>
-#include <gp_Lin2d.hxx>
-#include <gp_Circ2d.hxx>
-#include <gp_Elips2d.hxx>
-#include <gp_Hypr2d.hxx>
-#include <gp_Parab2d.hxx>
-#include <Geom_BSplineSurface.hxx>
-#include <Geom_SurfaceOfRevolution.hxx>
-#include <Geom_SurfaceOfLinearExtrusion.hxx>
-#include <Geom_OffsetSurface.hxx>
-#include <Geom2d_BezierCurve.hxx>
-#include <Geom2d_BSplineCurve.hxx>
-#include <Precision.hxx>
-#include <Standard_Assert.hxx>
-#include <TColgp_Array1OfPnt2d.hxx>
-#include <TColgp_Array1OfPnt.hxx>
-#include <TColStd_Array1OfReal.hxx>
-#include <TColStd_Array1OfInteger.hxx>
-#include <TColStd_HSequenceOfReal.hxx>
-#include <Standard_NotImplemented.hxx>
+#include <Adaptor3d_HSurface.hxx>
+#include <Adaptor3d_InterFunc.hxx>
 #include <ElCLib.hxx>
 #include <ElSLib.hxx>
-#include <Adaptor3d_InterFunc.hxx>
+#include <Geom2d_BezierCurve.hxx>
+#include <Geom2d_BSplineCurve.hxx>
+#include <Geom_BezierCurve.hxx>
+#include <Geom_BSplineCurve.hxx>
+#include <Geom_BSplineSurface.hxx>
+#include <Geom_OffsetSurface.hxx>
+#include <Geom_SurfaceOfLinearExtrusion.hxx>
+#include <Geom_SurfaceOfRevolution.hxx>
+#include <gp_Ax22d.hxx>
+#include <gp_Circ.hxx>
+#include <gp_Circ2d.hxx>
+#include <gp_Elips.hxx>
+#include <gp_Elips2d.hxx>
+#include <gp_Hypr.hxx>
+#include <gp_Hypr2d.hxx>
+#include <gp_Lin.hxx>
+#include <gp_Lin2d.hxx>
+#include <gp_Parab.hxx>
+#include <gp_Parab2d.hxx>
+#include <gp_Pnt.hxx>
+#include <gp_Pnt2d.hxx>
+#include <gp_Vec.hxx>
+#include <gp_Vec2d.hxx>
 #include <math_FunctionRoots.hxx>
-#include <ElSLib.hxx>
+#include <Precision.hxx>
+#include <Standard_Assert.hxx>
+#include <Standard_DomainError.hxx>
+#include <Standard_NoSuchObject.hxx>
+#include <Standard_NotImplemented.hxx>
+#include <Standard_OutOfRange.hxx>
+#include <TColgp_Array1OfPnt.hxx>
+#include <TColgp_Array1OfPnt2d.hxx>
+#include <TColStd_Array1OfInteger.hxx>
+#include <TColStd_Array1OfReal.hxx>
+#include <TColStd_HSequenceOfReal.hxx>
 
 static gp_Pnt to3d(const gp_Pln& Pl, const gp_Pnt2d& P)
 {
@@ -743,6 +757,18 @@ void Adaptor3d_CurveOnSurface::Load(const Handle(Adaptor2d_HCurve2d)& C)
      }
 }
 
+//=======================================================================
+//function : Load
+//purpose  : 
+//=======================================================================
+
+void Adaptor3d_CurveOnSurface::Load (const Handle(Adaptor2d_HCurve2d)& C,
+                                     const Handle(Adaptor3d_HSurface)& S) 
+{
+  Load (C);
+  Load (S);
+}
+
 //=======================================================================
 //function : FirstParameter
 //purpose  : 
@@ -820,16 +846,19 @@ Standard_Integer Adaptor3d_CurveOnSurface::NbIntervals (const GeomAbs_Shape S) c
   Standard_Integer nu,nv,nc;
   nu=mySurface->NbUIntervals(S);
   nv=mySurface->NbVIntervals(S);
+  nc=myCurve->NbIntervals(S);
+
+  // Allocate the memory for arrays TabU, TabV, TabC only once using the buffer TabBuf.
+  TColStd_Array1OfReal TabBuf(1, nu + nv + nc + 3);
+  TColStd_Array1OfReal TabU(TabBuf(1), 1, nu+1);
+  TColStd_Array1OfReal TabV(TabBuf(nu + 2), 1, nv+1);
+  TColStd_Array1OfReal TabC(TabBuf(nu + nv + 3), 1, nc+1);
 
-  TColStd_Array1OfReal TabU(1,nu+1);
-  TColStd_Array1OfReal TabV(1,nv+1);
   Standard_Integer NbSample = 20;
   Standard_Real U,V,Tdeb,Tfin;
   Tdeb=myCurve->FirstParameter();
   Tfin=myCurve->LastParameter();
 
-  nc=myCurve->NbIntervals(S);
-  TColStd_Array1OfReal TabC(1,nc+1);
   myCurve->Intervals(TabC,S);
 
   Standard_Real Tol= Precision::PConfusion()/10;
