@@ -15,11 +15,11 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <BOPDS_PassKey.ixx>
+
+#include <BOPDS_PassKey.hxx>
 
 #include <stdio.h>
-
-#ifdef WNT
+#ifdef _MSC_VER
 #pragma warning( disable : 4101) 
 #endif
 
