@@ -14,55 +14,56 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <BRepFill_CompatibleWires.ixx>
 
-#include <BRepAdaptor_Curve.hxx>
-
-#include <BRepFill.hxx>
-#include <BRepLib.hxx>
-#include <BRepLib_FindSurface.hxx>
-#include <BRepLib_MakeWire.hxx>
-#include <BRepLib_MakeEdge.hxx>
-#include <BRepCheck_Wire.hxx>
-#include <BRepExtrema_DistShapeShape.hxx>
 #include <Bnd_Box.hxx>
-#include <BRepBndLib.hxx>
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
-#include <BRepTools_WireExplorer.hxx>
-#include <BRepLProp.hxx>
+#include <BRepAdaptor_Curve.hxx>
+#include <BRepBndLib.hxx>
+#include <BRepCheck_Wire.hxx>
+#include <BRepExtrema_DistShapeShape.hxx>
+#include <BRepFill.hxx>
+#include <BRepFill_CompatibleWires.hxx>
 #include <BRepGProp.hxx>
+#include <BRepLib.hxx>
+#include <BRepLib_FindSurface.hxx>
+#include <BRepLib_MakeEdge.hxx>
+#include <BRepLib_MakeWire.hxx>
+#include <BRepLProp.hxx>
+#include <BRepTools_WireExplorer.hxx>
+#include <Geom_Plane.hxx>
+#include <Geom_Surface.hxx>
+#include <gp.hxx>
+#include <gp_Ax2.hxx>
+#include <gp_Circ.hxx>
+#include <gp_Elips.hxx>
+#include <gp_Pln.hxx>
+#include <gp_Vec.hxx>
 #include <GProp_GProps.hxx>
 #include <GProp_PrincipalProps.hxx>
-#include <Geom_Surface.hxx>
-#include <Geom_Plane.hxx>
 #include <Precision.hxx>
-#include <TopAbs.hxx> 
+#include <Standard_ConstructionError.hxx>
+#include <Standard_NoSuchObject.hxx>
+#include <TColgp_HArray1OfPnt.hxx>
+#include <TColgp_HArray1OfVec.hxx>
+#include <TColStd_Array1OfInteger.hxx>
+#include <TColStd_Array1OfReal.hxx>
+#include <TColStd_MapOfInteger.hxx>
+#include <TColStd_SequenceOfReal.hxx>
+#include <TopAbs.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
 #include <TopoDS.hxx>
+#include <TopoDS_Edge.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
-#include <TopTools_DataMapOfShapeListOfShape.hxx>
-#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
 #include <TopTools_DataMapIteratorOfDataMapOfShapeListOfShape.hxx>
+#include <TopTools_DataMapOfShapeListOfShape.hxx>
+#include <TopTools_DataMapOfShapeSequenceOfShape.hxx>
 #include <TopTools_HSequenceOfShape.hxx>
+#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
+#include <TopTools_ListIteratorOfListOfShape.hxx>
+#include <TopTools_ListOfShape.hxx>
 #include <TopTools_SequenceOfShape.hxx>
-#include <TopTools_ListOfShape.hxx>    
-
-#include <gp.hxx>
-#include <gp_Vec.hxx>
-#include <gp_Ax2.hxx>
-#include <gp_Pln.hxx>
-#include <gp_Circ.hxx>
-#include <gp_Elips.hxx>
-#include <TColgp_HArray1OfVec.hxx>
-#include <TColgp_HArray1OfPnt.hxx>
-
-#include <TColStd_Array1OfInteger.hxx>
-#include <TColStd_MapOfInteger.hxx>
-#include <TColStd_Array1OfReal.hxx>
-#include <TColStd_SequenceOfReal.hxx>
 
 #ifdef OCCT_DEBUG_EFV
 static void EdgesFromVertex (const TopoDS_Wire&   W,
@@ -116,6 +117,30 @@ static void EdgesFromVertex (const TopoDS_Wire&   W,
 }
 				      
 #endif
+
+//=======================================================================
+//function : AddNewEdge
+//purpose  : for <theEdge> find all newest edges
+//           in <theEdgeNewEdges> recursively
+//=======================================================================
+
+static void AddNewEdge(const TopoDS_Shape& theEdge,
+                       const TopTools_DataMapOfShapeSequenceOfShape& theEdgeNewEdges,
+                       TopTools_ListOfShape& ListNewEdges)
+{
+  if (theEdgeNewEdges.IsBound(theEdge))
+  {
+    const TopTools_SequenceOfShape& NewEdges = theEdgeNewEdges(theEdge);
+    for (Standard_Integer i = 1; i <= NewEdges.Length(); i++)
+    {
+      TopoDS_Shape anEdge = NewEdges(i);
+      AddNewEdge(anEdge, theEdgeNewEdges, ListNewEdges);
+    }
+  }
+  else
+    ListNewEdges.Append(theEdge);
+}
+
 static void SeqOfVertices (const TopoDS_Wire&   W,
 			   TopTools_SequenceOfShape& S)
 {
@@ -430,7 +455,8 @@ static Standard_Boolean EdgeIntersectOnWire (const gp_Pnt& P1,
 					     const TopTools_DataMapOfShapeListOfShape& Map,
 					     const TopoDS_Wire&   W,
 					     TopoDS_Vertex& Vsol,
-					     TopoDS_Wire&   newW)
+					     TopoDS_Wire&   newW,
+                                             TopTools_DataMapOfShapeSequenceOfShape& theEdgeNewEdges)
 {
 
   BRepTools_WireExplorer anExp;
@@ -462,23 +488,24 @@ static Standard_Boolean EdgeIntersectOnWire (const gp_Pnt& P1,
   if (DSS.IsDone()) {
     // choose the solution closest to P2
     Standard_Integer isol = 1;
-    Standard_Real dss = P2.Distance(DSS.PointOnShape2(isol));
+    gp_Pnt Psol = DSS.PointOnShape2(isol);
+    Standard_Real dss = P2.Distance(Psol);
     for (Standard_Integer iss=2; iss<=DSS.NbSolution(); iss++) {
-      if (dss>P2.Distance(DSS.PointOnShape2(iss))) {
-	dss = P2.Distance(DSS.PointOnShape2(iss));
-	isol = iss;
+      gp_Pnt Pss = DSS.PointOnShape2(iss);
+      Standard_Real aDist = P2.Distance(Pss);
+      if (dss > aDist) {
+        dss = aDist;
+        isol = iss;
+#ifdef OCCT_DEBUG
+        Psol = Pss;
+#endif
       }
     }
-#ifdef OCCT_DEBUG
-    gp_Pnt Psol = 
-#endif
-      DSS.PointOnShape2(isol);
+
     // is the solution a new vertex ?
     NewVertex = (DSS.SupportTypeShape2(isol) != BRepExtrema_IsVertex);
     if (NewVertex) {
-      TopoDS_Shape aLocalShape = DSS.SupportOnShape2(isol);
-      TopoDS_Edge E = TopoDS::Edge(aLocalShape);
-//      TopoDS_Edge E = TopoDS::Edge(DSS.SupportOnShape2(isol));
+      TopoDS_Edge E = TopoDS::Edge(DSS.SupportOnShape2(isol));
       Standard_Real tol = Precision::PConfusion();
       Standard_Real first,last,param;
       BRep_Tool::Range(E,first,last);
@@ -509,6 +536,8 @@ static Standard_Boolean EdgeIntersectOnWire (const gp_Pnt& P1,
       TopoDS_Shape aLocalShape = DSS.SupportOnShape2(isol);
       TopoDS_Edge E = TopoDS::Edge(aLocalShape);
 //      TopoDS_Edge E = TopoDS::Edge(DSS.SupportOnShape2(isol));
+      TopTools_SequenceOfShape EmptySeq;
+      theEdgeNewEdges.Bind(E, EmptySeq);
       Standard_Real first,last,param;
       DSS.ParOnEdgeS2(isol,param);
       BRep_Tool::Range(E,first,last);
@@ -523,6 +552,7 @@ static Standard_Boolean EdgeIntersectOnWire (const gp_Pnt& P1,
 	  SR.Clear();
 	  SR.Append(param);
 	  TrimEdge(E,SR,first,last,SO,SE);
+          theEdgeNewEdges(E) = SE;
 	  TopoDS_Vertex VV1,VV2;
 	  TopExp::Vertices(TopoDS::Edge(SE.Value(1)),VV1,VV2);
 	  if (TopExp::FirstVertex(E).IsSame(VV1)
@@ -852,10 +882,11 @@ void BRepFill_CompatibleWires::
   // initialisation 
   Standard_Integer NbSects=myWork.Length();
   BRepTools_WireExplorer anExp;
-  TopoDS_Vertex V1, V2;
-  
+  TopTools_DataMapOfShapeSequenceOfShape EdgeNewEdges;
+
   Standard_Boolean allClosed = Standard_True;
   Standard_Integer i,ii,ideb=1,ifin=NbSects;
+
   for (i=1; i<=NbSects; i++) {
     Handle(BRepCheck_Wire) Checker = new BRepCheck_Wire(TopoDS::Wire(myWork(i)));
     allClosed = (allClosed && (Checker->Closed() == BRepCheck_NoError));
@@ -945,8 +976,6 @@ void BRepFill_CompatibleWires::
     if (SeqV.Length()>NbMaxV) 
       Standard_NoSuchObject::Raise("BRepFill::SameNumberByPolarMethod failed");
     
-    // extremity of the first wire
-    V1 = TopoDS::Vertex(SeqV.Value(1));	
     // loop on vertices of wire1
     for (ii=1;ii<=SeqV.Length();ii++) {
       
@@ -974,8 +1003,8 @@ void BRepFill_CompatibleWires::
       if (Pnew.Distance(Pos->Value(i-1))>Precision::Confusion()) {
 	Standard_Real percent = myPercent;
 	NewVertex = EdgeIntersectOnWire(Pos->Value(i-1),Pnew,percent,
-				    RMap,TopoDS::Wire(myWork(i-1)),
-				    Vsol,newwire);
+                                        RMap,TopoDS::Wire(myWork(i-1)),
+                                        Vsol,newwire,EdgeNewEdges);
 	if (NewVertex) myWork(i-1) = newwire;
 	RMap(Vi).Append(Vsol);
       }
@@ -1022,8 +1051,6 @@ void BRepFill_CompatibleWires::
     if ( SeqV.Length()>NbMaxV || SeqV.Length()>SizeMap ) 
       Standard_NoSuchObject::Raise("BRepFill::SameNumberByPolarMethod failed");
     
-    // extremity of the first wire
-    V1 = TopoDS::Vertex(SeqV.Value(1));
 
     // next wire 
     const TopoDS_Wire& wire2 = TopoDS::Wire(myWork(i+1));
@@ -1060,8 +1087,8 @@ void BRepFill_CompatibleWires::
 	if (Pnew.Distance(Pos->Value(i+1))>Precision::Confusion()) {
 	  Standard_Real percent = myPercent;
 	  NewVertex = EdgeIntersectOnWire(Pos->Value(i+1),Pnew,percent,
-				      MapVLV,TopoDS::Wire(myWork(i+1)),
-				      Vsol,newwire);
+                                          MapVLV,TopoDS::Wire(myWork(i+1)),
+                                          Vsol,newwire,EdgeNewEdges);
 	  MapVLV(VRoot).Append(Vsol);
 	  if (NewVertex) myWork(i+1) = newwire;
 	}
@@ -1110,11 +1137,11 @@ void BRepFill_CompatibleWires::
 	// parse candidate edges
 	Standard_Real scal1,scal2;
 	if ( (V1.IsSame(VVF)&&V2.IsSame(VVL)) || (V2.IsSame(VVF)&&V1.IsSame(VVL)) ) {
-	  Standard_Real U1 = BRep_Tool::Parameter(VVF,E);
-	  Standard_Real U2 = BRep_Tool::Parameter(VVL,E);
-	  BRepAdaptor_Curve Curve(E);
-	  gp_Pnt PP1 = Curve.Value(0.1*(U1+9*U2));
-	  gp_Pnt PP2 = Curve.Value(0.1*(9*U1+U2));
+	  Standard_Real U1param = BRep_Tool::Parameter(VVF,E);
+	  Standard_Real U2param = BRep_Tool::Parameter(VVL,E);
+	  BRepAdaptor_Curve CurveE(E);
+	  gp_Pnt PP1 = CurveE.Value(0.1*(U1param +9* U2param));
+	  gp_Pnt PP2 = CurveE.Value(0.1*(9* U1param + U2param));
   
 	  for (rang=i;rang>ideb;rang--) {
 	    Transform(WithRotation, PP1,
@@ -1213,6 +1240,19 @@ void BRepFill_CompatibleWires::
     Standard_NoSuchObject::Raise("BRepFill_CompatibleWires::SameNumberByPolarMethod failed");
   }
 
+  //Fill <myMap>
+  TopTools_DataMapIteratorOfDataMapOfShapeListOfShape itmap(myMap);
+  for (; itmap.More(); itmap.Next())
+  {
+    TopoDS_Shape anEdge = itmap.Key();
+    TopTools_ListOfShape ListOfNewEdges;
+
+    //for each edge of <myMap> find all newest edges
+    //in <EdgeNewEdges> recursively
+    AddNewEdge(anEdge, EdgeNewEdges, ListOfNewEdges);
+    
+    myMap(anEdge) = ListOfNewEdges;
+  }
 }
 
 //=======================================================================
@@ -1518,12 +1558,12 @@ void BRepFill_CompatibleWires::ComputeOrigin(const  Standard_Boolean /*polar*/ )
   gp_Vec NormalOfFirstPlane = FirstPlane.Axis().Direction();
   for (i = ideb+1; i <= ifin; i++)
     {
-      const TopoDS_Wire& wire = TopoDS::Wire(myWork(i));
+      const TopoDS_Wire& aWire = TopoDS::Wire(myWork(i));
 
       //Compute offset vector as current bary center projected on first plane
       //to first bary center
       gp_Pln CurPlane;
-      PlaneOfWire(wire, CurPlane);
+      PlaneOfWire(aWire, CurPlane);
       gp_Pnt CurBary = CurPlane.Location();
       gp_Vec aVec(FirstBary, CurBary);
       gp_Vec anOffsetProj = (aVec * NormalOfFirstPlane) * NormalOfFirstPlane;
@@ -1535,7 +1575,7 @@ void BRepFill_CompatibleWires::ComputeOrigin(const  Standard_Boolean /*polar*/ )
       BB.MakeWire(newwire);
       
       TopTools_SequenceOfShape SeqVertices, SeqEdges;
-      for (anExp.Init(wire); anExp.More(); anExp.Next())
+      for (anExp.Init(aWire); anExp.More(); anExp.Next())
 	{
 	  SeqVertices.Append( anExp.CurrentVertex() );
 	  SeqEdges.Append( anExp.Current() );
