@@ -69,6 +69,13 @@ namespace {
   private:
     Handle(BRepMesh_DataStructureOfDelaun) myStructure;
   };
+
+  inline void UpdateBndBox(const gp_XY& thePnt1, const gp_XY& thePnt2, Bnd_B2d& theBox)
+  {
+    theBox.Add( thePnt1 );
+    theBox.Add( thePnt2 );
+    theBox.Enlarge(Precision);
+  }
 } // anonymous namespace
 
 //=======================================================================
@@ -307,7 +314,7 @@ void BRepMesh_Delaun::createTriangles(const Standard_Integer         theVertexIn
     Standard_Integer     anEdgeId = anEdges.Key();
     const BRepMesh_Edge& anEdge   = GetEdge( anEdgeId );
 
-    Standard_Boolean isPositive = (Standard_Boolean)thePoly( anEdgeId );
+    const Standard_Boolean isPositive = thePoly (anEdgeId) != 0;
 
     Standard_Integer aNodes[3];
     if ( isPositive )
@@ -355,16 +362,16 @@ void BRepMesh_Delaun::createTriangles(const Standard_Integer         theVertexIn
     Standard_Boolean isSensOK = (aDist12 > 0. && aDist23 > 0.);
     if (isSensOK)
     {
-      Standard_Integer anEdges[3];
+      Standard_Integer anEdgeIds[3];
       Standard_Boolean anEdgesOri[3];
       for ( Standard_Integer aTriLinkIt = 0; aTriLinkIt < 3; ++aTriLinkIt )
       {
         const Standard_Integer& anEdgeInfo = anEdgesInfo[aTriLinkIt];
-        anEdges[aTriLinkIt]    = Abs( anEdgeInfo );
+        anEdgeIds[aTriLinkIt]    = Abs( anEdgeInfo );
         anEdgesOri[aTriLinkIt] = anEdgeInfo > 0;
       }
 
-      addTriangle( anEdges, anEdgesOri, aNodes );
+      addTriangle(anEdgeIds, anEdgesOri, aNodes );
     }
     else
     {
@@ -422,7 +429,9 @@ void BRepMesh_Delaun::createTrianglesOnNewVertices(
   Handle(NCollection_IncAllocator) aAllocator =
     new NCollection_IncAllocator(BRepMesh::MEMORY_BLOCK_SIZE_HUGE);
 
-  BRepMesh::MapOfIntegerInteger aLoopEdges(10, aAllocator);
+  Standard_Real aTolU, aTolV;
+  myMeshData->Data()->GetTolerance(aTolU, aTolV);
+  const Standard_Real aSqTol = aTolU * aTolU + aTolV * aTolV;
 
   // Insertion of nodes :
   Standard_Boolean isModify = Standard_True;
@@ -431,8 +440,8 @@ void BRepMesh_Delaun::createTrianglesOnNewVertices(
   Standard_Integer anUpper = theVertexIndexes.Upper();
   for( ; anIndex <= anUpper; ++anIndex ) 
   {
-    aLoopEdges.Clear();
     aAllocator->Reset(Standard_False);
+    BRepMesh::MapOfIntegerInteger aLoopEdges(10, aAllocator);
     
     Standard_Integer aVertexIdx = theVertexIndexes( anIndex );    
     const BRepMesh_Vertex& aVertex = GetVertex( aVertexIdx );
@@ -447,20 +456,23 @@ void BRepMesh_Delaun::createTrianglesOnNewVertices(
       // To add a node in the mesh it is necessary to check conditions: 
       // - the node should be within the boundaries of the mesh and so in an existing triangle
       // - all adjacent triangles should belong to a component connected with this triangle
-      if ( Contains( aCircleIt.Value(), aVertex, onEgdeId ) )
+      if ( Contains( aCircleIt.Value(), aVertex, aSqTol, onEgdeId ) )
       {
-        if ( onEgdeId == 0 )
+        if (onEgdeId != 0 && GetEdge(onEgdeId).Movability() != BRepMesh_Free)
         {
-          aTriangleId = aCircleIt.Value();
-          aCirclesList.Remove( aCircleIt );
-          break;
-        }
-        else if ( GetEdge( onEgdeId ).Movability() == BRepMesh_Free )
-        {
-          aTriangleId = aCircleIt.Value();
-          aCirclesList.Remove( aCircleIt );
-          break;
+          // We can skip free vertex too close to the frontier edge.
+          if (aVertex.Movability() == BRepMesh_Free)
+            continue;
+
+          // However, we should add vertex that have neighboring frontier edges.
         }
+
+        // Remove triangle even if it contains frontier edge in order 
+        // to prevent appearance of incorrect configurations like free 
+        // edge glued with frontier #26407
+        aTriangleId = aCircleIt.Value();
+        aCirclesList.Remove( aCircleIt );
+        break;
       }
     }
 
@@ -496,25 +508,56 @@ void BRepMesh_Delaun::createTrianglesOnNewVertices(
       createTriangles( aVertexIdx, aLoopEdges );
     }
   }
-  // Check that internal edges are not crossed by triangles
+
+  insertInternalEdges();
+
+  // Adjustment of meshes to boundary edges
+  frontierAdjust();
+}
+
+//=======================================================================
+//function : insertInternalEdges
+//purpose  : 
+//=======================================================================
+void BRepMesh_Delaun::insertInternalEdges()
+{
   BRepMesh::HMapOfInteger anInternalEdges = InternalEdges();
 
   // Destruction of triancles intersecting internal edges 
   // and their replacement by makeshift triangles
+  Standard_Integer e[3];
+  Standard_Boolean o[3];
   BRepMesh::MapOfInteger::Iterator anInernalEdgesIt( *anInternalEdges );
   for ( ; anInernalEdgesIt.More(); anInernalEdgesIt.Next() )
   {
-    Standard_Integer aNbC;
-    aNbC = myMeshData->ElementsConnectedTo( anInernalEdgesIt.Key() ).Extent();
-    if ( aNbC == 0 )
+    const Standard_Integer aLinkIndex = anInernalEdgesIt.Key();
+    const BRepMesh_PairOfIndex& aPair = myMeshData->ElementsConnectedTo(aLinkIndex);
+
+    // Check both sides of link for adjusted triangle.
+    Standard_Boolean isGo[2] = { Standard_True, Standard_True };
+    for (Standard_Integer aTriangleIt = 1; aTriangleIt <= aPair.Extent(); ++aTriangleIt)
     {
-      meshLeftPolygonOf( anInernalEdgesIt.Key(), Standard_True  ); 
-      meshLeftPolygonOf( anInernalEdgesIt.Key(), Standard_False ); 
+      GetTriangle(aPair.Index(aTriangleIt)).Edges(e, o);
+      for (Standard_Integer i = 0; i < 3; ++i)
+      {
+        if (e[i] == aLinkIndex)
+        {
+          isGo[o[i] ? 0 : 1] = Standard_False;
+          break;
+        }
+      }
+    }
+
+    if (isGo[0])
+    {
+      meshLeftPolygonOf(aLinkIndex, Standard_True);
+    }
+
+    if (isGo[1])
+    {
+      meshLeftPolygonOf(aLinkIndex, Standard_False);
     }
   }
-
-  // Adjustment of meshes to boundary edges
-  frontierAdjust();
 }
 
 //=======================================================================
@@ -584,6 +627,7 @@ void BRepMesh_Delaun::cleanupMesh()
 
   for(;;)
   {
+    aAllocator->Reset(Standard_False);
     BRepMesh::MapOfIntegerInteger aLoopEdges(10, aAllocator);
     BRepMesh::MapOfInteger aDelTriangles(10, aAllocator);
 
@@ -665,7 +709,6 @@ void BRepMesh_Delaun::cleanupMesh()
         myMeshData->RemoveLink( aLoopEdgesIt.Key() );
     }
 
-    aAllocator->Reset(Standard_False);
     if ( aDeletedTrianglesNb == 0 )
       break;
   }
@@ -778,9 +821,8 @@ void BRepMesh_Delaun::fillBndBox(BRepMesh::SequenceOfBndB2d& theBoxes,
                                  const BRepMesh_Vertex&      theV1,
                                  const BRepMesh_Vertex&      theV2)
 {
-  Bnd_B2d aBox;      
-  aBox.Add( theV1.Coord() );
-  aBox.Add( theV2.Coord() );
+  Bnd_B2d aBox;
+  UpdateBndBox(theV1.Coord(), theV2.Coord(), aBox);
   theBoxes.Append( aBox );
 }
 
@@ -1035,8 +1077,8 @@ Standard_Boolean BRepMesh_Delaun::checkIntersection(
   const Standard_Boolean             isSkipLastEdge,
   Bnd_B2d&                           theLinkBndBox ) const
 {
-  theLinkBndBox.Add( GetVertex( theLink.FirstNode() ).Coord() );
-  theLinkBndBox.Add( GetVertex( theLink.LastNode()  ).Coord() );
+  UpdateBndBox(GetVertex(theLink.FirstNode()).Coord(),
+    GetVertex(theLink.LastNode()).Coord(), theLinkBndBox);
 
   Standard_Integer aPolyLen = thePolygon.Length();
   // Don't check intersection with the last link
@@ -1075,10 +1117,17 @@ Standard_Boolean BRepMesh_Delaun::checkIntersection(
 //function : addTriangle
 //purpose  : Add a triangle based on the given oriented edges into mesh
 //=======================================================================
-inline void BRepMesh_Delaun::addTriangle( const Standard_Integer (&theEdgesId)[3],
-                                          const Standard_Boolean (&theEdgesOri)[3],
-                                          const Standard_Integer (&theNodesId)[3] )
+void BRepMesh_Delaun::addTriangle( const Standard_Integer (&theEdgesId)[3],
+                                   const Standard_Boolean (&theEdgesOri)[3],
+                                   const Standard_Integer (&theNodesId)[3])
 {
+  for (Standard_Integer i = 0; i < 3; ++i)
+  {
+    const BRepMesh_PairOfIndex& aPair = myMeshData->ElementsConnectedTo(theEdgesId[i]);
+    if (aPair.Extent() == 2)
+      // it is forbidden to have more than two triangles connected to the same link
+      return;
+  }
   Standard_Integer aNewTriangleId = 
     myMeshData->AddElement(BRepMesh_Triangle(theEdgesId, 
       theEdgesOri, BRepMesh_Free));
@@ -1457,8 +1506,7 @@ Standard_Integer BRepMesh_Delaun::createAndReplacePolygonLink(
     theNodes[0], theNodes[1], BRepMesh_Free ) );
 
   Bnd_B2d aNewBox;
-  aNewBox.Add( thePnts[0] );
-  aNewBox.Add( thePnts[1] );
+  UpdateBndBox(thePnts[0].Coord(), thePnts[1].Coord(), aNewBox);
 
   switch ( theReplaceFlag )
   {
@@ -1858,8 +1906,7 @@ void BRepMesh_Delaun::decomposeSimplePolygon(
       const gp_Pnt2d&         aLinkFirstVertex = aRefVertices[aRefLinkNodeIt];
 
       Bnd_B2d aBox;
-      aBox.Add( aLinkFirstVertex );
-      aBox.Add( aPivotVertex );
+      UpdateBndBox(aLinkFirstVertex.Coord(), aPivotVertex.Coord(), aBox);
 
       BRepMesh_Edge aCheckLink( aLinkFirstNode, aPivotNode, BRepMesh_Free );
 
@@ -1943,8 +1990,7 @@ void BRepMesh_Delaun::decomposeSimplePolygon(
     thePolyBoxes.Split(aUsedLinkId, thePolyBoxesCut);
 
     Bnd_B2d aBox;
-    aBox.Add( aRefVertices[0] );
-    aBox.Add( aRefVertices[2] );
+    UpdateBndBox(aRefVertices[0].Coord(), aRefVertices[2].Coord(), aBox);
     thePolyBoxesCut.Prepend( aBox );
   }
   else
@@ -1958,9 +2004,7 @@ void BRepMesh_Delaun::decomposeSimplePolygon(
     thePolygon.SetValue( 1, -aNewEdgesInfo[1] );
 
     Bnd_B2d aBox;
-    aBox.Add( aRefVertices[1] );
-    aBox.Add( aRefVertices[2] );
-
+    UpdateBndBox(aRefVertices[1].Coord(), aRefVertices[2].Coord(), aBox);
     thePolyBoxes.SetValue( 1, aBox );
   }
 }
@@ -1994,7 +2038,7 @@ void BRepMesh_Delaun::RemoveVertex( const BRepMesh_Vertex& theVertex )
     Standard_Integer aPivotNode = anEdge.LastNode();
     Standard_Integer anEdgeId   = aLoopEdgesIt.Key();
     
-    Standard_Boolean isPositive = (Standard_Boolean)aLoopEdges( anEdgeId );
+    Standard_Boolean isPositive = (aLoopEdges (anEdgeId) != 0);
     if ( !isPositive )
     {
       Standard_Integer aTmp;
@@ -2165,7 +2209,8 @@ Standard_Boolean BRepMesh_Delaun::UseEdge( const Standard_Integer /*theIndex*/ )
 BRepMesh::HMapOfInteger BRepMesh_Delaun::getEdgesByType(
   const BRepMesh_DegreeOfFreedom theEdgeType ) const
 {
-  BRepMesh::HMapOfInteger aResult = new BRepMesh::MapOfInteger;
+  Handle(NCollection_IncAllocator) anAlloc = new NCollection_IncAllocator;
+  BRepMesh::HMapOfInteger aResult = new BRepMesh::MapOfInteger(1, anAlloc);
   BRepMesh::MapOfInteger::Iterator anEdgeIt( myMeshData->LinksOfDomain() );
 
   for ( ; anEdgeIt.More(); anEdgeIt.Next() )
@@ -2189,17 +2234,12 @@ BRepMesh::HMapOfInteger BRepMesh_Delaun::getEdgesByType(
 //=======================================================================
 Standard_Real BRepMesh_Delaun::calculateDist( const gp_XY            theVEdges[3],
                                               const gp_XY            thePoints[3],
-                                              const Standard_Integer theEdgesId[3],
                                               const BRepMesh_Vertex& theVertex,
                                               Standard_Real          theDistance[3],
                                               Standard_Real          theSqModulus[3],
                                               Standard_Integer&      theEdgeOn ) const
 {
-  Standard_Real aMinDist = -1;
-  if ( !theVEdges || !thePoints || !theEdgesId || 
-       !theDistance || !theSqModulus )
-    return aMinDist;
-    
+  Standard_Real aMinDist = RealLast();
   for( Standard_Integer i = 0; i < 3; ++i )
   {
     theSqModulus[i] = theVEdges[i].SquareModulus();
@@ -2211,9 +2251,9 @@ Standard_Real BRepMesh_Delaun::calculateDist( const gp_XY            theVEdges[3
     Standard_Real aDist = theDistance[i] * theDistance[i];
     aDist /= theSqModulus[i];
     
-    if ( aMinDist < 0 || aDist < aMinDist )
+    if ( aDist < aMinDist )
     {
-      theEdgeOn = theEdgesId[i];
+      theEdgeOn = i;
       aMinDist  = aDist;
     }
   }
@@ -2229,7 +2269,8 @@ Standard_Real BRepMesh_Delaun::calculateDist( const gp_XY            theVEdges[3
 //=======================================================================
 Standard_Boolean BRepMesh_Delaun::Contains( const Standard_Integer theTriangleId,
                                             const BRepMesh_Vertex& theVertex,
-                                            Standard_Integer&      theEdgeOn ) const
+                                            const Standard_Real    theSqTolerance,
+                                            Standard_Integer&      theEdgeOn) const
 {
   theEdgeOn = 0;
   
@@ -2264,34 +2305,24 @@ Standard_Boolean BRepMesh_Delaun::Contains( const Standard_Integer theTriangleId
   Standard_Real aDistance[3];
   Standard_Real aSqModulus[3];
 
-  Standard_Real aMinDist;  
-  aMinDist = calculateDist( aVEdges, aPoints, e, theVertex, aDistance, aSqModulus, theEdgeOn );
-  if ( aMinDist < 0 )
+  Standard_Real aSqMinDist;
+  Standard_Integer aEdgeOnId;
+  aSqMinDist = calculateDist( aVEdges, aPoints, theVertex, aDistance, aSqModulus, aEdgeOnId );
+  if ( aSqMinDist < 0 )
     return Standard_False;
-      
-  if ( aMinDist > Precision2 )
-  {
-    Standard_Integer anEdgeId = theEdgeOn;
-    theEdgeOn = 0;
-    
-    if ( anEdgeId != 0 ) 
-    {
-      Standard_Integer i = 0;
-      for ( ; i < 3; ++i )
-      {
-        if( e[i] == anEdgeId )
-          break;
-      }
-      
-      if( anEdges[i]->Movability() != BRepMesh_Free )
-        if ( aDistance[i] < ( aSqModulus[i] / 5. ) )
-          theEdgeOn = e[i];
-    }
-  }
 
-  return ( aDistance[0] + aDistance[1] + aDistance[2] != 0. &&
-            ( ( aDistance[0] >= 0. && aDistance[1] >= 0. && aDistance[2] >= 0. ) ||
-              ( aDistance[0] <= 0. && aDistance[1] <= 0. && aDistance[2] <= 0. ) ) );
+  const Standard_Boolean isNotFree = (anEdges[aEdgeOnId]->Movability() != BRepMesh_Free);
+  if ( aSqMinDist > theSqTolerance )
+  {
+    if (isNotFree && aDistance[aEdgeOnId] < ( aSqModulus[aEdgeOnId] / 5. ))
+      theEdgeOn = e[aEdgeOnId];
+  }
+  else if (isNotFree)
+    return Standard_False;
+  else
+    theEdgeOn = e[aEdgeOnId];
+
+  return (aDistance[0] >= 0. && aDistance[1] >= 0. && aDistance[2] >= 0.);
 }
 
 //=============================================================================
@@ -2355,3 +2386,71 @@ Standard_Real BRepMesh_Delaun::polyArea(const BRepMesh::SequenceOfInteger& thePo
 
   return aArea / 2.;
 }
+
+#ifdef OCCT_DEBUG
+//=======================================================================
+//function : BRepMesh_DumpPoly
+//purpose  : 
+//=======================================================================
+#include <TopoDS_Compound.hxx>
+#include <BRep_Builder.hxx>
+#include <Standard_ErrorHandler.hxx>
+#include <BRepBuilderAPI_MakeEdge.hxx>
+#include <BRepTools.hxx>
+Standard_CString BRepMesh_DumpPoly(void*            thePolygon,
+                                   void*            theMeshHandlePtr,
+                                   Standard_CString theFileNameStr)
+{
+  if (thePolygon == 0 || theFileNameStr == 0)
+  {
+    return "Error: file name or polygon data is null";
+  }
+
+  BRepMesh::SequenceOfInteger& aPolygon = *(BRepMesh::SequenceOfInteger*)thePolygon;
+
+  Handle(BRepMesh_DataStructureOfDelaun) aMeshData = 
+    *(Handle(BRepMesh_DataStructureOfDelaun)*)theMeshHandlePtr;
+
+  if (aMeshData.IsNull())
+    return "Error: mesh data is empty";
+
+  TopoDS_Compound aMesh;
+  BRep_Builder aBuilder;
+  aBuilder.MakeCompound(aMesh);
+
+  try
+  {
+    OCC_CATCH_SIGNALS
+
+    BRepMesh::SequenceOfInteger::Iterator aLinksIt(aPolygon);
+    for (; aLinksIt.More(); aLinksIt.Next())
+    {
+      const BRepMesh_Edge& aLink = aMeshData->GetLink(Abs(aLinksIt.Value()));
+
+      gp_Pnt aPnt[2];
+      for (Standard_Integer i = 0; i < 2; ++i)
+      {
+        const Standard_Integer aNodeId = 
+          (i == 0) ? aLink.FirstNode() : aLink.LastNode();
+
+        const gp_XY& aNode = aMeshData->GetNode(aNodeId).Coord();
+        aPnt[i] = gp_Pnt(aNode.X(), aNode.Y(), 0.);
+      }
+
+      if (aPnt[0].SquareDistance(aPnt[1]) < Precision::SquareConfusion())
+        continue;
+
+      aBuilder.Add(aMesh, BRepBuilderAPI_MakeEdge(aPnt[0], aPnt[1]));
+    }
+
+    if (!BRepTools::Write(aMesh, theFileNameStr))
+      return "Error: write failed";
+  }
+  catch (Standard_Failure)
+  {
+    return Standard_Failure::Caught()->GetMessageString();
+  }
+
+  return theFileNameStr;
+}
+#endif
