@@ -330,7 +330,7 @@ static Standard_Integer CONTROL(Draw_Interpretor& theCommands,
 				Standard_Integer narg, const char** a)
 {
   if (narg >= 2) {
-    WithControl = strcmp("0",a[1]);
+    WithControl = strcmp("0", a[1]) != 0;
   }
   if (WithControl) {
     theCommands << "Mode avec controle";
@@ -340,7 +340,48 @@ static Standard_Integer CONTROL(Draw_Interpretor& theCommands,
   }
   return 0;
 }
-      
+
+//=======================================================================
+//function : reportOffsetState
+//purpose  : Print state of offset operation by error code.
+//=======================================================================
+static void reportOffsetState(Draw_Interpretor& theCommands,
+                              const BRepOffset_Error theErrorCode)
+{
+  switch(theErrorCode)
+  {
+  case BRepOffset_NoError:
+    {
+      theCommands << "OK. Offset performed succesfully.";
+      break;
+    }
+  case BRepOffset_BadNormalsOnGeometry:
+    {
+      theCommands << "ERROR. Degenerated normal on input data.";
+      break;
+    }
+  case BRepOffset_C0Geometry:
+    {
+      theCommands << "ERROR. C0 continuity of input data.";
+      break;
+    }
+  case BRepOffset_NullOffset:
+    {
+      theCommands << "ERROR. Null offset of all faces.";
+      break;
+    }
+  case BRepOffset_NotConnectedShell:
+    {
+      theCommands << "ERROR. Incorrect set of faces to remove, the remaining shell is not connected.";
+      break;
+    }
+  default:
+    {
+      theCommands << "ERROR. offsetperform operation not done.";
+      break;
+    }
+  }
+}
 
 //=======================================================================
 //function : PRW
@@ -503,7 +544,7 @@ static Standard_Integer PRW(Draw_Interpretor& theCommands,
     else {
       // il faudrait inverser V et appeler PerfomFromEnd...
       //cout << "Not Implemented" << endl;
-      theCommands << "Not Implemented" << "\n";
+      theCommands << "Not Implemented\n";
     }
   }
   if (!thePFace.IsDone()) {
@@ -668,7 +709,7 @@ static Standard_Integer PRF(Draw_Interpretor& theCommands,
     else { //FUntil.IsNull()
       // il faudrait inverser V et appeler PerfomFromEnd...
       //cout << "Not Implemented" << endl;
-      theCommands << "Not Implemented" << "\n";
+      theCommands << "Not Implemented\n";
     }
   }
   if (!thePFace.IsDone()) {
@@ -691,10 +732,22 @@ static Standard_Integer PRF(Draw_Interpretor& theCommands,
 static Standard_Integer SPLS(Draw_Interpretor& ,
 			     Standard_Integer narg, const char** a)
 {
-  Standard_Integer newnarg ;
+  Standard_Integer newnarg;
 
-  if (narg<3) return 1;
+  if (narg < 3)
+  {
+    cout << "Invalid number of arguments. Should be : splitshape result shape [splitedges] \
+            [face wire/edge/compound [wire/edge/compound ...] \
+            [face wire/edge/compound [wire/edge/compound...] ...] \
+            [@ edgeonshape edgeonwire [edgeonshape edgeonwire...]]" << endl;
+    return 1;
+  }
   TopoDS_Shape S = DBRep::Get(a[2]);
+  if (S.IsNull())
+  {
+    cout << "Invalid input shape " << a[2]<<endl;
+    return 1;
+  }
   BRepFeat_SplitShape Spls(S);
   Standard_Boolean pick = Standard_False;
   TopoDS_Shape EF;
@@ -711,20 +764,42 @@ static Standard_Integer SPLS(Draw_Interpretor& ,
       (newnarg !=narg && ((narg-newnarg)<=2 || (narg-newnarg)%2 != 1))) {
     return 1;
   }
-
-  if (i<newnarg) {
+  Standard_Boolean isSplittingEdges = Standard_False;
+  TopTools_SequenceOfShape aSplitEdges;
+  if (i < newnarg) {
     pick = (a[i][0] == '.');
-    EF = DBRep::Get(a[i],TopAbs_FACE);
-    if (EF.IsNull()) return 1;
+   
+    TopoDS_Shape aSh = DBRep::Get(a[i]);
+    if (aSh.IsNull())
+    {
+      cout << "Invalid input shape " <<a[i]<<endl;
+      return 1;
+    }
+
+
+    if (aSh.ShapeType() == TopAbs_FACE)
+      EF = TopoDS::Face(aSh);
+    else
+    {
+      if (aSh.ShapeType() == TopAbs_COMPOUND || aSh.ShapeType() == TopAbs_WIRE || aSh.ShapeType() == TopAbs_EDGE)
+      {
+        TopExp_Explorer aExpE(aSh, TopAbs_EDGE, TopAbs_FACE);
+        for (; aExpE.More(); aExpE.Next())
+          aSplitEdges.Append(aExpE.Current());
+
+        isSplittingEdges = !aSplitEdges.IsEmpty();
+      }
+    }
+
   }
-  
+  i++;
   while (i < newnarg) {
     if (pick) {
       DBRep_DrawableShape::LastPick(EF,u,v);
     }
-    if (EF.ShapeType() == TopAbs_FACE) {
+    if (!isSplittingEdges  && !EF.IsNull() && EF.ShapeType() == TopAbs_FACE) {
       // face wire/edge ...
-      i++;
+     
       while (i < newnarg) {
 	TopoDS_Shape W;
 	Standard_Boolean rever = Standard_False;
@@ -745,7 +820,6 @@ static Standard_Integer SPLS(Draw_Interpretor& ,
 	}
 	TopAbs_ShapeEnum wtyp = W.ShapeType();
 	if (wtyp != TopAbs_WIRE && wtyp != TopAbs_EDGE && wtyp != TopAbs_COMPOUND && pick) {
-	  Standard_Real u,v;
 	  DBRep_DrawableShape::LastPick(W,u,v);
 	  wtyp = W.ShapeType();
 	}
@@ -771,11 +845,36 @@ static Standard_Integer SPLS(Draw_Interpretor& ,
       }
     }
     else
-      return 1;
+    {
+      if (isSplittingEdges)
+      {
+        TopoDS_Shape aSh = DBRep::Get(a[i]);
+        if (aSh.IsNull())
+        {
+          cout << "Invalid input shape " <<a[i]<< endl;
+          return 1;
+        }
+        TopExp_Explorer aExpE(aSh, TopAbs_EDGE, TopAbs_FACE);
+        for (; aExpE.More(); aExpE.Next())
+          aSplitEdges.Append(aExpE.Current());
+      }
+      else
+      {
+         cout << "Invalid input arguments. Should be : splitshape result shape [splitedges] \
+            [face wire/edge/compound [wire/edge/compound ...] \
+            [face wire/edge/compound [wire/edge/compound...] ...] \
+            [@ edgeonshape edgeonwire [edgeonshape edgeonwire...]]"<<endl;
+        return 1;
+      }
+    }
+    i++;
   }
   
+  if (isSplittingEdges)
+    Spls.Add(aSplitEdges);
+
   // ici, i vaut newnarg
-  for (i++; i<narg; i+=2) {
+  for (; i < narg; i += 2) {
     TopoDS_Shape Ew,Es;
     TopoDS_Shape aLocalShape(DBRep::Get(a[i],TopAbs_EDGE));
     Es = TopoDS::Edge(aLocalShape);
@@ -787,6 +886,7 @@ static Standard_Integer SPLS(Draw_Interpretor& ,
     Ew = TopoDS::Edge(aLocalShape);
 //    Ew = TopoDS::Edge(DBRep::Get(a[i+1],TopAbs_EDGE));
     if (Ew.IsNull()) {
+      cout << "Invalid input shape " <<a[i+1]<< endl;
       return 1;
     }
     Spls.Add(TopoDS::Edge(Ew),TopoDS::Edge(Es));
@@ -801,13 +901,9 @@ static Standard_Integer SPLS(Draw_Interpretor& ,
 //function : thickshell
 //purpose  : 
 //=======================================================================
-
-Standard_Integer thickshell(Draw_Interpretor& ,
-			    Standard_Integer n, const char** a)
+Standard_Integer thickshell(Draw_Interpretor& theCommands,
+  Standard_Integer n, const char** a)
 {
-
-  //OSD_Chronometer Clock;
-  
   if ( n < 4) return 1;
   TopoDS_Shape  S  = DBRep::Get(a[2]);
   if (S.IsNull()) return 1;
@@ -816,30 +912,27 @@ Standard_Integer thickshell(Draw_Interpretor& ,
 
   GeomAbs_JoinType JT= GeomAbs_Arc;
   if (n > 4)
-    {
-      if (!strcmp(a[4],"i"))
-	JT = GeomAbs_Intersection;
-      if (!strcmp(a[4],"t"))
-	JT = GeomAbs_Tangent;
-    }
-  
+  {
+    if (!strcmp(a[4],"i"))
+      JT = GeomAbs_Intersection;
+    if (!strcmp(a[4],"t"))
+      JT = GeomAbs_Tangent;
+  }
+
   Standard_Boolean Inter = Standard_False; //Standard_True;
   Standard_Real    Tol = Precision::Confusion();
   if (n > 5)
     Tol = Draw::Atof(a[5]);
 
   BRepOffset_MakeOffset B;
-  B.Initialize(S,Of,Tol,BRepOffset_Skin,Inter,0,JT, Standard_True);
-
-//  Clock.Start();
+  B.Initialize(S,Of,Tol,BRepOffset_Skin,Inter,0,JT,Standard_True);
 
   B.MakeOffsetShape();
-  //B.MakeThickSolid ();
 
-//  Clock.Show();
+  const BRepOffset_Error aRetCode = B.Error();
+  reportOffsetState(theCommands, aRetCode);
 
   DBRep::Set(a[1],B.Shape());
-
   return 0;
 }
 
@@ -848,12 +941,9 @@ Standard_Integer thickshell(Draw_Interpretor& ,
 //purpose  : 
 //=======================================================================
 
-Standard_Integer offsetshape(Draw_Interpretor& ,
-			     Standard_Integer n, const char** a)
+Standard_Integer offsetshape(Draw_Interpretor& theCommands,
+                             Standard_Integer n, const char** a)
 {
-
-  //OSD_Chronometer Clock;
-  
   if ( n < 4) return 1;
   TopoDS_Shape  S  = DBRep::Get(a[2]);
   if (S.IsNull()) return 1;
@@ -861,7 +951,8 @@ Standard_Integer offsetshape(Draw_Interpretor& ,
   Standard_Real    Of    = Draw::Atof(a[3]);
   Standard_Boolean Inter = (!strcmp(a[0],"offsetcompshape"));
   GeomAbs_JoinType JT= GeomAbs_Arc;
-  if (!strcmp(a[0],"offsetinter")) {
+  if (!strcmp(a[0],"offsetinter"))
+  {
     JT    = GeomAbs_Intersection;
     Inter = Standard_True;
   }
@@ -869,9 +960,11 @@ Standard_Integer offsetshape(Draw_Interpretor& ,
   BRepOffset_MakeOffset B;
   Standard_Integer      IB  = 4;
   Standard_Real         Tol = Precision::Confusion();
-  if (n > 4) {
+  if (n > 4)
+  {
     TopoDS_Shape  SF  = DBRep::Get(a[4],TopAbs_FACE);
-    if (SF.IsNull()) {
+    if (SF.IsNull())
+    {
       IB  = 5;
       Tol = Draw::Atof(a[4]);
     }
@@ -882,19 +975,21 @@ Standard_Integer offsetshape(Draw_Interpretor& ,
   //----------------------------------------
   Standard_Boolean YaBouchon = Standard_False;
 
-  for (Standard_Integer i = IB ; i < n; i++) {
+  for (Standard_Integer i = IB ; i < n; i++)
+  {
     TopoDS_Shape  SF  = DBRep::Get(a[i],TopAbs_FACE);
-    if (!SF.IsNull()) {
+    if (!SF.IsNull())
+    {
       YaBouchon = Standard_True;
       B.AddFace(TopoDS::Face(SF));
     }
   }
 
-//  Clock.Start();
-
   if (!YaBouchon)  B.MakeOffsetShape();
   else             B.MakeThickSolid ();
-//  Clock.Show();
+
+  const BRepOffset_Error aRetCode = B.Error();
+  reportOffsetState(theCommands, aRetCode);
 
   DBRep::Set(a[1],B.Shape());
 
@@ -907,63 +1002,63 @@ static Standard_Boolean      theYaBouchon;
 static Standard_Real         TheTolerance = Precision::Confusion();
 static Standard_Boolean      TheInter     = Standard_False;
 static GeomAbs_JoinType      TheJoin      = GeomAbs_Arc;
+static Standard_Boolean      RemoveIntEdges = Standard_False;
 
 Standard_Integer offsetparameter(Draw_Interpretor& di,
-				 Standard_Integer n, const char** a)
+                                 Standard_Integer n, const char** a)
 {
   if ( n == 1 ) { 
-    //cout << " OffsetParameter Tol Inter(c/p) JoinType(a/i)" << endl;
-    //cout << " Current Values" << endl;
-    //cout << "   --> Tolerance :" << TheTolerance << endl;
-    //cout << "   --> TheInter  :";
-    di << " OffsetParameter Tol Inter(c/p) JoinType(a/i)" << "\n";
-    di << " Current Values" << "\n";
-    di << "   --> Tolerance :" << TheTolerance << "\n";
-    di << "   --> TheInter  :";
+    di << " offsetparameter Tol Inter(c/p) JoinType(a/i/t) [RemoveInternalEdges(r/k)]\n";
+    di << " Current Values\n";
+    di << "   --> Tolerance : " << TheTolerance << "\n";
+    di << "   --> TheInter  : ";
     if ( TheInter) {
-      //cout << "Complet" ;
       di << "Complet" ;
     } else {
-      //cout << "Partial";
       di << "Partial";
     }
-    //cout << endl << "   --> TheJoin   :";
-    di << "\n" << "   --> TheJoin   :";
+    di << "\n   --> TheJoin   : ";
     
     switch (TheJoin) {
-    //case GeomAbs_Arc:          cout << " Arc";          break;
-    //case GeomAbs_Intersection: cout << " Intersection"; break;
-    case GeomAbs_Arc:          di << " Arc";          break;
-    case GeomAbs_Intersection: di << " Intersection"; break;
+    case GeomAbs_Arc:          di << "Arc";          break;
+    case GeomAbs_Intersection: di << "Intersection"; break;
     default:
       break ;
     }
-    //cout << endl;
+    //
+    di << "\n   --> Internal Edges : ";
+    if (RemoveIntEdges) {
+      di << "Remove";
+    }
+    else {
+      di << "Keep";
+    }
     di << "\n";
-
+    //
     return 0;
   }
 
   if ( n < 4 ) return 1;
-  
+  //
   TheTolerance = Draw::Atof(a[1]);
-  TheInter     = strcmp(a[2],"p");
-  
+  TheInter     = strcmp(a[2],"p") != 0;
+  //
   if      ( !strcmp(a[3],"a")) TheJoin = GeomAbs_Arc;
   else if ( !strcmp(a[3],"i")) TheJoin = GeomAbs_Intersection;
   else if ( !strcmp(a[3],"t")) TheJoin = GeomAbs_Tangent;
-    
-  return 0;    
+  //
+  RemoveIntEdges = (n >= 5) ? !strcmp(a[4], "r") : Standard_False;
+  //
+  return 0;
 }
 
-
 //=======================================================================
 //function : offsetinit
 //purpose  : 
 //=======================================================================
 
 Standard_Integer offsetload(Draw_Interpretor& ,
-			    Standard_Integer n, const char** a)
+  Standard_Integer n, const char** a)
 {
   if ( n < 2) return 1;
   TopoDS_Shape  S  = DBRep::Get(a[1]);
@@ -973,7 +1068,8 @@ Standard_Integer offsetload(Draw_Interpretor& ,
   TheRadius = Of;
 //  Standard_Boolean Inter = Standard_True;
   
-  TheOffset.Initialize(S,Of,TheTolerance,BRepOffset_Skin,TheInter,0,TheJoin);
+  TheOffset.Initialize(S,Of,TheTolerance,BRepOffset_Skin,TheInter,0,TheJoin,
+                       Standard_False, RemoveIntEdges);
   //------------------------------------------
   // recuperation et chargement des bouchons.
   //----------------------------------------
@@ -1031,112 +1127,14 @@ Standard_Integer offsetperform(Draw_Interpretor& theCommands,
     }
   else
     {
-      // Return state of problem.
-      BRepOffset_Error anError = TheOffset.Error();
-
-      switch(anError)
-      {
-      case BRepOffset_BadNormalsOnGeometry:
-        {
-          theCommands << "ERROR. Degenerated normal on input data.";
-          break;
-        }
-      case BRepOffset_C0Geometry:
-        {
-          theCommands << "ERROR. C0 continuity of input data.";
-          break;
-        }
-      case BRepOffset_NullOffset:
-        {
-          theCommands << "ERROR. Null offset of all faces.";
-          break;
-        }
-      case BRepOffset_NotConnectedShell:
-        {
-          theCommands << "ERROR. Incorrect set of faces to remove, the remaining shell is not connected.";
-          break;
-        }
-
-      default:
-        {
-          theCommands << "ERROR. offsetperform operation not done.";
-          break;
-        }
-      }
-    return 1;
+      const BRepOffset_Error aRetCode = TheOffset.Error();
+      reportOffsetState(theCommands, aRetCode);
     }
 
   return 0;
   }
 
 
-//=======================================================================
-//function : Debou
-//purpose  : 
-//=======================================================================
-
-static Standard_Integer Debou(Draw_Interpretor& theCommands,
-			      Standard_Integer narg, const char** a)
-{
-  Standard_Integer i ;
-  Standard_Integer newnarg ;
-
-  if (narg<7) return 1;
-  
-  TopoDS_Shape S = DBRep::Get(a[2]);
-
-  Standard_Boolean Fuse;
-  if (!strcasecmp("F",a[3])) {
-    Fuse = Standard_True;
-  }
-  else if (!strcasecmp("C",a[3])) {
-    Fuse = Standard_False;
-  }
-  else {
-    return 1;
-  }
-
-  for ( newnarg = 4; newnarg < narg; newnarg++) {
-    if (a[newnarg][0] == '@') {
-      break;
-    }
-  }
-  if (newnarg >= narg-1 || newnarg == 4) {
-    return 1;
-  }
-
-
-  TopTools_ListOfShape LF,LF2;
-  for ( i=4; i<newnarg; i++) {
-    TopoDS_Shape aLocalShape(DBRep::Get(a[i],TopAbs_FACE));
-    LF.Append(aLocalShape);
-//    LF.Append(TopoDS::Face(DBRep::Get(a[i],TopAbs_FACE)));
-  }
-
-  for (i=newnarg+1; i<narg; i++) {
-    TopoDS_Shape aLocalShape(DBRep::Get(a[i],TopAbs_FACE));
-    LF2.Append(aLocalShape);
-//    LF2.Append(TopoDS::Face(DBRep::Get(a[i],TopAbs_FACE)));
-  }
-
-  //BRepFeat_LocalOperation BLoc(S);
-  //BLoc.Perform(LF,LF2,Fuse);
-  //BLoc.Build();
-  BRepFeat_Builder BLoc;
-  BLoc.Init(S, S);
-  BLoc.Perform();
-  BLoc.PerformResult();
-  if (!BLoc.ErrorStatus()) {
-//    dout.Clear();
-    DBRep::Set(a[1],BLoc.Shape());
-    dout.Flush();
-    return 0;
-  }
-  theCommands << "Local operation not done" ;
-  return 1;
-}
-
-
 //=======================================================================
 //function : ROW
 //purpose  : 
@@ -2302,8 +2300,8 @@ void BRepTest::FeatureCommands (Draw_Interpretor& theCommands)
 
 
   theCommands.Add("splitshape",
-		  "splitshape result shape face wire/edge/compound [wire/edge/compound ...][face wire/edge/compound [wire/edge/compound...] ...] [@ edgeonshape edgeonwire [edgeonshape edgeonwire...]]",
-		  __FILE__,SPLS,g);
+    "splitshape result shape [splitedges] [face wire/edge/compound [wire/edge/compound ...][face wire/edge/compound [wire/edge/compound...] ...] [@ edgeonshape edgeonwire [edgeonshape edgeonwire...]]",
+    __FILE__, SPLS, g);
 
 
   theCommands.Add("thickshell",
@@ -2319,7 +2317,7 @@ void BRepTest::FeatureCommands (Draw_Interpretor& theCommands)
 		  __FILE__,offsetshape,g);
 
   theCommands.Add("offsetparameter",
-		  "offsetparameter tol inter(a/i) join(a/i)",
+		  "offsetparameter Tol Inter(c/p) JoinType(a/i/t) [RemoveInternalEdges(r/k)]",
 		  __FILE__,offsetparameter);
 
   theCommands.Add("offsetload",
@@ -2334,12 +2332,6 @@ void BRepTest::FeatureCommands (Draw_Interpretor& theCommands)
 		  "offsetperform result",
 		  __FILE__,offsetperform,g);
 
-
-  theCommands.Add("deboucle", 
-		  " Essai de debouclage partiel: deboucle result shape F/C face [face...] @ face [face...]",
-		  __FILE__,Debou,g);
-
-
   theCommands.Add("glue", 
 		  "glue result shapenew shapebase facenew facebase [facenew facebase...] [edgenew edgebase [edgenew edgebase...]]",
 		  __FILE__,GLU,g);
