@@ -164,7 +164,7 @@ static Standard_Integer plate (Draw_Interpretor & di,Standard_Integer n,const ch
     Adaptor3d_CurveOnSurface ConS(C,S);
     Handle (Adaptor3d_HCurveOnSurface) HConS = new Adaptor3d_HCurveOnSurface(ConS);
     Fronts->SetValue(i,HConS);
-    Handle(BRepFill_CurveConstraint) Cont
+    Handle(GeomPlate_CurveConstraint) Cont
       = new BRepFill_CurveConstraint(HConS,
 				     Tang->Value(i),
 				     NbPtsCur->Value(i));
@@ -251,7 +251,8 @@ static Standard_Integer gplate (Draw_Interpretor & ,Standard_Integer n,const cha
     if ((Conti==0)||(Conti==-1))
       { Handle(BRepAdaptor_HCurve) C = new BRepAdaptor_HCurve();
 	C->ChangeCurve().Initialize(E);
-	Handle(BRepFill_CurveConstraint) Cont= new BRepFill_CurveConstraint(C,Conti);
+        const Handle(Adaptor3d_HCurve)& aC = C; // to avoid ambiguity
+	Handle(GeomPlate_CurveConstraint) Cont= new BRepFill_CurveConstraint(aC,Conti);
 	Henri.Add(Cont);
      }
     else 
@@ -267,7 +268,7 @@ static Standard_Integer gplate (Draw_Interpretor & ,Standard_Integer n,const cha
 	C->ChangeCurve2d().Initialize(E,F);
 	Adaptor3d_CurveOnSurface ConS(C,S);
 	Handle (Adaptor3d_HCurveOnSurface) HConS = new Adaptor3d_HCurveOnSurface(ConS);
-	Handle(BRepFill_CurveConstraint) Cont= new BRepFill_CurveConstraint(HConS,Conti);
+	Handle(GeomPlate_CurveConstraint) Cont= new BRepFill_CurveConstraint(HConS,Conti);
 	Henri.Add(Cont);
       }
   }
@@ -363,7 +364,7 @@ static Standard_Integer approxplate (Draw_Interpretor & di,Standard_Integer n,co
     Adaptor3d_CurveOnSurface ConS(C,S);
     Handle (Adaptor3d_HCurveOnSurface) HConS = new Adaptor3d_HCurveOnSurface(ConS);
     Fronts->SetValue(i,HConS);
-    Handle(BRepFill_CurveConstraint) Cont
+    Handle(GeomPlate_CurveConstraint) Cont
       = new BRepFill_CurveConstraint(HConS,
 				     Tang->Value(i),
 				     NbPtsCur->Value(i));
@@ -507,7 +508,7 @@ static Standard_Integer filling( Draw_Interpretor & di, Standard_Integer n, cons
 	  if (F.IsNull())
 	    {
 	      //cout<<endl<<"Wrong parameters"<<endl<<endl;
-	      di<<"\n"<<"Wrong parameters"<<"\n"<<"\n";
+	      di<<"\nWrong parameters\n\n";
 	      return 1;
 	    }
 	  else
@@ -526,7 +527,7 @@ static Standard_Integer filling( Draw_Interpretor & di, Standard_Integer n, cons
       if (E.IsNull())
 	{
 	  //cout<<"Wrong parameters"<<endl;
-	  di<<"Wrong parameters"<<"\n";
+	  di<<"Wrong parameters\n";
 	  return 1;
 	}
       //TopoDS_Shape alocalFace(DBRep::Get( a[i], TopAbs_FACE ) );
@@ -558,7 +559,7 @@ static Standard_Integer filling( Draw_Interpretor & di, Standard_Integer n, cons
 	  if (F.IsNull()) 
 	    {
 	      //cout<<"Wrong parameters"<<endl;
-	      di<<"Wrong parameters"<<"\n";
+	      di<<"Wrong parameters\n";
 	      return 1;
 	    }
 	  Order = Draw::Atoi( a[i++] );
@@ -571,7 +572,7 @@ static Standard_Integer filling( Draw_Interpretor & di, Standard_Integer n, cons
   if (! MakeFilling.IsDone())
     {
       //cout<<"filling failed"<<endl;
-      di<<"filling failed"<<"\n";
+      di<<"filling failed\n";
       return 0;
     }
 
@@ -590,7 +591,7 @@ static Standard_Integer filling( Draw_Interpretor & di, Standard_Integer n, cons
   Chrono.Show(Tps);
   //cout<<"*** FIN DE FILLING ***"<<endl;
   //cout<<"Temps de calcul  : "<<Tps<<endl;
-  di<<"*** FIN DE FILLING ***"<<"\n";
+  di<<"*** FIN DE FILLING ***\n";
   di<<"Temps de calcul  : "<<Tps<<"\n";
 #endif
 
@@ -608,11 +609,11 @@ static Standard_Integer fillingparam( Draw_Interpretor & di, Standard_Integer n,
     //cout << "-c t2d t3d tang tcur : to set tolerances" << endl;
     //cout << "-a maxdeg maxseg : Approximation option" << endl;
     di << "fillingparam : options are"  <<"\n";
-    di << "-l : to list current values" << "\n";
+    di << "-l : to list current values\n";
     di << "-i : to set default values"   << "\n";
-    di << "-r deg nbPonC nbIt anis : to set filling options" <<"\n";
-    di << "-c t2d t3d tang tcur : to set tolerances" << "\n";
-    di << "-a maxdeg maxseg : Approximation option" << "\n";
+    di << "-r deg nbPonC nbIt anis : to set filling options\n";
+    di << "-c t2d t3d tang tcur : to set tolerances\n";
+    di << "-a maxdeg maxseg : Approximation option\n";
   }
   else if (n > 1)
     {
@@ -638,15 +639,15 @@ static Standard_Integer fillingparam( Draw_Interpretor & di, Standard_Integer n,
 	  di<<"Degree = "<<Degree<<"\n";
 	  di<<"NbPtsOnCur = "<<NbPtsOnCur<<"\n";
 	  di<<"NbIter = "<<NbIter<<"\n";
-	  di<<"Anisotropie = "<< (Standard_Integer) Anisotropie<<"\n"<<"\n";
+	  di<<"Anisotropie = "<< (Standard_Integer) Anisotropie<<"\n\n";
 	  
 	  di<<"Tol2d = "<<Tol2d<<"\n";
 	  di<<"Tol3d = "<<Tol3d<<"\n";
 	  di<<"TolAng = "<<TolAng<<"\n";
-	  di<<"TolCurv = "<<TolCurv<<"\n"<<"\n";
+	  di<<"TolCurv = "<<TolCurv<<"\n\n";
 	  
 	  di<<"MaxDeg = "<<MaxDeg<<"\n";
-	  di<<"MaxSegments = "<<MaxSegments<<"\n"<<"\n";
+	  di<<"MaxSegments = "<<MaxSegments<<"\n\n";
 	}
       else if (strcmp( flag, "-i" ) == 0 && n == 2)
 	{
@@ -668,7 +669,7 @@ static Standard_Integer fillingparam( Draw_Interpretor & di, Standard_Integer n,
 	  Degree      = Draw::Atoi( a[2] );
 	  NbPtsOnCur  = Draw::Atoi( a[3] );
 	  NbIter      = Draw::Atoi( a[4] );
-	  Anisotropie = Draw::Atoi( a[5] );
+	  Anisotropie = Draw::Atoi( a[5] ) != 0;
 	}
       else if (strcmp( flag, "-c" ) == 0 && n == 6)
 	{
@@ -685,7 +686,7 @@ static Standard_Integer fillingparam( Draw_Interpretor & di, Standard_Integer n,
       else
 	{
 	  //cout<<"Wrong parameters"<<endl;
-	  di<<"Wrong parameters"<<"\n";
+	  di<<"Wrong parameters\n";
 	  return 1;
 	}
     }
