@@ -14,30 +14,37 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <Bisector_BisecPC.ixx>
+
 #include <Bisector.hxx>
-#include <Geom2dAdaptor_Curve.hxx>
-#include <Geom2d_Curve.hxx>
-#include <Geom2d_Line.hxx>
-#include <Geom2d_CartesianPoint.hxx>
-#include <Geom2dInt_GInter.hxx>
-#include <Geom2dGcc.hxx>
+#include <Bisector_BisecPC.hxx>
+#include <ElCLib.hxx>
 #include <GccEnt_Position.hxx>
+#include <Geom2d_CartesianPoint.hxx>
+#include <Geom2d_Curve.hxx>
+#include <Geom2d_Geometry.hxx>
+#include <Geom2d_Line.hxx>
+#include <Geom2d_TrimmedCurve.hxx>
+#include <Geom2dAdaptor_Curve.hxx>
+#include <Geom2dAPI_ProjectPointOnCurve.hxx>
+#include <Geom2dGcc.hxx>
 #include <Geom2dGcc_Circ2d2TanRad.hxx>
 #include <Geom2dGcc_QualifiedCurve.hxx>
-#include <Geom2d_TrimmedCurve.hxx>
-#include <Geom2dAPI_ProjectPointOnCurve.hxx>
+#include <Geom2dInt_GInter.hxx>
 #include <Geom2dLProp_CLProps2d.hxx>
-#include <gp_Pnt2d.hxx>
-#include <gp_Vec2d.hxx>
-#include <gp_Ax2d.hxx>  
 #include <gp.hxx>
-#include <Precision.hxx>
-#include <ElCLib.hxx>
+#include <gp_Ax2d.hxx>
+#include <gp_Pnt2d.hxx>
+#include <gp_Trsf2d.hxx>
+#include <gp_Vec2d.hxx>
 #include <IntRes2d_IntersectionPoint.hxx>
-
+#include <Precision.hxx>
 #include <Standard_DivideByZero.hxx>
+#include <Standard_DomainError.hxx>
 #include <Standard_NotImplemented.hxx>
+#include <Standard_RangeError.hxx>
+#include <Standard_Type.hxx>
+
+IMPLEMENT_STANDARD_RTTIEXT(Bisector_BisecPC,Bisector_Curve)
 
 //=============================================================================
 //function :
@@ -381,11 +388,11 @@ void Bisector_BisecPC::Values(const Standard_Real    U,
   case 2 :  {curve->D3(UOnCurve,PC,Tu,Tuu,T3u);break;}
   }
   
-  gp_Vec2d PPC(PC.X() - point.X(), PC.Y() - point.Y());
+  gp_Vec2d aPPC(PC.X() - point.X(), PC.Y() - point.Y());
   gp_Vec2d Nor( - Tu.Y(), Tu.X());
   
-  Standard_Real SquarePPC = PPC.SquareMagnitude();
-  Standard_Real NorPPC    = Nor.Dot(PPC);
+  Standard_Real SquarePPC = aPPC.SquareMagnitude();
+  Standard_Real NorPPC    = Nor.Dot(aPPC);
   Standard_Real A1;
 
   if (Abs(NorPPC) > gp::Resolution() && (NorPPC*sign) < 0.) {
@@ -397,8 +404,8 @@ void Bisector_BisecPC::Values(const Standard_Real    U,
   if (N == 0) return;                                 // End Calculation Point;
 
   gp_Vec2d      Nu ( - Tuu.Y() , Tuu.X());            // derivative of the normal by U.
-  Standard_Real NuPPC     = Nu .Dot(PPC);
-  Standard_Real TuPPC     = Tu .Dot(PPC);
+  Standard_Real NuPPC     = Nu .Dot(aPPC);
+  Standard_Real TuPPC     = Tu .Dot(aPPC);
   Standard_Real NorPPCE2  = NorPPC*NorPPC;
   Standard_Real A2        = TuPPC/NorPPC - 0.5*NuPPC*SquarePPC/NorPPCE2;
 
@@ -410,8 +417,8 @@ void Bisector_BisecPC::Values(const Standard_Real    U,
   gp_Vec2d Nuu ( - T3u.Y() , T3u.X());
   
   Standard_Real NorPPCE4 = NorPPCE2*NorPPCE2;
-  Standard_Real NuuPPC   = Nuu.Dot(PPC);
-  Standard_Real TuuPPC   = Tuu.Dot(PPC);
+  Standard_Real NuuPPC   = Nuu.Dot(aPPC);
+  Standard_Real TuuPPC   = Tuu.Dot(aPPC);
   
   Standard_Real A21 = TuuPPC/NorPPC - TuPPC*NuPPC/NorPPCE2;
   Standard_Real A22 = (0.5*NuuPPC*SquarePPC + NuPPC*TuPPC)/NorPPCE2 - 
@@ -465,12 +472,12 @@ Standard_Real Bisector_BisecPC::Distance (const Standard_Real U) const
   Standard_Real UOnCurve = LinkBisCurve(U);
   
   curve->D1(UOnCurve,PC,Tan);
-  gp_Vec2d PPC(PC.X() - point.X(), PC.Y() - point.Y());
+  gp_Vec2d aPPC(PC.X() - point.X(), PC.Y() - point.Y());
   gp_Vec2d Nor( - Tan.Y(), Tan.X());
 
   Standard_Real NorNor       = Nor.SquareMagnitude();
-  Standard_Real SquareMagPPC = PPC.SquareMagnitude();
-  Standard_Real Prosca       = Nor.Dot(PPC);
+  Standard_Real SquareMagPPC = aPPC.SquareMagnitude();
+  Standard_Real Prosca       = Nor.Dot(aPPC);
   
   if (point.IsEqual(PC,Precision::Confusion())) {
     if (isConvex) { return 0.;}
@@ -634,7 +641,7 @@ void Bisector_BisecPC::CuspFilter()
 void Bisector_BisecPC::ComputeIntervals ()
 {
   Standard_Real U1 =0.,U2 =0.,UProj =0.;
-  Standard_Real UStart,UEnd;
+  Standard_Real UStart = 0., UEnd = 0.;
   Standard_Real Dist1,Dist2,DistProj;
   isEmpty        = Standard_False;     
   shiftParameter = 0.;
