@@ -14,58 +14,48 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <ChFi2d.hxx>
-#include <ChFi2d_Builder.ixx>
 
+#include <BRep_Builder.hxx>
+#include <BRep_Tool.hxx>
 #include <BRepAdaptor_Surface.hxx>
 #include <BRepLib.hxx>
 #include <BRepLib_MakeEdge.hxx>
 #include <BRepLib_MakeFace.hxx>
-
-#include <BRep_Builder.hxx>
-#include <BRep_Tool.hxx>
-
+#include <ChFi2d.hxx>
+#include <ChFi2d_Builder.hxx>
 #include <ElCLib.hxx>
-
 #include <GccEnt_Position.hxx>
-
+#include <Geom2d_Circle.hxx>
+#include <Geom2d_Curve.hxx>
+#include <Geom2d_Line.hxx>
+#include <Geom2d_TrimmedCurve.hxx>
+#include <Geom2dGcc_Circ2d2TanRad.hxx>
+#include <Geom2dGcc_QualifiedCurve.hxx>
+#include <Geom2dInt_GInter.hxx>
 #include <Geom_Circle.hxx>
 #include <Geom_Curve.hxx>
 #include <Geom_Line.hxx>
 #include <Geom_Plane.hxx>
 #include <Geom_Surface.hxx>
-
-
-#include <Geom2d_TrimmedCurve.hxx>
-#include <Geom2d_Circle.hxx>
-#include <Geom2d_Curve.hxx>
-#include <Geom2d_Line.hxx>
-
-#include <Geom2dInt_GInter.hxx>
-#include <Geom2dGcc_Circ2d2TanRad.hxx>
-#include <Geom2dGcc_QualifiedCurve.hxx>
-
-#include <IntRes2d_IntersectionPoint.hxx>
-
+#include <gp_Circ2d.hxx>
 #include <gp_Pln.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Pnt2d.hxx>
-#include <gp_Circ2d.hxx>
 #include <gp_Vec2d.hxx>
-
+#include <IntRes2d_IntersectionPoint.hxx>
 #include <Precision.hxx>
-
 #include <TopAbs_Orientation.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
 #include <TopLoc_Location.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
-#include <TopTools_IndexedMapOfShape.hxx>
-
 #include <TopoDS.hxx>
 #include <TopoDS_Edge.hxx>
+#include <TopoDS_Face.hxx>
+#include <TopoDS_Vertex.hxx>
 #include <TopoDS_Wire.hxx>
+#include <TopTools_DataMapIteratorOfDataMapOfShapeShape.hxx>
+#include <TopTools_IndexedMapOfShape.hxx>
+#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 static Standard_Boolean IsIssuedFrom(const TopoDS_Edge& E,
 				     const TopTools_IndexedMapOfShape& Map,
@@ -784,14 +774,14 @@ TopoDS_Edge ChFi2d_Builder::BuildFilletEdge(const TopoDS_Vertex& V,
   Handle(Geom2d_Curve) basisC1,basisC2; 
   Handle(Geom2d_TrimmedCurve) T1 = Handle(Geom2d_TrimmedCurve)::DownCast(C1);
   if (!T1.IsNull())
-    basisC1 = Handle(Geom2d_Curve)::DownCast(T1->BasisCurve());
+    basisC1 = T1->BasisCurve();
   else
-    basisC1 = Handle(Geom2d_Curve)::DownCast(C1);
+    basisC1 = C1;
   Handle(Geom2d_TrimmedCurve) T2 = Handle(Geom2d_TrimmedCurve)::DownCast(C2);
   if (!T2.IsNull())
-    basisC2 = Handle(Geom2d_Curve)::DownCast(T2->BasisCurve());
+    basisC2 = T2->BasisCurve();
   else
-    basisC2 = Handle(Geom2d_Curve)::DownCast(C2);
+    basisC2 = C2;
 
   if (basisC1->DynamicType() == STANDARD_TYPE(Geom2d_Circle)) {
     Handle(Geom2d_Circle) CC1 = Handle(Geom2d_Circle)::DownCast(basisC1);
@@ -1051,8 +1041,7 @@ TopoDS_Edge ChFi2d_Builder::BuildFilletEdge(const TopoDS_Vertex& V,
     if (OE1 == TopAbs_REVERSED) {
       vec1.Reverse();
     } // if (OE1 ...
-    Standard_Real cross = vec1*vec;
-    Standard_Boolean Sense = cross > 0.;
+    Standard_Boolean Sense = ( vec1*vec ) > 0.;
     if (U1 > Vv1 && U1 > 2.*M_PI) {
       ElCLib::AdjustPeriodic(0.,2.*M_PI,Precision::Confusion(),U1,Vv1);
     } // if (U1 ... 
@@ -1143,9 +1132,9 @@ Standard_Boolean IsLineOrCircle(const TopoDS_Edge& E,
   Handle(Geom2d_Curve) basisC; 
   Handle(Geom2d_TrimmedCurve) TC = Handle(Geom2d_TrimmedCurve)::DownCast(C);
   if (!TC.IsNull())
-    basisC = Handle(Geom2d_Curve)::DownCast(TC->BasisCurve());
+    basisC = TC->BasisCurve();
   else
-    basisC = Handle(Geom2d_Curve)::DownCast(C);
+    basisC = C;
 
   if ( basisC->DynamicType() == STANDARD_TYPE(Geom2d_Circle)
       || basisC->DynamicType() == STANDARD_TYPE(Geom2d_Line) ) {
