@@ -14,46 +14,50 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <ChFi3d_ChBuilder.ixx>
-#include <ChFi3d.hxx>
-#include <ChFi3d_Builder_0.hxx>
-
-#include <TopOpeBRepDS_HDataStructure.hxx>
-#include <TopOpeBRepBuild_HBuilder.hxx>
-#include <ChFiDS_Spine.hxx>
-#include <ChFiDS_ChamfSpine.hxx>
-#include <ChFiDS_Stripe.hxx>
-#include <ChFiDS_ListOfStripe.hxx>
-#include <ChFiDS_ListIteratorOfListOfStripe.hxx>
-#include <ChFiDS_Regul.hxx>
-#include <ChFiDS_ListIteratorOfRegularities.hxx>	
-#include <ChFiDS_SecHArray1.hxx>
-#include <ChFiDS_HData.hxx>
-#include <ChFiDS_CircSection.hxx>
 
+#include <Adaptor3d_TopolTool.hxx>
 #include <Blend_Point.hxx>
-#include <BRepBlend_Line.hxx>
+#include <BlendFunc_SectionShape.hxx>
+#include <BRepAdaptor_Curve2d.hxx>
+#include <BRepAdaptor_HCurve2d.hxx>
+#include <BRepAdaptor_HSurface.hxx>
+#include <BRepAdaptor_Surface.hxx>
 #include <BRepBlend_Chamfer.hxx>
 #include <BRepBlend_ChamfInv.hxx>
 #include <BRepBlend_ChAsym.hxx>
 #include <BRepBlend_ChAsymInv.hxx>
-#include <BlendFunc_SectionShape.hxx>
+#include <BRepBlend_Line.hxx>
 #include <BRepBlend_Walking.hxx>
-#include <BRepAdaptor_HSurface.hxx>
-#include <BRepAdaptor_Curve2d.hxx>
-#include <GeomAdaptor_HCurve.hxx>
-
-
-#include <Extrema_GenLocateExtPS.hxx>
-#include <BRepAdaptor_Surface.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
-#include <TopAbs.hxx>
-
-#include <ElSLib.hxx>
 #include <BRepTools.hxx>
-
-#include <Standard_NotImplemented.hxx>
+#include <ChFi3d.hxx>
+#include <ChFi3d_Builder_0.hxx>
+#include <ChFi3d_ChBuilder.hxx>
+#include <ChFiDS_ChamfSpine.hxx>
+#include <ChFiDS_CircSection.hxx>
+#include <ChFiDS_HData.hxx>
+#include <ChFiDS_HElSpine.hxx>
+#include <ChFiDS_ListIteratorOfListOfStripe.hxx>
+#include <ChFiDS_ListIteratorOfRegularities.hxx>
+#include <ChFiDS_ListOfStripe.hxx>
+#include <ChFiDS_Regul.hxx>
+#include <ChFiDS_SecHArray1.hxx>
+#include <ChFiDS_Spine.hxx>
+#include <ChFiDS_Stripe.hxx>
+#include <ChFiDS_SurfData.hxx>
+#include <ElSLib.hxx>
+#include <Extrema_GenLocateExtPS.hxx>
+#include <GeomAdaptor_HCurve.hxx>
+#include <Standard_ConstructionError.hxx>
 #include <Standard_DomainError.hxx>
+#include <Standard_NotImplemented.hxx>
+#include <TopAbs.hxx>
+#include <TopoDS_Edge.hxx>
+#include <TopoDS_Face.hxx>
+#include <TopoDS_Shape.hxx>
+#include <TopoDS_Vertex.hxx>
+#include <TopOpeBRepBuild_HBuilder.hxx>
+#include <TopOpeBRepDS_HDataStructure.hxx>
+#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 #ifdef OCCT_DEBUG
 extern Standard_Boolean ChFi3d_GettraceCHRON();
@@ -796,8 +800,8 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
 			    const Standard_Boolean              RecOnS1,
 			    const Standard_Boolean              RecOnS2,
 			    const math_Vector&                  Soldep,
-			    Standard_Boolean&                   intf,
-			    Standard_Boolean&                   intl)
+			    Standard_Integer&                   intf,
+			    Standard_Integer&                   intl)
      
 {
   Handle(ChFiDS_ChamfSpine) 
@@ -883,12 +887,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
     
     Standard_Boolean reverse = (!Forward || Inside);
     if(intf && reverse){
-      Standard_Boolean ok = 0;
+      Standard_Boolean ok = Standard_False;
       const ChFiDS_CommonPoint& cp1 = Data->VertexFirstOnS1();
       if(cp1.IsOnArc()){
 	TopoDS_Face F1 = S1->ChangeSurface().Face();
 	TopoDS_Face bid;
-	ok = intf = !SearchFace(Spine,cp1,F1,bid);
+	intf = !SearchFace(Spine,cp1,F1,bid);
+	ok = intf != 0;
       }
       const ChFiDS_CommonPoint& cp2 = Data->VertexFirstOnS2();
       if(cp2.IsOnArc() && !ok){
@@ -898,12 +903,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
       }
     }
     if(intl){
-      Standard_Boolean ok = 0;
+      Standard_Boolean ok = Standard_False;
       const ChFiDS_CommonPoint& cp1 = Data->VertexLastOnS1();
       if(cp1.IsOnArc()){
 	TopoDS_Face F1 = S1->ChangeSurface().Face();
 	TopoDS_Face bid;
-	ok = intl = !SearchFace(Spine,cp1,F1,bid);
+	intl = !SearchFace(Spine,cp1,F1,bid);
+	ok = intl != 0;
       }
       const ChFiDS_CommonPoint& cp2 = Data->VertexLastOnS2();
       if(cp2.IsOnArc() && !ok){
@@ -963,12 +969,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
     
     Standard_Boolean reverse = (!Forward || Inside);
     if(intf && reverse){
-      Standard_Boolean ok = 0;
+      Standard_Boolean ok = Standard_False;
       const ChFiDS_CommonPoint& cp1 = Data->VertexFirstOnS1();
       if(cp1.IsOnArc()){
 	TopoDS_Face F1 = S1->ChangeSurface().Face();
 	TopoDS_Face bid;
-	ok = intf = !SearchFace(Spine,cp1,F1,bid);
+	intf = !SearchFace(Spine,cp1,F1,bid);
+	ok = intf != 0;
       }
       const ChFiDS_CommonPoint& cp2 = Data->VertexFirstOnS2();
       if(cp2.IsOnArc() && !ok){
@@ -978,12 +985,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
       }
     }
     if(intl){
-      Standard_Boolean ok = 0;
+      Standard_Boolean ok = Standard_False;
       const ChFiDS_CommonPoint& cp1 = Data->VertexLastOnS1();
       if(cp1.IsOnArc()){
 	TopoDS_Face F1 = S1->ChangeSurface().Face();
 	TopoDS_Face bid;
-	ok = intl = !SearchFace(Spine,cp1,F1,bid);
+	intl = !SearchFace(Spine,cp1,F1,bid);
+	ok = intl != 0;
       }
       const ChFiDS_CommonPoint& cp2 = Data->VertexLastOnS2();
       if(cp2.IsOnArc() && !ok){
@@ -1048,12 +1056,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
 
       Standard_Boolean reverse = (!Forward || Inside);
       if(intf && reverse){
-	Standard_Boolean ok = 0;
+	Standard_Boolean ok = Standard_False;
 	const ChFiDS_CommonPoint& cp1 = Data->VertexFirstOnS1();
 	if(cp1.IsOnArc()){
 	  TopoDS_Face F1 = S1->ChangeSurface().Face();
 	  TopoDS_Face bid;
-	  ok = intf = !SearchFace(Spine,cp1,F1,bid);
+	  intf = !SearchFace(Spine,cp1,F1,bid);
+	  ok = intf != 0;
 	}
 	const ChFiDS_CommonPoint& cp2 = Data->VertexFirstOnS2();
 	if(cp2.IsOnArc() && !ok){
@@ -1064,12 +1073,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
       }
       
       if(intl){
-	Standard_Boolean ok = 0;
+	Standard_Boolean ok = Standard_False;
 	const ChFiDS_CommonPoint& cp1 = Data->VertexLastOnS1();
 	if(cp1.IsOnArc()){
 	  TopoDS_Face F1 = S1->ChangeSurface().Face();
 	  TopoDS_Face bid;
-	  ok = intl = !SearchFace(Spine,cp1,F1,bid);
+	  intl = !SearchFace(Spine,cp1,F1,bid);
+	  ok = intl != 0;
 	}
 	const ChFiDS_CommonPoint& cp2 = Data->VertexLastOnS2();
 	if(cp2.IsOnArc() && !ok){
@@ -1132,12 +1142,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
 
       Standard_Boolean reverse = (!Forward || Inside);
       if(intf && reverse){
-	Standard_Boolean ok = 0;
+	Standard_Boolean ok = Standard_False;
 	const ChFiDS_CommonPoint& cp1 = Data->VertexFirstOnS1();
 	if(cp1.IsOnArc()){
 	  TopoDS_Face F1 = S1->ChangeSurface().Face();
 	  TopoDS_Face bid;
-	  ok = intf = !SearchFace(Spine,cp1,F1,bid);
+	  intf = !SearchFace(Spine,cp1,F1,bid);
+	  ok = intf != 0;
 	}
 	const ChFiDS_CommonPoint& cp2 = Data->VertexFirstOnS2();
 	if(cp2.IsOnArc() && !ok){
@@ -1148,12 +1159,13 @@ ChFi3d_ChBuilder::SimulSurf(Handle(ChFiDS_SurfData)&            Data,
       }
       
       if(intl){
-	Standard_Boolean ok = 0;
+	Standard_Boolean ok = Standard_False;
 	const ChFiDS_CommonPoint& cp1 = Data->VertexLastOnS1();
 	if(cp1.IsOnArc()){
 	  TopoDS_Face F1 = S1->ChangeSurface().Face();
 	  TopoDS_Face bid;
-	  ok = intl = !SearchFace(Spine,cp1,F1,bid);
+	  intl = !SearchFace(Spine,cp1,F1,bid);
+	  ok = intl != 0;
 	}
 	const ChFiDS_CommonPoint& cp2 = Data->VertexLastOnS2();
 	if(cp2.IsOnArc() && !ok){
@@ -1328,8 +1340,11 @@ Standard_Boolean ChFi3d_ChBuilder::PerformFirstSection
     
     Standard_Real tol = tolesp*1.e2;
 //    Standard_Real u,v;
-    Extrema_GenLocateExtPS proj1(pt1,S1->Surface(),SolDep(1),SolDep(2),tol,tol);
-    Extrema_GenLocateExtPS proj2(pt2,S2->Surface(),SolDep(3),SolDep(4),tol,tol);
+    Extrema_GenLocateExtPS proj1(S1->Surface(), tol, tol);
+    proj1.Perform(pt1, SolDep(1), SolDep(2));
+    Extrema_GenLocateExtPS proj2(S2->Surface(), tol, tol);
+    proj2.Perform(pt2, SolDep(3), SolDep(4));
+
     if( proj1.IsDone() ){
       (proj1.Point()).Parameter(SolDep(1),SolDep(2)); 
     }
@@ -1385,8 +1400,12 @@ Standard_Boolean ChFi3d_ChBuilder::PerformFirstSection
     
     Standard_Real tol = tolesp*1.e2;
 //    Standard_Real u,v;
-    Extrema_GenLocateExtPS proj1(pt1,S1->Surface(),SolDep(1),SolDep(2),tol,tol);
-    Extrema_GenLocateExtPS proj2(pt2,S2->Surface(),SolDep(3),SolDep(4),tol,tol);
+
+    Extrema_GenLocateExtPS proj1(S1->Surface(), tol, tol);
+    proj1.Perform(pt1, SolDep(1), SolDep(2));
+    Extrema_GenLocateExtPS proj2(S2->Surface(), tol, tol);
+    proj2.Perform(pt2, SolDep(3), SolDep(4));
+
     if( proj1.IsDone() ){
       (proj1.Point()).Parameter(SolDep(1),SolDep(2)); 
     }
@@ -1453,8 +1472,10 @@ Standard_Boolean ChFi3d_ChBuilder::PerformFirstSection
       
       Standard_Real tol = tolesp*1.e2;
 //      Standard_Real u,v;
-      Extrema_GenLocateExtPS proj1(pt1,S1->Surface(),SolDep(1),SolDep(2),tol,tol);
-      Extrema_GenLocateExtPS proj2(pt2,S2->Surface(),SolDep(3),SolDep(4),tol,tol);
+      Extrema_GenLocateExtPS proj1(S1->Surface(), tol, tol);
+      proj1.Perform(pt1, SolDep(1), SolDep(2));
+      Extrema_GenLocateExtPS proj2(S2->Surface(), tol, tol);
+      proj2.Perform(pt2, SolDep(3), SolDep(4));
       if( proj1.IsDone() ){
 	(proj1.Point()).Parameter(SolDep(1),SolDep(2)); 
       }
@@ -1521,8 +1542,10 @@ Standard_Boolean ChFi3d_ChBuilder::PerformFirstSection
       
       Standard_Real tol = tolesp*1.e2;
 //      Standard_Real u,v;
-      Extrema_GenLocateExtPS proj1(pt1,S2->Surface(),SolDep(1),SolDep(2),tol,tol);
-      Extrema_GenLocateExtPS proj2(pt2,S1->Surface(),SolDep(3),SolDep(4),tol,tol);
+      Extrema_GenLocateExtPS proj1(S2->Surface(), tol, tol);
+      proj1.Perform(pt1, SolDep(1), SolDep(2));
+      Extrema_GenLocateExtPS proj2(S1->Surface(), tol, tol);
+      proj2.Perform(pt2, SolDep(3), SolDep(4));
       if( proj1.IsDone() ) {
 	(proj1.Point()).Parameter(SolDep(1),SolDep(2)); 
       }
@@ -1570,8 +1593,8 @@ ChFi3d_ChBuilder::PerformSurf(ChFiDS_SequenceOfSurfData&          SeqData,
 			      const Standard_Boolean              RecOnS1,
 			      const Standard_Boolean              RecOnS2,
 			      const math_Vector&                  Soldep,
-			      Standard_Boolean&                   intf,
-			      Standard_Boolean&                   intl)
+			      Standard_Integer&                   intf,
+			      Standard_Integer&                   intl)
      
 {
   Handle(ChFiDS_SurfData) Data = SeqData(1);
