@@ -71,7 +71,7 @@
 #include <DNaming_SphereDriver.hxx>
 #include <DNaming_PointDriver.hxx>
 #include <DNaming_Line3DDriver.hxx>
-#ifdef WNT
+#ifdef _WIN32
 #define EXCEPTION ...
 #else
 #define EXCEPTION Standard_Failure
@@ -109,7 +109,7 @@ static Standard_Integer  DNaming_AddObject(Draw_Interpretor& di,
       return 0;
     }
   }
-  di << "DNaming_AddObject: Error" << "\n";
+  di << "DNaming_AddObject: Error\n";
   return 1;
 }
 
@@ -293,7 +293,7 @@ static Standard_Integer  DNaming_AddFunction(Draw_Interpretor& di,
       return 0;
     }
   }
-  di << "DNaming_AddObject: Error" << "\n";
+  di << "DNaming_AddObject: Error\n";
   return 1;
 }
 
@@ -455,18 +455,12 @@ static Standard_Integer DNaming_BoxDZ (Draw_Interpretor& theDI,
   return 1;  
 }
 
-//=======================================================================
-static TFunction_Logbook& GetLogBook ()
-{
-  static TFunction_Logbook myLog;
-  return myLog;
-}
 //=======================================================================
 //function : Compute
 //purpose  : Performs the calling to a driver with the given Function ID.
 //=======================================================================
 static Standard_Integer ComputeFunction(const Handle(TFunction_Function)& theFun, 
-					TFunction_Logbook& theLog)
+                                        Handle(TFunction_Logbook)& theLog)
 {
   Handle(TFunction_DriverTable) aTable = TFunction_DriverTable::Get();
   Handle(TFunction_Driver) aDriver;
@@ -506,6 +500,7 @@ static Standard_Integer DNaming_SolveFlatFrom (Draw_Interpretor& /*theDI*/,
 #ifdef OCCT_DEBUG
     cout << "DNaming_SolveFlatFrom: Father label = " << entry << endl;
 #endif
+    Handle(TFunction_Logbook) logbook = TFunction_Logbook::Set(FatherLab);
     Standard_Boolean found(Standard_False);
     TDF_ChildIterator it(FatherLab, Standard_False);  
     for(;it.More(); it.Next()) {
@@ -526,7 +521,9 @@ static Standard_Integer DNaming_SolveFlatFrom (Draw_Interpretor& /*theDI*/,
       else {
 	TDF_Tool::Entry(funLabel, entry);
 	try {
-	  Standard_Integer aRes = ComputeFunction(aFun, GetLogBook());
+      // We clear the logbook because the execution starts not from the begining of the function list (some functions ar skipped).
+      logbook->Clear();
+	  Standard_Integer aRes = ComputeFunction(aFun, logbook);
 	  if(aRes != 0) {
 	    cout << "DNaming_SolveFlatFrom: Driver failed at label = " << entry << endl;
 	    return 1;
@@ -558,13 +555,14 @@ static Standard_Integer DNaming_InitLogBook (Draw_Interpretor& /*theDI*/,
     Handle(TDocStd_Document) aDoc;   
     Standard_CString aDocS(theArg[1]);
     if (!DDocStd::GetDocument(aDocS, aDoc)) return 1;  
-    if(GetLogBook().IsEmpty()) {
+    Handle(TFunction_Logbook) logbook = TFunction_Logbook::Set(aDoc->Main());
+    if(logbook->IsEmpty()) {
 #ifdef OCCT_DEBUG
       cout << "DNaming_InitLogBook : is empty" <<endl;
 #endif
     }
     else {
-      GetLogBook().Clear();
+      logbook->Clear();
 #ifdef OCCT_DEBUG
       cout << "DNaming_InitLogBook : cleaned" <<endl;
 #endif
@@ -586,12 +584,12 @@ static Standard_Integer DNaming_CheckLogBook (Draw_Interpretor& /*theDI*/,
   if (theNb == 2) {
     Handle(TDocStd_Document) aDoc;   
     Standard_CString aDocS(theArg[1]);
-    if (!DDocStd::GetDocument(aDocS, aDoc)) return 1;  
-    if(GetLogBook().IsEmpty())
+    if (!DDocStd::GetDocument(aDocS, aDoc)) return 1;
+    Handle(TFunction_Logbook) logbook = TFunction_Logbook::Set(aDoc->Main());
+    if(logbook->IsEmpty())
       cout << "DNaming_CheckLogBook : is empty" <<endl;
     else {
-      TDF_LabelMap aMap;
-      aMap = GetLogBook().GetValid();
+      const TDF_LabelMap& aMap = logbook->GetValid();
       TDF_MapIteratorOfLabelMap it(aMap);
       TCollection_AsciiString entry;
       cout << "DNaming_CheckLogBook : LogBook current state:" <<endl;
@@ -625,7 +623,8 @@ static Standard_Integer DNaming_ComputeFun (Draw_Interpretor& /*theDI*/,
     funLabel.FindAttribute(TFunction_Function::GetID(), aFun);
     if(aFun.IsNull()) return 1;
     if(!aFun.IsNull()) {
-      Standard_Integer aRes = ComputeFunction(aFun, GetLogBook());
+      Handle(TFunction_Logbook) logbook = TFunction_Logbook::Set(funLabel);
+      Standard_Integer aRes = ComputeFunction(aFun, logbook);
       if(aRes != 0) {
 	 cout << "DNaming_ComputeFun : No Driver or Driver failed" << endl;
 	 return 1;
@@ -683,10 +682,10 @@ static Standard_Integer DNaming_AttachShape (Draw_Interpretor& di,
 	  aResultLabel.ForgetAllAttributes(Standard_True);
 	  Standard_Boolean aKeepOrientation(Standard_False);
 	  if (nb >= 6) 
-	    aKeepOrientation = (Standard_Boolean) Draw::Atoi(a[5]);
+	    aKeepOrientation = Draw::Atoi(a[5]) != 0;
 	  Standard_Boolean aGeometry(Standard_False);
 	  if (nb == 7) 
-	    aGeometry = (Standard_Boolean) Draw::Atoi(a[6]);
+	    aGeometry = Draw::Atoi(a[6]) != 0;
 	  Handle(TNaming_NamedShape) aCont =  DNaming::GetObjectValue(aContext);
 #ifdef OCCT_DEBUG
 	  if(aCont.IsNull() || aCont->IsEmpty())
@@ -760,10 +759,10 @@ static Standard_Integer DNaming_XAttachShape (Draw_Interpretor& di,
 	  aResultLabel.ForgetAllAttributes(Standard_True);
 	  Standard_Boolean aKeepOrientation(Standard_False);
 	  if (nb >= 5) 
-	    aKeepOrientation = (Standard_Boolean) Draw::Atoi(a[4]);
+	    aKeepOrientation = Draw::Atoi(a[4]) != 0;
 	  Standard_Boolean aGeometry(Standard_False);
 	  if (nb == 6) 
-	    aGeometry = (Standard_Boolean) Draw::Atoi(a[5]);
+	    aGeometry = Draw::Atoi(a[5]) != 0;
 	  Handle(TNaming_NamedShape) aCont =  DNaming::GetObjectValue(aContext);
 
 	  if(aCont.IsNull() || aCont->IsEmpty())
@@ -1537,17 +1536,17 @@ static Standard_Integer DNaming_PntOffset (Draw_Interpretor& theDI,
     Handle(TFunction_Function) aFun = GetFunction(objLabel,funGUID);
     if(!aFun.IsNull()) {
       Standard_Real value(0.0);
-      Standard_Boolean isDX = (strcmp(theArg[3],"skip"));
+      Standard_Boolean isDX = strcmp(theArg[3],"skip") != 0;
       if(isDX) {
 	value = Draw::Atof(theArg[3]);
 	DNaming::GetReal(aFun,PNT_DX)->Set(value);
       }
-      Standard_Boolean isDY = (strcmp(theArg[4],"skip"));
+      Standard_Boolean isDY = strcmp(theArg[4],"skip") != 0;
       if(isDY) {
 	value = Draw::Atof(theArg[4]);
 	DNaming::GetReal(aFun,PNT_DY)->Set(value);
       }
-      Standard_Boolean isDZ = (strcmp(theArg[5],"skip"));
+      Standard_Boolean isDZ = strcmp(theArg[5],"skip") != 0;
       if(isDZ) {
 	value = Draw::Atof(theArg[5]);
 	DNaming::GetReal(aFun,PNT_DZ)->Set(value);
@@ -1904,11 +1903,11 @@ static Standard_Integer DNaming_TestSingle (Draw_Interpretor& theDI,
     Standard_Boolean XSelection(Standard_False);
     Standard_Boolean Geometry(Standard_False);
     if(theNb == 4)
-      Orientation = (Standard_Boolean)Draw::Atoi(theArg[3]);
+      Orientation = Draw::Atoi(theArg[3]) != 0;
     if(theNb == 5)
-      XSelection = (Standard_Boolean)Draw::Atoi(theArg[4]);
+      XSelection = Draw::Atoi(theArg[4]) != 0;
     if (theNb == 6) 
-      Geometry = (Standard_Boolean) Draw::Atoi(theArg[5]);
+      Geometry = Draw::Atoi(theArg[5]) != 0;
     Handle(TNaming_NamedShape) aNS = DNaming::GetObjectValue( aCntObj);
 
     if(!aNS.IsNull() && !aNS->IsEmpty()) {
@@ -2043,11 +2042,11 @@ static Standard_Integer DNaming_Multiple (Draw_Interpretor& theDI,
     Standard_Boolean XSelection(Standard_False);
     Standard_Boolean Geometry(Standard_False);
     if(theNb == 4)
-      Orientation = (Standard_Boolean)Draw::Atoi(theArg[3]);
+      Orientation = Draw::Atoi(theArg[3]) != 0;
     if(theNb == 5)
-      XSelection = (Standard_Boolean)Draw::Atoi(theArg[4]);
+      XSelection = Draw::Atoi(theArg[4]) != 0;
     if (theNb == 6) 
-      Geometry = (Standard_Boolean) Draw::Atoi(theArg[5]);
+      Geometry = Draw::Atoi(theArg[5]) != 0;
     Handle(TNaming_NamedShape) aNS = DNaming::GetObjectValue( aCntObj);
 
     if(!aNS.IsNull() && !aNS->IsEmpty()) {
@@ -2169,7 +2168,7 @@ void DNaming::ModelingCommands (Draw_Interpretor& theCommands)
 		   __FILE__, DNaming_AddObject, g2);
 
   theCommands.Add ("AddFunction", 
-                   "AddFunction D ObjEntry FunNane[Box|Sph|Cyl|Cut|Fuse|Prism|Revol|PMove|Fillet|Attach|XAttach]",
+                   "AddFunction D ObjEntry FunName[Box|Sph|Cyl|Cut|Fuse|Prism|Revol|PMove|Fillet|Attach|XAttach]",
 		   __FILE__, DNaming_AddFunction, g2);
 
   theCommands.Add ("AddBox", "AddBox Doc dx dy dz",      __FILE__, DNaming_AddBox, g2);
