@@ -14,26 +14,28 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <Standard_Macro.hxx>
-#include <Standard_Stream.hxx>
-#include <Standard_SStream.hxx>
-#include <Standard_Version.hxx>
 
-#include <Draw.ixx>
+#include <Draw.hxx>
 #include <Draw_Appli.hxx>
 #include <Draw_Chronometer.hxx>
+#include <Draw_Drawable3D.hxx>
 #include <Draw_Printer.hxx>
-
+#include <Draw_ProgressIndicator.hxx>
 #include <Message.hxx>
 #include <Message_Messenger.hxx>
-
-#include <OSD_MemInfo.hxx>
-#include <OSD_MAllocHook.hxx>
-#include <OSD_Chronometer.hxx>
 #include <OSD.hxx>
+#include <OSD_Chronometer.hxx>
+#include <OSD_Environment.hxx>
 #include <OSD_Exception_CTRL_BREAK.hxx>
-#include <OSD_PerfMeter.h>
+#include <OSD_MAllocHook.hxx>
+#include <OSD_MemInfo.hxx>
+#include <Standard_Macro.hxx>
+#include <Standard_SStream.hxx>
+#include <Standard_Stream.hxx>
+#include <Standard_Version.hxx>
+#include <TCollection_AsciiString.hxx>
 
+#include <OSD_PerfMeter.h>
 #ifdef _WIN32
 
 #include <windows.h>
@@ -81,8 +83,8 @@ static Standard_Integer chronom(Draw_Interpretor& di,
     else
       Draw_Chrono = (*a[1] == '1');
 
-    if (Draw_Chrono) di << "Chronometers activated."<<"\n";
-    else di << "Chronometers desactivated."<<"\n";
+    if (Draw_Chrono) di << "Chronometers activated.\n";
+    else di << "Chronometers desactivated.\n";
   }
   else {
     Handle(Draw_Drawable3D) D = Draw::Get(a[1]);
@@ -120,8 +122,8 @@ static Standard_Integer dchronom(Draw_Interpretor& I,
     else
       Draw_Chrono = (*a[1] == '1');
 
-    if (Draw_Chrono) I << "Chronometers activated."<<"\n";
-    else I << "Chronometers desactivated."<<"\n";
+    if (Draw_Chrono) I << "Chronometers activated.\n";
+    else I << "Chronometers desactivated.\n";
   }
   else {
     Handle(Draw_Drawable3D) D = Draw::Get(a[1]);
@@ -185,7 +187,7 @@ static Standard_Integer spy(Draw_Interpretor& di, Standard_Integer n, const char
   Draw_Spying = Standard_False;
   if (n > 1) {
     if (!Draw_Spyfile.open(a[1],ios::out)) {
-      di << "Cannot open "<<a[1]<<" for writing"<<"\n";
+      di << "Cannot open "<<a[1]<<" for writing\n";
       return 1;
     }
     Draw_Spying = Standard_True;
@@ -291,10 +293,10 @@ static Standard_Integer dversion(Draw_Interpretor& di, Standard_Integer, const c
 #else
   di << "FreeImage disabled\n";
 #endif
-#ifdef HAVE_OPENCL
-  di << "OpenCL enabled (HAVE_OPENCL)\n";
+#ifdef HAVE_GLES2
+  di << "OpenGL: ES2\n";
 #else
-  di << "OpenCL disabled\n";
+  di << "OpenGL: desktop\n";
 #endif
 #ifdef HAVE_VTK
   di << "VTK enabled (HAVE_VTK)\n";
@@ -321,7 +323,11 @@ static Standard_Integer dversion(Draw_Interpretor& di, Standard_Integer, const c
 #elif defined(__SUNPRO_C)
   di << "Compiler: Sun Studio (__SUNPRO_C = " << __SUNPROC_C << ")\n";
 #elif defined(_MSC_VER)
-  di << "Compiler: MS Visual C++ " << (int)(_MSC_VER/100-6) << "." << (int)((_MSC_VER/10)-60-10*(int)(_MSC_VER/100-6)) << " (_MSC_FULL_VER = " << _MSC_FULL_VER << ")\n";
+  #if _MSC_VER < 1900
+    di << "Compiler: MS Visual C++ " << (int)(_MSC_VER/100-6) << "." << (int)((_MSC_VER/10)-60-10*(int)(_MSC_VER/100-6)) << " (_MSC_FULL_VER = " << _MSC_FULL_VER << ")\n";
+  #else
+    di << "Compiler: MS Visual C++ " << (int)(_MSC_VER/100-5) << "." << (int)((_MSC_VER/10)-50-10*(int)(_MSC_VER/100-5)) << " (_MSC_FULL_VER = " << _MSC_FULL_VER << ")\n";
+  #endif
 #elif defined(__GNUC__)
   di << "Compiler: GCC " << __GNUC__ << "." << __GNUC_MINOR__ << "." << __GNUC_PATCHLEVEL__ << "\n";
 #else
@@ -333,7 +339,7 @@ static Standard_Integer dversion(Draw_Interpretor& di, Standard_Integer, const c
   di << "Cygwin\n";
 #endif
 #if defined(__MINGW64__)
-  di << "MinGW 64 " << __MINGW64_MAJOR_VERSION << "." << __MINGW64_MINOR_VERSION << "\n";
+  di << "MinGW 64 " << __MINGW64_VERSION_MAJOR << "." << __MINGW64_VERSION_MINOR << "\n";
 #elif defined(__MINGW32__)
   di << "MinGW 32 " << __MINGW32_MAJOR_VERSION << "." << __MINGW32_MINOR_VERSION << "\n";
 #endif 
@@ -361,6 +367,10 @@ static Standard_Integer dversion(Draw_Interpretor& di, Standard_Integer, const c
 #elif defined(__ANDROID__) /* must be before Linux */
   #include <android/api-level.h>
   di << "OS: Android (__ANDROID_API__ = " << __ANDROID_API__ << ")\n";
+#elif defined(__QNXNTO__)
+  di << "OS: QNX Neutrino\n";
+#elif defined(__QNX__)
+  di << "OS: QNX\n";
 #elif defined(__linux__)
   di << "OS: Linux\n";
 #elif defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
@@ -406,13 +416,13 @@ static unsigned int __stdcall CpuFunc (void * /*param*/)
     aCurrent = clock_t(anUserSeconds + aSystemSeconds);
     anElapCurrent = clock_t(aTimer.ElapsedTime());
     
-    if ((aCurrent - CPU_CURRENT) >= CPU_LIMIT)
+    if (CPU_LIMIT > 0 && (aCurrent - CPU_CURRENT) >= CPU_LIMIT)
     {
       cout << "Process killed by CPU limit (" << CPU_LIMIT << " sec)" << endl;
       aTimer.Stop();
       ExitProcess (2);
     }
-    if ((anElapCurrent) >= CPU_LIMIT)
+    if (CPU_LIMIT > 0 && anElapCurrent >= CPU_LIMIT)
     {
       cout << "Process killed by elapsed limit (" << CPU_LIMIT << " sec)" << endl;
       aTimer.Stop();
@@ -433,9 +443,7 @@ static void *CpuFunc(void* /*threadarg*/)
   {
     sleep (5);
     anElapCurrent = clock_t(aTimer.ElapsedTime());
-    if ( CPU_LIMIT < 0 )
-      return NULL;
-    if ((anElapCurrent) >= CPU_LIMIT) {
+    if (CPU_LIMIT >0 && (anElapCurrent) >= CPU_LIMIT) {
       cout << "Process killed by elapsed limit  (" << CPU_LIMIT << " sec)" << endl;
       exit(2);
     }
@@ -545,44 +553,44 @@ By default <logfile> is \"mem-log.txt\", <outfile> is \"mem-stat.txt\""
     int aType = (n > 2 ? Draw::Atoi(a[2]) : 1);
     if (aType < 0 || aType > 2)
     {
-      di << "unknown op of the command set" << "\n";
+      di << "unknown op of the command set\n";
       return 1;
     }
     else if (aType == 0)
     {
       OSD_MAllocHook::SetCallback(NULL);
-      di << "callback is unset" << "\n";
+      di << "callback is unset\n";
     }
     else if (aType == 1)
     {
       OSD_MAllocHook::SetCallback(OSD_MAllocHook::GetCollectBySize());
-      di << "callback is set to CollectBySize" << "\n";
+      di << "callback is set to CollectBySize\n";
     }
     else //if (aType == 2)
     {
       OSD_MAllocHook::SetCallback(OSD_MAllocHook::GetLogFileHandler());
-      di << "callback is set to LogFileHandler" << "\n";
+      di << "callback is set to LogFileHandler\n";
     }
   }
   else if (strcmp(a[1], "reset") == 0)
   {
     OSD_MAllocHook::GetCollectBySize()->Reset();
-    di << "CollectBySize handler is reset" << "\n";
+    di << "CollectBySize handler is reset\n";
   }
   else if (strcmp(a[1], "open") == 0)
   {
     const char* aFileName = (n > 2 ? a[2] : "mem-log.txt");
     if (!OSD_MAllocHook::GetLogFileHandler()->Open(aFileName))
     {
-      di << "cannot create file " << aFileName << " for writing" << "\n";
+      di << "cannot create file " << aFileName << " for writing\n";
       return 1;
     }
-    di << "log file " << aFileName << " is opened for writing" << "\n";
+    di << "log file " << aFileName << " is opened for writing\n";
   }
   else if (strcmp(a[1], "close") == 0)
   {
     OSD_MAllocHook::GetLogFileHandler()->Close();
-    di << "log file is closed" << "\n";
+    di << "log file is closed\n";
   }
   else if (strcmp(a[1], "report1") == 0)
   {
@@ -591,7 +599,7 @@ By default <logfile> is \"mem-log.txt\", <outfile> is \"mem-stat.txt\""
       aOutFile = a[2];
     if (OSD_MAllocHook::GetCollectBySize()->MakeReport(aOutFile))
     {
-      di << "report " << aOutFile << " has been created" << "\n";
+      di << "report " << aOutFile << " has been created\n";
     }
     else
     {
@@ -616,7 +624,7 @@ By default <logfile> is \"mem-log.txt\", <outfile> is \"mem-stat.txt\""
     }
     if (OSD_MAllocHook::LogFileHandler::MakeReport(aLogFile, aOutFile, includeAlive))
     {
-      di << "report " << aOutFile << " has been created" << "\n";
+      di << "report " << aOutFile << " has been created\n";
     }
     else
     {
@@ -737,6 +745,31 @@ static int dperf (Draw_Interpretor& theDI, Standard_Integer theArgNb, const char
   return 0;
 }
 
+//==============================================================================
+//function : dsetsignal
+//purpose  :
+//==============================================================================
+
+static int dsetsignal (Draw_Interpretor& theDI, Standard_Integer theArgNb, const char** theArgVec)
+{
+  // arm FPE handler if argument is provided and its first symbol is not '0'
+  // or if environment variable CSF_FPE is set and its first symbol is not '0'
+  bool setFPE = false;
+  if (theArgNb > 1)
+  {
+    setFPE = (theArgVec[1][0] == '1' || theArgVec[1][0] == 't');
+  }
+  else
+  {
+    OSD_Environment aEnv ("CSF_FPE");
+    TCollection_AsciiString aEnvStr = aEnv.Value();
+    setFPE = (! aEnvStr.IsEmpty() && aEnvStr.Value(1) != '0');
+  }
+  OSD::SetSignal (setFPE);
+  theDI << "Signal handlers are set, with FPE " << (setFPE ? "armed" : "disarmed"); 
+  return 0;
+}
+
 //==============================================================================
 //function : dtracelevel
 //purpose  :
@@ -861,6 +894,8 @@ void Draw::BasicCommands(Draw_Interpretor& theCommands)
 	  __FILE__, dmeminfo, g);
   theCommands.Add("dperf","dperf [reset] -- show performance counters, reset if argument is provided",
 		  __FILE__,dperf,g);
+  theCommands.Add("dsetsignal","dsetsignal [fpe=0] -- set OSD signal handler, with FPE option if argument is given",
+		  __FILE__,dsetsignal,g);
 
   // Logging commands; note that their names are hard-coded in the code
   // of Draw_Interpretor, thus should not be changed without update of that code!
