@@ -14,25 +14,23 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <Draw.ixx>
 
-#include <Standard_Stream.hxx>
-#include <Standard_SStream.hxx>
-
-#include <Draw_Display.hxx>
+#include <Draw.hxx>
 #include <Draw_Appli.hxx>
-#include <Draw_Number.hxx>
-#include <Draw_Axis3D.hxx>
 #include <Draw_Axis2D.hxx>
-#include <Draw_Grid.hxx>
+#include <Draw_Axis3D.hxx>
+#include <Draw_Display.hxx>
 #include <Draw_Drawable3D.hxx>
-#include <Draw_SequenceOfDrawable3D.hxx>
+#include <Draw_Grid.hxx>
+#include <Draw_Number.hxx>
 #include <Draw_ProgressIndicator.hxx>
-
+#include <Draw_SequenceOfDrawable3D.hxx>
 #include <NCollection_Map.hxx>
+#include <Standard_SStream.hxx>
+#include <Standard_Stream.hxx>
+#include <TCollection_AsciiString.hxx>
 
 #include <ios>
-
 #ifdef _WIN32
 extern Draw_Viewer dout;
 #endif
@@ -214,7 +212,7 @@ static Standard_Integer restore(Draw_Interpretor& di, Standard_Integer n, const
   
   filebuf fic;
   istream in(&fic);
-  OSD_OpenFileBuf(fic,fname,ios::in);
+  OSD_OpenStream (fic, fname, ios::in);
   if (!fic.is_open()) {
     di << "Cannot open file for reading : "<<fname;
     return 1;
@@ -229,15 +227,29 @@ static Standard_Integer restore(Draw_Interpretor& di, Standard_Integer n, const
     progress->Show();
 
     Draw_SaveAndRestore* tool = Draw_First;
+    Draw_SaveAndRestore* aDBRepTool = NULL;
     while (tool) {
-      if (!strcmp(typ,tool->Name())) break;
+      const char* toolName = tool->Name();
+      if (!strcmp(typ,toolName)) break;
+      if (!strcmp("DBRep_DrawableShape",toolName))
+        aDBRepTool = tool;
       Draw::SetProgressBar(progress);
       tool = tool->Next();
     }
-    if (tool) {
+
+    if (!tool)
+    {
+      //assume that this file stores a DBRep_DrawableShape variable
+      tool = aDBRepTool;
+      in.seekg(0, ios::beg);
+    }
+
+    if (tool)
+    {
       Handle(Draw_Drawable3D) D = tool->Restore(in);
       Draw::Set(name,D,tool->Disp() && autodisp);
     }
+
     else {
       di << "Cannot restore a  " << typ;
       return 1;
@@ -527,7 +539,7 @@ static Standard_Integer copy(Draw_Interpretor& , Standard_Integer n, const char*
 	D = D->Copy();
       else 
 	// clear old name
-	Draw::Set(a[i],Handle(Draw_Drawable3D()));
+	Draw::Set(a[i],Handle(Draw_Drawable3D)());
 
       Draw::Set(a[i+1],D);
     }
