@@ -12,61 +12,57 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <FilletSurf_InternalBuilder.ixx>
-#include <FilletSurf_StatusDone.hxx>
-#include <FilletSurf_ErrorTypeStatus.hxx>
-#include <FilletSurf_StatusType.hxx>
 
-#include <ChFi3d_FilBuilder.hxx>
-#include <ChFi3d_Builder_0.hxx>
-
-#include <ChFiDS_HData.hxx>
-#include <ChFiDS_FilSpine.hxx>
-#include <ChFiDS_HElSpine.hxx>
-#include <ChFiDS_Stripe.hxx>
-#include <ChFiDS_ListOfStripe.hxx>
-#include <ChFiDS_ListIteratorOfListOfStripe.hxx>
-#include <ChFiDS_SurfData.hxx>
-#include <ChFiDS_SequenceOfSurfData.hxx>
-#include <ChFiDS_FaceInterference.hxx>
-#include <ChFiDS_CommonPoint.hxx>
-#include <ChFiDS_CircSection.hxx>
-#include <ChFiDS_SecHArray1.hxx>
-
-#include <BRepBlend_Line.hxx>
+#include <Adaptor3d_TopolTool.hxx>
+#include <BRep_Tool.hxx>
+#include <BRepAdaptor_HCurve.hxx>
+#include <BRepAdaptor_HCurve2d.hxx>
+#include <BRepAdaptor_HSurface.hxx>
 #include <BRepBlend_ConstRad.hxx>
 #include <BRepBlend_ConstRadInv.hxx>
-
-#include <TopoDS.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
-
-#include <BRep_Tool.hxx>
-
-#include <BRepAdaptor_HCurve.hxx>
+#include <BRepBlend_Line.hxx>
+#include <BRepExtrema_DistShapeShape.hxx>
+#include <ChFi3d_Builder_0.hxx>
+#include <ChFi3d_FilBuilder.hxx>
+#include <ChFiDS_CircSection.hxx>
+#include <ChFiDS_CommonPoint.hxx>
+#include <ChFiDS_FaceInterference.hxx>
+#include <ChFiDS_FilSpine.hxx>
+#include <ChFiDS_HData.hxx>
+#include <ChFiDS_HElSpine.hxx>
+#include <ChFiDS_ListIteratorOfListOfStripe.hxx>
+#include <ChFiDS_ListOfStripe.hxx>
+#include <ChFiDS_SecHArray1.hxx>
+#include <ChFiDS_SequenceOfSurfData.hxx>
+#include <ChFiDS_Spine.hxx>
+#include <ChFiDS_Stripe.hxx>
+#include <ChFiDS_SurfData.hxx>
+#include <ElSLib.hxx>
+#include <FilletSurf_ErrorTypeStatus.hxx>
+#include <FilletSurf_InternalBuilder.hxx>
+#include <FilletSurf_StatusDone.hxx>
+#include <FilletSurf_StatusType.hxx>
+#include <Geom2d_Curve.hxx>
+#include <Geom_Circle.hxx>
+#include <Geom_Curve.hxx>
+#include <Geom_Plane.hxx>
+#include <Geom_Surface.hxx>
+#include <Geom_TrimmedCurve.hxx>
+#include <GeomAbs_Shape.hxx>
+#include <GeomAdaptor_HCurve.hxx>
 #include <GeomAdaptor_HSurface.hxx>
 #include <GeomAdaptor_Surface.hxx>
-#include <GeomAbs_Shape.hxx>
-
-#include <TopOpeBRepDS_HDataStructure.hxx>
-
-#include <Geom_Surface.hxx>
-#include <Geom_Plane.hxx>
-#include <Geom_Curve.hxx>
-#include <Geom_TrimmedCurve.hxx>
-#include <Geom_Circle.hxx>
-#include <GeomAdaptor_HCurve.hxx>
-
-#include <ElSLib.hxx>
-
 #include <gp_Circ.hxx>
 #include <gp_Pln.hxx>
-
 #include <IntCurveSurface_HInter.hxx>
 #include <IntCurveSurface_IntersectionPoint.hxx>
-#include <BRepExtrema_DistShapeShape.hxx> 
-
-#include <Standard_ConstructionError.hxx>
 #include <Precision.hxx>
+#include <Standard_ConstructionError.hxx>
+#include <TopoDS.hxx>
+#include <TopoDS_Face.hxx>
+#include <TopoDS_Shape.hxx>
+#include <TopOpeBRepDS_HDataStructure.hxx>
+#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 static Standard_Boolean isinlist(const TopoDS_Shape&         E,
 				 const TopTools_ListOfShape& L){
@@ -243,15 +239,15 @@ Standard_Integer  FilletSurf_InternalBuilder::Add(const TopTools_ListOfShape& E,
   }
   if(!periodic && yatrou) return 2;
   if(periodic && yatrou){
-    Standard_Boolean vraitrou = 0, debut = 0;
+    Standard_Boolean vraitrou = 0, aLocalDebut = 0;
     for(Standard_Integer i = sp->NbEdges(); i > yatrou; i--){
       TopoDS_Edge cured = sp->Edges(i);
       if(isinlist(cured,E)){
 	if(vraitrou) return 2;
 	newsp->PutInFirst(cured);
       }
-      else if(debut) vraitrou = 1;
-      debut = 1;
+      else if(aLocalDebut) vraitrou = 1;
+      aLocalDebut = 1;
     }
   }
 
@@ -324,8 +320,8 @@ Standard_Boolean
 					 const Standard_Boolean RecOnS1, 
 					 const Standard_Boolean RecOnS2, 
 					 const math_Vector& Soldep, 
-					 Standard_Boolean& Intf, 
-					 Standard_Boolean& Intl)
+					 Standard_Integer& Intf, 
+					 Standard_Integer& Intl)
 {
   Handle(ChFiDS_SurfData) Data = SeqData(1);
   Handle(ChFiDS_FilSpine) fsp = Handle(ChFiDS_FilSpine)::DownCast(Spine);
@@ -376,14 +372,15 @@ Standard_Boolean
   done = CompleteData(Data,Func,lin,S1,S2,Or,0,0,0,0);
   if(!done)  Standard_Failure::Raise("PerformSurf : Failed approximation!");
 //  maybesingular = (Func.GetMinimalDistance()<=100*tolapp3d);
-  Standard_Boolean ok = 0;
+  Standard_Boolean ok = Standard_False;
   if(!Forward){
     Intf = 0;
     const ChFiDS_CommonPoint& cpf1 = Data->VertexFirstOnS1();
     if(cpf1.IsOnArc()){
       TopoDS_Face F1 = S1->ChangeSurface().Face();
       TopoDS_Face bid;
-      ok = Intf = !SearchFace(Spine,cpf1,F1,bid);
+      Intf = !SearchFace(Spine,cpf1,F1,bid);
+      ok = Intf != 0;
     }
     const ChFiDS_CommonPoint& cpf2 = Data->VertexFirstOnS2();
     if(cpf2.IsOnArc() && !ok){
@@ -393,12 +390,13 @@ Standard_Boolean
     }
   }
   Intl = 0;
-  ok = 0;
+  ok = Standard_False;
   const ChFiDS_CommonPoint& cpl1 = Data->VertexLastOnS1();
   if(cpl1.IsOnArc()){
     TopoDS_Face F1 = S1->ChangeSurface().Face();
     TopoDS_Face bid;
-    ok = Intl = !SearchFace(Spine,cpl1,F1,bid);
+    Intl = !SearchFace(Spine,cpl1,F1,bid);
+    ok = Intl != 0;
   }
   const ChFiDS_CommonPoint& cpl2 = Data->VertexLastOnS2();
   if(cpl2.IsOnArc() && !ok){
@@ -414,17 +412,17 @@ Standard_Boolean
   return Standard_True;
 }
 
-void FilletSurf_InternalBuilder::PerformSurf(ChFiDS_SequenceOfSurfData&, const Handle(ChFiDS_HElSpine)&, const Handle(ChFiDS_Spine)&, const int, const Handle(BRepAdaptor_HSurface)&, const Handle(Adaptor3d_TopolTool)&, const Handle(BRepAdaptor_HCurve2d)&, const Handle(BRepAdaptor_HSurface)&, const Handle(BRepAdaptor_HCurve2d)&, unsigned int&, const Handle(BRepAdaptor_HSurface)&, const Handle(Adaptor3d_TopolTool)&, const TopAbs_Orientation, const double, const double, const double, double&, double&, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const math_Vector&)
+void FilletSurf_InternalBuilder::PerformSurf (ChFiDS_SequenceOfSurfData& , const Handle(ChFiDS_HElSpine)& , const Handle(ChFiDS_Spine)& , const Standard_Integer , const Handle(BRepAdaptor_HSurface)& , const Handle(Adaptor3d_TopolTool)& , const Handle(BRepAdaptor_HCurve2d)& , const Handle(BRepAdaptor_HSurface)& , const Handle(BRepAdaptor_HCurve2d)& , Standard_Boolean& , const Handle(BRepAdaptor_HSurface)& , const Handle(Adaptor3d_TopolTool)& , const TopAbs_Orientation , const Standard_Real , const Standard_Real , const Standard_Real , Standard_Real& , Standard_Real& , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const math_Vector& )
 {
  Standard_DomainError::Raise("BlendFunc_CSConstRad::Section : Not implemented");
 }
 
-void FilletSurf_InternalBuilder::PerformSurf(ChFiDS_SequenceOfSurfData&, const Handle(ChFiDS_HElSpine)&, const Handle(ChFiDS_Spine)&, const int, const Handle(BRepAdaptor_HSurface)&, const Handle(Adaptor3d_TopolTool)&, const Handle(BRepAdaptor_HCurve2d)&, const Handle(BRepAdaptor_HSurface)&, const Handle(BRepAdaptor_HCurve2d)&, unsigned int&, const TopAbs_Orientation, const Handle(BRepAdaptor_HSurface)&, const Handle(Adaptor3d_TopolTool)&, const Handle(BRepAdaptor_HCurve2d)&, const Handle(BRepAdaptor_HSurface)&, const Handle(BRepAdaptor_HCurve2d)&, unsigned int&, const TopAbs_Orientation, const double, const double, const double, double&, double&, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const math_Vector&)
+void FilletSurf_InternalBuilder::PerformSurf (ChFiDS_SequenceOfSurfData& , const Handle(ChFiDS_HElSpine)& , const Handle(ChFiDS_Spine)& , const Standard_Integer , const Handle(BRepAdaptor_HSurface)& , const Handle(Adaptor3d_TopolTool)& , const TopAbs_Orientation , const Handle(BRepAdaptor_HSurface)& , const Handle(Adaptor3d_TopolTool)& , const Handle(BRepAdaptor_HCurve2d)& , const Handle(BRepAdaptor_HSurface)& , const Handle(BRepAdaptor_HCurve2d)& , Standard_Boolean& , const Standard_Real , const Standard_Real , const Standard_Real , Standard_Real& , Standard_Real& , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const math_Vector& )
 {
  Standard_DomainError::Raise("BlendFunc_CSConstRad::Section : Not implemented");
 }
 
-void FilletSurf_InternalBuilder::PerformSurf(ChFiDS_SequenceOfSurfData&, const Handle(ChFiDS_HElSpine)&, const Handle(ChFiDS_Spine)&, const int, const Handle(BRepAdaptor_HSurface)&, const Handle(Adaptor3d_TopolTool)&, const TopAbs_Orientation, const Handle(BRepAdaptor_HSurface)&, const Handle(Adaptor3d_TopolTool)&, const Handle(BRepAdaptor_HCurve2d)&, const Handle(BRepAdaptor_HSurface)&, const Handle(BRepAdaptor_HCurve2d)&, unsigned int&, const double, const double, const double, double&, double&, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const unsigned int, const math_Vector&)
+void FilletSurf_InternalBuilder::PerformSurf (ChFiDS_SequenceOfSurfData& , const Handle(ChFiDS_HElSpine)& , const Handle(ChFiDS_Spine)& , const Standard_Integer , const Handle(BRepAdaptor_HSurface)& , const Handle(Adaptor3d_TopolTool)& , const Handle(BRepAdaptor_HCurve2d)& , const Handle(BRepAdaptor_HSurface)& , const Handle(BRepAdaptor_HCurve2d)& , Standard_Boolean& , const TopAbs_Orientation , const Handle(BRepAdaptor_HSurface)& , const Handle(Adaptor3d_TopolTool)& , const Handle(BRepAdaptor_HCurve2d)& , const Handle(BRepAdaptor_HSurface)& , const Handle(BRepAdaptor_HCurve2d)& , Standard_Boolean& , const TopAbs_Orientation , const Standard_Real , const Standard_Real , const Standard_Real , Standard_Real& , Standard_Real& , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const Standard_Boolean , const math_Vector& )
 {
  Standard_DomainError::Raise("BlendFunc_CSConstRad::Section : Not implemented");
 }
