@@ -29,22 +29,34 @@
 
 #define No_Standard_OutOfRange
 
-#include <Geom_BSplineCurve.ixx>
-#include <gp.hxx>
-#include <ElCLib.hxx>
+
 #include <BSplCLib.hxx>
 #include <BSplCLib_KnotDistribution.hxx>
 #include <BSplCLib_MultDistribution.hxx>
-#include <Standard_NotImplemented.hxx>
+#include <ElCLib.hxx>
+#include <Geom_BSplineCurve.hxx>
+#include <Geom_Geometry.hxx>
+#include <Geom_UndefinedDerivative.hxx>
+#include <gp.hxx>
+#include <gp_Pnt.hxx>
+#include <gp_Trsf.hxx>
+#include <gp_Vec.hxx>
 #include <Standard_ConstructionError.hxx>
+#include <Standard_DimensionError.hxx>
+#include <Standard_DomainError.hxx>
+#include <Standard_NoSuchObject.hxx>
+#include <Standard_NotImplemented.hxx>
 #include <Standard_OutOfRange.hxx>
+#include <Standard_RangeError.hxx>
 #include <Standard_Real.hxx>
+#include <Standard_Type.hxx>
+
+IMPLEMENT_STANDARD_RTTIEXT(Geom_BSplineCurve,Geom_BoundedCurve)
 
 //=======================================================================
 //function : CheckCurveData
 //purpose  : Internal use only
 //=======================================================================
-
 static void CheckCurveData
 (const TColgp_Array1OfPnt&         CPoles,
  const TColStd_Array1OfReal&       CKnots,
@@ -125,12 +137,11 @@ Geom_BSplineCurve::Geom_BSplineCurve
 {
   // check
   
-  CheckCurveData (Poles,
-		  Knots,
-		  Mults,
-		  Degree,
-		  Periodic);
-
+  CheckCurveData(Poles,
+                 Knots,
+                 Mults,
+                 Degree,
+                 Periodic);
 
   // copy arrays
 
@@ -145,11 +156,6 @@ Geom_BSplineCurve::Geom_BSplineCurve
   mults->ChangeArray1() = Mults;
 
   UpdateKnots();
-  cachepoles = new TColgp_HArray1OfPnt(1,Degree + 1);
-  parametercache = 0.0e0 ;
-  spanlenghtcache = 0.0e0 ;
-  spanindexcache = 0 ;
-
 }
 
 //=======================================================================
@@ -174,11 +180,11 @@ Geom_BSplineCurve::Geom_BSplineCurve
 
   // check
   
-  CheckCurveData (Poles,
-		  Knots,
-		  Mults,
-		  Degree,
-		  Periodic);
+  CheckCurveData(Poles,
+                 Knots,
+                 Mults,
+                 Degree,
+                 Periodic);
 
   if (Weights.Length() != Poles.Length())
     Standard_ConstructionError::Raise("Geom_BSplineCurve");
@@ -197,11 +203,9 @@ Geom_BSplineCurve::Geom_BSplineCurve
   
   poles =  new TColgp_HArray1OfPnt(1,Poles.Length());
   poles->ChangeArray1() = Poles;
-  cachepoles = new TColgp_HArray1OfPnt(1,Degree + 1);
   if (rational) {
     weights =  new TColStd_HArray1OfReal(1,Weights.Length());
     weights->ChangeArray1() = Weights;
-    cacheweights  = new TColStd_HArray1OfReal(1,Degree + 1);
   }
 
   knots = new TColStd_HArray1OfReal(1,Knots.Length());
@@ -211,9 +215,6 @@ Geom_BSplineCurve::Geom_BSplineCurve
   mults->ChangeArray1() = Mults;
 
   UpdateKnots();
-  parametercache = 0.0e0 ;
-  spanlenghtcache = 0.0e0 ;
-  spanindexcache = 0 ;
 }
 
 //=======================================================================
@@ -263,9 +264,9 @@ void Geom_BSplineCurve::IncreaseDegree  (const Standard_Integer Degree)
     
     BSplCLib::IncreaseDegree
       (deg,Degree, periodic,
-       poles->Array1(),weights->Array1(),
+       poles->Array1(),&weights->Array1(),
        knots->Array1(),mults->Array1(),
-       npoles->ChangeArray1(),nweights->ChangeArray1(),
+       npoles->ChangeArray1(),&nweights->ChangeArray1(),
        nknots->ChangeArray1(),nmults->ChangeArray1());
   }
   else {
@@ -274,7 +275,7 @@ void Geom_BSplineCurve::IncreaseDegree  (const Standard_Integer Degree)
        poles->Array1(),BSplCLib::NoWeights(),
        knots->Array1(),mults->Array1(),
        npoles->ChangeArray1(),
-       *((TColStd_Array1OfReal*) NULL),
+       BSplCLib::NoWeights(),
        nknots->ChangeArray1(),nmults->ChangeArray1());
   }
 
@@ -370,7 +371,7 @@ void  Geom_BSplineCurve::InsertKnots(const TColStd_Array1OfReal& Knots,
 
   if (!BSplCLib::PrepareInsertKnots(deg,periodic,
 				    knots->Array1(),mults->Array1(),
-				    Knots,Mults,nbpoles,nbknots,Epsilon,Add))
+				    Knots,&Mults,nbpoles,nbknots,Epsilon,Add))
     Standard_ConstructionError::Raise("Geom_BSplineCurve::InsertKnots");
 
   if (nbpoles == poles->Length()) return;
@@ -388,10 +389,10 @@ void  Geom_BSplineCurve::InsertKnots(const TColStd_Array1OfReal& Knots,
     Handle(TColStd_HArray1OfReal) nweights = 
       new TColStd_HArray1OfReal(1,nbpoles);
     BSplCLib::InsertKnots(deg,periodic,
-			  poles->Array1(), weights->Array1(),
+			  poles->Array1(), &weights->Array1(),
 			  knots->Array1(), mults->Array1(),
-			  Knots, Mults,
-			  npoles->ChangeArray1(), nweights->ChangeArray1(),
+			  Knots, &Mults,
+			  npoles->ChangeArray1(), &nweights->ChangeArray1(),
 			  nknots->ChangeArray1(), nmults->ChangeArray1(),
 			  Epsilon, Add);
     weights = nweights;
@@ -400,9 +401,9 @@ void  Geom_BSplineCurve::InsertKnots(const TColStd_Array1OfReal& Knots,
     BSplCLib::InsertKnots(deg,periodic,
 			  poles->Array1(), BSplCLib::NoWeights(),
 			  knots->Array1(), mults->Array1(),
-			  Knots, Mults,
+			  Knots, &Mults,
 			  npoles->ChangeArray1(),
-			  *((TColStd_Array1OfReal*) NULL),
+        BSplCLib::NoWeights(),
 			  nknots->ChangeArray1(), nmults->ChangeArray1(),
 			  Epsilon, Add);
   }
@@ -456,9 +457,9 @@ Standard_Boolean  Geom_BSplineCurve::RemoveKnot(const Standard_Integer Index,
       new TColStd_HArray1OfReal(1,npoles->Length());
     if (!BSplCLib::RemoveKnot
 	(Index, M, deg, periodic,
-	 poles->Array1(),weights->Array1(), 
+	 poles->Array1(),&weights->Array1(), 
 	 knots->Array1(),mults->Array1(),
-	 npoles->ChangeArray1(), nweights->ChangeArray1(),
+	 npoles->ChangeArray1(), &nweights->ChangeArray1(),
 	 nknots->ChangeArray1(),nmults->ChangeArray1(),
 	 Tolerance))
       return Standard_False;
@@ -470,7 +471,7 @@ Standard_Boolean  Geom_BSplineCurve::RemoveKnot(const Standard_Integer Index,
 	 poles->Array1(), BSplCLib::NoWeights(),
 	 knots->Array1(),mults->Array1(),
 	 npoles->ChangeArray1(),
-	 *((TColStd_Array1OfReal*) NULL),
+   BSplCLib::NoWeights(),
 	 nknots->ChangeArray1(),nmults->ChangeArray1(),
 	 Tolerance))
       return Standard_False;
@@ -524,8 +525,8 @@ Standard_Real Geom_BSplineCurve::ReversedParameter
 void Geom_BSplineCurve::Segment(const Standard_Real U1,
 				const Standard_Real U2)
 {
-  Standard_DomainError_Raise_if ( U2 < U1,
-				 "Geom_BSplineCurve::Segment");
+  if (U2 < U1)
+    Standard_DomainError::Raise("Geom_BSplineCurve::Segment");
   
   Standard_Real NewU1, NewU2;
   Standard_Real U,DU=0,aDDU=0;
@@ -539,9 +540,9 @@ void Geom_BSplineCurve::Segment(const Standard_Real U1,
   if (periodic) {
     Standard_Real Period = LastParameter() - FirstParameter();
     DU = U2 - U1;
-    while (DU > Period)
-      DU -= Period;
-    if (DU <= Epsilon(Period))
+    if (DU - Period > Precision::PConfusion())
+      Standard_DomainError::Raise("Geom_BSplineCurve::Segment");
+    if (DU > Period)
       DU = Period;
     aDDU = DU;
   }
@@ -782,14 +783,15 @@ void Geom_BSplineCurve::SetPeriodic ()
 
 void Geom_BSplineCurve::SetOrigin(const Standard_Integer Index)
 {
-  Standard_NoSuchObject_Raise_if( !periodic,
-				 "Geom_BSplineCurve::SetOrigin");
+  if (!periodic)
+    Standard_NoSuchObject::Raise("Geom_BSplineCurve::SetOrigin");
+
   Standard_Integer i,k;
   Standard_Integer first = FirstUKnotIndex();
   Standard_Integer last  = LastUKnotIndex();
 
-  Standard_DomainError_Raise_if( (Index < first) || (Index > last),
-				"Geom_BSplineCurve::SetOrigine");
+  if ((Index < first) || (Index > last))
+    Standard_DomainError::Raise("Geom_BSplineCurve::SetOrigin");
 
   Standard_Integer nbknots = knots->Length();
   Standard_Integer nbpoles = poles->Length();
@@ -871,8 +873,8 @@ void Geom_BSplineCurve::SetOrigin(const Standard_Integer Index)
 void Geom_BSplineCurve::SetOrigin(const Standard_Real U,
 				  const Standard_Real Tol)
 {
-  Standard_NoSuchObject_Raise_if( !periodic,
-				 "Geom_BSplineCurve::SetOrigin");
+  if (!periodic)
+    Standard_NoSuchObject::Raise("Geom_BSplineCurve::SetOrigin");
   //U est il dans la period.
   Standard_Real uf = FirstParameter(), ul = LastParameter();
   Standard_Real u = U, period = ul - uf;
@@ -937,9 +939,9 @@ void Geom_BSplineCurve::SetNotPeriodic ()
       
       BSplCLib::Unperiodize
 	(deg,mults->Array1(),knots->Array1(),poles->Array1(),
-	 weights->Array1(),nmults->ChangeArray1(),
+	 &weights->Array1(),nmults->ChangeArray1(),
 	 nknots->ChangeArray1(),npoles->ChangeArray1(),
-	 nweights->ChangeArray1());
+	 &nweights->ChangeArray1());
       
     }
     else {
@@ -948,7 +950,7 @@ void Geom_BSplineCurve::SetNotPeriodic ()
 	(deg,mults->Array1(),knots->Array1(),poles->Array1(),
 	 BSplCLib::NoWeights(),nmults->ChangeArray1(),
 	 nknots->ChangeArray1(),npoles->ChangeArray1(),
-	 *((TColStd_Array1OfReal*) NULL));
+   BSplCLib::NoWeights());
       
     }
     poles   = npoles;
@@ -974,7 +976,6 @@ void Geom_BSplineCurve::SetPole
   if (Index < 1 || Index > poles->Length()) Standard_OutOfRange::Raise();
   poles->SetValue (Index, P);
   maxderivinvok = 0;
-  InvalidateCache() ;
 }
 
 //=======================================================================
@@ -1023,7 +1024,6 @@ void Geom_BSplineCurve::SetWeight
     rational = !weights.IsNull();
   }
   maxderivinvok = 0;
-  InvalidateCache() ;
 }
 
 //=======================================================================
@@ -1032,11 +1032,11 @@ void Geom_BSplineCurve::SetWeight
 //=======================================================================
 
 void Geom_BSplineCurve::MovePoint(const Standard_Real U,
-				  const gp_Pnt& P,
-				  const Standard_Integer Index1,
-				  const Standard_Integer Index2,
-				  Standard_Integer& FirstModifiedPole,
-				  Standard_Integer& LastmodifiedPole)
+                                  const gp_Pnt& P,
+                                  const Standard_Integer Index1,
+                                  const Standard_Integer Index2,
+                                  Standard_Integer& FirstModifiedPole,
+                                  Standard_Integer& LastmodifiedPole)
 {
   if (Index1 < 1 || Index1 > poles->Length() || 
       Index2 < 1 || Index2 > poles->Length() || Index1 > Index2) {
@@ -1047,12 +1047,11 @@ void Geom_BSplineCurve::MovePoint(const Standard_Real U,
   D0(U, P0);
   gp_Vec Displ(P0, P);
   BSplCLib::MovePoint(U, Displ, Index1, Index2, deg, rational, poles->Array1(), 
-		      weights->Array1(), flatknots->Array1(), 
-		      FirstModifiedPole, LastmodifiedPole, npoles);
+                      weights->Array1(), flatknots->Array1(), 
+                      FirstModifiedPole, LastmodifiedPole, npoles);
   if (FirstModifiedPole) {
     poles->ChangeArray1() = npoles;
     maxderivinvok = 0;
-    InvalidateCache() ;
   }
 }
 
@@ -1061,14 +1060,13 @@ void Geom_BSplineCurve::MovePoint(const Standard_Real U,
 //purpose  : 
 //=======================================================================
 
-void Geom_BSplineCurve::
-MovePointAndTangent(const Standard_Real U,
-		    const gp_Pnt&       P,
-		    const gp_Vec&       Tangent,
-		    const Standard_Real    Tolerance,
-		    const Standard_Integer StartingCondition,
-		    const Standard_Integer EndingCondition,
-		    Standard_Integer&      ErrorStatus) 
+void Geom_BSplineCurve::MovePointAndTangent(const Standard_Real    U,
+                                            const gp_Pnt&          P,
+                                            const gp_Vec&          Tangent,
+                                            const Standard_Real    Tolerance,
+                                            const Standard_Integer StartingCondition,
+                                            const Standard_Integer EndingCondition,
+                                            Standard_Integer&      ErrorStatus) 
 {
   Standard_Integer ii ;
   if (IsPeriodic()) {
@@ -1086,26 +1084,24 @@ MovePointAndTangent(const Standard_Real U,
      delta_derivative) ;
   gp_Vec delta(P0, P);
   for (ii = 1 ; ii <= 3 ; ii++) {
-    delta_derivative.SetCoord(ii, 
-			      Tangent.Coord(ii)- delta_derivative.Coord(ii)) ;
+    delta_derivative.SetCoord(ii, Tangent.Coord(ii)-delta_derivative.Coord(ii));
   }
   BSplCLib::MovePointAndTangent(U,
-				delta,
-				delta_derivative,
-				Tolerance,
-				deg,
-				rational,
-				StartingCondition,
-				EndingCondition,
-				poles->Array1(), 
-				weights->Array1(), 
-				flatknots->Array1(), 
-				new_poles,
-				ErrorStatus) ;
+                                delta,
+                                delta_derivative,
+                                Tolerance,
+                                deg,
+                                rational,
+                                StartingCondition,
+                                EndingCondition,
+                                poles->Array1(), 
+                                weights->Array1(), 
+                                flatknots->Array1(), 
+                                new_poles,
+                                ErrorStatus) ;
   if (!ErrorStatus) {
     poles->ChangeArray1() = new_poles;
     maxderivinvok = 0;
-    InvalidateCache() ;
   }
 }
 
@@ -1119,11 +1115,11 @@ void Geom_BSplineCurve::UpdateKnots()
   rational = !weights.IsNull();
 
   Standard_Integer MaxKnotMult = 0;
-  BSplCLib::KnotAnalysis (deg, 
-		periodic,
-		knots->Array1(), 
-		mults->Array1(), 
-		knotSet, MaxKnotMult);
+  BSplCLib::KnotAnalysis(deg, 
+                         periodic,
+                         knots->Array1(), 
+                         mults->Array1(), 
+                         knotSet, MaxKnotMult);
   
   if (knotSet == GeomAbs_Uniform && !periodic)  {
     flatknots = knots;
@@ -1132,10 +1128,10 @@ void Geom_BSplineCurve::UpdateKnots()
     flatknots = new TColStd_HArray1OfReal 
       (1, BSplCLib::KnotSequenceLength(mults->Array1(),deg,periodic));
 
-    BSplCLib::KnotSequence (knots->Array1(), 
-			    mults->Array1(),
-			    deg,periodic,
-			    flatknots->ChangeArray1());
+    BSplCLib::KnotSequence(knots->Array1(), 
+                           mults->Array1(),
+                           deg,periodic,
+                           flatknots->ChangeArray1());
   }
   
   if (MaxKnotMult == 0)  smooth = GeomAbs_CN;
@@ -1148,36 +1144,6 @@ void Geom_BSplineCurve::UpdateKnots()
       default :  smooth = GeomAbs_C3;   break;
     }
   }
-  InvalidateCache() ;
-}
-
-//=======================================================================
-//function : Invalidate the Cache
-//purpose  : as the name says
-//=======================================================================
-
-void Geom_BSplineCurve::InvalidateCache() 
-{
-  validcache = 0 ;
-}
-
-//=======================================================================
-//function : check if the Cache is valid
-//purpose  : as the name says
-//=======================================================================
-
-Standard_Boolean Geom_BSplineCurve::IsCacheValid
-(const Standard_Real  U)  const 
-{
-  //Roman Lygin 26.12.08, performance improvements
-  //1. avoided using NewParameter = (U - parametercache) / spanlenghtcache
-  //to check against [0, 1), as division is CPU consuming
-  //2. minimized use of if, as branching is also CPU consuming
-  Standard_Real aDelta = U - parametercache;
-
-  return ( validcache &&
-      (aDelta >= 0.0e0) &&
-      ((aDelta < spanlenghtcache) || (spanindexcache == flatknots->Upper() - deg)) );
 }
 
 //=======================================================================
@@ -1200,83 +1166,3 @@ void Geom_BSplineCurve::PeriodicNormalization(Standard_Real&  Parameter) const
   }
 }
 
-//=======================================================================
-//function : Validate the Cache
-//purpose  : that is compute the cache so that it is valid
-//=======================================================================
-
-void Geom_BSplineCurve::ValidateCache(const Standard_Real  Parameter) 
-{
-  Standard_Real NewParameter ;
-  Standard_Integer LocalIndex = 0 ;
-  //
-  // check if the degree did not change
-  //
-  if (cachepoles->Upper() < deg + 1)
-    cachepoles = new TColgp_HArray1OfPnt(1,deg + 1);
-  if (rational)
-  {
-    if (cacheweights.IsNull() || cacheweights->Upper() < deg + 1)
-     cacheweights  = new TColStd_HArray1OfReal(1,deg + 1);
-  }
-  else if (!cacheweights.IsNull())
-    cacheweights.Nullify();
-
-  BSplCLib::LocateParameter(deg,
-			    (flatknots->Array1()),
-			    (BSplCLib::NoMults()),
-			    Parameter,
-			    periodic,
-			    LocalIndex,
-			    NewParameter);
-  spanindexcache = LocalIndex ;
-  if (Parameter == flatknots->Value(LocalIndex + 1)) {
-    
-    LocalIndex += 1 ;
-    parametercache = flatknots->Value(LocalIndex) ;
-    if (LocalIndex == flatknots->Upper() - deg) {
-      //
-      // for the last span if the parameter is outside of 
-      // the domain of the curve than use the last knot
-      // and normalize with the last span Still set the
-      // spanindexcache to flatknots->Upper() - deg so that
-      // the IsCacheValid will know for sure we are extending
-      // the Bspline 
-      //
-      
-      spanlenghtcache = flatknots->Value(LocalIndex - 1) - parametercache ;
-    }
-    else {
-      spanlenghtcache = flatknots->Value(LocalIndex + 1) - parametercache ;
-    }
-  }
-  else {
-    parametercache = flatknots->Value(LocalIndex) ;
-    spanlenghtcache = flatknots->Value(LocalIndex + 1) - parametercache ;
-  }
-  
-  if  (rational) {
-    BSplCLib::BuildCache(parametercache,
-			 spanlenghtcache,
-			 periodic,
-			 deg,
-			 (flatknots->Array1()),
-			 poles->Array1(),
-			 weights->Array1(),
-			 cachepoles->ChangeArray1(),
-			 cacheweights->ChangeArray1()) ;
-  }
-  else {
-    BSplCLib::BuildCache(parametercache,
-			 spanlenghtcache,
-			 periodic,
-			 deg,
-			 (flatknots->Array1()),
-			 poles->Array1(),
-			 *((TColStd_Array1OfReal*) NULL),
-			 cachepoles->ChangeArray1(),
-			 *((TColStd_Array1OfReal*) NULL)) ;
-  }
-  validcache = 1 ;
-}
-
