@@ -27,23 +27,29 @@
 #define No_Standard_OutOfRange
 #define No_Standard_DimensionError
 
-#include <Geom2d_BezierCurve.ixx>
-#include <PLib.hxx>
-#include <BSplCLib.hxx>
+
+#include <Geom2d_BezierCurve.hxx>
+#include <Geom2d_Geometry.hxx>
 #include <gp.hxx>
+#include <gp_Pnt2d.hxx>
+#include <gp_Trsf2d.hxx>
+#include <gp_Vec2d.hxx>
 #include <gp_XY.hxx>
+#include <PLib.hxx>
 #include <Standard_ConstructionError.hxx>
 #include <Standard_DimensionError.hxx>
 #include <Standard_OutOfRange.hxx>
 #include <Standard_RangeError.hxx>
-#include <TColStd_Array1OfReal.hxx>
+#include <Standard_Type.hxx>
 #include <TColStd_Array1OfInteger.hxx>
+#include <TColStd_Array1OfReal.hxx>
+
+IMPLEMENT_STANDARD_RTTIEXT(Geom2d_BezierCurve,Geom2d_BoundedCurve)
 
 //=======================================================================
 //function : Rational
 //purpose  : check rationality of an array of weights
 //=======================================================================
-
 static Standard_Boolean Rational(const TColStd_Array1OfReal& W)
 {
   Standard_Integer i, n = W.Length();
@@ -62,8 +68,7 @@ static Standard_Boolean Rational(const TColStd_Array1OfReal& W)
 //=======================================================================
 
 Geom2d_BezierCurve::Geom2d_BezierCurve
- (const TColgp_Array1OfPnt2d& Poles):
- validcache(0), parametercache(0.), spanlenghtcache(1.)
+ (const TColgp_Array1OfPnt2d& Poles)
 {
   //  copy the poles
   
@@ -84,9 +89,8 @@ Geom2d_BezierCurve::Geom2d_BezierCurve
 //=======================================================================
 
 Geom2d_BezierCurve::Geom2d_BezierCurve
-(const TColgp_Array1OfPnt2d&  Poles, 
- const TColStd_Array1OfReal& Weights):
- validcache(0), parametercache(0.), spanlenghtcache(1.)
+(const TColgp_Array1OfPnt2d&  Poles,
+ const TColStd_Array1OfReal& Weights)
 
 {
   // copy the poles
@@ -150,18 +154,18 @@ void Geom2d_BezierCurve::Increase (const Standard_Integer Deg)
   if (IsRational()) {
     nweights = new TColStd_HArray1OfReal(1,Deg+1);
     BSplCLib::IncreaseDegree(Degree(), Deg, 0,
-			     poles->Array1(),weights->Array1(),
+			     poles->Array1(),&weights->Array1(),
 			     bidknots, bidmults,
-			     npoles->ChangeArray1(),nweights->ChangeArray1(),
+			     npoles->ChangeArray1(),&nweights->ChangeArray1(),
 			     bidknots, bidmults);
   }
   else {
     BSplCLib::IncreaseDegree(Degree(), Deg, 0,
 			     poles->Array1(),
-			     *((TColStd_Array1OfReal*) NULL),
+			     BSplCLib::NoWeights(),
 			     bidknots, bidmults,
 			     npoles->ChangeArray1(),
-			     *((TColStd_Array1OfReal*) NULL),
+			     BSplCLib::NoWeights(),
 			     bidknots, bidmults);
   }
   
@@ -341,8 +345,6 @@ void Geom2d_BezierCurve::Reverse ()
       cweights(nbpoles-i+1) = w;
     }
   }
-  
-  UpdateCoefficients();
 }
 
 
@@ -371,21 +373,21 @@ void Geom2d_BezierCurve::Segment
 //   WARNING : when calling trimming be carefull that the cache
 //   is computed regarding 0.0e0 and not 1.0e0 
 //
-
+  TColStd_Array1OfReal bidflatknots(BSplCLib::FlatBezierKnots(Degree()), 1, 2 * (Degree() + 1));
+  TColgp_Array1OfPnt2d coeffs(1, poles->Size());
   if (IsRational()) {
-    PLib::Trimming(U1,U2,coeffs->ChangeArray1(),wcoeffs->ChangeArray1());
-    PLib::CoefficientsPoles(coeffs->Array1(),wcoeffs->Array1(),
-			    poles->ChangeArray1(),weights->ChangeArray1());
+    TColStd_Array1OfReal wcoeffs(1, poles->Size());
+    BSplCLib::BuildCache(0.0, 1.0, 0, Degree(), bidflatknots,
+        poles->Array1(), &weights->Array1(), coeffs, &wcoeffs);
+    PLib::Trimming(U1, U2, coeffs, &wcoeffs);
+    PLib::CoefficientsPoles(coeffs, &wcoeffs, poles->ChangeArray1(), &weights->ChangeArray1());
   }
   else {
-    PLib::Trimming(U1,U2,coeffs->ChangeArray1(),
-		   *((TColStd_Array1OfReal*) NULL));
-    PLib::CoefficientsPoles(coeffs->Array1(),
-			    *((TColStd_Array1OfReal*) NULL),
-			    poles->ChangeArray1(),
-			    *((TColStd_Array1OfReal*) NULL));
+    BSplCLib::BuildCache(0.0, 1.0, 0, Degree(), bidflatknots,
+        poles->Array1(), BSplCLib::NoWeights(), coeffs, BSplCLib::NoWeights());
+    PLib::Trimming(U1, U2, coeffs, PLib::NoWeights());
+    PLib::CoefficientsPoles(coeffs, PLib::NoWeights(), poles->ChangeArray1(), PLib::NoWeights());
   }
-  UpdateCoefficients();
 }
 
 
@@ -407,8 +409,6 @@ void Geom2d_BezierCurve::SetPole
   if (Index == 1 || Index == cpoles.Length()) {
     closed = (cpoles(1).Distance(cpoles(NbPoles())) <= gp::Resolution());
   }
-  
-  UpdateCoefficients();
 }
 
 
@@ -454,7 +454,6 @@ void Geom2d_BezierCurve::SetWeight
     
     // set weights of 1.
     weights = new TColStd_HArray1OfReal(1,nbpoles);
-    wcoeffs = new TColStd_HArray1OfReal(1,nbpoles);
     weights->Init(1.);
   }
   
@@ -462,14 +461,8 @@ void Geom2d_BezierCurve::SetWeight
   cweights(Index) = Weight;
   
   // is it turning into non rational
-  if (wasrat) {
-    if (!Rational(cweights)) {
-      weights.Nullify();
-      wcoeffs.Nullify();
-    }
-  }
-  
-  UpdateCoefficients();
+  if (wasrat && !Rational(cweights))
+    weights.Nullify();
 }
 
 
@@ -546,18 +539,7 @@ Standard_Integer Geom2d_BezierCurve::Degree () const
 
 void Geom2d_BezierCurve::D0 (const Standard_Real U, gp_Pnt2d& P ) const
 {
-//  Idee lumineuse sacrifiee sur l autel des performances.
-//
-//  if(!CoefficientsOK(U)) 
-//    ((Geom2d_BezierCurve*)(void*)this)->UpdateCoefficients(U);
-  if (IsRational())
-    BSplCLib::CacheD0(U,Degree(),parametercache,spanlenghtcache,
-		      coeffs->Array1(),wcoeffs->Array1(),P);
-  else 
-    BSplCLib::CacheD0(U,Degree(),parametercache,spanlenghtcache,
-		      coeffs->Array1(),
-		      *((TColStd_Array1OfReal*) NULL),
-		      P);
+  BSplCLib::D0(U, Poles(), Weights(), P);
 }
 
 //=======================================================================
@@ -569,18 +551,7 @@ void Geom2d_BezierCurve::D1(const Standard_Real U,
 			    gp_Pnt2d& P, 
 			    gp_Vec2d& V1) const
 {
-//  Idee lumineuse sacrifiee sur l autel des performances.
-//
-//  if(!CoefficientsOK(U)) 
-//    ((Geom2d_BezierCurve*)(void*)this)->UpdateCoefficients(U);
-  if (IsRational())
-    BSplCLib::CacheD1(U,Degree(),parametercache,spanlenghtcache,
-		      coeffs->Array1(),wcoeffs->Array1(),P,V1);
-  else 
-    BSplCLib::CacheD1(U,Degree(),parametercache,spanlenghtcache,
-		      coeffs->Array1(),
-		      *((TColStd_Array1OfReal*) NULL),
-		      P,V1);
+  BSplCLib::D1(U, Poles(), Weights(), P, V1);
 }
 
 //=======================================================================
@@ -593,18 +564,7 @@ void Geom2d_BezierCurve::D2 (const Standard_Real U,
 			     gp_Vec2d& V1,
 			     gp_Vec2d& V2) const
 {
-//  Idee lumineuse sacrifiee sur l autel des performances.
-//
-//  if(!CoefficientsOK(U)) 
-//    ((Geom2d_BezierCurve*)(void*)this)->UpdateCoefficients(U);
-  if (IsRational())
-    BSplCLib::CacheD2(U,Degree(),parametercache,spanlenghtcache,
-		      coeffs->Array1(),wcoeffs->Array1(),P,V1,V2);
-  else 
-    BSplCLib::CacheD2(U,Degree(),parametercache,spanlenghtcache,
-		      coeffs->Array1(),
-		      *((TColStd_Array1OfReal*) NULL),
-		      P,V1,V2);
+  BSplCLib::D2(U, Poles(), Weights(), P, V1, V2);
 }
 
 //=======================================================================
@@ -618,18 +578,7 @@ void Geom2d_BezierCurve::D3 (const Standard_Real U,
 			     gp_Vec2d& V2,
 			     gp_Vec2d& V3) const
 {
-//  Idee lumineuse sacrifiee sur l autel des performances.
-//
-//  if(!CoefficientsOK(U)) 
-//    ((Geom2d_BezierCurve*)(void*)this)->UpdateCoefficients(U);
-  if (IsRational())
-    BSplCLib::CacheD3(U,Degree(),parametercache,spanlenghtcache,
-		      coeffs->Array1(),wcoeffs->Array1(),P,V1,V2,V3);
-  else 
-    BSplCLib::CacheD3(U,Degree(),parametercache,spanlenghtcache,
-		      coeffs->Array1(),
-		      *((TColStd_Array1OfReal*) NULL),
-		      P,V1,V2,V3);
+  BSplCLib::D3(U, Poles(), Weights(), P, V1, V2, V3);
 }
 
 //=======================================================================
@@ -648,13 +597,13 @@ gp_Vec2d Geom2d_BezierCurve::DN (const Standard_Real U,
   
   if (IsRational())
     BSplCLib::DN(U,N,0,Degree(),Standard_False,
-		 poles->Array1(),weights->Array1(),
-		 bidknots,bidmults,V);
+		 poles->Array1(),&weights->Array1(),
+		 bidknots,&bidmults,V);
   else 
     BSplCLib::DN(U,N,0,Degree(),Standard_False,
 		 poles->Array1(),
-		 *((TColStd_Array1OfReal*) NULL),
-		 bidknots,bidmults,V);
+		 BSplCLib::NoWeights(),
+		 bidknots,&bidmults,V);
   return V;
 }
 
@@ -707,7 +656,7 @@ Standard_Integer Geom2d_BezierCurve::NbPoles () const
 //purpose  : 
 //=======================================================================
 
-gp_Pnt2d Geom2d_BezierCurve::Pole (const Standard_Integer Index) const
+const gp_Pnt2d& Geom2d_BezierCurve::Pole (const Standard_Integer Index) const
 {
   Standard_OutOfRange_Raise_if (Index < 1 || Index > poles->Length(),
 				"Geom2d_BezierCurve::Pole");
@@ -790,8 +739,6 @@ void Geom2d_BezierCurve::Transform (const gp_Trsf2d& T)
   
   for (Standard_Integer i = 1; i <= nbpoles; i++) 
     cpoles (i).Transform(T);
-  
-  UpdateCoefficients();
 }
 
 
@@ -812,7 +759,7 @@ void Geom2d_BezierCurve::Resolution(const Standard_Real ToleranceUV,
     
     if (IsRational()) {  
       BSplCLib::Resolution(poles->Array1(),
-			   weights->Array1(),
+			   &weights->Array1(),
 			   poles->Length(),
 			   bidflatknots,
 			   Degree(),
@@ -821,7 +768,7 @@ void Geom2d_BezierCurve::Resolution(const Standard_Real ToleranceUV,
     }
     else {
       BSplCLib::Resolution(poles->Array1(),
-			   *((TColStd_Array1OfReal*) NULL),
+			   BSplCLib::NoWeights(),
 			   poles->Length(),
 			   bidflatknots,
 			   Degree(),
@@ -868,60 +815,10 @@ void Geom2d_BezierCurve::Init
   rational = !Weights.IsNull();
   
   // set fields
-  poles   = Poles;
-  coeffs  = new TColgp_HArray1OfPnt2d  (1,nbpoles);
-  
-  if (rational) {
+  poles = Poles;
+  if (rational)
     weights = Weights;
-    wcoeffs = new TColStd_HArray1OfReal (1, nbpoles, 0.0);
-  }
-  else {
-    weights.Nullify();
-    wcoeffs.Nullify();
-  }
-  
-  UpdateCoefficients();
-}
-
-
-//=======================================================================
-//function : CoefficientsOK
-//purpose  : 
-//=======================================================================
-
-//Standard_Boolean Geom2d_BezierCurve::CoefficientsOK(const Standard_Real U)const
-Standard_Boolean Geom2d_BezierCurve::CoefficientsOK(const Standard_Real )const
-{
-  return (validcache) ;
-			
-}
-
-
-//=======================================================================
-//function : UpdateCoefficients
-//purpose  : 
-//=======================================================================
-
-//void Geom2d_BezierCurve::UpdateCoefficients(const Standard_Real U)
-void Geom2d_BezierCurve::UpdateCoefficients(const Standard_Real )
-{
-  maxderivinvok = 0;
-  parametercache = 0.;
-//  
-//  Idee lumineuse sacrifiee sur l autel des performances.
-//  if (U >= 1.) parametercache = 1.;
-  TColStd_Array1OfReal bidflatknots(BSplCLib::FlatBezierKnots(Degree()),
-				    1, 2*(Degree()+1));
-  if (IsRational())
-    BSplCLib::BuildCache(parametercache,spanlenghtcache,0,Degree(),
-			 bidflatknots,poles->Array1(),weights->Array1(),
-			 coeffs->ChangeArray1(),wcoeffs->ChangeArray1());
   else
-    BSplCLib::BuildCache(parametercache,spanlenghtcache,0,Degree(),
-			 bidflatknots,poles->Array1(),
-			 *((TColStd_Array1OfReal*) NULL),
-			 coeffs->ChangeArray1(),
-			 *((TColStd_Array1OfReal*) NULL));
-  validcache = 1;
+    weights.Nullify();
 }
 
