@@ -11,16 +11,33 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <IGESData_IGESEntity.ixx>
+
+#include <gp_GTrsf.hxx>
+#include <IGESData_ColorEntity.hxx>
+#include <IGESData_DirChecker.hxx>
+#include <IGESData_GeneralModule.hxx>
+#include <IGESData_IGESEntity.hxx>
+#include <IGESData_IGESReaderTool.hxx>
+#include <IGESData_IGESType.hxx>
+#include <IGESData_LabelDisplayEntity.hxx>
+#include <IGESData_LevelListEntity.hxx>
+#include <IGESData_LineFontEntity.hxx>
 #include <IGESData_NameEntity.hxx>
+#include <IGESData_ReadWriteModule.hxx>
 #include <IGESData_SingleParentEntity.hxx>
+#include <IGESData_TransfEntity.hxx>
+#include <IGESData_ViewKindEntity.hxx>
+#include <Interface_EntityIterator.hxx>
+#include <Interface_EntityList.hxx>
 #include <Interface_InterfaceError.hxx>
-#include <Standard_NoSuchObject.hxx>
-#include <stdio.h>
-
 #include <Interface_Macros.hxx>
+#include <Standard_NoSuchObject.hxx>
 #include <Standard_PCharacter.hxx>
+#include <Standard_Type.hxx>
+#include <TCollection_HAsciiString.hxx>
 
+#include <stdio.h>
+IMPLEMENT_STANDARD_RTTIEXT(IGESData_IGESEntity,MMgt_TShared)
 
 #define ThisEntity  Handle(IGESData_IGESEntity)::DownCast(This())
 
@@ -392,7 +409,7 @@ Handle(TCollection_HAsciiString) IGESData_IGESEntity::NameValue () const
     Standard_Boolean IGESData_IGESEntity::ArePresentAssociativities () const
 {
   if (!theAssocs.IsEmpty()) return Standard_True;
-  return (theStatusNum & IGESFlagAssocs);
+  return (theStatusNum & IGESFlagAssocs) != 0;
 }
 
     Standard_Integer IGESData_IGESEntity::NbAssociativities () const
@@ -443,7 +460,7 @@ Handle(TCollection_HAsciiString) IGESData_IGESEntity::NameValue () const
     Standard_Boolean IGESData_IGESEntity::ArePresentProperties () const
 {
   if (!theProps.IsEmpty()) return Standard_True;
-  return (theStatusNum & IGESFlagProps);
+  return (theStatusNum & IGESFlagProps) != 0;
 }
 
     Standard_Integer IGESData_IGESEntity::NbProperties () const
