@@ -12,36 +12,35 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <OSD_Path.ixx>
 
-static OSD_SysType whereAmI(){
-#if defined(__digital__) || defined(__FreeBSD__) || defined(SUNOS) || defined(__APPLE__)
+#include <OSD_OSDError.hxx>
+#include <OSD_Path.hxx>
+#include <Standard_ConstructionError.hxx>
+#include <Standard_NullObject.hxx>
+#include <Standard_NumericError.hxx>
+#include <Standard_ProgramError.hxx>
+#include <TCollection_AsciiString.hxx>
+
+static OSD_SysType whereAmI()
+{
+#if defined(__digital__) || defined(__FreeBSD__) || defined(SUNOS) || defined(__APPLE__) || defined(__QNX__) || defined(__FreeBSD_kernel__)
   return OSD_UnixBSD;
-}
 #elif defined(sgi)  || defined(IRIX) || defined(__sun)  || defined(SOLARIS) ||  defined(__sco__) || defined(__hpux) || defined(HPUX)
   return OSD_UnixSystemV;
-}
 #elif defined(__osf__) || defined(DECOSF1)
   return OSD_OSF;
-}
 #elif defined(OS2)
   return OSD_WindowsNT;
-}
 #elif defined(_WIN32) || defined(__WIN32__)
   return OSD_WindowsNT;
-}
 #elif defined(__CYGWIN32_) || defined(__MINGW32__)
   return OSD_WindowsNT;
-}
 #elif defined(vax) || defined(__vms)
   return OSD_VMS;
-}
-#elif defined(__linux__) || defined(LIN)
+#elif defined(__linux__) || defined(__linux)
   return OSD_LinuxREDHAT;
-}
 #elif defined(_AIX) || defined(AIX)
   return OSD_Aix;
-}
 #else
   struct utsname info;
   uname(&info);
@@ -51,8 +50,8 @@ static OSD_SysType whereAmI(){
   cout << info.version << endl;
   cout << info.machine << endl;
   return OSD_Default;
-}
 #endif
+}
 
 #if !(defined(_WIN32) || defined(__WIN32__))
 
@@ -256,17 +255,9 @@ static void DosExtract(const TCollection_AsciiString& what,
   buffer.Remove(1,disk.Length());  // Removes <<disk:>>
  }
 
- if (buffer.Search(".") != -1){ // There is an extension to extract
-  ext = buffer.Token(".",2); 
-  ext.Insert(1,'.');            // Prepends 'dot'
-  pos = buffer.Search(".");     // Removes extension from buffer
-  if (pos != -1)
-   buffer.Remove(pos,ext.Length());
- }
-
  trek = buffer;
 
- trek.ChangeAll('\\','|');  
+ trek.ChangeAll('\\','|');
 
  pos = trek.Search("..");
  while (pos != -1){        // Changes every ".." by '^'
@@ -275,16 +266,20 @@ static void DosExtract(const TCollection_AsciiString& what,
   pos = trek.Search("..");
  }
 
- pos = trek.SearchFromEnd("|");  // Extract name
+ pos = trek.SearchFromEnd ("|");  // Extract name
  if (pos != -1) {
-  p = (Standard_PCharacter)trek.ToCString();
-  name = &p[pos];
-  trek.Remove(trek.Search(name),name.Length());
+   p = (Standard_PCharacter)trek.ToCString ();
+   name = &p[pos];
+   if (name.Length ()) trek.Remove (pos + 1, name.Length ());
  }
  else {   // No '|' means no trek but a name
-  name = buffer;
-  trek = "";
+   name = buffer;
+   trek = "";
  }
+
+ pos = name.SearchFromEnd (".");
+ if (pos != -1)      // There is an extension to extract
+   ext = name.Split (pos - 1);
 }
 
 
@@ -409,21 +404,8 @@ void OSD_Path::SetValues(const TCollection_AsciiString& Nod,
                          const TCollection_AsciiString& Dsk,
                          const TCollection_AsciiString& Trk,
                          const TCollection_AsciiString& Nam,
-                         const TCollection_AsciiString& ext){
-
- if (!Nod.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetValues argument : Node");
- if (!UsrNm.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetValues argument : User Name");
- if (!Dsk.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetValues argument : Disk");
- if (!Trk.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetValues argument : Trek");
- if (!Nam.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetValues argument : Name");
- if (!ext.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetValues argument : Extension");
-
+                         const TCollection_AsciiString& ext)
+{
  myNode = Nod;
  myUserName = UsrNm;
  myPassword = Passwd;
@@ -837,8 +819,6 @@ TCollection_AsciiString OSD_Path::Name()const{
 
 
 void OSD_Path::SetNode(const TCollection_AsciiString& aName){
- if (!aName.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetNode bad name");
  myNode = aName;
 }
 
@@ -846,8 +826,6 @@ void OSD_Path::SetNode(const TCollection_AsciiString& aName){
 
 
 void OSD_Path::SetUserName(const TCollection_AsciiString& aName){
- if (!aName.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetUserName bad name");
  myUserName = aName;
 }
 
@@ -855,8 +833,6 @@ void OSD_Path::SetUserName(const TCollection_AsciiString& aName){
 
 
 void OSD_Path::SetPassword(const TCollection_AsciiString& aName){
- if (!aName.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetPassword bad name");
   myPassword = aName;
 }
 
@@ -864,8 +840,6 @@ void OSD_Path::SetPassword(const TCollection_AsciiString& aName){
 
 
 void OSD_Path::SetDisk(const TCollection_AsciiString& aName){
- if (!aName.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetDisk bad name");
   myDisk = aName;
 }
 
@@ -873,8 +847,6 @@ void OSD_Path::SetDisk(const TCollection_AsciiString& aName){
 
 
 void OSD_Path::SetTrek(const TCollection_AsciiString& aName){
- if (!aName.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetTrek bad name");
   myTrek = aName;
 }
 
@@ -882,8 +854,6 @@ void OSD_Path::SetTrek(const TCollection_AsciiString& aName){
 
 
 void OSD_Path::SetName(const TCollection_AsciiString& aName){
- if (!aName.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetName bad name");
   myName = aName;
 }
 
@@ -891,8 +861,6 @@ void OSD_Path::SetName(const TCollection_AsciiString& aName){
 
 
 void OSD_Path::SetExtension(const TCollection_AsciiString& aName){
- if (!aName.IsAscii())
-  Standard_ConstructionError::Raise("OSD_Path::SetExtension bad name");
   myExtension = aName;
 }
 
@@ -925,11 +893,11 @@ OSD_Path ::  OSD_Path (
 {
 
  Standard_Integer        i, j, len;
- static char __drive [ _MAX_DRIVE ];
- static char __dir [ _MAX_DIR ];
- static char __trek [ _MAX_DIR ];
- static char __fname [ _MAX_FNAME ];
- static char __ext [ _MAX_EXT ];
+ char __drive [ _MAX_DRIVE ];
+ char __dir [ _MAX_DIR ];
+ char __trek [ _MAX_DIR ];
+ char __fname [ _MAX_FNAME ];
+ char __ext [ _MAX_EXT ];
 
  memset(__drive, 0,_MAX_DRIVE);
  memset(__dir, 0,_MAX_DIR);
@@ -1050,7 +1018,7 @@ void OSD_Path :: SystemName (
 
  Standard_Integer        i, j;
  TCollection_AsciiString fullPath;
- static Standard_Character trek [ _MAX_PATH ];
+ Standard_Character trek [ _MAX_PATH ];
  Standard_Character      chr;
 
  memset(trek,0,_MAX_PATH);
@@ -1113,7 +1081,7 @@ void OSD_Path :: DownTrek ( const TCollection_AsciiString& aName ) {
 
  Standard_Integer pos = myTrek.Length ();
 
- if (  aName.Value ( 1 ) != '|'    &&
+ if ( !aName.IsEmpty() && aName.Value ( 1 ) != '|'    &&
        pos                                 &&
        myTrek.Value ( pos ) != '|'
  )
@@ -1131,7 +1099,7 @@ Standard_Integer OSD_Path :: TrekLength () const {
  Standard_Integer i      = 1;
  Standard_Integer retVal = 0;
 
- if (  myTrek.IsEmpty () || myTrek.Length () == 1 && myTrek.Value ( 1 ) == '|'  )
+ if (  myTrek.IsEmpty () || (myTrek.Length () == 1 && myTrek.Value ( 1 ) == '|') )
 
   return retVal;
 
