@@ -20,10 +20,12 @@
 #include <OpenGl_ShaderProgram.hxx>
 #include <OpenGl_ShaderStates.hxx>
 #include <OpenGl_Text.hxx>
-#include <OpenGl_Utils.hxx>
 #include <OpenGl_Workspace.hxx>
+#include <OpenGl_View.hxx>
 
 #include <Font_FontMgr.hxx>
+#include <Font_FTFont.hxx>
+#include <Graphic3d_TransformUtils.hxx>
 #include <TCollection_HAsciiString.hxx>
 
 #ifdef HAVE_GL2PS
@@ -111,8 +113,9 @@ namespace
   {
 
     char aPsFont[64];
-    getGL2PSFontName (theAspect.FontName().ToCString(), aPsFont);
+    getGL2PSFontName (theAspect.Aspect()->Font().ToCString(), aPsFont);
 
+    (void)theIs2d;
   #if !defined(GL_ES_VERSION_2_0)
     if (theIs2d)
     {
@@ -130,11 +133,11 @@ namespace
     // Standard GL2PS's alignment isn't used, because it doesn't work correctly
     // for all formats, therefore alignment is calculated manually relative
     // to the bottom-left corner, which corresponds to the GL2PS_TEXT_BL value
-    gl2psTextOpt (theText.ToCString(), aPsFont, (GLshort)theHeight, GL2PS_TEXT_BL, theAspect.Angle());
+    gl2psTextOpt (theText.ToCString(), aPsFont, (GLshort)theHeight, GL2PS_TEXT_BL, (float )theAspect.Aspect()->GetTextAngle());
   }
 #endif
 
-};
+} // anonymous namespace
 
 // =======================================================================
 // function : OpenGl_Text
@@ -146,7 +149,9 @@ OpenGl_Text::OpenGl_Text()
   myWinZ (0.0f),
   myScaleHeight (1.0f),
   myPoint  (0.0f, 0.0f, 0.0f),
-  myIs2d   (false)
+  myIs2d   (false),
+  myHasPlane (false),
+  myHasAnchorPoint (true)
 {
   myParams.Height = 10;
   myParams.HAlign = Graphic3d_HTA_LEFT;
@@ -168,11 +173,39 @@ OpenGl_Text::OpenGl_Text (const Standard_Utf8Char* theText,
   myParams (theParams),
   myString (theText),
   myPoint  (thePoint),
-  myIs2d   (false)
+  myIs2d   (false),
+  myHasPlane (false),
+  myHasAnchorPoint (true)
 {
   //
 }
 
+// =======================================================================
+// function : OpenGl_Text
+// purpose  :
+// =======================================================================
+OpenGl_Text::OpenGl_Text (const Standard_Utf8Char* theText,
+                          const gp_Ax2&            theOrientation,
+                          const OpenGl_TextParam&  theParams,
+                          const bool               theHasOwnAnchor)
+: myWinX         (0.0),
+  myWinY         (0.0),
+  myWinZ         (0.0),
+  myScaleHeight  (1.0),
+  myExportHeight (1.0),
+  myParams       (theParams),
+  myString       (theText),
+  myIs2d         (false),
+  myOrientation  (theOrientation),
+  myHasPlane     (true),
+  myHasAnchorPoint (theHasOwnAnchor)
+{
+  const gp_Pnt& aPoint = theOrientation.Location();
+  myPoint = OpenGl_Vec3 (static_cast<Standard_ShortReal> (aPoint.X()),
+                         static_cast<Standard_ShortReal> (aPoint.Y()),
+                         static_cast<Standard_ShortReal> (aPoint.Z()));
+}
+
 // =======================================================================
 // function : SetPosition
 // purpose  :
@@ -254,7 +287,7 @@ void OpenGl_Text::Init (const Handle(OpenGl_Context)&     theCtx,
   myParams     = theParams;
   myPoint.xy() = thePoint;
   myPoint.z()  = 0.0f;
-  myString.FromUnicode ((Standard_Utf16Char* )theText.ToExtString());
+  myString.FromUnicode (theText.ToExtString());
 }
 
 // =======================================================================
@@ -277,7 +310,7 @@ void OpenGl_Text::releaseVbos (OpenGl_Context* theCtx)
     Handle(OpenGl_VertexBuffer)& aVerts = myVertsVbo.ChangeValue (anIter);
     Handle(OpenGl_VertexBuffer)& aTCrds = myTCrdsVbo.ChangeValue (anIter);
 
-    if (theCtx)
+    if (theCtx != NULL)
     {
       theCtx->DelayedRelease (aVerts);
       theCtx->DelayedRelease (aTCrds);
@@ -285,9 +318,16 @@ void OpenGl_Text::releaseVbos (OpenGl_Context* theCtx)
     aVerts.Nullify();
     aTCrds.Nullify();
   }
+  if (theCtx != NULL
+  && !myBndVertsVbo.IsNull())
+  {
+    theCtx->DelayedRelease (myBndVertsVbo);
+  }
+
   myTextures.Clear();
   myVertsVbo.Clear();
   myTCrdsVbo.Clear();
+  myBndVertsVbo.Nullify();
 }
 
 // =======================================================================
@@ -299,11 +339,12 @@ void OpenGl_Text::Release (OpenGl_Context* theCtx)
   releaseVbos (theCtx);
   if (!myFont.IsNull())
   {
-    Handle(OpenGl_Context) aCtx = theCtx;
     const TCollection_AsciiString aKey = myFont->ResourceKey();
     myFont.Nullify();
-    if (aCtx)
-      aCtx->ReleaseResource (aKey, Standard_True);
+    if (theCtx != NULL)
+    {
+      theCtx->ReleaseResource (aKey, Standard_True);
+    }
   }
 }
 
@@ -315,6 +356,7 @@ void OpenGl_Text::StringSize (const Handle(OpenGl_Context)& theCtx,
                               const NCollection_String&     theText,
                               const OpenGl_AspectText&      theTextAspect,
                               const OpenGl_TextParam&       theParams,
+                              const unsigned int            theResolution,
                               Standard_ShortReal&           theWidth,
                               Standard_ShortReal&           theAscent,
                               Standard_ShortReal&           theDescent)
@@ -322,8 +364,8 @@ void OpenGl_Text::StringSize (const Handle(OpenGl_Context)& theCtx,
   theWidth   = 0.0f;
   theAscent  = 0.0f;
   theDescent = 0.0f;
-  const TCollection_AsciiString aFontKey = FontKey (theTextAspect, theParams.Height);
-  Handle(OpenGl_Font) aFont = FindFont (theCtx, theTextAspect, theParams.Height, aFontKey);
+  const TCollection_AsciiString aFontKey = FontKey (theTextAspect, theParams.Height, theResolution);
+  Handle(OpenGl_Font) aFont = FindFont (theCtx, theTextAspect, theParams.Height, theResolution, aFontKey);
   if (aFont.IsNull() || !aFont->IsValid())
   {
     return;
@@ -354,16 +396,16 @@ void OpenGl_Text::StringSize (const Handle(OpenGl_Context)& theCtx,
     }
     else if (aCharThis == ' ')
     {
-      aWidth += aFont->AdvanceX (aCharThis, aCharNext);
+      aWidth += aFont->FTFont()->AdvanceX (aCharThis, aCharNext);
       continue;
     }
     else if (aCharThis == '\t')
     {
-      aWidth += aFont->AdvanceX (' ', aCharNext) * 8.0f;
+      aWidth += aFont->FTFont()->AdvanceX (' ', aCharNext) * 8.0f;
       continue;
     }
 
-    aWidth += aFont->AdvanceX (aCharThis, aCharNext);
+    aWidth += aFont->FTFont()->AdvanceX (aCharThis, aCharNext);
   }
   theWidth = Max (theWidth, aWidth);
 
@@ -378,34 +420,29 @@ void OpenGl_Text::StringSize (const Handle(OpenGl_Context)& theCtx,
 // =======================================================================
 void OpenGl_Text::Render (const Handle(OpenGl_Workspace)& theWorkspace) const
 {
-  const OpenGl_AspectText*      aTextAspect  = theWorkspace->AspectText (Standard_True);
+  const OpenGl_AspectText*      aTextAspect  = theWorkspace->ApplyAspectText();
   const Handle(OpenGl_Texture)  aPrevTexture = theWorkspace->DisableTexture();
   const Handle(OpenGl_Context)& aCtx         = theWorkspace->GetGlContext();
+#if !defined(GL_ES_VERSION_2_0)
+  const Standard_Integer aPrevPolygonMode  = aCtx->SetPolygonMode (GL_FILL);
+  const bool             aPrevHatchingMode = aCtx->SetPolygonHatchEnabled (false);
+#endif
 
   // Bind custom shader program or generate default version
   if (aCtx->core20fwd != NULL)
   {
-    aCtx->ShaderManager()->BindProgram (
-      aTextAspect, aTextAspect->ShaderProgramRes (aCtx));
+    aCtx->ShaderManager()->BindFontProgram (aTextAspect->ShaderProgramRes (aCtx));
   }
 
+  myOrientationMatrix = theWorkspace->View()->Camera()->OrientationMatrix();
+  myProjMatrix.Convert (aCtx->ProjectionState.Current());
+
   // use highlight color or colors from aspect
-  if (theWorkspace->NamedStatus & OPENGL_NS_HIGHLIGHT)
-  {
-    render (theWorkspace->PrinterContext(),
-            aCtx,
-            *aTextAspect,
-            *theWorkspace->HighlightColor,
-            *theWorkspace->HighlightColor);
-  }
-  else
-  {
-    render (theWorkspace->PrinterContext(),
-            aCtx,
-            *aTextAspect,
-            aTextAspect->Color(),
-            aTextAspect->SubtitleColor());
-  }
+  render (aCtx,
+          *aTextAspect,
+          theWorkspace->TextColor(),
+          theWorkspace->TextSubtitleColor(),
+          theWorkspace->View()->RenderingParams().Resolution);
 
   aCtx->BindProgram (NULL);
 
@@ -414,9 +451,13 @@ void OpenGl_Text::Render (const Handle(OpenGl_Workspace)& theWorkspace) const
   {
     theWorkspace->EnableTexture (aPrevTexture);
   }
+#if !defined(GL_ES_VERSION_2_0)
+  aCtx->SetPolygonMode         (aPrevPolygonMode);
+  aCtx->SetPolygonHatchEnabled (aPrevHatchingMode);
+#endif
 
   // restore Z buffer settings
-  if (theWorkspace->UseZBuffer() && theWorkspace->UseDepthTest())
+  if (theWorkspace->UseZBuffer())
   {
     glEnable (GL_DEPTH_TEST);
   }
@@ -426,71 +467,108 @@ void OpenGl_Text::Render (const Handle(OpenGl_Workspace)& theWorkspace) const
 // function : Render
 // purpose  :
 // =======================================================================
-void OpenGl_Text::Render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
-                          const Handle(OpenGl_Context)&        theCtx,
-                          const OpenGl_AspectText&             theTextAspect) const
+void OpenGl_Text::Render (const Handle(OpenGl_Context)& theCtx,
+                          const OpenGl_AspectText&      theTextAspect,
+                          const unsigned int            theResolution) const
 {
-  render (thePrintCtx, theCtx, theTextAspect, theTextAspect.Color(), theTextAspect.SubtitleColor());
+  render (theCtx, theTextAspect,
+          theTextAspect.Aspect()->ColorRGBA(),
+          theTextAspect.Aspect()->ColorSubTitleRGBA(),
+          theResolution);
 }
 
 // =======================================================================
 // function : setupMatrix
 // purpose  :
 // =======================================================================
-void OpenGl_Text::setupMatrix (const Handle(OpenGl_PrinterContext)& thePrintCtx,
-                               const Handle(OpenGl_Context)&        theCtx,
-                               const OpenGl_AspectText&             theTextAspect,
-                               const OpenGl_Vec3                    theDVec) const
+void OpenGl_Text::setupMatrix (const Handle(OpenGl_Context)& theCtx,
+                               const OpenGl_AspectText&      theTextAspect,
+                               const OpenGl_Vec3             theDVec) const
 {
   OpenGl_Mat4d aModViewMat;
+  OpenGl_Mat4d aProjectMat;
+  if (myHasPlane && myHasAnchorPoint)
+  {
+    aProjectMat = myProjMatrix * myOrientationMatrix;
+  }
+  else
+  {
+    aProjectMat = myProjMatrix;
+  }
 
   if (myIs2d)
   {
-    OpenGl_Utils::Translate<GLdouble> (aModViewMat, myPoint.x() + theDVec.x(), myPoint.y() + theDVec.y(), 0.f);
-    OpenGl_Utils::Scale<GLdouble> (aModViewMat, 1.f, -1.f, 1.f);
-    OpenGl_Utils::Rotate<GLdouble> (aModViewMat, theTextAspect.Angle(), 0.f, 0.f, 1.f);
+    Graphic3d_TransformUtils::Translate<GLdouble> (aModViewMat, myPoint.x() + theDVec.x(), myPoint.y() + theDVec.y(), 0.f);
+    Graphic3d_TransformUtils::Scale<GLdouble> (aModViewMat, 1.f, -1.f, 1.f);
+    Graphic3d_TransformUtils::Rotate<GLdouble> (aModViewMat, theTextAspect.Aspect()->GetTextAngle(), 0.f, 0.f, 1.f);
   }
   else
   {
     // align coordinates to the nearest integer
     // to avoid extra interpolation issues
     GLdouble anObjX, anObjY, anObjZ;
-    OpenGl_Utils::UnProject<Standard_Real> (std::floor (myWinX + theDVec.x()),
-                                            std::floor (myWinY + theDVec.y()),
-                                            myWinZ + theDVec.z(),
-                                            OpenGl_Mat4d::Map (THE_IDENTITY_MATRIX),
-                                            OpenGl_Mat4d::Map (myProjMatrix),
-                                            myViewport,
-                                            anObjX,
-                                            anObjY,
-                                            anObjZ);
+    Graphic3d_TransformUtils::UnProject<Standard_Real> (std::floor (myWinX + theDVec.x()),
+                                                        std::floor (myWinY + theDVec.y()),
+                                                        myWinZ + theDVec.z(),
+                                                        OpenGl_Mat4d::Map (THE_IDENTITY_MATRIX),
+                                                        OpenGl_Mat4d::Map (aProjectMat),
+                                                        theCtx->Viewport(),
+                                                        anObjX,
+                                                        anObjY,
+                                                        anObjZ);
 
-    OpenGl_Utils::Translate<GLdouble> (aModViewMat, anObjX, anObjY, anObjZ);
-    OpenGl_Utils::Rotate<GLdouble> (aModViewMat, theTextAspect.Angle(), 0.0, 0.0, 1.0);
-
-    if (!theTextAspect.IsZoomable())
+    if (myHasPlane)
     {
-    #ifdef _WIN32
-      // if the context has assigned printer context, use it's parameters
-      if (!thePrintCtx.IsNull())
-      {
-        // get printing scaling in x and y dimensions
-        GLfloat aTextScalex = 1.0f, aTextScaley = 1.0f;
-        thePrintCtx->GetScale (aTextScalex, aTextScaley);
+      const gp_Dir& aVectorDir   = myOrientation.XDirection();
+      const gp_Dir& aVectorUp    = myOrientation.Direction();
+      const gp_Dir& aVectorRight = myOrientation.YDirection();
 
-        // text should be scaled in all directions with same
-        // factor to save its proportions, so use height (y) scaling
-        // as it is better for keeping text/3d graphics proportions
-        OpenGl_Utils::Scale<GLdouble> (aModViewMat, aTextScaley, aTextScaley, aTextScaley);
+      aModViewMat.SetColumn (2, OpenGl_Vec3d (aVectorUp.X(), aVectorUp.Y(), aVectorUp.Z()));
+      aModViewMat.SetColumn (1, OpenGl_Vec3d (aVectorRight.X(), aVectorRight.Y(), aVectorRight.Z()));
+      aModViewMat.SetColumn (0, OpenGl_Vec3d (aVectorDir.X(), aVectorDir.Y(), aVectorDir.Z()));
+
+      if (!myHasAnchorPoint)
+      {
+        OpenGl_Mat4d aPosMat;
+        aPosMat.SetColumn (3, OpenGl_Vec3d (myPoint.x(), myPoint.y(), myPoint.z()));
+        aPosMat *= aModViewMat;
+        aModViewMat.SetColumn (3, aPosMat.GetColumn (3));
       }
-    #endif
-      OpenGl_Utils::Scale<GLdouble> (aModViewMat, myScaleHeight, myScaleHeight, myScaleHeight);
+      else
+      {
+        aModViewMat.SetColumn (3, OpenGl_Vec3d (anObjX, anObjY, anObjZ));
+      }
+    }
+    else
+    {
+      Graphic3d_TransformUtils::Translate<GLdouble> (aModViewMat, anObjX, anObjY, anObjZ);
+      Graphic3d_TransformUtils::Rotate<GLdouble> (aModViewMat, theTextAspect.Aspect()->GetTextAngle(), 0.0, 0.0, 1.0);
+    }
+
+    if (!theTextAspect.Aspect()->GetTextZoomable())
+    {
+      Graphic3d_TransformUtils::Scale<GLdouble> (aModViewMat, myScaleHeight, myScaleHeight, myScaleHeight);
     }
   }
 
-  theCtx->WorldViewState.SetCurrent<Standard_Real> (aModViewMat);
+  if (myHasPlane && !myHasAnchorPoint)
+  {
+    OpenGl_Mat4d aCurrentWorldViewMat;
+    aCurrentWorldViewMat.Convert (theCtx->WorldViewState.Current());
+    theCtx->WorldViewState.SetCurrent<Standard_Real> (aCurrentWorldViewMat * aModViewMat);
+  }
+  else
+  {
+    theCtx->WorldViewState.SetCurrent<Standard_Real> (aModViewMat);
+  }
   theCtx->ApplyWorldViewMatrix();
 
+  if (!myIs2d)
+  {
+    theCtx->ProjectionState.SetCurrent<Standard_Real> (aProjectMat);
+    theCtx->ApplyProjectionMatrix();
+  }
+
   if (!theCtx->ActiveProgram().IsNull())
   {
     // Upload updated state to shader program
@@ -502,14 +580,8 @@ void OpenGl_Text::setupMatrix (const Handle(OpenGl_PrinterContext)& thePrintCtx,
 // function : drawText
 // purpose  :
 // =======================================================================
-
-void OpenGl_Text::drawText (const Handle(OpenGl_PrinterContext)& ,
-                            const Handle(OpenGl_Context)&        theCtx,
-                          #ifdef HAVE_GL2PS
-                            const OpenGl_AspectText&             theTextAspect) const
-                          #else
-                            const OpenGl_AspectText&                          ) const
-                          #endif
+void OpenGl_Text::drawText (const Handle(OpenGl_Context)& theCtx,
+                            const OpenGl_AspectText&      theTextAspect) const
 {
 #ifdef HAVE_GL2PS
   if (theCtx->IsFeedback())
@@ -518,6 +590,8 @@ void OpenGl_Text::drawText (const Handle(OpenGl_PrinterContext)& ,
     exportText (myString, myIs2d, theTextAspect, (Standard_Integer )myExportHeight);
     return;
   }
+#else
+  (void )theTextAspect;
 #endif
 
   if (myVertsVbo.Length() != myTextures.Length()
@@ -549,11 +623,15 @@ void OpenGl_Text::drawText (const Handle(OpenGl_PrinterContext)& ,
 // purpose  :
 // =======================================================================
 TCollection_AsciiString OpenGl_Text::FontKey (const OpenGl_AspectText& theAspect,
-                                              const Standard_Integer   theHeight)
+                                              const Standard_Integer   theHeight,
+                                              const unsigned int       theResolution)
 {
-  const Font_FontAspect anAspect = (theAspect.FontAspect() != Font_FA_Undefined) ? theAspect.FontAspect() : Font_FA_Regular;
-  return theAspect.FontName()
+  const Font_FontAspect anAspect = theAspect.Aspect()->GetTextFontAspect() != Font_FA_Undefined
+                                 ? theAspect.Aspect()->GetTextFontAspect()
+                                 : Font_FA_Regular;
+  return theAspect.Aspect()->Font()
        + TCollection_AsciiString(":") + Standard_Integer(anAspect)
+       + TCollection_AsciiString(":") + Standard_Integer(theResolution)
        + TCollection_AsciiString(":") + theHeight;
 }
 
@@ -564,6 +642,7 @@ TCollection_AsciiString OpenGl_Text::FontKey (const OpenGl_AspectText& theAspect
 Handle(OpenGl_Font) OpenGl_Text::FindFont (const Handle(OpenGl_Context)& theCtx,
                                            const OpenGl_AspectText&      theAspect,
                                            const Standard_Integer        theHeight,
+                                           const unsigned int            theResolution,
                                            const TCollection_AsciiString theKey)
 {
   Handle(OpenGl_Font) aFont;
@@ -575,23 +654,26 @@ Handle(OpenGl_Font) OpenGl_Text::FindFont (const Handle(OpenGl_Context)& theCtx,
   if (!theCtx->GetResource (theKey, aFont))
   {
     Handle(Font_FontMgr) aFontMgr = Font_FontMgr::GetInstance();
-    const Handle(TCollection_HAsciiString) aFontName = new TCollection_HAsciiString (theAspect.FontName());
-    const Font_FontAspect anAspect = (theAspect.FontAspect() != Font_FA_Undefined) ? theAspect.FontAspect() : Font_FA_Regular;
+    const Handle(TCollection_HAsciiString) aFontName = new TCollection_HAsciiString (theAspect.Aspect()->Font());
+    const Font_FontAspect anAspect = theAspect.Aspect()->GetTextFontAspect() != Font_FA_Undefined
+                                   ? theAspect.Aspect()->GetTextFontAspect()
+                                   : Font_FA_Regular;
     Handle(Font_SystemFont) aRequestedFont = aFontMgr->FindFont (aFontName, anAspect, theHeight);
     Handle(Font_FTFont) aFontFt;
     if (!aRequestedFont.IsNull())
     {
       aFontFt = new Font_FTFont (NULL);
-      if (aFontFt->Init (aRequestedFont->FontPath()->ToCString(), theHeight))
+
+      if (aFontFt->Init (aRequestedFont->FontPath()->ToCString(), theHeight, theResolution))
       {
         aFont = new OpenGl_Font (aFontFt, theKey);
         if (!aFont->Init (theCtx))
         {
           TCollection_ExtendedString aMsg;
           aMsg += "Font '";
-          aMsg += theAspect.FontName();
+          aMsg += theAspect.Aspect()->Font();
           aMsg += "' - initialization of GL resources has failed!";
-          theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION_ARB, GL_DEBUG_TYPE_ERROR_ARB, 0, GL_DEBUG_SEVERITY_HIGH_ARB, aMsg);
+          theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION, GL_DEBUG_TYPE_ERROR, 0, GL_DEBUG_SEVERITY_HIGH, aMsg);
           aFontFt.Nullify();
           aFont->Release (theCtx.operator->());
           aFont = new OpenGl_Font (aFontFt, theKey);
@@ -601,10 +683,10 @@ Handle(OpenGl_Font) OpenGl_Text::FindFont (const Handle(OpenGl_Context)& theCtx,
       {
         TCollection_ExtendedString aMsg;
         aMsg += "Font '";
-        aMsg += theAspect.FontName();
+        aMsg += theAspect.Aspect()->Font();
         aMsg += "' is broken or has incompatible format! File path: ";
         aMsg += aRequestedFont->FontPath()->ToCString();
-        theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION_ARB, GL_DEBUG_TYPE_ERROR_ARB, 0, GL_DEBUG_SEVERITY_HIGH_ARB, aMsg);
+        theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION, GL_DEBUG_TYPE_ERROR, 0, GL_DEBUG_SEVERITY_HIGH, aMsg);
         aFontFt.Nullify();
         aFont = new OpenGl_Font (aFontFt, theKey);
       }
@@ -613,9 +695,9 @@ Handle(OpenGl_Font) OpenGl_Text::FindFont (const Handle(OpenGl_Context)& theCtx,
     {
       TCollection_ExtendedString aMsg;
       aMsg += "Font '";
-      aMsg += theAspect.FontName();
+      aMsg += theAspect.Aspect()->Font();
       aMsg += "' is not found in the system!";
-      theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION_ARB, GL_DEBUG_TYPE_ERROR_ARB, 0, GL_DEBUG_SEVERITY_HIGH_ARB, aMsg);
+      theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION, GL_DEBUG_TYPE_ERROR, 0, GL_DEBUG_SEVERITY_HIGH, aMsg);
       aFont = new OpenGl_Font (aFontFt, theKey);
     }
 
@@ -624,22 +706,68 @@ Handle(OpenGl_Font) OpenGl_Text::FindFont (const Handle(OpenGl_Context)& theCtx,
   return aFont;
 }
 
+// =======================================================================
+// function : drawRect
+// purpose  :
+// =======================================================================
+void OpenGl_Text::drawRect (const Handle(OpenGl_Context)& theCtx,
+                            const OpenGl_AspectText&      theTextAspect,
+                            const OpenGl_Vec4&            theColorSubs) const
+{
+  Handle(OpenGl_ShaderProgram) aPrevProgram = theCtx->ActiveProgram();
+  if (myBndVertsVbo.IsNull())
+  {
+    OpenGl_Vec2 aQuad[4] =
+    {
+      OpenGl_Vec2(myBndBox.Right, myBndBox.Bottom),
+      OpenGl_Vec2(myBndBox.Right, myBndBox.Top),
+      OpenGl_Vec2(myBndBox.Left,  myBndBox.Bottom),
+      OpenGl_Vec2(myBndBox.Left,  myBndBox.Top)
+    };
+    myBndVertsVbo = new OpenGl_VertexBuffer();
+    myBndVertsVbo->Init (theCtx, 2, 4, aQuad[0].GetData());
+  }
+
+  if (theCtx->core20fwd != NULL)
+  {
+    // bind flat program
+    theCtx->ShaderManager()->BindFaceProgram (Handle(OpenGl_Texture)(), Standard_False, Standard_False, Standard_False, Handle(OpenGl_ShaderProgram)());
+  }
+#if !defined(GL_ES_VERSION_2_0)
+  if (theCtx->core11 != NULL
+   && theCtx->ActiveProgram().IsNull())
+  {
+    glBindTexture (GL_TEXTURE_2D, 0);
+  }
+#endif
+  theCtx->SetColor4fv (theColorSubs);
+  setupMatrix (theCtx, theTextAspect, OpenGl_Vec3 (0.0f, 0.0f, 0.00001f));
+  myBndVertsVbo->BindAttribute (theCtx, Graphic3d_TOA_POS);
+
+  theCtx->core20fwd->glDrawArrays (GL_TRIANGLE_STRIP, 0, 4);
+
+  myBndVertsVbo->UnbindAttribute (theCtx, Graphic3d_TOA_POS);
+  theCtx->BindProgram (aPrevProgram);
+}
+
 // =======================================================================
 // function : render
 // purpose  :
 // =======================================================================
-void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
-                          const Handle(OpenGl_Context)&        theCtx,
-                          const OpenGl_AspectText&             theTextAspect,
-                          const TEL_COLOUR&                    theColorText,
-                          const TEL_COLOUR&                    theColorSubs) const
+void OpenGl_Text::render (const Handle(OpenGl_Context)& theCtx,
+                          const OpenGl_AspectText&      theTextAspect,
+                          const OpenGl_Vec4&            theColorText,
+                          const OpenGl_Vec4&            theColorSubs,
+                          const unsigned int            theResolution) const
 {
   if (myString.IsEmpty())
   {
     return;
   }
 
-  const TCollection_AsciiString aFontKey = FontKey (theTextAspect, myParams.Height);
+  // Note that using difference resolution in different Views in same Viewer
+  // will lead to performance regression (for example, text will be recreated every time).
+  const TCollection_AsciiString aFontKey = FontKey (theTextAspect, myParams.Height, theResolution);
   if (!myFont.IsNull()
    && !myFont->ResourceKey().IsEqual (aFontKey))
   {
@@ -649,7 +777,7 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
 
   if (myFont.IsNull())
   {
-    myFont = FindFont (theCtx, theTextAspect, myParams.Height, aFontKey);
+    myFont = FindFont (theCtx, theTextAspect, myParams.Height, theResolution, aFontKey);
   }
   if (!myFont->WasInitialized())
   {
@@ -658,14 +786,27 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
 
   if (myTextures.IsEmpty())
   {
-    OpenGl_TextFormatter aFormatter;
+    Font_TextFormatter aFormatter;
     aFormatter.SetupAlignment (myParams.HAlign, myParams.VAlign);
     aFormatter.Reset();
-    aFormatter.Append (theCtx, myString, *myFont.operator->());
+
+    aFormatter.Append (myString, *myFont->FTFont().operator->());
     aFormatter.Format();
 
-    aFormatter.Result (theCtx, myTextures, myVertsVbo, myTCrdsVbo);
+    OpenGl_TextBuilder aBuilder;
+    aBuilder.Perform (aFormatter,
+                      theCtx,
+                      *myFont.operator->(),
+                      myTextures,
+                      myVertsVbo,
+                      myTCrdsVbo);
+
     aFormatter.BndBox (myBndBox);
+    if (!myBndVertsVbo.IsNull())
+    {
+      myBndVertsVbo->Release (theCtx.get());
+      myBndVertsVbo.Nullify();
+    }
   }
 
   if (myTextures.IsEmpty())
@@ -676,51 +817,59 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
   myExportHeight = 1.0f;
   myScaleHeight  = 1.0f;
 
-  theCtx->WorldViewState.Push();
+  if (myHasPlane && !myHasAnchorPoint)
+  {
+    OpenGl_Mat4d aWorldViewMat;
+    aWorldViewMat.Convert (theCtx->WorldViewState.Current());
+    theCtx->WorldViewState.Push();
+    theCtx->WorldViewState.SetCurrent<Standard_Real> (aWorldViewMat);
+    theCtx->ApplyWorldViewMatrix();
+  }
+  else
+  {
+    theCtx->WorldViewState.Push();
+  }
 
   myModelMatrix.Convert (theCtx->WorldViewState.Current() * theCtx->ModelWorldState.Current());
 
   if (!myIs2d)
   {
-    glGetIntegerv (GL_VIEWPORT,          myViewport);
-    myProjMatrix.Convert (theCtx->ProjectionState.Current());
-
-    OpenGl_Utils::Project<Standard_Real> (myPoint.x(),
-                                          myPoint.y(),
-                                          myPoint.z(),
-                                          myModelMatrix,
-                                          myProjMatrix,
-                                          myViewport,
-                                          myWinX,
-                                          myWinY,
-                                          myWinZ);
+    Graphic3d_TransformUtils::Project<Standard_Real> (myPoint.x(),
+                                                      myPoint.y(),
+                                                      myPoint.z(),
+                                                      myModelMatrix,
+                                                      myProjMatrix,
+                                                      theCtx->Viewport(),
+                                                      myWinX,
+                                                      myWinY,
+                                                      myWinZ);
 
     // compute scale factor for constant text height
     GLdouble x1, y1, z1;
-    OpenGl_Utils::UnProject<Standard_Real> (myWinX,
-                                            myWinY,
-                                            myWinZ,
-                                            OpenGl_Mat4d::Map (THE_IDENTITY_MATRIX),
-                                            myProjMatrix,
-                                            myViewport,
-                                            x1,
-                                            y1,
-                                            z1);
+    Graphic3d_TransformUtils::UnProject<Standard_Real> (myWinX,
+                                                        myWinY,
+                                                        myWinZ,
+                                                        OpenGl_Mat4d::Map (THE_IDENTITY_MATRIX),
+                                                        myProjMatrix,
+                                                        theCtx->Viewport(),
+                                                        x1,
+                                                        y1,
+                                                        z1);
 
     GLdouble x2, y2, z2;
     const GLdouble h = (GLdouble )myFont->FTFont()->PointSize();
-    OpenGl_Utils::UnProject<Standard_Real> (myWinX,
-                                            myWinY + h,
-                                            myWinZ,
-                                            OpenGl_Mat4d::Map (THE_IDENTITY_MATRIX),
-                                            myProjMatrix,
-                                            myViewport,
-                                            x2,
-                                            y2,
-                                            z2);
+    Graphic3d_TransformUtils::UnProject<Standard_Real> (myWinX,
+                                                        myWinY + h,
+                                                        myWinZ,
+                                                        OpenGl_Mat4d::Map (THE_IDENTITY_MATRIX),
+                                                        myProjMatrix,
+                                                        theCtx->Viewport(),
+                                                        x2,
+                                                        y2,
+                                                        z2);
 
     myScaleHeight = (y2 - y1) / h;
-    if (theTextAspect.IsZoomable())
+    if (theTextAspect.Aspect()->GetTextZoomable())
     {
       myExportHeight = (float )h;
     }
@@ -735,12 +884,8 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
 #endif
 
   // setup depth test
-  if (!myIs2d
-   && theTextAspect.StyleType() != Aspect_TOST_ANNOTATION)
-  {
-    glEnable (GL_DEPTH_TEST);
-  }
-  else
+  if (myIs2d
+   || theTextAspect.Aspect()->Style() == Aspect_TOST_ANNOTATION)
   {
     glDisable (GL_DEPTH_TEST);
   }
@@ -773,7 +918,7 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
   glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
   // extra drawings
-  switch (theTextAspect.DisplayType())
+  switch (theTextAspect.Aspect()->DisplayType())
   {
     case Aspect_TODT_BLEND:
     {
@@ -785,34 +930,20 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
     }
     case Aspect_TODT_SUBTITLE:
     {
-    #if !defined(GL_ES_VERSION_2_0)
-      if (theCtx->core11 != NULL)
-      {
-        theCtx->core11->glColor3fv (theColorSubs.rgb);
-        setupMatrix (thePrintCtx, theCtx, theTextAspect, OpenGl_Vec3 (0.0f, 0.0f, 0.00001f));
-
-        glBindTexture (GL_TEXTURE_2D, 0);
-        glBegin (GL_QUADS);
-        glVertex2f (myBndBox.Left,  myBndBox.Top);
-        glVertex2f (myBndBox.Right, myBndBox.Top);
-        glVertex2f (myBndBox.Right, myBndBox.Bottom);
-        glVertex2f (myBndBox.Left,  myBndBox.Bottom);
-        glEnd();
-      }
-    #endif
+      drawRect (theCtx, theTextAspect, theColorSubs);
       break;
     }
     case Aspect_TODT_DEKALE:
     {
-      theCtx->SetColor4fv (*(const OpenGl_Vec4* )theColorSubs.rgb);
-      setupMatrix (thePrintCtx, theCtx, theTextAspect, OpenGl_Vec3 (+1.0f, +1.0f, 0.00001f));
-      drawText    (thePrintCtx, theCtx, theTextAspect);
-      setupMatrix (thePrintCtx, theCtx, theTextAspect, OpenGl_Vec3 (-1.0f, -1.0f, 0.00001f));
-      drawText    (thePrintCtx, theCtx, theTextAspect);
-      setupMatrix (thePrintCtx, theCtx, theTextAspect, OpenGl_Vec3 (-1.0f, +1.0f, 0.00001f));
-      drawText    (thePrintCtx, theCtx, theTextAspect);
-      setupMatrix (thePrintCtx, theCtx, theTextAspect, OpenGl_Vec3 (+1.0f, -1.0f, 0.00001f));
-      drawText    (thePrintCtx, theCtx, theTextAspect);
+      theCtx->SetColor4fv (theColorSubs);
+      setupMatrix (theCtx, theTextAspect, OpenGl_Vec3 (+1.0f, +1.0f, 0.00001f));
+      drawText    (theCtx, theTextAspect);
+      setupMatrix (theCtx, theTextAspect, OpenGl_Vec3 (-1.0f, -1.0f, 0.00001f));
+      drawText    (theCtx, theTextAspect);
+      setupMatrix (theCtx, theTextAspect, OpenGl_Vec3 (-1.0f, +1.0f, 0.00001f));
+      drawText    (theCtx, theTextAspect);
+      setupMatrix (theCtx, theTextAspect, OpenGl_Vec3 (+1.0f, -1.0f, 0.00001f));
+      drawText    (theCtx, theTextAspect);
       break;
     }
     case Aspect_TODT_DIMENSION:
@@ -823,9 +954,15 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
   }
 
   // main draw call
-  theCtx->SetColor4fv (*(const OpenGl_Vec4* )theColorText.rgb);
-  setupMatrix (thePrintCtx, theCtx, theTextAspect, OpenGl_Vec3 (0.0f, 0.0f, 0.0f));
-  drawText    (thePrintCtx, theCtx, theTextAspect);
+  theCtx->SetColor4fv (theColorText);
+  setupMatrix (theCtx, theTextAspect, OpenGl_Vec3 (0.0f, 0.0f, 0.0f));
+  drawText    (theCtx, theTextAspect);
+
+  if (!myIs2d)
+  {
+    theCtx->ProjectionState.SetCurrent<Standard_Real> (myProjMatrix);
+    theCtx->ApplyProjectionMatrix();
+  }
 
 #if !defined(GL_ES_VERSION_2_0)
   if (theCtx->core11 != NULL)
@@ -834,10 +971,8 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
   }
 #endif
 
-  if (theTextAspect.DisplayType() == Aspect_TODT_DIMENSION)
+  if (theTextAspect.Aspect()->DisplayType() == Aspect_TODT_DIMENSION)
   {
-    setupMatrix (thePrintCtx, theCtx, theTextAspect, OpenGl_Vec3 (0.0f, 0.0f, 0.00001f));
-
     glDisable (GL_BLEND);
     if (!myIs2d)
     {
@@ -857,17 +992,7 @@ void OpenGl_Text::render (const Handle(OpenGl_PrinterContext)& thePrintCtx,
     glStencilFunc (GL_ALWAYS, 1, 0xFF);
     glStencilOp (GL_KEEP, GL_KEEP, GL_REPLACE);
 
-  #if !defined(GL_ES_VERSION_2_0)
-    if (theCtx->core11 != NULL)
-    {
-      glBegin (GL_QUADS);
-      glVertex2f (myBndBox.Left,  myBndBox.Top);
-      glVertex2f (myBndBox.Right, myBndBox.Top);
-      glVertex2f (myBndBox.Right, myBndBox.Bottom);
-      glVertex2f (myBndBox.Left,  myBndBox.Bottom);
-      glEnd();
-    }
-  #endif
+    drawRect (theCtx, theTextAspect, OpenGl_Vec4 (1.0f, 1.0f, 1.0f, 1.0f));
 
     glStencilFunc (GL_ALWAYS, 0, 0xFF);
 
