@@ -16,13 +16,14 @@
 
 #include <OpenGl_ArbFBO.hxx>
 #include <OpenGl_Context.hxx>
-#include <OpenGl_GlCore15.hxx>
+#include <OpenGl_GlCore32.hxx>
 #include <Graphic3d_TextureParams.hxx>
+#include <TCollection_ExtendedString.hxx>
 #include <Standard_Assert.hxx>
 #include <Image_PixMap.hxx>
 
-IMPLEMENT_STANDARD_HANDLE (OpenGl_Texture, OpenGl_Resource)
-IMPLEMENT_STANDARD_RTTIEXT(OpenGl_Texture, OpenGl_Resource)
+
+IMPLEMENT_STANDARD_RTTIEXT(OpenGl_Texture,OpenGl_Resource)
 
 //! Simple class to reset unpack alignment settings
 struct OpenGl_UnpackAlignmentSentry
@@ -50,10 +51,12 @@ struct OpenGl_UnpackAlignmentSentry
 // =======================================================================
 OpenGl_Texture::OpenGl_Texture (const Handle(Graphic3d_TextureParams)& theParams)
 : OpenGl_Resource(),
+  myRevision (0),
   myTextureId (NO_TEXTURE),
   myTarget (GL_TEXTURE_2D),
   mySizeX (0),
   mySizeY (0),
+  mySizeZ (0),
   myTextFormat (GL_RGBA),
   myHasMipmaps (Standard_False),
   myIsAlpha    (false),
@@ -78,7 +81,7 @@ OpenGl_Texture::~OpenGl_Texture()
 // function : HasMipmaps
 // purpose  :
 // =======================================================================
-const Standard_Boolean OpenGl_Texture::HasMipmaps() const
+Standard_Boolean OpenGl_Texture::HasMipmaps() const
 {
   return myHasMipmaps;
 }
@@ -134,7 +137,7 @@ void OpenGl_Texture::Release (OpenGl_Context* theGlCtx)
     glDeleteTextures (1, &myTextureId);
   }
   myTextureId = NO_TEXTURE;
-  mySizeX = mySizeY = 0;
+  mySizeX = mySizeY = mySizeZ = 0;
 }
 
 // =======================================================================
@@ -355,6 +358,20 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
                            const Graphic3d_TypeOfTexture theType,
                            const Image_PixMap*           theImage)
 {
+#if !defined(GL_ES_VERSION_2_0)
+  const GLenum aTarget = theType == Graphic3d_TOT_1D
+                       ? GL_TEXTURE_1D
+                       : GL_TEXTURE_2D;
+#else
+  const GLenum aTarget = GL_TEXTURE_2D;
+#endif
+  const Standard_Boolean toCreateMipMaps = (theType == Graphic3d_TOT_2D_MIPMAP);
+  const bool toPatchExisting = IsValid()
+                            && myTextFormat == thePixelFormat
+                            && myTarget == aTarget
+                            && myHasMipmaps == toCreateMipMaps
+                            && mySizeX  == theSizeX
+                            && (mySizeY == theSizeY || theType == Graphic3d_TOT_1D);
   if (!Create (theCtx))
   {
     Release (theCtx.operator->());
@@ -371,27 +388,72 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
     myIsAlpha = thePixelFormat == GL_ALPHA;
   }
 
-  myHasMipmaps             = Standard_False;
+  myHasMipmaps             = toCreateMipMaps;
   myTextFormat             = thePixelFormat;
 #if !defined(GL_ES_VERSION_2_0)
   const GLint anIntFormat  = theTextFormat;
 #else
   // ES does not support sized formats and format conversions - them detected from data type
   const GLint anIntFormat  = thePixelFormat;
+  (void) theTextFormat;
 #endif
-  const GLsizei aWidth     = theSizeX;
-  const GLsizei aHeight    = theSizeY;
-  const GLsizei aMaxSize   = theCtx->MaxTextureSize();
 
-  // Notice that formally general NPOT textures are required by OpenGL 2.0 specifications
-  // however some hardware (NV30 - GeForce FX, RadeOn 9xxx and Xxxx) supports GLSL but not NPOT!
-  // Trying to create NPOT textures on such hardware will not fail
-  // but driver will fall back into software rendering,
-  const bool    toForceP2  = !theCtx->IsGlGreaterEqual (3, 0) && !theCtx->arbNPTW;
-  const GLsizei aWidthOut  = toForceP2 ? OpenGl_Context::GetPowerOfTwo (aWidth,  aMaxSize) : Min (aWidth,  aMaxSize);
-  const GLsizei aHeightOut = toForceP2 ? OpenGl_Context::GetPowerOfTwo (aHeight, aMaxSize) : Min (aHeight, aMaxSize);
-  const GLenum  aFilter    = (myParams->Filter() == Graphic3d_TOTF_NEAREST) ? GL_NEAREST : GL_LINEAR;
-  const GLenum  aWrapMode  = myParams->IsRepeat() ? GL_REPEAT : theCtx->TextureWrapClamp();
+  const GLsizei aMaxSize = theCtx->MaxTextureSize();
+  if (theSizeX > aMaxSize
+   || theSizeY > aMaxSize)
+  {
+    TCollection_ExtendedString aWarnMessage = TCollection_ExtendedString ("Error: Texture dimension - ")
+      + theSizeX + "x" + theSizeY + " exceeds hardware limits (" + aMaxSize + "x" + aMaxSize + ")";
+
+    theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION, GL_DEBUG_TYPE_ERROR, 0, GL_DEBUG_SEVERITY_HIGH, aWarnMessage);
+    Release (theCtx.operator->());
+    return false;
+  }
+#if !defined(GL_ES_VERSION_2_0)
+  else if (!theCtx->IsGlGreaterEqual (3, 0) && !theCtx->arbNPTW)
+  {
+    // Notice that formally general NPOT textures are required by OpenGL 2.0 specifications
+    // however some hardware (NV30 - GeForce FX, RadeOn 9xxx and Xxxx) supports GLSL but not NPOT!
+    // Trying to create NPOT textures on such hardware will not fail
+    // but driver will fall back into software rendering,
+    const GLsizei aWidthP2  = OpenGl_Context::GetPowerOfTwo (theSizeX, aMaxSize);
+    const GLsizei aHeightP2 = OpenGl_Context::GetPowerOfTwo (theSizeY, aMaxSize);
+
+    if (theSizeX != aWidthP2
+     || (theType != Graphic3d_TOT_1D && theSizeY != aHeightP2))
+    {
+      TCollection_ExtendedString aWarnMessage =
+        TCollection_ExtendedString ("Error: NPOT Textures (") + theSizeX + "x" + theSizeY + ") are not supported by hardware.";
+
+      theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION, GL_DEBUG_TYPE_PORTABILITY, 0, GL_DEBUG_SEVERITY_HIGH, aWarnMessage);
+
+      Release (theCtx.operator->());
+      return false;
+    }
+  }
+#else
+  else if (!theCtx->IsGlGreaterEqual (3, 0) && theType == Graphic3d_TOT_2D_MIPMAP)
+  {
+    // Mipmap NPOT textures are not supported by OpenGL ES 2.0.
+    const GLsizei aWidthP2  = OpenGl_Context::GetPowerOfTwo (theSizeX, aMaxSize);
+    const GLsizei aHeightP2 = OpenGl_Context::GetPowerOfTwo (theSizeY, aMaxSize);
+
+    if (theSizeX != aWidthP2
+     || theSizeY != aHeightP2)
+    {
+      TCollection_ExtendedString aWarnMessage =
+        TCollection_ExtendedString ("Error: Mipmap NPOT Textures (") + theSizeX + "x" + theSizeY + ") are not supported by OpenGL ES 2.0";
+
+      theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION, GL_DEBUG_TYPE_PORTABILITY, 0, GL_DEBUG_SEVERITY_HIGH, aWarnMessage);
+
+      Release (theCtx.operator->());
+      return false;
+    }
+  }
+#endif
+
+  const GLenum  aFilter   = (myParams->Filter() == Graphic3d_TOTF_NEAREST) ? GL_NEAREST : GL_LINEAR;
+  const GLenum  aWrapMode = myParams->IsRepeat() ? GL_REPEAT : theCtx->TextureWrapClamp();
 
 #if !defined(GL_ES_VERSION_2_0)
   GLint aTestWidth  = 0;
@@ -401,6 +463,8 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
 
   // setup the alignment
   OpenGl_UnpackAlignmentSentry anUnpackSentry;
+  (void)anUnpackSentry; // avoid compiler warning
+
   if (aDataPtr != NULL)
   {
     const GLint anAligment = Min ((GLint )theImage->MaxRowAligmentBytes(), 8); // OpenGL supports alignment upto 8 bytes
@@ -414,42 +478,27 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
   #endif
   }
 
+  myTarget = aTarget;
   switch (theType)
   {
     case Graphic3d_TOT_1D:
     {
     #if !defined(GL_ES_VERSION_2_0)
-      myTarget = GL_TEXTURE_1D;
       Bind (theCtx);
       glTexParameteri (GL_TEXTURE_1D, GL_TEXTURE_MAG_FILTER, aFilter);
       glTexParameteri (GL_TEXTURE_1D, GL_TEXTURE_MIN_FILTER, aFilter);
       glTexParameteri (GL_TEXTURE_1D, GL_TEXTURE_WRAP_S,     aWrapMode);
-
-      Image_PixMap aCopy;
-      if (aDataPtr != NULL)
+      if (toPatchExisting)
       {
-        if (aWidth != aWidthOut)
-        {
-          glPixelStorei (GL_PACK_ALIGNMENT,  1);
-          glPixelStorei (GL_PACK_ROW_LENGTH, 0);
-          if (!aCopy.InitTrash (theImage->Format(), Standard_Size(aWidthOut), 1)
-            || gluScaleImage (thePixelFormat,
-                              aWidth,    1, theDataType, theImage->Data(),
-                              aWidthOut, 1, theDataType, aCopy.ChangeData()) != 0)
-          {
-            Unbind (theCtx);
-            Release (theCtx.operator->());
-            return false;
-          }
-
-          aDataPtr = (GLvoid* )aCopy.Data();
-          anUnpackSentry.Reset();
-        }
+        glTexSubImage1D (GL_TEXTURE_1D, 0, 0,
+                         theSizeX, thePixelFormat, theDataType, aDataPtr);
+        Unbind (theCtx);
+        return true;
       }
 
       // use proxy to check texture could be created or not
       glTexImage1D (GL_PROXY_TEXTURE_1D, 0, anIntFormat,
-                    aWidthOut, 0,
+                    theSizeX, 0,
                     thePixelFormat, theDataType, NULL);
       glGetTexLevelParameteriv (GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_WIDTH, &aTestWidth);
       if (aTestWidth == 0)
@@ -461,7 +510,7 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
       }
 
       glTexImage1D (GL_TEXTURE_1D, 0, anIntFormat,
-                    aWidthOut, 0,
+                    theSizeX, 0,
                     thePixelFormat, theDataType, aDataPtr);
       if (glGetError() != GL_NO_ERROR)
       {
@@ -470,57 +519,37 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
         return false;
       }
 
-      mySizeX = aWidthOut;
+      mySizeX = theSizeX;
       mySizeY = 1;
 
       Unbind (theCtx);
       return true;
     #else
+      Release (theCtx.operator->());
       return false;
     #endif
     }
     case Graphic3d_TOT_2D:
     {
-      myTarget = GL_TEXTURE_2D;
       Bind (theCtx);
       glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, aFilter);
       glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, aFilter);
       glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S,     aWrapMode);
       glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T,     aWrapMode);
-
-      Image_PixMap aCopy;
-      if (aDataPtr != NULL)
+      if (toPatchExisting)
       {
-        if (aWidth != aWidthOut || aHeight != aHeightOut)
-        {
-        #if !defined(GL_ES_VERSION_2_0)
-          // scale texture
-          glPixelStorei (GL_PACK_ALIGNMENT,  1);
-          glPixelStorei (GL_PACK_ROW_LENGTH, 0);
-          if (!aCopy.InitTrash (theImage->Format(), Standard_Size(aWidthOut), Standard_Size(aHeightOut))
-            || gluScaleImage (thePixelFormat,
-                              aWidth,    aHeight,    theDataType, theImage->Data(),
-                              aWidthOut, aHeightOut, theDataType, aCopy.ChangeData()) != 0)
-          {
-            Unbind (theCtx);
-            Release (theCtx.operator->());
-            return false;
-          }
-
-          aDataPtr = (GLvoid* )aCopy.Data();
-          anUnpackSentry.Reset();
-        #else
-          Unbind (theCtx);
-          Release (theCtx.operator->());
-          return false;
-        #endif
-        }
+        glTexSubImage2D (GL_TEXTURE_2D, 0,
+                         0, 0,
+                         theSizeX, theSizeY,
+                         thePixelFormat, theDataType, aDataPtr);
+        Unbind (theCtx);
+        return true;
       }
 
     #if !defined(GL_ES_VERSION_2_0)
       // use proxy to check texture could be created or not
       glTexImage2D (GL_PROXY_TEXTURE_2D, 0, anIntFormat,
-                    aWidthOut, aHeightOut, 0,
+                    theSizeX, theSizeY, 0,
                     thePixelFormat, theDataType, NULL);
       glGetTexLevelParameteriv (GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_WIDTH,  &aTestWidth);
       glGetTexLevelParameteriv (GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_HEIGHT, &aTestHeight);
@@ -534,7 +563,7 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
     #endif
 
       glTexImage2D (GL_TEXTURE_2D, 0, anIntFormat,
-                    aWidthOut, aHeightOut, 0,
+                    theSizeX, theSizeY, 0,
                     thePixelFormat, theDataType, aDataPtr);
       if (glGetError() != GL_NO_ERROR)
       {
@@ -543,17 +572,14 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
         return false;
       }
 
-      mySizeX = aWidthOut;
-      mySizeY = aHeightOut;
+      mySizeX = theSizeX;
+      mySizeY = theSizeY;
 
       Unbind (theCtx);
       return true;
     }
     case Graphic3d_TOT_2D_MIPMAP:
     {
-      myTarget     = GL_TEXTURE_2D;
-      myHasMipmaps = Standard_True;
-
       GLenum aFilterMin = aFilter;
       aFilterMin = GL_NEAREST_MIPMAP_NEAREST;
       if (myParams->Filter() == Graphic3d_TOTF_BILINEAR)
@@ -570,73 +596,89 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
       glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, aFilter);
       glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S,     aWrapMode);
       glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T,     aWrapMode);
-
-      if (theCtx->arbFBO != NULL
-       && aWidth == aWidthOut && aHeight == aHeightOut)
+      if (toPatchExisting)
       {
-      #if !defined(GL_ES_VERSION_2_0)
-        // use proxy to check texture could be created or not
-        glTexImage2D (GL_PROXY_TEXTURE_2D, 0, anIntFormat,
-                      aWidthOut, aHeightOut, 0,
-                      thePixelFormat, theDataType, NULL);
-        glGetTexLevelParameteriv (GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_WIDTH,  &aTestWidth);
-        glGetTexLevelParameteriv (GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_HEIGHT, &aTestHeight);
-        if (aTestWidth == 0 || aTestHeight == 0)
+        glTexSubImage2D (GL_TEXTURE_2D, 0,
+                         0, 0,
+                         theSizeX, theSizeY,
+                         thePixelFormat, theDataType, aDataPtr);
+        if (theCtx->arbFBO != NULL)
         {
-          // no memory or broken input parameters
-          Unbind (theCtx);
-          Release (theCtx.operator->());
-          return false;
+          // generate mipmaps
+          theCtx->arbFBO->glGenerateMipmap (GL_TEXTURE_2D);
+          if (glGetError() != GL_NO_ERROR)
+          {
+            Unbind (theCtx);
+            Release (theCtx.operator->());
+            return false;
+          }
         }
-      #endif
 
-        // upload main picture
-        glTexImage2D (GL_TEXTURE_2D, 0, anIntFormat,
-                      aWidthOut, aHeightOut, 0,
-                      thePixelFormat, theDataType, theImage->Data());
+        Unbind (theCtx);
+        return true;
+      }
+
+    #if !defined(GL_ES_VERSION_2_0)
+      // use proxy to check texture could be created or not
+      glTexImage2D (GL_PROXY_TEXTURE_2D, 0, anIntFormat,
+                    theSizeX, theSizeY, 0,
+                    thePixelFormat, theDataType, NULL);
+      glGetTexLevelParameteriv (GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_WIDTH,  &aTestWidth);
+      glGetTexLevelParameteriv (GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_HEIGHT, &aTestHeight);
+      if (aTestWidth == 0 || aTestHeight == 0)
+      {
+        // no memory or broken input parameters
+        Unbind (theCtx);
+        Release (theCtx.operator->());
+        return false;
+      }
+    #endif
+
+      // upload main picture
+      glTexImage2D (GL_TEXTURE_2D, 0, anIntFormat,
+                    theSizeX, theSizeY, 0,
+                    thePixelFormat, theDataType, theImage->Data());
+      if (glGetError() != GL_NO_ERROR)
+      {
+        Unbind (theCtx);
+        Release (theCtx.operator->());
+        return false;
+      }
+
+      mySizeX = theSizeX;
+      mySizeY = theSizeY;
+
+      if (theCtx->arbFBO != NULL)
+      {
+        // generate mipmaps
+        //glHint (GL_GENERATE_MIPMAP_HINT, GL_NICEST);
+        theCtx->arbFBO->glGenerateMipmap (GL_TEXTURE_2D);
+
         if (glGetError() != GL_NO_ERROR)
         {
           Unbind (theCtx);
           Release (theCtx.operator->());
           return false;
         }
-
-        mySizeX = aWidthOut;
-        mySizeY = aHeightOut;
-
-        // generate mipmaps
-        //glHint (GL_GENERATE_MIPMAP_HINT, GL_NICEST);
-        theCtx->arbFBO->glGenerateMipmap (GL_TEXTURE_2D);
-
-        Unbind (theCtx);
-        return true;
       }
       else
       {
-      #if !defined(GL_ES_VERSION_2_0)
-        bool isCreated = gluBuild2DMipmaps (GL_TEXTURE_2D, anIntFormat,
-                                            aWidth, aHeight,
-                                            thePixelFormat, theDataType, theImage->Data()) == 0;
-        if (isCreated)
-        {
-          glGetTexLevelParameteriv (GL_TEXTURE_2D, 0, GL_TEXTURE_WIDTH,  &mySizeX);
-          glGetTexLevelParameteriv (GL_TEXTURE_2D, 0, GL_TEXTURE_HEIGHT, &mySizeY);
-        }
+        const TCollection_ExtendedString aWarnMessage ("Warning: generating mipmaps requires GL_ARB_framebuffer_object extension which is missing.");
+
+        theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION, GL_DEBUG_TYPE_PORTABILITY, 0, GL_DEBUG_SEVERITY_HIGH, aWarnMessage);
 
         Unbind (theCtx);
-        return isCreated;
-      #else
-        Unbind (theCtx);
+        Release (theCtx.operator->());
         return false;
-      #endif
       }
-    }
-    default:
-    {
-      Release (theCtx.operator->());
-      return false;
+
+      Unbind (theCtx);
+      return true;
     }
   }
+
+  Release (theCtx.operator->());
+  return false;
 }
 
 // =======================================================================
@@ -669,6 +711,58 @@ bool OpenGl_Texture::Init (const Handle(OpenGl_Context)& theCtx,
                theType, &theImage);
 }
 
+// =======================================================================
+// function : Init2DMultisample
+// purpose  :
+// =======================================================================
+bool OpenGl_Texture::Init2DMultisample (const Handle(OpenGl_Context)& theCtx,
+                                        const GLsizei                 theNbSamples,
+                                        const GLint                   theTextFormat,
+                                        const GLsizei                 theSizeX,
+                                        const GLsizei                 theSizeY)
+{
+  if (!Create (theCtx)
+    || theNbSamples > theCtx->MaxMsaaSamples()
+    || theNbSamples < 1)
+  {
+    return false;
+  }
+
+  const GLsizei aNbSamples = OpenGl_Context::GetPowerOfTwo (theNbSamples, theCtx->MaxMsaaSamples());
+  myTarget = GL_TEXTURE_2D_MULTISAMPLE;
+  if(theSizeX > theCtx->MaxTextureSize()
+  || theSizeY > theCtx->MaxTextureSize())
+  {
+    return false;
+  }
+
+  Bind (theCtx);
+  //myTextFormat = theTextFormat;
+#if !defined(GL_ES_VERSION_2_0)
+  if (theCtx->Functions()->glTexStorage2DMultisample != NULL)
+  {
+    theCtx->Functions()->glTexStorage2DMultisample (myTarget, aNbSamples, theTextFormat, theSizeX, theSizeY, GL_FALSE);
+  }
+  else
+  {
+    theCtx->Functions()->glTexImage2DMultisample   (myTarget, aNbSamples, theTextFormat, theSizeX, theSizeY, GL_FALSE);
+  }
+#else
+  theCtx->Functions()  ->glTexStorage2DMultisample (myTarget, aNbSamples, theTextFormat, theSizeX, theSizeY, GL_FALSE);
+#endif
+  if (theCtx->core11fwd->glGetError() != GL_NO_ERROR)
+  {
+    Unbind (theCtx);
+    return false;
+  }
+
+  mySizeX = theSizeX;
+  mySizeY = theSizeY;
+
+  Unbind (theCtx);
+  return true;
+}
+
 // =======================================================================
 // function : InitRectangle
 // purpose  :
@@ -746,6 +840,129 @@ bool OpenGl_Texture::InitRectangle (const Handle(OpenGl_Context)& theCtx,
   Unbind (theCtx);
   return true;
 #else
+  (void )theSizeX;
+  (void )theSizeY;
+  (void )theFormat;
   return false;
 #endif
 }
+
+// =======================================================================
+// function : Init3D
+// purpose  :
+// =======================================================================
+bool OpenGl_Texture::Init3D (const Handle(OpenGl_Context)& theCtx,
+                             const GLint                   theTextFormat,
+                             const GLenum                  thePixelFormat,
+                             const GLenum                  theDataType,
+                             const Standard_Integer        theSizeX,
+                             const Standard_Integer        theSizeY,
+                             const Standard_Integer        theSizeZ,
+                             const void*                   thePixels)
+{
+  if (theCtx->Functions()->glTexImage3D == NULL)
+  {
+    TCollection_ExtendedString aMsg ("Error: three-dimensional textures are not supported by hardware.");
+
+    theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION,
+                         GL_DEBUG_TYPE_ERROR,
+                         0,
+                         GL_DEBUG_SEVERITY_HIGH,
+                         aMsg);
+
+    return false;
+  }
+
+  if (!Create(theCtx))
+  {
+    return false;
+  }
+
+  myTarget = GL_TEXTURE_3D;
+
+  const GLsizei aSizeX = Min (theCtx->MaxTextureSize(), theSizeX);
+  const GLsizei aSizeY = Min (theCtx->MaxTextureSize(), theSizeY);
+  const GLsizei aSizeZ = Min (theCtx->MaxTextureSize(), theSizeZ);
+
+  Bind (theCtx);
+
+  if (theDataType == GL_FLOAT && !theCtx->arbTexFloat)
+  {
+    TCollection_ExtendedString aMsg ("Error: floating-point textures are not supported by hardware.");
+
+    theCtx->PushMessage (GL_DEBUG_SOURCE_APPLICATION,
+                         GL_DEBUG_TYPE_ERROR,
+                         0,
+                         GL_DEBUG_SEVERITY_HIGH,
+                         aMsg);
+
+    Release (theCtx.operator->());
+    Unbind (theCtx);
+    return false;
+  }
+
+  const GLint anIntFormat = theTextFormat;
+
+#if !defined (GL_ES_VERSION_2_0)
+  theCtx->core15fwd->glTexImage3D (GL_PROXY_TEXTURE_3D,
+                                   0,
+                                   anIntFormat,
+                                   aSizeX,
+                                   aSizeY,
+                                   aSizeZ,
+                                   0,
+                                   thePixelFormat,
+                                   theDataType,
+                                   NULL);
+
+  GLint aTestSizeX = 0;
+  GLint aTestSizeY = 0;
+  GLint aTestSizeZ = 0;
+
+  glGetTexLevelParameteriv (GL_PROXY_TEXTURE_3D, 0, GL_TEXTURE_WIDTH, &aTestSizeX);
+  glGetTexLevelParameteriv (GL_PROXY_TEXTURE_3D, 0, GL_TEXTURE_HEIGHT, &aTestSizeY);
+  glGetTexLevelParameteriv (GL_PROXY_TEXTURE_3D, 0, GL_TEXTURE_DEPTH, &aTestSizeZ);
+
+  if (aTestSizeX == 0 || aTestSizeY == 0 || aTestSizeZ == 0)
+  {
+    Unbind (theCtx);
+    Release (theCtx.operator->());
+    return false;
+  }
+#endif
+
+  const GLenum aWrapMode = myParams->IsRepeat() ? GL_REPEAT :  theCtx->TextureWrapClamp();
+  const GLenum aFilter   = (myParams->Filter() == Graphic3d_TOTF_NEAREST) ? GL_NEAREST : GL_LINEAR;
+
+  glTexParameteri (myTarget, GL_TEXTURE_WRAP_S, aWrapMode);
+  glTexParameteri (myTarget, GL_TEXTURE_WRAP_T, aWrapMode);
+  glTexParameteri (myTarget, GL_TEXTURE_WRAP_R, aWrapMode);
+
+  glTexParameteri (myTarget, GL_TEXTURE_MIN_FILTER, aFilter);
+  glTexParameteri (myTarget, GL_TEXTURE_MAG_FILTER, aFilter);
+
+  theCtx->Functions()->glTexImage3D (myTarget,
+                                     0,
+                                     anIntFormat,
+                                     aSizeX,
+                                     aSizeY,
+                                     aSizeZ,
+                                     0,
+                                     thePixelFormat,
+                                     theDataType,
+                                     thePixels);
+
+  if (glGetError() != GL_NO_ERROR)
+  {
+    Unbind (theCtx);
+    Release (theCtx.operator->());
+    return false;
+  }
+
+  mySizeX = aSizeX;
+  mySizeY = aSizeY;
+  mySizeZ = aSizeZ;
+
+  Unbind (theCtx);
+  return true;
+}
