@@ -30,6 +30,7 @@
 #include <Geom_Circle.hxx>
 #include <Geom_Ellipse.hxx>
 #include <Geom_Plane.hxx>
+#include <Geom_BSplineSurface.hxx>
 #include <gp_Pln.hxx>
 #include <Geom2d_Curve.hxx>
 #include <GeomAPI.hxx>
@@ -68,7 +69,6 @@
 #include <TopoDS_Compound.hxx>
 #include <TopoDS_CompSolid.hxx>
 #include <StdSelect_ShapeTypeFilter.hxx>
-#include <QABugs_MyText.hxx>
 #include <Prs3d_Projector.hxx>
 #include <HLRAlgo_Projector.hxx>
 #include <Standard_ErrorHandler.hxx>
@@ -127,7 +127,7 @@ static Standard_Integer BUC60842 (Draw_Interpretor& di, Standard_Integer /*argc*
 static Standard_Integer BUC60843 (Draw_Interpretor& di, Standard_Integer argc,const char ** argv)
 {
   if (argc != 4 && argc != 5 && argc != 6 && argc != 7) {
-    di << "Usage : " << argv[0] << "result_shape name_of_circle name_of_curve [ par1 [ tol ] ]" << "\n";
+    di << "Usage : " << argv[0] << "result_shape name_of_circle name_of_curve [ par1 [ tol ] ]\n";
     return 1;
   }
 
@@ -142,7 +142,7 @@ static Standard_Integer BUC60843 (Draw_Interpretor& di, Standard_Integer argc,co
   Handle(Geom2d_Curve)  aCur2d1 = DrawTrSurf::GetCurve2d(argv[2]);
   Handle(Geom2d_Curve)  aCur2d2 = DrawTrSurf::GetCurve2d(argv[3]);
   if (aCur2d1.IsNull() || aCur2d2.IsNull()) {
-    di << "Faulty : not curves" << "\n";
+    di << "Faulty : not curves\n";
     return 1;
   }
   Standard_Boolean c1IsCircle = Standard_False;
@@ -161,7 +161,7 @@ static Standard_Integer BUC60843 (Draw_Interpretor& di, Standard_Integer argc,co
       Handle(Geom2d_Line) glin = new Geom2d_Line(lin); 
       DrawTrSurf::Set(argv[1], glin);
     } else {
-      di << "Faulty : tangent line is not done." << "\n";
+      di << "Faulty : tangent line is not done.\n";
     }
   }
   else {
@@ -175,7 +175,7 @@ static Standard_Integer BUC60843 (Draw_Interpretor& di, Standard_Integer argc,co
       Handle(Geom2d_Line) glin = new Geom2d_Line(lin); 
       DrawTrSurf::Set(argv[1], glin);
     } else {
-      di << "Faulty : tangent line is not done." << "\n";
+      di << "Faulty : tangent line is not done.\n";
     }
   }   
   return 0;
@@ -185,7 +185,7 @@ static Standard_Integer BUC60970 (Draw_Interpretor& di, Standard_Integer argc, c
 {
   if(argc!=3)
   {
-    di << "Usage : " << argv[0] << " shape result" <<"\n";
+    di << "Usage : " << argv[0] << " shape result\n";
     return 1;
   }
 
@@ -289,7 +289,7 @@ static Standard_Integer  BUC60818(Draw_Interpretor& di, Standard_Integer argc, c
 static Standard_Integer BUC60915_1(Draw_Interpretor& di, Standard_Integer argc, const char ** argv)
 {
   if (argc > 1) {
-    di<<"Function don't has parameters"<<"\n";
+    di<<"Function don't has parameters\n";
     return 1;
   }
 
@@ -390,62 +390,34 @@ static Standard_Integer  OCC138 (Draw_Interpretor& di, Standard_Integer /*argc*/
   BRepPrimAPI_MakeBox box2(gp_Pnt(120, 120, 120),  gp_Pnt(300, 300,300));
   BRepPrimAPI_MakeBox box3(gp_Pnt(320, 320, 320),  gp_Pnt(500, 500,500));
 
-  Handle(AIS_Shape) ais1 = new AIS_Shape(box1.Shape());
-  Handle(AIS_Shape) ais2 = new AIS_Shape(box2.Shape());
-  Handle(AIS_Shape) ais3 = new AIS_Shape(box3.Shape());
+  Handle(AIS_InteractiveObject) ais1 = new AIS_Shape(box1.Shape());
+  Handle(AIS_InteractiveObject) ais2 = new AIS_Shape(box2.Shape());
+  Handle(AIS_InteractiveObject) ais3 = new AIS_Shape(box3.Shape());
 
   aContext->Display(ais1);
   aContext->Display(ais2);
   aContext->Display(ais3);
 
-  aContext->AddOrRemoveCurrentObject(ais1);
-  aContext->AddOrRemoveCurrentObject(ais2);
-  aContext->AddOrRemoveCurrentObject(ais3);
+  aContext->AddOrRemoveSelected(ais1);
+  aContext->AddOrRemoveSelected(ais2);
+  aContext->AddOrRemoveSelected(ais3);
 
-  di << "\n No of currents = " << aContext->NbCurrents();
+  di << "\n No of currents = " << aContext->NbSelected();
 
-  aContext->InitCurrent();
+  aContext->InitSelected();
 
   int count = 1;
-  while(aContext->MoreCurrent())
+  while(aContext->MoreSelected())
   {
     di << "\n count is = " << count++;
-    Handle(AIS_InteractiveObject) ais = aContext->Current();
-    aContext->AddOrRemoveCurrentObject(ais);
-    aContext->InitCurrent();
+    Handle(AIS_InteractiveObject) ais = aContext->SelectedInteractive();
+    aContext->AddOrRemoveSelected(ais);
+    aContext->InitSelected();
   }
 
   return 0; 
 }
 
-static Standard_Integer BUC60821(Draw_Interpretor& di, Standard_Integer argc,const char ** argv )   
-{
-
-  if(argc < 3){
-    di << "Usage: " << argv[0] << " TextHight1 TextHight2 TextHight2";
-    return(-1);
-  }
-
-  Handle(AIS_InteractiveContext) aContext = ViewerTest::GetAISContext();
-
-  if(aContext.IsNull()) 
-  { 
-    di << "use 'vinit' command before " << argv[0] << "\n";
-    return -1;
-  }
-
-  Handle(QABugs_MyText) txt1 = new QABugs_MyText("Gosha1",gp_Pnt(0,0,0),Font_NOF_ASCII_SIMPLEX,Quantity_NOC_RED,Draw::Atoi(argv[1]));
-  aContext->Display(txt1);
-
-  Handle(QABugs_MyText) txt2 = new QABugs_MyText("Gosha2",gp_Pnt(0,0,100),Font_NOF_ASCII_SIMPLEX,Quantity_NOC_YELLOW,Draw::Atoi(argv[2]));
-  aContext->Display(txt2);
-
-  Handle(QABugs_MyText) txt3 = new QABugs_MyText("Gosha3",gp_Pnt(0,100,100),Font_NOF_ASCII_SIMPLEX,Quantity_NOC_SKYBLUE,Draw::Atoi(argv[3]));
-  aContext->Display(txt3);
-
-  return 0;
-}
-
 static int geom_get_2Dpt_from_3Dpt(const gp_Pnt& pnt3d, const gp_Pln& pln, gp_Pnt2d& pnt2d)
 { 
   int ret = 0; 
@@ -534,7 +506,7 @@ static Standard_Integer OCC280 (Draw_Interpretor& di, Standard_Integer argc, con
     return -1;
   }
   if ( argc != 3) {
-    di << "ERROR : Usage : " << argv[0] << " hlr=0/1 setsurfecedetail=0/1; set perspecrive view" << "\n";
+    di << "ERROR : Usage : " << argv[0] << " hlr=0/1 setsurfecedetail=0/1; set perspecrive view\n";
     return 1;
   }
 
@@ -545,10 +517,6 @@ static Standard_Integer OCC280 (Draw_Interpretor& di, Standard_Integer argc, con
 
   TCollection_AsciiString anOldName = ViewerTest::GetCurrentViewName();
   Handle(V3d_Viewer) aViewer = ViewerTest::GetViewerFromContext();
-  if (Draw::Atoi (argv[2]))
-  {
-    aViewer->SetDefaultSurfaceDetail (V3d_TEX_ALL);
-  }
   aViewer->SetDefaultTypeOfView (V3d_PERSPECTIVE);
   Handle(Aspect_Window) asp = ViewerTest::CurrentView()->Window();
   Handle(V3d_View) aNewView = aViewer->CreateView();
@@ -637,9 +605,9 @@ static Standard_Integer  OCC138LC (Draw_Interpretor& di, Standard_Integer /*argc
   BRepPrimAPI_MakeBox box2(gp_Pnt(120, 120, 120),  gp_Pnt(300, 300,300));
   BRepPrimAPI_MakeBox box3(gp_Pnt(320, 320, 320),  gp_Pnt(500, 500,500));
 
-  Handle(AIS_Shape) ais1 = new AIS_Shape(box1.Shape());
-  Handle(AIS_Shape) ais2 = new AIS_Shape(box2.Shape());
-  Handle(AIS_Shape) ais3 = new AIS_Shape(box3.Shape());
+  Handle(AIS_InteractiveObject) ais1 = new AIS_Shape(box1.Shape());
+  Handle(AIS_InteractiveObject) ais2 = new AIS_Shape(box2.Shape());
+  Handle(AIS_InteractiveObject) ais3 = new AIS_Shape(box3.Shape());
 
   aContext->Display(ais1);
   aContext->Display(ais2);
@@ -682,9 +650,9 @@ static Standard_Integer  OCC189 (Draw_Interpretor& di, Standard_Integer /*argc*/
   BRepPrimAPI_MakeBox box2(gp_Pnt(120, 120, 120),  gp_Pnt(300, 300, 300));
   BRepPrimAPI_MakeBox box3(gp_Pnt(320, 320, 320),  gp_Pnt(500, 500, 500));
 
-  Handle(AIS_Shape) ais1 = new AIS_Shape(box1.Shape());
-  Handle(AIS_Shape) ais2 = new AIS_Shape(box2.Shape());
-  Handle(AIS_Shape) ais3 = new AIS_Shape(box3.Shape());
+  Handle(AIS_InteractiveObject) ais1 = new AIS_Shape(box1.Shape());
+  Handle(AIS_InteractiveObject) ais2 = new AIS_Shape(box2.Shape());
+  Handle(AIS_InteractiveObject) ais3 = new AIS_Shape(box3.Shape());
 
   aContext1->Display(ais1);
   aContext1->Display(ais2);
@@ -694,51 +662,51 @@ static Standard_Integer  OCC189 (Draw_Interpretor& di, Standard_Integer /*argc*/
   aContext2->Display(ais2);
   aContext2->Display(ais3);
 
-  aContext1->AddOrRemoveCurrentObject(ais1);
-  aContext1->AddOrRemoveCurrentObject(ais2);
-  aContext1->AddOrRemoveCurrentObject(ais3);
+  aContext1->AddOrRemoveSelected(ais1);
+  aContext1->AddOrRemoveSelected(ais2);
+  aContext1->AddOrRemoveSelected(ais3);
 
   di << "\n Stage : 1";
-  di << "\n \t No of currents on aContext1 = " << aContext1->NbCurrents();
-  di << "\n \t No of currents on aContext2 = " << aContext2->NbCurrents() << "\n\n";
+  di << "\n \t No of currents on aContext1 = " << aContext1->NbSelected();
+  di << "\n \t No of currents on aContext2 = " << aContext2->NbSelected() << "\n\n";
 
-  di << "\n aContext1->IsCurrent = " << (Standard_Integer) aContext1->IsCurrent(ais1) << ", aContext2->IsCurrent = " << (Standard_Integer) aContext2->IsCurrent(ais1) << " ";
+  di << "\n aContext1->IsSelected = " << (Standard_Integer) aContext1->IsCurrent(ais1) << ", aContext2->IsCurrent = " << (Standard_Integer) aContext2->IsCurrent(ais1) << " ";
 
-  aContext2->AddOrRemoveCurrentObject(ais1);
-  aContext2->AddOrRemoveCurrentObject(ais2);
-  aContext2->AddOrRemoveCurrentObject(ais3);
+  aContext2->AddOrRemoveSelected(ais1);
+  aContext2->AddOrRemoveSelected(ais2);
+  aContext2->AddOrRemoveSelected(ais3);
 
   di << "\n Stage : 2";
-  di << "\n \t No of currents on aContext1 = " << aContext1->NbCurrents();
-  di << "\n \t No of currents on aContext2 = " << aContext2->NbCurrents() << "\n\n";
+  di << "\n \t No of currents on aContext1 = " << aContext1->NbSelected();
+  di << "\n \t No of currents on aContext2 = " << aContext2->NbSelected() << "\n\n";
 
-  aContext1->InitCurrent();
+  aContext1->InitSelected();
   int count1 = 1;
-  while(aContext1->MoreCurrent())
+  while(aContext1->MoreSelected())
   {
     di << "\n count1 is = " << count1++;
-    Handle(AIS_InteractiveObject) ais = aContext1->Current();
-    aContext1->AddOrRemoveCurrentObject(ais);
-    aContext1->InitCurrent();
+    Handle(AIS_InteractiveObject) ais = aContext1->SelectedInteractive();
+    aContext1->AddOrRemoveSelected(ais);
+    aContext1->InitSelected();
   }
 
   di << "\n Stage : 3";
-  di << "\n \t No of currents on aContext1 = " << aContext1->NbCurrents();
-  di << "\n \t No of currents on aContext2 = " << aContext2->NbCurrents() << "\n\n";
+  di << "\n \t No of currents on aContext1 = " << aContext1->NbSelected();
+  di << "\n \t No of currents on aContext2 = " << aContext2->NbSelected() << "\n\n";
 
-  aContext2->InitCurrent();
+  aContext2->InitSelected();
   int count2 = 1;
-  while(aContext2->MoreCurrent())
+  while(aContext2->MoreSelected())
   {
     di << "\n count2 is = " << count2++;
-    Handle(AIS_InteractiveObject) ais = aContext2->Current();
-    aContext2->AddOrRemoveCurrentObject(ais);
-    aContext2->InitCurrent();
+    Handle(AIS_InteractiveObject) ais = aContext2->SelectedInteractive();
+    aContext2->AddOrRemoveSelected(ais);
+    aContext2->InitSelected();
   }
 
   di << "\n\n Stage : 4";
-  di << "\n \t No of currents on aContext1 = " << aContext1->NbCurrents();
-  di << "\n \t No of currents on aContext2 = " << aContext2->NbCurrents();
+  di << "\n \t No of currents on aContext1 = " << aContext1->NbSelected();
+  di << "\n \t No of currents on aContext2 = " << aContext2->NbSelected();
 
   return 0; 
 }
@@ -752,7 +720,7 @@ static Standard_Integer  OCC189 (Draw_Interpretor& di, Standard_Integer /*argc*/
 static Standard_Integer OCC566(Draw_Interpretor& di,Standard_Integer n,const char ** a)
 {
   if (n < 2) {
-    di<<"Usage: " << a[0] << " shape [ xmin ymin zmin xmax ymax zmax]"<<"\n";
+    di<<"Usage: " << a[0] << " shape [ xmin ymin zmin xmax ymax zmax]\n";
     return 1;
   }
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -781,7 +749,7 @@ static Standard_Integer OCC566(Draw_Interpretor& di,Standard_Integer n,const cha
 static Standard_Integer OCC570 (Draw_Interpretor& di, Standard_Integer argc,const char ** argv)
 {
   if (argc < 2) {
-    di<<"Usage: " << argv[0] << " result"<<"\n";
+    di<<"Usage: " << argv[0] << " result\n";
     return 1;
   }
 
@@ -828,7 +796,7 @@ static Standard_Integer OCC570 (Draw_Interpretor& di, Standard_Integer argc,cons
     }
     catch(Standard_Failure)
     {
-      di << argv[0] << ": Exception in fillet"<<"\n";
+      di << argv[0] << ": Exception in fillet\n";
       return 2;
     }
   }
@@ -888,7 +856,7 @@ static Standard_Integer UPDATEVOL(Draw_Interpretor& di,
                                   const char ** a)
 {
   if(Rake == 0){
-    di << "MakeFillet non initialise"<<"\n";
+    di << "MakeFillet non initialise\n";
     return 1 ;
   }
   if(narg%2 != 0 || narg < 4) return 1;
@@ -905,7 +873,7 @@ static Standard_Integer UPDATEVOL(Draw_Interpretor& di,
   const Standard_Boolean aLawMode = !strcmp(a[0],"OCC570evollaw");
   if (aLawMode)
   {
-    di<<"INFO: Using law to define variable fillet"<<"\n";
+    di<<"INFO: Using law to define variable fillet\n";
     Handle(Law_Interpol) law = new Law_Interpol;
     law->Set(uandr);
     Rake->Add(law,E);
@@ -921,7 +889,7 @@ static Standard_Integer BUILDEVOL(Draw_Interpretor& di,
                                   const char **)
 {
   if(Rake == 0){
-    di << "MakeFillet non initialise"<<"\n";
+    di << "MakeFillet non initialise\n";
     return 1 ;
   }
   Rake->Build();
@@ -947,13 +915,13 @@ static Standard_Integer OCC606 ( Draw_Interpretor& di, Standard_Integer n, const
 {
   if (n != 3 && n != 4)
   {
-    di << "Usage : " << a[0] << " result shape [-t]" << "\n";
+    di << "Usage : " << a[0] << " result shape [-t]\n";
     return 0;
   }
 
   Standard_Boolean TrimMode = (n == 4);
-  if (TrimMode) di<<"INFO: Using trimmed curves..."<<"\n";
-  else di<<"INFO: Using non trimmed curves..."<<"\n";
+  if (TrimMode) di<<"INFO: Using trimmed curves...\n";
+  else di<<"INFO: Using non trimmed curves...\n";
 
   TopoDS_Shape S = DBRep::Get(a[2]);
 
@@ -993,7 +961,7 @@ static Standard_Integer OCC606 ( Draw_Interpretor& di, Standard_Integer n, const
     }
     catch(Standard_Failure)
     {
-      di<<"ERROR: Exception in GeomFill_NSections"<<"\n";
+      di<<"ERROR: Exception in GeomFill_NSections\n";
     }
   }
 
@@ -1009,7 +977,7 @@ static Standard_Integer OCC813 (Draw_Interpretor& di, Standard_Integer argc,cons
 {
   if (argc < 3)
   {
-    di << "Usage : " << argv[0] << " U V" << "\n";
+    di << "Usage : " << argv[0] << " U V\n";
     return 1;
   }
 
@@ -1148,7 +1116,7 @@ static Standard_Integer OCC884 (Draw_Interpretor& di, Standard_Integer argc, con
 {
   if (argc < 3 || argc > 5)
   {
-    di << "Usage : " << argv[0] << " result shape [toler [maxtoler]]" << "\n";
+    di << "Usage : " << argv[0] << " result shape [toler [maxtoler]]\n";
     return 1;
   }
 
@@ -1157,7 +1125,7 @@ static Standard_Integer OCC884 (Draw_Interpretor& di, Standard_Integer argc, con
   TopExp_Explorer exp(shape, TopAbs_EDGE);
   if (!exp.More())
   {
-    di<<"Error: no edge found"<<"\n";
+    di<<"Error: no edge found\n";
     return 1;
   }
 
@@ -1278,7 +1246,7 @@ static Standard_Integer OCC1188 (Draw_Interpretor& di, Standard_Integer argc, co
 {
   if (argc < 2 || argc > 3)
   {
-    di << "Usage : " << argv[0] << " imagefile [filltype] : Load image as background" << "\n";
+    di << "Usage : " << argv[0] << " imagefile [filltype] : Load image as background\n";
     return 1;
   }
 
@@ -1300,7 +1268,7 @@ static Standard_Integer OCC1188 (Draw_Interpretor& di, Standard_Integer argc, co
     else
     {
       di << "Wrong fill type : " << szType << "\n";
-      di << "Must be one of CENTERED, TILED, STRETCH, NONE" << "\n";
+      di << "Must be one of CENTERED, TILED, STRETCH, NONE\n";
       return 1;
     }
   }
@@ -1322,7 +1290,7 @@ static Standard_Integer OCC1174_1 (Draw_Interpretor& di, Standard_Integer argc,
 {
   if (argc != 2)
   {
-    di << "Usage : " << argv[0] << " shape" << "\n";
+    di << "Usage : " << argv[0] << " shape\n";
     return 1;
   }
 
@@ -1380,7 +1348,7 @@ static Standard_Integer OCC1174_2 (Draw_Interpretor& di, Standard_Integer argc,
 {
   if (argc != 2)
   {
-    di << "Usage : " << argv[0] << " shape" << "\n";
+    di << "Usage : " << argv[0] << " shape\n";
     return 1;
   }
 
@@ -1432,7 +1400,7 @@ static Standard_Integer OCCN1 (Draw_Interpretor& di, Standard_Integer argc, cons
 {
   if (argc != 4)
   {
-    di << "Usage : " << argv[0] << " angle fuse(1 for boss / 0 for slot) length" << "\n";
+    di << "Usage : " << argv[0] << " angle fuse(1 for boss / 0 for slot) length\n";
     return 1;
   }
 
@@ -1493,7 +1461,7 @@ static Standard_Integer OCCN1 (Draw_Interpretor& di, Standard_Integer argc, cons
 static Standard_Integer OCCN2 (Draw_Interpretor& di, Standard_Integer argc, const char ** argv)
 {
   if (argc > 2) {
-    di << "Usage : " << argv[0] << " [BRepAlgoAPI/BRepAlgo = 1/0]" << "\n";
+    di << "Usage : " << argv[0] << " [BRepAlgoAPI/BRepAlgo = 1/0]\n";
     return 1;
   }
   Standard_Boolean IsBRepAlgoAPI = Standard_True;
@@ -1524,19 +1492,19 @@ static Standard_Integer OCCN2 (Draw_Interpretor& di, Standard_Integer argc, cons
 
   TopoDS_Shape shape;
   if (IsBRepAlgoAPI) {
-    di << "BRepAlgoAPI_Section section(cylinder_sh, sphere_sh)" <<"\n";
+    di << "BRepAlgoAPI_Section section(cylinder_sh, sphere_sh)\n";
     BRepAlgoAPI_Section section(cylinder_sh, sphere_sh);
     section.Build();
     if(!section.IsDone()){
-      di << "Error performing intersection: not done." << "\n";
+      di << "Error performing intersection: not done.\n";
     }
     shape = section.Shape();
   } else {
-    di << "BRepAlgo_Section section(cylinder_sh, sphere_sh)" <<"\n";
+    di << "BRepAlgo_Section section(cylinder_sh, sphere_sh)\n";
     BRepAlgo_Section section(cylinder_sh, sphere_sh);
     section.Build();
     if(!section.IsDone()){
-      di << "Error performing intersection: not done." << "\n";
+      di << "Error performing intersection: not done.\n";
     }
     shape = section.Shape();
   }
@@ -1560,7 +1528,7 @@ static Standard_Integer OCC2569 (Draw_Interpretor& di, Standard_Integer argc, co
     return 1;
   }
   if(argc != 3) {
-    di << "Usage : " << argv[0] << " nbpoles result" << "\n";
+    di << "Usage : " << argv[0] << " nbpoles result\n";
     return 1;
   }
 
@@ -1589,7 +1557,7 @@ static Standard_Integer OCC2569 (Draw_Interpretor& di, Standard_Integer argc, co
 static Standard_Integer OCC1642 (Draw_Interpretor& di, Standard_Integer argc, const char ** argv)
 {
   if (argc != 10) {
-    di<<"Usage: " << argv[0] << " FinalWare FinalFace InitWare InitFace shape FixReorder FixDegenerated FixConnected FixSelfIntersection"<<"\n";
+    di<<"Usage: " << argv[0] << " FinalWare FinalFace InitWare InitFace shape FixReorder FixDegenerated FixConnected FixSelfIntersection\n";
     return 1;
   }
 
@@ -1748,7 +1716,7 @@ static Standard_Integer OCC1642 (Draw_Interpretor& di, Standard_Integer argc, co
       (Standard_Integer) advWA->CheckSelfIntersectingEdge(j, points2d, points3d);
 
 
-    ShapeExtend_Status status = ShapeExtend_FAIL1;
+    status = ShapeExtend_FAIL1;
     if(advWA->StatusSelfIntersection(status))
 
       status = ShapeExtend_FAIL2;
@@ -1783,7 +1751,6 @@ void QABugs::Commands_17(Draw_Interpretor& theCommands) {
   theCommands.Add ("BUC60818", "BUC60818", __FILE__, BUC60818, group);
   theCommands.Add ("BUC60915", "BUC60915", __FILE__, BUC60915_1, group);
   theCommands.Add ("OCC138", "OCC138", __FILE__, OCC138, group);
-  theCommands.Add ("BUC60821","BUC60821",__FILE__,BUC60821,group);
   theCommands.Add ("OCC353","OCC353",__FILE__,OCC353,group);
   theCommands.Add ("OCC280","OCC280 hlr=0/1 setsurfecedetail=0/1; set perspecrive view",__FILE__,OCC280,group);
   theCommands.Add ("OCC232", "OCC232", __FILE__, OCC232 , group);
