@@ -26,43 +26,46 @@
 //#4  szv           S4163: optimizations
 //:r9 abv 09.04.99: id_turbine-C.stp #3865: check degenerated 2d point by recomputing to 3d instead of Resolution
 //:s5 abv 22.04.99  Adding debug printouts in catch {} blocks
-#include <ShapeAnalysis_Surface.ixx>
 
+#include <Adaptor3d_Curve.hxx>
+#include <Adaptor3d_IsoCurve.hxx>
+#include <Bnd_Box.hxx>
+#include <BndLib_Add3dCurve.hxx>
+#include <ElSLib.hxx>
+#include <Geom_BezierSurface.hxx>
 #include <Geom_BoundedSurface.hxx>
 #include <Geom_BSplineSurface.hxx>
-#include <Geom_BezierSurface.hxx> //S4135
 #include <Geom_ConicalSurface.hxx>
-#include <Geom_OffsetSurface.hxx> //S4135
+#include <Geom_Curve.hxx>
+#include <Geom_OffsetSurface.hxx>
 #include <Geom_RectangularTrimmedSurface.hxx>
 #include <Geom_SphericalSurface.hxx>
+#include <Geom_Surface.hxx>
 #include <Geom_SurfaceOfLinearExtrusion.hxx>
 #include <Geom_SurfaceOfRevolution.hxx>
 #include <Geom_ToroidalSurface.hxx>
-
-#include <ElSLib.hxx>
-
+#include <GeomAbs_SurfaceForm.hxx>
+#include <GeomAdaptor_Curve.hxx>
+#include <GeomAdaptor_HSurface.hxx>
+#include <gp_Pnt.hxx>
+#include <gp_Pnt2d.hxx>
 #include <Precision.hxx>
-
+#include <ShapeAnalysis.hxx>
 #include <ShapeAnalysis_Curve.hxx>
-
+#include <ShapeAnalysis_Surface.hxx>
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_Failure.hxx>
 #include <Standard_NoSuchObject.hxx>
-#include <ShapeAnalysis.hxx>
-
-#include <Adaptor3d_Curve.hxx>
-#include <GeomAdaptor_Curve.hxx>
-#include <Adaptor3d_IsoCurve.hxx>
-
-#include <GeomAbs_SurfaceForm.hxx>
-#include <BndLib_Add3dCurve.hxx>
+#include <Standard_Type.hxx>
 
+IMPLEMENT_STANDARD_RTTIEXT(ShapeAnalysis_Surface,MMgt_TShared)
 
+//S4135
+//S4135
 //=======================================================================
 //function : ShapeAnalysis_Surface
 //purpose  :
 //=======================================================================
-
 ShapeAnalysis_Surface::ShapeAnalysis_Surface(const Handle(Geom_Surface)& S) :
        mySurf (S),
        myExtOK(Standard_False), //:30
@@ -71,7 +74,8 @@ ShapeAnalysis_Surface::ShapeAnalysis_Surface(const Handle(Geom_Surface)& S) :
        myIsoBoxes (Standard_False),
        myGap (0.), myUDelt (0.01), myVDelt (0.01), myUCloseVal (-1), myVCloseVal (-1)
 {
-  S->Bounds(myUF,myUL,myVF,myVL);
+  mySurf->Bounds(myUF,myUL,myVF,myVL);
+  myAdSur = new GeomAdaptor_HSurface (mySurf);
 }
 
 //=======================================================================
@@ -83,10 +87,11 @@ void ShapeAnalysis_Surface::Init(const Handle(Geom_Surface)& S)
 {
   if (mySurf == S) return;
   myExtOK = Standard_False; //:30
-  mySurf = S;  myAdSur.Nullify();
+  mySurf = S;
   myNbDeg = -1;
   myUCloseVal = myVCloseVal = -1;  myGap = 0.;
   mySurf->Bounds (myUF,myUL,myVF,myVL);
+  myAdSur = new GeomAdaptor_HSurface (mySurf);
   myIsos = Standard_False;
   myIsoBoxes = Standard_False;
   myIsoUF.Nullify(); myIsoUL.Nullify(); myIsoVF.Nullify(); myIsoVL.Nullify();
@@ -114,8 +119,6 @@ void ShapeAnalysis_Surface::Init(const Handle(ShapeAnalysis_Surface)& other)
 
 const Handle(GeomAdaptor_HSurface)& ShapeAnalysis_Surface::Adaptor3d()
 {
-  if (myAdSur.IsNull() && !mySurf.IsNull())
-    myAdSur = new GeomAdaptor_HSurface (mySurf);
   return myAdSur;
 }
 
@@ -188,19 +191,19 @@ void ShapeAnalysis_Surface::ComputeSingularities()
 	   (mySurf->IsKind(STANDARD_TYPE(Geom_OffsetSurface)))) { //rln S4135
 
     //rln S4135 //:r3
-    myP3d     [0] = mySurf->Value (su1, 0.5 * (sv1 + sv2));
+    myP3d     [0] = myAdSur->Value (su1, 0.5 * (sv1 + sv2));
     myFirstP2d[0].SetCoord (su1, sv2); 
     myLastP2d [0].SetCoord (su1, sv1);
 
-    myP3d     [1] = mySurf->Value (su2, 0.5 * (sv1 + sv2));
+    myP3d     [1] = myAdSur->Value (su2, 0.5 * (sv1 + sv2));
     myFirstP2d[1].SetCoord (su2, sv1); 
     myLastP2d [1].SetCoord (su2, sv2);
 
-    myP3d     [2] = mySurf->Value (0.5 * (su1 + su2), sv1);
+    myP3d     [2] = myAdSur->Value (0.5 * (su1 + su2), sv1);
     myFirstP2d[2].SetCoord (su1, sv1); 
     myLastP2d [2].SetCoord (su2, sv1);
     
-    myP3d     [3] = mySurf->Value (0.5 * (su1 + su2), sv2);
+    myP3d     [3] = myAdSur->Value (0.5 * (su1 + su2), sv2);
     myFirstP2d[3].SetCoord (su2, sv2); 
     myLastP2d [3].SetCoord (su1, sv2);
 
@@ -212,10 +215,10 @@ void ShapeAnalysis_Surface::ComputeSingularities()
     myLastPar [2] = myLastPar [3] = su2;
     myUIsoDeg [2] = myUIsoDeg [3] = Standard_False;
 
-    gp_Pnt Corner1 = mySurf->Value(su1,sv1);
-    gp_Pnt Corner2 = mySurf->Value(su1,sv2);
-    gp_Pnt Corner3 = mySurf->Value(su2,sv1);
-    gp_Pnt Corner4 = mySurf->Value(su2,sv2);
+    gp_Pnt Corner1 = myAdSur->Value(su1,sv1);
+    gp_Pnt Corner2 = myAdSur->Value(su1,sv2);
+    gp_Pnt Corner3 = myAdSur->Value(su2,sv1);
+    gp_Pnt Corner4 = myAdSur->Value(su2,sv2);
 
     myPreci[0] = Max (Corner1.Distance(Corner2), Max (myP3d[0].Distance(Corner1), myP3d[0].Distance(Corner2)));
     myPreci[1] = Max (Corner3.Distance(Corner4), Max (myP3d[1].Distance(Corner3), myP3d[1].Distance(Corner4)));
@@ -584,8 +587,8 @@ Standard_Boolean ShapeAnalysis_Surface::IsUClosed(const Standard_Real preci)
 	Standard_Integer nbvk = bs->NbVKnots();
 	for (Standard_Integer i = 1; i <= nbvk; i ++) {
 	  Standard_Real v = bs->VKnot(i);
-	  gp_Pnt p1 = bs->Value (uf, v);
-	  gp_Pnt p2 = bs->Value (ul, v);
+	  gp_Pnt p1 = SurfAdapt.Value (uf, v);
+	  gp_Pnt p2 = SurfAdapt.Value (ul, v);
 	  myUCloseVal = Max (myUCloseVal, p1.SquareDistance (p2));
 	  distmin     = Min (distmin,     p1.SquareDistance (p2));
 	  if (i > 1) {
@@ -634,8 +637,8 @@ Standard_Boolean ShapeAnalysis_Surface::IsUClosed(const Standard_Real preci)
       Standard_Real distmin = RealLast();
       Standard_Integer nbpoints = 101; //can be revised
       for (Standard_Integer i = 0; i < nbpoints; i++) {
-	gp_Pnt p1 = mySurf->Value (uf, vf + (vl - vf ) * i / (nbpoints - 1));
-	gp_Pnt p2 = mySurf->Value (ul, vf + (vl - vf ) * i / (nbpoints - 1));
+	gp_Pnt p1 = SurfAdapt.Value (uf, vf + (vl - vf ) * i / (nbpoints - 1));
+	gp_Pnt p2 = SurfAdapt.Value (ul, vf + (vl - vf ) * i / (nbpoints - 1));
 	myUCloseVal = Max (myUCloseVal, p1.SquareDistance (p2));
 	distmin     = Min (distmin,     p1.SquareDistance (p2));
       }
@@ -710,14 +713,14 @@ Standard_Boolean ShapeAnalysis_Surface::IsVClosed(const Standard_Real preci)
 	Standard_Integer nbuk = bs->NbUKnots();
 	for (Standard_Integer i = 1; i <= nbuk; i ++) {
 	  Standard_Real u = bs->UKnot(i);
-	  gp_Pnt p1 = bs->Value (u, vf);
-	  gp_Pnt p2 = bs->Value (u, vl);
+	  gp_Pnt p1 = SurfAdapt.Value (u, vf);
+	  gp_Pnt p2 = SurfAdapt.Value (u, vl);
 	  myVCloseVal = Max (myVCloseVal, p1.SquareDistance (p2));
 	  distmin     = Min (distmin,     p1.SquareDistance (p2));
 	  if (i > 1) {
 	    u = 0.5 * (bs->UKnot(i-1) + bs->UKnot(i));
-	    p1 = bs->Value (u, vf);
-	    p2 = bs->Value (u, vl);
+	    p1 = SurfAdapt.Value (u, vf);
+	    p2 = SurfAdapt.Value (u, vl);
 	    myVCloseVal = Max (myVCloseVal, p1.SquareDistance (p2));
 	    distmin     = Min (distmin,     p1.SquareDistance (p2));
 	  }
@@ -760,8 +763,8 @@ Standard_Boolean ShapeAnalysis_Surface::IsVClosed(const Standard_Real preci)
       Standard_Real distmin = RealLast();
       Standard_Integer nbpoints = 101; //can be revised
       for (Standard_Integer i = 0; i < nbpoints; i++) {
-	gp_Pnt p1 = mySurf->Value (uf + (ul - uf ) * i / (nbpoints - 1), vf);
-	gp_Pnt p2 = mySurf->Value (uf + (ul - uf ) * i / (nbpoints - 1), vl);
+	gp_Pnt p1 = SurfAdapt.Value (uf + (ul - uf ) * i / (nbpoints - 1), vf);
+	gp_Pnt p2 = SurfAdapt.Value (uf + (ul - uf ) * i / (nbpoints - 1), vl);
 	myVCloseVal = Max (myVCloseVal, p1.SquareDistance (p2));
 	distmin     = Min (distmin,     p1.SquareDistance (p2));
       }
@@ -780,7 +783,7 @@ Standard_Boolean ShapeAnalysis_Surface::IsVClosed(const Standard_Real preci)
 //function : SurfaceNewton
 //purpose  : Newton algo (S4030)
 //=======================================================================
-Standard_Boolean ShapeAnalysis_Surface::SurfaceNewton(const gp_Pnt2d &p2dPrev,
+Standard_Integer ShapeAnalysis_Surface::SurfaceNewton(const gp_Pnt2d &p2dPrev,
                                                       const gp_Pnt& P3D,
                                                       const Standard_Real preci,
                                                       gp_Pnt2d &sol)
@@ -801,13 +804,13 @@ Standard_Boolean ShapeAnalysis_Surface::SurfaceNewton(const gp_Pnt2d &p2dPrev,
   for ( Standard_Integer i=0; i < 25; i++ ) {
     gp_Vec ru, rv, ruu, rvv, ruv;
     gp_Pnt pnt;
-    mySurf->D2 ( U, V, pnt, ru, rv, ruu, rvv, ruv );
+    SurfAdapt.D2 ( U, V, pnt, ru, rv, ruu, rvv, ruv );
 
     // normal
     Standard_Real ru2 = ru * ru, rv2 = rv * rv;
     gp_Vec n = ru ^ rv;
     Standard_Real nrm2 = n.SquareMagnitude();
-    if ( nrm2 < 1e-10 ) break; // n == 0, use standard
+    if ( nrm2 < 1e-10 || Precision::IsPositiveInfinite(nrm2)) break; // n == 0, use standard
 
     // descriminant
     gp_Vec rs = P3D.XYZ() - Value ( U, V ).XYZ();
@@ -849,7 +852,7 @@ Standard_Boolean ShapeAnalysis_Surface::SurfaceNewton(const gp_Pnt2d &p2dPrev,
 //	cout << "Newton: solution found in " << i+1 << " iterations" << endl;
     sol.SetCoord( U, V );
     
-    return ( nrm2 < 0.01 * ru2 * rv2 ? 2 : Standard_True ); //:q6
+    return ( nrm2 < 0.01 * ru2 * rv2 ? 2 : 1 ); //:q6
   }
 //      cout << "Newton: failed after " << i+1 << " iterations (fail " << fail << " )" << endl;
   return Standard_False;
@@ -908,8 +911,8 @@ gp_Pnt2d ShapeAnalysis_Surface::NextValueOfUV(const gp_Pnt2d &p2dPrev,
       }
 
       gp_Pnt2d sol;
-      Standard_Boolean res = SurfaceNewton(p2dPrev,P3D,preci,sol);
-      if ( res )
+      Standard_Integer res = SurfaceNewton(p2dPrev,P3D,preci,sol);
+      if (res != 0)
       {
         Standard_Real gap = P3D.Distance ( Value(sol) );
         if ( res == 2 || //:q6 abv 19 Mar 99: protect against strange attractors
@@ -999,7 +1002,8 @@ gp_Pnt2d ShapeAnalysis_Surface::ValueOfUV(const gp_Pnt& P3D,const Standard_Real
 	//conic case
 	gp_Pnt2d prev(S,T);
 	gp_Pnt2d solution;
-	if (SurfaceNewton(prev,P3D,preci,solution)) {
+	if (SurfaceNewton(prev,P3D,preci,solution) != 0)
+  {
 #ifdef OCCT_DEBUG
 	  cout <<"Newton found point on conic extrusion"<<endl;
 #endif
@@ -1033,10 +1037,9 @@ gp_Pnt2d ShapeAnalysis_Surface::ValueOfUV(const gp_Pnt& P3D,const Standard_Real
       du = Min (myUDelt, SurfAdapt.UResolution (preci));
       dv = Min (myVDelt, SurfAdapt.VResolution (preci));
     }
-        myExtSrf = mySurf;
 	Standard_Real Tol = Precision::PConfusion();
         myExtPS.SetFlag (Extrema_ExtFlag_MIN);
-	myExtPS.Initialize ( myExtSrf, uf-du, ul+du, vf-dv, vl+dv, Tol, Tol );
+	myExtPS.Initialize (SurfAdapt, uf-du, ul+du, vf-dv, vl+dv, Tol, Tol );
 	myExtOK = Standard_True;
       }
       myExtPS.Perform ( P3D );
@@ -1057,7 +1060,7 @@ gp_Pnt2d ShapeAnalysis_Surface::ValueOfUV(const gp_Pnt& P3D,const Standard_Real
         // file CEA_cuve-V5.igs Entityes 244, 259, 847, 925
         // if project point3D on SurfaceOfRevolution Extreme recompute 2d point, but
         // returns an old distance from 3d to solution :-(
-        gp_Pnt aCheckPnt = mySurf->Value( S, T );
+        gp_Pnt aCheckPnt = SurfAdapt.Value( S, T );
         dist2Min = P3D.SquareDistance(aCheckPnt);
         // end of WORKAROUND
 	Standard_Real disSurf = sqrt (dist2Min);//, disCurv =1.e10;
@@ -1071,7 +1074,8 @@ gp_Pnt2d ShapeAnalysis_Surface::ValueOfUV(const gp_Pnt& P3D,const Standard_Real
 	Standard_Boolean possLockal = Standard_False; //:study S4030 (optimizing)
 	if (disSurf > preci) {
 	  gp_Pnt2d pp(UU,VV);
-	  if ( SurfaceNewton(pp,P3D,preci,pp))  { //:q2 abv 16 Mar 99: PRO7226 #412920
+	  if (SurfaceNewton (pp, P3D, preci, pp) != 0)
+    { //:q2 abv 16 Mar 99: PRO7226 #412920
 	    Standard_Real dist = P3D.Distance ( Value(pp) );
 	    if ( dist < disSurf ) {
 	      disSurf = dist;
@@ -1084,7 +1088,7 @@ gp_Pnt2d ShapeAnalysis_Surface::ValueOfUV(const gp_Pnt& P3D,const Standard_Real
 	      Standard_Real Tol = Precision::Confusion();
 	      gp_Vec D1U, D1V;
 	      gp_Pnt pnt;
-	      mySurf->D1(UU, VV, pnt, D1U, D1V);
+	      SurfAdapt.D1(UU, VV, pnt, D1U, D1V);
 	      gp_Vec b = D1U.Crossed(D1V);
 	      gp_Vec a (pnt, P3D);
 	      Standard_Real ab = a.Dot(b);
@@ -1167,7 +1171,7 @@ gp_Pnt2d ShapeAnalysis_Surface::ValueOfUV(const gp_Pnt& P3D,const Standard_Real
   } //:c9
   //szv#4:S4163:12Mar99 waste raise
   //if (!computed) Standard_NoSuchObject::Raise("PCurveLib_ProjectPointOnSurf::ValueOfUV untreated surface type");
-  if (computed) { if (myGap <= 0) myGap = P3D.Distance (mySurf->Value (S,T)); }
+  if (computed) { if (myGap <= 0) myGap = P3D.Distance (SurfAdapt.Value (S,T)); }
   else { myGap = -1.; S = 0.; T = 0.; }
   return gp_Pnt2d( S, T);
 }
@@ -1189,7 +1193,7 @@ Standard_Real ShapeAnalysis_Surface::UVFromIso(const gp_Pnt& P3d,const Standard_
 
   //  Initialisation des recherches : point deja trouve (?)
   UU = U; VV = V;
-  gp_Pnt depart = mySurf->Value (U,V);
+  gp_Pnt depart = myAdSur->Value (U,V);
   theMin = depart.Distance(P3d);
     
   if (theMin < preci/10) return theMin;  // c etait deja OK
