@@ -93,6 +93,9 @@ Standard_Boolean ShapeFix::SameParameter(const TopoDS_Shape& shape,
   for ( TopExp_Explorer anEdgeExp(shape, TopAbs_FACE); anEdgeExp.More(); anEdgeExp.Next() )
     ++aNbFaces;
 
+  TopTools_IndexedDataMapOfShapeListOfShape aMapEF;
+  TopExp::MapShapesAndAncestors(shape, TopAbs_EDGE, TopAbs_FACE, aMapEF);
+
   BRep_Builder B;
   //Standard_Integer nbexcp = 0; 
   Standard_Integer nbfail = 0,  numedge = 0; 
@@ -104,7 +107,7 @@ Standard_Boolean ShapeFix::SameParameter(const TopoDS_Shape& shape,
   Message_Msg doneMsg("FixEdge.SameParameter.MSG0");
 
   // Start progress scope (no need to check if progress exists -- it is safe)
-  Message_ProgressSentry aPSentry(theProgress, "Fixing same parameter problem", 0, 2, 1);
+  Message_ProgressSentry aPSentryForSameParam(theProgress, "Fixing same parameter problem", 0, 2, 1);
 
   {
     // Start progress scope (no need to check if progress exists -- it is safe)
@@ -129,7 +132,21 @@ Standard_Boolean ShapeFix::SameParameter(const TopoDS_Shape& shape,
           B.SameParameter (E,Standard_False);
         }
 
-        sfe->FixSameParameter (E); // K2-SEP97
+        TopTools_ListOfShape aListOfFaces;
+        aMapEF.FindFromKey(E, aListOfFaces);
+        if (aListOfFaces.Extent() != 0)
+        {
+          TopTools_ListOfShape::Iterator aListOfFacesIt(aListOfFaces);
+          for ( ; aListOfFacesIt.More() ; aListOfFacesIt.Next())
+          {
+            TopoDS_Face aF = TopoDS::Face( aListOfFacesIt.Value() );
+            sfe->FixSameParameter (E, aF);
+          }
+        }
+        else
+        {
+          sfe->FixSameParameter (E); // K2-SEP97
+        }
 
         if (!BRep_Tool::SameParameter (E)) { ierr = 1; nbfail ++; }
         
@@ -155,7 +172,7 @@ Standard_Boolean ShapeFix::SameParameter(const TopoDS_Shape& shape,
 
   }
   // Switch to "Update tolerances" step
-  aPSentry.Next();
+  aPSentryForSameParam.Next();
 
   {
     // Start progress scope (no need to check if progress exists -- it is safe)
