@@ -16,57 +16,53 @@
 
 // pdn 17.12.98 ie_exhaust-A.stp
 
-#include <ShapeFix_Shell.ixx>
-
-#include <Precision.hxx>
-#include <TopAbs.hxx>
-#include <TopoDS_Iterator.hxx>
-#include <TopoDS_Shape.hxx>
-#include <TopoDS_Face.hxx>
-#include <TopoDS_Edge.hxx>
-#include <TopoDS_Shell.hxx>
-#include <TopoDS.hxx>
-#include <TopExp_Explorer.hxx>
-#include <TopExp.hxx>
-
-#include <TColStd_SequenceOfInteger.hxx>
-#include <TopTools_SequenceOfShape.hxx>
-#include <TopTools_MapOfShape.hxx>
-#include <TopTools_MapIteratorOfMapOfShape.hxx>
-#include <TopTools_IndexedMapOfShape.hxx>
-#include <TopTools_DataMapOfShapeShape.hxx>
-#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
-#include <TopTools_ListOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
-
+#include <Bnd_Array1OfBox.hxx>
+#include <Bnd_Box.hxx>
 #include <BRep_Builder.hxx>
 #include <BRep_Tool.hxx>
-
-#include <ShapeAnalysis_Shell.hxx>
-#include <ShapeExtend.hxx>
-#include <ShapeBuild_ReShape.hxx> 
-#include <Message_Msg.hxx>
-#include <Message_ProgressSentry.hxx>
-#include <TopTools_DataMapOfShapeInteger.hxx>
-#include <TopTools_DataMapOfShapeInteger.hxx>
-#include <TopTools_DataMapOfShapeInteger.hxx>
-#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
-#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
-#include <TColStd_DataMapOfIntegerListOfInteger.hxx>
-#include <Bnd_Box.hxx>
 #include <BRepBndLib.hxx>
-#include <Bnd_Array1OfBox.hxx>
+#include <Message_Msg.hxx>
+#include <Message_ProgressIndicator.hxx>
+#include <Message_ProgressSentry.hxx>
+#include <Precision.hxx>
+#include <ShapeAnalysis_Shell.hxx>
+#include <ShapeBuild_ReShape.hxx>
+#include <ShapeExtend.hxx>
+#include <ShapeExtend_BasicMsgRegistrator.hxx>
+#include <ShapeFix_Face.hxx>
+#include <ShapeFix_Shell.hxx>
+#include <Standard_Type.hxx>
+#include <TColStd_DataMapOfIntegerListOfInteger.hxx>
 #include <TColStd_MapOfInteger.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeInteger.hxx>
+#include <TColStd_SequenceOfInteger.hxx>
+#include <TopAbs.hxx>
+#include <TopExp.hxx>
+#include <TopExp_Explorer.hxx>
+#include <TopoDS.hxx>
+#include <TopoDS_Compound.hxx>
+#include <TopoDS_Edge.hxx>
+#include <TopoDS_Face.hxx>
 #include <TopoDS_Iterator.hxx>
-#include <TopTools_IndexedMapOfShape.hxx>
+#include <TopoDS_Shape.hxx>
+#include <TopoDS_Shell.hxx>
+#include <TopTools_DataMapIteratorOfDataMapOfShapeInteger.hxx>
+#include <TopTools_DataMapOfShapeInteger.hxx>
+#include <TopTools_DataMapOfShapeShape.hxx>
+#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
 #include <TopTools_IndexedDataMapOfShapeShape.hxx>
+#include <TopTools_IndexedMapOfShape.hxx>
+#include <TopTools_ListIteratorOfListOfShape.hxx>
+#include <TopTools_ListOfShape.hxx>
+#include <TopTools_MapIteratorOfMapOfShape.hxx>
+#include <TopTools_MapOfShape.hxx>
+#include <TopTools_SequenceOfShape.hxx>
+
+IMPLEMENT_STANDARD_RTTIEXT(ShapeFix_Shell,ShapeFix_Root)
 
 //=======================================================================
 //function : ShapeFix_Shell
 //purpose  : 
 //=======================================================================
-
 ShapeFix_Shell::ShapeFix_Shell()
 {    
   myStatus = ShapeExtend::EncodeStatus (ShapeExtend_OK);
@@ -185,7 +181,7 @@ static Standard_Boolean GetFreeEdges(const TopoDS_Shape& aShape,TopTools_MapOfSh
       else  MapEdges.Remove(edge);
     }
   }
-  return (MapEdges.Extent());
+  return !MapEdges.IsEmpty();
 }
 //=======================================================================
 // function : GetShells
@@ -580,9 +576,7 @@ static void GlueClosedCandidate(TopTools_SequenceOfShape& OpenShells,
     
     //Filling map MapOtherShells which contains candidate to creation of closed shell
     // with aShell.
-    
-    TopTools_DataMapOfShapeInteger MapOtherShells;
-    
+    NCollection_DataMap<TopoDS_Shape, Standard_Boolean, TopTools_ShapeMapHasher> MapOtherShells;
     for(Standard_Integer j = i+1 ; j <= OpenShells.Length();j++ )  {
       Standard_Boolean isAddShell = Standard_True;
       Standard_Boolean isReversed = Standard_False;
@@ -607,17 +601,19 @@ static void GlueClosedCandidate(TopTools_SequenceOfShape& OpenShells,
       if(!isAddShell) continue;
       MapOtherShells.Bind(OpenShells.Value(j),isReversed);
     }
-    if(!MapOtherShells.Extent()) continue;
+    if(MapOtherShells.IsEmpty()) continue;
     
     
-    if(MapOtherShells.Extent() >1) {
-      
+    if (!MapOtherShells.IsEmpty())
+    {
       // Case of compsolid when more than two shells have the same free boundary.
       TopTools_SequenceOfShape aSeqCandidate;
       aSeqCandidate.Append(OpenShells.Value(i));
       
-      for(TopTools_DataMapIteratorOfDataMapOfShapeInteger aIt(MapOtherShells); aIt.More(); aIt.Next())
-       aSeqCandidate.Append(aIt.Key());
+      for (NCollection_DataMap<TopoDS_Shape, Standard_Boolean, TopTools_ShapeMapHasher>::Iterator aIt(MapOtherShells); aIt.More(); aIt.Next())
+      {
+        aSeqCandidate.Append(aIt.Key());
+      }
       
       //Creation all possibly shells from choosen candidate.And
       // addition of them to temporary sequence.
@@ -631,9 +627,9 @@ static void GlueClosedCandidate(TopTools_SequenceOfShape& OpenShells,
           aB.MakeShell(aNewSh);
           for(TopoDS_Iterator aIt1(aSeqCandidate.Value(k),Standard_False); aIt1.More(); aIt1.Next())
             aB.Add(aNewSh,aIt1.Value());
-          Standard_Integer isRev = MapOtherShells.Find(aSeqCandidate.Value(l));
+          Standard_Boolean isRev = MapOtherShells.Find(aSeqCandidate.Value(l));
           if(k !=1) {
-            isRev = ((isRev == MapOtherShells.Find(aSeqCandidate.Value(k))) ? 1 : 0);
+            isRev = (isRev == MapOtherShells.Find(aSeqCandidate.Value(k)));
           }
           for(TopExp_Explorer aExp(aSeqCandidate.Value(l),TopAbs_FACE); aExp.More(); aExp.Next()) {
             TopoDS_Shape aFace = (isRev ? aExp.Current().Reversed(): aExp.Current());
@@ -660,9 +656,8 @@ static void GlueClosedCandidate(TopTools_SequenceOfShape& OpenShells,
       TopoDS_Shape addShell;
       Standard_Boolean isReversed = Standard_False;
       for(Standard_Integer j1 = i+1 ; j1 <= OpenShells.Length();j1++ )  {
-        if(!MapOtherShells.IsBound(OpenShells.Value(j1))) continue;
+        if(!MapOtherShells.Find (OpenShells.Value(j1), isReversed)) continue;
         addShell = OpenShells.Value(j1);
-        isReversed = MapOtherShells.Find(addShell);
         OpenShells.Remove(j1);
         break;
       }
