@@ -13,15 +13,18 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
+#ifdef _WIN32
+#include <windows.h>
+#endif
+
 #include <Standard_MMgrOpt.hxx>
 #include <Standard_OutOfMemory.hxx>
 #include <Standard_Assert.hxx>
 
 #include <stdio.h>
+#include <errno.h>
 
-#ifdef _WIN32
-# include <windows.h>
-#else
+#ifndef _WIN32
 # include <sys/mman.h>    /* mmap() */
 #endif
 
@@ -31,6 +34,9 @@
 extern "C" int getpagesize() ;
 #endif
 
+#ifdef _WIN32
+#include <Strsafe.h>
+#endif
 //======================================================================
 // Assumptions
 //======================================================================
@@ -77,10 +83,10 @@ extern "C" int getpagesize() ;
 #elif defined(__APPLE__)
 #define MMAP_BASE_ADDRESS  0x80000000
 #define MMAP_FLAGS (MAP_ANON | MAP_PRIVATE)
-#elif defined(LIN)
+#elif defined(__linux__)
 #define MMAP_BASE_ADDRESS 0x20000000
 #define MMAP_FLAGS (MAP_PRIVATE)
-#elif defined(WNT)
+#elif defined(_WIN32)
 //static HANDLE myhMap;
 #else
 #define MMAP_BASE_ADDRESS 0x60000000
@@ -131,10 +137,6 @@ extern "C" int getpagesize() ;
 #define GET_USER(block)    (((Standard_Size*)(block)) + BLOCK_SHIFT)
 #define GET_BLOCK(storage) (((Standard_Size*)(storage))-BLOCK_SHIFT)
 
-// create static instance of out-of-memory exception to protect
-// against possible lack of memory for its raising
-static Handle(Standard_OutOfMemory) anOutOfMemError = new Standard_OutOfMemory;
-
 //=======================================================================
 //function : Standard_MMgr
 //purpose  : 
@@ -197,7 +199,7 @@ void Standard_MMgrOpt::Initialize()
     myNbPages = 1000;
   
   // get system-dependent page size
-#ifndef WNT
+#ifndef _WIN32
   myPageSize = getpagesize();
   if ( ! myPageSize )
     myMMap = 0;
@@ -247,7 +249,7 @@ void Standard_MMgrOpt::Initialize()
       perror("ERR_MEMRY_FAIL");
 #endif
     
-#if defined(IRIX) || defined(__sgi) || defined(SOLARIS) || defined(__sun) || defined(LIN) || defined(linux) || defined(__FreeBSD__) || defined(__ANDROID__)
+#if defined(IRIX) || defined(__sgi) || defined(SOLARIS) || defined(__sun) || defined(__linux__) || defined(__FreeBSD__) || defined(__ANDROID__)
     if ((myMMap = open ("/dev/zero", O_RDWR)) < 0) {
       if ((myMMap = open ("/dev/null", O_RDWR)) < 0){
         myMMap = 0;
@@ -399,7 +401,7 @@ Standard_Address Standard_MMgrOpt::Allocate(const Standard_Size aSize)
           aBlock = (Standard_Size*)calloc(RoundSizeN+BLOCK_SHIFT, sizeof(Standard_Size));
         // if still not succeeded, raise exception
         if ( ! aBlock )
-          anOutOfMemError->Reraise ("Standard_MMgrOpt::Allocate(): malloc failed");
+          Standard_OutOfMemory::Raise ("Standard_MMgrOpt::Allocate(): malloc failed");
       }
 
       // initialize new block header by its size
@@ -505,7 +507,7 @@ Standard_Integer Standard_MMgrOpt::Purge(Standard_Boolean )
   // release memory pools containing no busy memory;
   // for that for each pool count the summary size of blocks
   // got from the free lists allocated from this pool
-#ifndef WNT
+#ifndef _WIN32
   const Standard_Size PoolSize = myPageSize * myNbPages;
 #else
   const Standard_Size PoolSize =
@@ -708,7 +710,7 @@ retry:
 
   // if MMap option is ON, allocate using memory mapped files
   if (myMMap) {
-#ifndef WNT
+#ifndef _WIN32
 
     // align size to page size
     const Standard_Size AlignedSize = PAGE_ALIGN(Size, myPageSize);
@@ -724,13 +726,13 @@ retry:
       if ( Purge(Standard_False) )
         goto retry;
       // if nothing helps, raise exception
-      anOutOfMemError->Reraise (strerror(errcode));
+      Standard_OutOfMemory::Raise (strerror(errcode));
     }
 
     // save actually allocated size into argument
     Size = AlignedSize;
 
-#else /* WNT */
+#else /* _WIN32 */
 
     // align size to page size, taking into account additional space needed to
     // store handle to the memory map
@@ -755,10 +757,16 @@ retry:
         goto retry;
       // if nothing helps, make error message and raise exception
       const int BUFSIZE=1024;
-      char message[BUFSIZE];
-      if ( FormatMessage (FORMAT_MESSAGE_FROM_SYSTEM, 0, GetLastError(), 0, message, BUFSIZE-1, 0) <=0 )
-        strcpy (message, "Standard_MMgrOpt::AllocMemory() failed to mmap");
-      anOutOfMemError->Reraise (message);
+
+      wchar_t message[BUFSIZE];
+
+      if ( FormatMessageW (FORMAT_MESSAGE_FROM_SYSTEM, 0, GetLastError(), 0,
+        message, BUFSIZE-1, 0) <=0 )
+        StringCchCopyW(message, _countof(message), L"Standard_MMgrOpt::AllocMemory() failed to mmap");
+
+      char messageA[BUFSIZE];
+      WideCharToMultiByte(CP_UTF8, 0, message, -1, messageA, sizeof(messageA), NULL, NULL);
+      Standard_OutOfMemory::Raise(messageA);
     }
 
     // record map handle in the beginning
@@ -781,7 +789,7 @@ retry:
       if ( Purge(Standard_False) )
         goto retry;
       // if nothing helps, raise exception
-      anOutOfMemError->Reraise ("Standard_MMgrOpt::Allocate(): malloc failed");
+      Standard_OutOfMemory::Raise ("Standard_MMgrOpt::Allocate(): malloc failed");
     }
   }
   // clear whole block if clearing option is set
@@ -797,14 +805,14 @@ retry:
 
 void Standard_MMgrOpt::FreeMemory (Standard_Address aBlock, 
                                    const Standard_Size
-#ifndef WNT                                   
+#ifndef _WIN32                                   
                                    aSize
 #endif
                                   )
 {
   // release memory (either free or unmap)
   if ( myMMap ) {
-#ifndef WNT
+#ifndef _WIN32
     // align size to page size, just the same as in AllocMemory()
     const Standard_Size AlignedSize = PAGE_ALIGN(aSize, myPageSize);
     munmap((char*)aBlock, AlignedSize);
