@@ -51,9 +51,9 @@
 #include <TDataStd_RealArray.hxx>
 #include <TDocStd_Document.hxx>
 #include <TDocStd_Owner.hxx>
+#include <TDF_TagSource.hxx>
 
 
-IMPLEMENT_STANDARD_HANDLE(TObj_Object,MMgt_TShared)
 IMPLEMENT_STANDARD_RTTIEXT(TObj_Object,MMgt_TShared)
 
 //=======================================================================
@@ -1268,8 +1268,7 @@ void TObj_Object::CopyReferences
    new TObj_OcafObjectIterator(GetChildLabel(), NULL, Standard_True);
   for(; aSrcChildren->More(); aSrcChildren->Next())
   {
-    Handle(TObj_Object) aSrcChild =
-      Handle(TObj_Object)::DownCast(aSrcChildren->Value());
+    Handle(TObj_Object) aSrcChild = aSrcChildren->Value();
     TDF_Label aSrcL = aSrcChild->GetLabel();
     TDF_Label aDestLabel;
     if( !theRelocTable->HasRelocation(aSrcL, aDestLabel) )
@@ -1396,7 +1395,7 @@ void TObj_Object::SetFlags(const Standard_Integer theMask)
 Standard_Boolean TObj_Object::TestFlags(const Standard_Integer theMask) const
 {
   Standard_Integer aFlags = getInteger(DataTag_Flags);
-  return aFlags & theMask;
+  return (aFlags & theMask) != 0;
 }
 
 //=======================================================================
