@@ -14,77 +14,65 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <TopOpeBRep_LineInter.ixx>
-
-#include <TopOpeBRep.hxx>
-#include <TopOpeBRep_VPointInter.hxx>
-#include <TopOpeBRep_VPointInterIterator.hxx>
-#include <TopOpeBRep_FFTransitionTool.hxx>
-
-#include <IntPatch_IType.hxx>
-#include <Geom_Line.hxx>
-#include <Geom_Circle.hxx>
-#include <Geom_Ellipse.hxx>
-#include <Geom_Parabola.hxx>
-#include <Geom_Hyperbola.hxx>
-#include <Geom_TrimmedCurve.hxx>
-#include <IntPatch_ALineToWLine.hxx>
-#include <IntSurf_Quadric.hxx>
-#include <GeomAbs_SurfaceType.hxx> 
-#include <gp_Pnt.hxx>
 
 #include <Adaptor2d_HCurve2d.hxx>
 #include <BRepAdaptor_Curve2d.hxx>
-#include <TopAbs.hxx>
-
-#include <Standard_ProgramError.hxx>
+#include <BRepAdaptor_Surface.hxx>
+#include <Geom_Circle.hxx>
+#include <Geom_Curve.hxx>
+#include <Geom_Ellipse.hxx>
+#include <Geom_Hyperbola.hxx>
+#include <Geom_Line.hxx>
+#include <Geom_Parabola.hxx>
+#include <Geom_TrimmedCurve.hxx>
+#include <GeomAbs_SurfaceType.hxx>
+#include <gp_Pnt.hxx>
+#include <IntPatch_ALine.hxx>
+#include <IntPatch_ALineToWLine.hxx>
+#include <IntPatch_GLine.hxx>
+#include <IntPatch_IType.hxx>
+#include <IntPatch_Line.hxx>
+#include <IntPatch_RLine.hxx>
+#include <IntPatch_SequenceOfLine.hxx>
+#include <IntPatch_WLine.hxx>
+#include <IntSurf_Quadric.hxx>
 #include <Standard_NotImplemented.hxx>
+#include <Standard_ProgramError.hxx>
+#include <TCollection_AsciiString.hxx>
+#include <TopAbs.hxx>
+#include <TopoDS_Face.hxx>
+#include <TopoDS_Shape.hxx>
+#include <TopOpeBRep.hxx>
+#include <TopOpeBRep_Bipoint.hxx>
+#include <TopOpeBRep_FFTransitionTool.hxx>
+#include <TopOpeBRep_LineInter.hxx>
+#include <TopOpeBRep_VPointInter.hxx>
+#include <TopOpeBRep_VPointInterIterator.hxx>
+#include <TopOpeBRep_WPointInter.hxx>
+#include <TopOpeBRepDS_Transition.hxx>
+
+#include <BRepAdaptor_HSurface.hxx>
 
 #ifdef OCCT_DEBUG
 extern Standard_Boolean TopOpeBRep_GetcontextALWLNBP(Standard_Integer&);
 extern Standard_Boolean TopOpeBRep_GettraceCONIC();
-extern Standard_Boolean TopOpeBRepDS_GettraceDSF();
-extern Standard_Boolean TopOpeBRepDS_GettraceDSNC();
 #endif
 
 //-----------------------------------------------------------------------
-static Handle(IntPatch_WLine) FUN_ALINETOWLINE
-(const Handle(IntPatch_ALine)& AL,
- const BRepAdaptor_Surface surf1,const BRepAdaptor_Surface surf2)
-//-----------------------------------------------------------------------
+static void FUN_ALINETOWLINE (const Handle(IntPatch_ALine)& AL,
+                              const Handle(BRepAdaptor_HSurface) surf1,
+                              const Handle(BRepAdaptor_HSurface) surf2,
+                              IntPatch_SequenceOfLine& theLines)
 {
-  IntSurf_Quadric Quad1,Quad2;
-
-  switch(surf1.GetType())
-  {
-    case GeomAbs_Plane:    Quad1.SetValue(surf1.Plane()); break;
-    case GeomAbs_Cylinder: Quad1.SetValue(surf1.Cylinder()); break;
-    case GeomAbs_Sphere:   Quad1.SetValue(surf1.Sphere()); break;
-    case GeomAbs_Cone:     Quad1.SetValue(surf1.Cone()); break;
-    default : Standard_ProgramError::Raise
-      ("TopOpeBRep_LineInter::FUN_ALINETOWLINE"); break;
-  }
-  
-  switch(surf2.GetType())
-  {
-    case GeomAbs_Plane:    Quad2.SetValue(surf2.Plane()); break;
-    case GeomAbs_Cylinder: Quad2.SetValue(surf2.Cylinder()); break;
-    case GeomAbs_Sphere:   Quad2.SetValue(surf2.Sphere()); break;
-    case GeomAbs_Cone:     Quad2.SetValue(surf2.Cone()); break;
-    default : Standard_ProgramError::Raise
-      ("TopOpeBRep_LineInter::FUN_ALINETOWLINE"); break;
-  }
-
-  const Standard_Real deflectionmax = 0.01;
-  const Standard_Real pasUVmax = 0.05;
   Standard_Integer nbpointsmax = 200;
 #ifdef OCCT_DEBUG
   Standard_Integer newnbp;
   if (TopOpeBRep_GetcontextALWLNBP(newnbp)) nbpointsmax = newnbp;
 #endif
   IntPatch_ALineToWLine 
-    AToL(Quad1,Quad2,deflectionmax,pasUVmax,nbpointsmax);
-  return AToL.MakeWLine(AL);
+    AToL(surf1,surf2,nbpointsmax);
+
+  AToL.MakeWLine(AL, theLines);
 }
 
 //=======================================================================
@@ -116,18 +104,24 @@ void TopOpeBRep_LineInter::SetLine(const Handle(IntPatch_Line)& L,
 
   switch (type) {
   case IntPatch_Analytic :
-    myILA = *((Handle(IntPatch_ALine)*)&L); break;
+    myILA = Handle(IntPatch_ALine)::DownCast (L); break;
   case IntPatch_Restriction :
-    myILR = *((Handle(IntPatch_RLine)*)&L); break;
+    myILR = Handle(IntPatch_RLine)::DownCast (L); break;
   case IntPatch_Walking : 
-    myILW = *((Handle(IntPatch_WLine)*)&L); break;
+    myILW = Handle(IntPatch_WLine)::DownCast (L); break;
   default :  //"geometric" line
-    myILG = *((Handle(IntPatch_GLine)*)&L); break;
+    myILG = Handle(IntPatch_GLine)::DownCast (L); break;
   }
 
   // transform an analytic line to a walking line
   if (myTypeLineCurve == TopOpeBRep_ANALYTIC) {
-    myILW = ::FUN_ALINETOWLINE(myILA,S1,S2);
+    IntPatch_SequenceOfLine aSLin;
+    FUN_ALINETOWLINE(myILA,new BRepAdaptor_HSurface(S1),
+                        new BRepAdaptor_HSurface(S2), aSLin);
+
+    if(aSLin.Length() > 0)
+      myILW = Handle(IntPatch_WLine)::DownCast(aSLin.Value(1));
+
     myTypeLineCurve = TopOpeBRep_WALKING;
   }
 
@@ -637,16 +631,6 @@ void TopOpeBRep_LineInter::DumpBipoint
 
 void TopOpeBRep_LineInter::SetOK(const Standard_Boolean B)
 {
-#ifdef OCCT_DEBUG
-  if (TopOpeBRepDS_GettraceDSF() || TopOpeBRepDS_GettraceDSNC()) {
-    if (myOK != B) {
-      cout<<"line "<<myIndex<<" (";
-      TopOpeBRep::Print(myTypeLineCurve,cout);cout<<") ";
-      if (!B) cout<<"OK->NOK"; else cout<<"NOK->OK";
-      cout<<endl;
-    }
-  }
-#endif
   myOK = B;
 }
 
@@ -682,9 +666,7 @@ Standard_OStream& TopOpeBRep_LineInter::DumpLineTransitions(Standard_OStream& OS
 {
 #ifdef OCCT_DEBUG
   OS<<"transition from f1 / f2 "; TopAbs::Print(myF2.Orientation(),OS);
-  OS<<" : "; myLineTonF1.Dump(OS); OS<<endl;
   OS<<"transition from f2 / f1 "; TopAbs::Print(myF1.Orientation(),OS);
-  OS<<" : "; myLineTonF2.Dump(OS); OS<<endl;
 #endif
   return OS;
 }
