@@ -14,29 +14,38 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <TopOpeBRepBuild_Builder1.ixx>
-#include <TopOpeBRepTool_ShapeExplorer.hxx>
+
+#include <BRep_Tool.hxx>
+#include <BRepAdaptor_Surface.hxx>
+#include <BRepTopAdaptor_FClass2d.hxx>
+#include <Geom2d_Curve.hxx>
+#include <Geom2dAPI_ProjectPointOnCurve.hxx>
+#include <TColStd_MapOfInteger.hxx>
 #include <TopAbs_Orientation.hxx>
-#include <TopoDS.hxx>
-#include <TopOpeBRepDS_HDataStructure.hxx>
-#include <TopOpeBRepDS_ShapeWithState.hxx>
-#include <TopOpeBRepBuild_WireEdgeSet.hxx>
 #include <TopAbs_ShapeEnum.hxx>
 #include <TopExp.hxx>
-#include <TopOpeBRepTool_2d.hxx>
-#include <Geom2d_Curve.hxx>
-#include <BRepAdaptor_Surface.hxx>
-#include <BRep_Tool.hxx>
-#include <TopOpeBRepDS_EXPORT.hxx>
-#include <Geom2dAPI_ProjectPointOnCurve.hxx>
+#include <TopoDS.hxx>
+#include <TopoDS_Edge.hxx>
+#include <TopoDS_Face.hxx>
+#include <TopoDS_Shape.hxx>
+#include <TopOpeBRepBuild_Builder1.hxx>
+#include <TopOpeBRepBuild_GTopo.hxx>
+#include <TopOpeBRepBuild_HBuilder.hxx>
+#include <TopOpeBRepBuild_PaveSet.hxx>
+#include <TopOpeBRepBuild_ShellFaceSet.hxx>
 #include <TopOpeBRepBuild_Tools.hxx>
-#include <BRepTopAdaptor_FClass2d.hxx>
+#include <TopOpeBRepBuild_WireEdgeSet.hxx>
+#include <TopOpeBRepDS_BuildTool.hxx>
+#include <TopOpeBRepDS_EXPORT.hxx>
+#include <TopOpeBRepDS_HDataStructure.hxx>
 #include <TopOpeBRepDS_Interference.hxx>
-#include <TopOpeBRepDS_ShapeShapeInterference.hxx>
-#include <TopOpeBRepDS_ListOfInterference.hxx>
 #include <TopOpeBRepDS_ListIteratorOfListOfInterference.hxx>
+#include <TopOpeBRepDS_ListOfInterference.hxx>
+#include <TopOpeBRepDS_ShapeShapeInterference.hxx>
+#include <TopOpeBRepDS_ShapeWithState.hxx>
 #include <TopOpeBRepDS_Transition.hxx>
-#include <TColStd_MapOfInteger.hxx>
+#include <TopOpeBRepTool_2d.hxx>
+#include <TopOpeBRepTool_ShapeExplorer.hxx>
 
 //define parameter division number as 10*e^(-PI) = 0.43213918
 const Standard_Real PAR_T = 0.43213918;
@@ -546,9 +555,8 @@ void TopOpeBRepBuild_Builder1::GFillFaceSameDomSFS(const TopoDS_Shape& FOR,
     Standard_Boolean rev = Standard_False;
     for(Standard_Integer i = 1; i <= aEM.Extent(); i++) {
       const TopoDS_Shape& anEdge = aEM(i);
-      if(myMapOfEdgeWithFaceState.IsBound(anEdge)) {
-	rev = (Standard_Boolean)myMapOfEdgeWithFaceState.Find(anEdge);
-	break;
+      if (myMapOfEdgeWithFaceState.Find (anEdge, rev)) {
+        break;
       }
     }
     if(OrigRev)
@@ -662,7 +670,7 @@ void TopOpeBRepBuild_Builder1::GFillFaceSameDomWES(const TopoDS_Shape& FOR1,
 	      WES.AddStartElement(EOR);
 	    }
 	    
-	    myMapOfEdgeWithFaceState.Bind(EOR, (Standard_Integer)stateOfFaceOri); 
+	    myMapOfEdgeWithFaceState.Bind (EOR, stateOfFaceOri);
 	  }
 
 	  if(!UseEdges) {
@@ -731,7 +739,7 @@ void TopOpeBRepBuild_Builder1::GFillWireSameDomWES(const TopoDS_Shape& W,
 
 	OrientateEdgeOnFace(TopoDS::Edge(EOR), TopoDS::Face(myBaseFaceToFill), 
 			    TopoDS::Face(mySDFaceToFill), G1, stateOfFaceOri);
-	myMapOfEdgeWithFaceState.Bind(EOR, (Standard_Integer)stateOfFaceOri);
+	myMapOfEdgeWithFaceState.Bind (EOR, stateOfFaceOri);
 	WES.AddElement(EOR);
       }
     }
@@ -787,7 +795,7 @@ void TopOpeBRepBuild_Builder1::GFillEdgeSameDomWES(const TopoDS_Shape& EOR,
     Standard_Boolean stateOfFaceOri = Standard_False;
     OrientateEdgeOnFace(newE, TopoDS::Face(myBaseFaceToFill), 
 			TopoDS::Face(mySDFaceToFill), G1, stateOfFaceOri);
-    myMapOfEdgeWithFaceState.Bind(newE, (Standard_Integer)stateOfFaceOri);
+    myMapOfEdgeWithFaceState.Bind (newE, stateOfFaceOri);
 
     WES.AddStartElement(newE);
   }
@@ -840,7 +848,7 @@ void TopOpeBRepBuild_Builder1::GFillEdgeSameDomWES(const TopoDS_Shape& EOR,
 	  if(!IsRev)
 	    aPieceToKeep.Reverse();
 
-	  myMapOfEdgeWithFaceState.Bind(aPieceToKeep, (Standard_Integer)stateOfFaceOri);
+	  myMapOfEdgeWithFaceState.Bind (aPieceToKeep, stateOfFaceOri);
 
 	  WES.AddStartElement(aPieceToKeep);
 	}
@@ -971,7 +979,7 @@ void TopOpeBRepBuild_Builder1::GFillEdgeSameDomWES(const TopoDS_Shape& EOR,
 	Standard_Boolean stateOfFaceOri = Standard_False;
 	OrientateEdgeOnFace(aSplitPart, TopoDS::Face(myBaseFaceToFill), 
 			    TopoDS::Face(mySDFaceToFill), G1, stateOfFaceOri);
-	myMapOfEdgeWithFaceState.Bind(aSplitPart, (Standard_Integer)stateOfFaceOri);
+	myMapOfEdgeWithFaceState.Bind (aSplitPart, stateOfFaceOri);
 	
 	WES.AddStartElement(aSplitPart);	
       }
@@ -994,7 +1002,7 @@ void TopOpeBRepBuild_Builder1::GFillEdgeSameDomWES(const TopoDS_Shape& EOR,
       //compute orientation of the future face
       Standard_Boolean stateOfFaceOri = Standard_False;
       OrientateEdgeOnFace(aSplitPart, TopoDS::Face(myBaseFaceToFill), aSDFace, G1, stateOfFaceOri);
-      myMapOfEdgeWithFaceState.Bind(aSplitPart, (Standard_Integer)stateOfFaceOri);
+      myMapOfEdgeWithFaceState.Bind (aSplitPart, stateOfFaceOri);
 
       if(myBaseFaceToFill == mySDFaceToFill) {
 	mySourceShapes.Add(aSplitPart);
@@ -1170,7 +1178,7 @@ void TopOpeBRepBuild_Builder1::PerformONParts(const TopoDS_Shape& FOR1,
 	}
 	newE.Orientation(neworiE);
 
-	myMapOfEdgeWithFaceState.Bind(newE, (Standard_Integer)stateOfFaceOri);
+	myMapOfEdgeWithFaceState.Bind (newE, stateOfFaceOri);
 	WES.AddStartElement(newE);
       }
     }//end iteration on splON
