@@ -14,38 +14,40 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <TopOpeBRepBuild_FaceBuilder.ixx>
 
+#include <BRep_Builder.hxx>
+#include <BRep_Tool.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Pnt2d.hxx>
+#include <Precision.hxx>
+#include <Standard_ProgramError.hxx>
 #include <TopAbs_Orientation.hxx>
+#include <TopExp.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Compound.hxx>
-#include <TopoDS_Face.hxx>
 #include <TopoDS_Edge.hxx>
+#include <TopoDS_Face.hxx>
+#include <TopoDS_Shape.hxx>
 #include <TopoDS_Vertex.hxx>
-#include <TopOpeBRepDS_BuildTool.hxx>
-#include <BRep_Tool.hxx>
-#include <BRep_Builder.hxx>
-//#include <BRepAdaptor_Curve2d.hxx>
-#include <TopExp.hxx>
-#include <TopTools_Array1OfShape.hxx>
-#include <TopTools_ListOfShape.hxx>
-#include <TopTools_IndexedMapOfOrientedShape.hxx>
-#include <TopTools_IndexedDataMapOfShapeShape.hxx>
-#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
-#include <TopTools_DataMapOfShapeListOfShape.hxx>
-#include <TopTools_DataMapOfShapeListOfShape.hxx>
-#include <TopOpeBRepBuild_WireEdgeClassifier.hxx>
-#include <TopOpeBRepBuild_Loop.hxx>
 #include <TopOpeBRepBuild_BlockBuilder.hxx>
-#include <TopOpeBRepBuild_LoopSet.hxx>
-#include <Standard_ProgramError.hxx>
-#include <Precision.hxx>
-#include <TopTools_IndexedMapOfShape.hxx>
-#include <TopTools_DataMapOfShapeInteger.hxx>
 #include <TopOpeBRepBuild_define.hxx>
+#include <TopOpeBRepBuild_FaceBuilder.hxx>
+#include <TopOpeBRepBuild_Loop.hxx>
+#include <TopOpeBRepBuild_LoopSet.hxx>
+#include <TopOpeBRepBuild_ShapeSet.hxx>
+#include <TopOpeBRepBuild_WireEdgeClassifier.hxx>
+#include <TopOpeBRepBuild_WireEdgeSet.hxx>
+#include <TopOpeBRepDS_BuildTool.hxx>
+#include <TopTools_Array1OfShape.hxx>
+#include <TopTools_DataMapOfShapeInteger.hxx>
+#include <TopTools_DataMapOfShapeListOfShape.hxx>
+#include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
+#include <TopTools_IndexedDataMapOfShapeShape.hxx>
+#include <TopTools_IndexedMapOfOrientedShape.hxx>
+#include <TopTools_IndexedMapOfShape.hxx>
+#include <TopTools_ListOfShape.hxx>
 
+//#include <BRepAdaptor_Curve2d.hxx>
 #undef RM_HANGING
 // MSV: RM_HANGING behaviour: when state of wire is UNCLOSEDW we do not
 // remove the whole wire but remove the chains of hanging edges. This would
@@ -57,8 +59,6 @@
 
 #ifdef OCCT_DEBUG
 extern Standard_Boolean TopOpeBRepBuild_GettracePURGE();
-extern Standard_Boolean TopOpeBRepDS_GettraceSTRANGE();
-#include <TopOpeBRepDS_DSX.hxx>
 void debifb() {}
 #endif
 
@@ -90,10 +90,6 @@ TopOpeBRepBuild_FaceBuilder::TopOpeBRepBuild_FaceBuilder(TopOpeBRepBuild_WireEdg
 void TopOpeBRepBuild_FaceBuilder::InitFaceBuilder(TopOpeBRepBuild_WireEdgeSet& WES,const TopoDS_Shape& F,const Standard_Boolean ForceClass) 
 {
   myFace = TopoDS::Face(F);
-#ifdef OCCT_DEBUG
-  Standard_Boolean deb = TopOpeBRepDS_GettraceSPSX(myFace);
-  if (deb) debifb();
-#endif
   MakeLoops(WES);
   TopOpeBRepBuild_BlockBuilder& BB = myBlockBuilder;
   TopOpeBRepBuild_WireEdgeClassifier WEC(F,BB);
@@ -372,10 +368,8 @@ void TopOpeBRepBuild_FaceBuilder::CorrectGclosedWire(const TopTools_IndexedDataM
 {
   // prequesitory : edges described by <mapVon1Edge> are not closed,not degenerated
 #ifdef OCCT_DEBUG
-  Standard_Boolean trc = TopOpeBRepDS_GettraceSTRANGE();
   if (TopOpeBRepBuild_GettracePURGE()) {
     cout<<endl<<"* CorrectGclosedWire :"<<endl<<endl;
-    trc = Standard_True;
   }
 #endif
   
@@ -395,10 +389,6 @@ void TopOpeBRepBuild_FaceBuilder::CorrectGclosedWire(const TopTools_IndexedDataM
     TopoDS_Vertex newVref = TopoDS::Vertex(aLocalShape);
 //    TopoDS_Vertex newVref = TopoDS::Vertex(Vref.Oriented(V.Orientation()));
     BB.Add(E,newVref);
-#ifdef OCCT_DEBUG
-    Standard_Integer iV = i,iVref = mapVVref.FindIndex(Vref),iE = mapVon1Edge.FindIndex(V);
-    if (trc) cout << " replacing V "<<iV<<" with V "<<iVref<<" on edge "<<iE<<endl;
-#endif
     TopOpeBRepDS_BuildTool BT;
     BT.Parameter(E,newVref,paronE);
   }
