@@ -36,6 +36,7 @@
 #include <Prs3d_Drawer.hxx>
 #include <Prs3d_Presentation.hxx>
 #include <Prs3d_Root.hxx>
+#include <Prs3d_LineAspect.hxx>
 #include <Prs3d_ShadingAspect.hxx>
 #include <Select3D_SensitiveCurve.hxx>
 #include <SelectMgr_EntityOwner.hxx>
@@ -43,26 +44,27 @@
 #include <TCollection_AsciiString.hxx>
 #include <V3d_View.hxx>
 #include <V3d_Viewer.hxx>
-#include <Visual3d_View.hxx>
 #include <ViewerTest_DoubleMapOfInteractiveAndName.hxx>
 #include <ViewerTest_DoubleMapIteratorOfDoubleMapOfInteractiveAndName.hxx>
+#include <OpenGl_Group.hxx>
 
 extern Standard_Boolean VDisplayAISObject (const TCollection_AsciiString& theName,
                                            const Handle(AIS_InteractiveObject)& theAISObj,
                                            Standard_Boolean theReplaceIfExists = Standard_True);
 extern ViewerTest_DoubleMapOfInteractiveAndName& GetMapOfAIS();
 
+namespace {
+
 //=======================================================================
 //function : VUserDraw
 //purpose  : Checks availability and operation of UserDraw feature
 //=======================================================================
-DEFINE_STANDARD_HANDLE(VUserDrawObj, AIS_InteractiveObject)
 
 class VUserDrawObj : public AIS_InteractiveObject
 {
 public:
     // CASCADE RTTI
-    DEFINE_STANDARD_RTTI(VUserDrawObj);
+    DEFINE_STANDARD_RTTI_INLINE(VUserDrawObj,AIS_InteractiveObject);
 
     VUserDrawObj()
     {
@@ -81,17 +83,9 @@ public:
     Handle(VUserDrawObj) myIObj;
 
   public:
-    Element (const Handle(VUserDrawObj)& theIObj,
-             Graphic3d_BndBox4f* theBounds)
-    : myIObj( theIObj )
-    {
-      if (!myIObj.IsNull())
-        myIObj->GetBounds(theBounds);
-    }
+    Element (const Handle(VUserDrawObj)& theIObj) : myIObj (theIObj) {}
 
-    virtual ~Element ()
-    {
-    }
+    virtual ~Element() {}
 
     virtual void Render (const Handle(OpenGl_Workspace)& theWorkspace) const
     {
@@ -112,30 +106,36 @@ private:
     // Virtual methods implementation
     void Compute (const Handle(PrsMgr_PresentationManager3d)& thePresentationManager,
                   const Handle(Prs3d_Presentation)& thePresentation,
-                  const Standard_Integer theMode);
+                  const Standard_Integer theMode) Standard_OVERRIDE;
 
     void ComputeSelection (const Handle(SelectMgr_Selection)& theSelection,
-                           const Standard_Integer theMode);
+                           const Standard_Integer theMode) Standard_OVERRIDE;
 
     // Called by VUserDrawElement
     void Render(const Handle(OpenGl_Workspace)& theWorkspace) const;
-    void GetBounds(Graphic3d_BndBox4f* theBounds);
 
+private:
     GLfloat myCoords[6];
-
     friend class Element;
 };
-IMPLEMENT_STANDARD_HANDLE(VUserDrawObj, AIS_InteractiveObject)
-IMPLEMENT_STANDARD_RTTIEXT(VUserDrawObj, AIS_InteractiveObject)
 
-void VUserDrawObj::Compute(const Handle(PrsMgr_PresentationManager3d)& /*thePresentationManager*/,
-                           const Handle(Prs3d_Presentation)& thePresentation,
+void VUserDrawObj::Compute(const Handle(PrsMgr_PresentationManager3d)& thePrsMgr,
+                           const Handle(Prs3d_Presentation)& thePrs,
                            const Standard_Integer /*theMode*/)
 {
-  thePresentation->Clear();
+  thePrs->Clear();
 
-  Handle(Graphic3d_Group) aGrp = Prs3d_Root::CurrentGroup(thePresentation);
-  aGrp->UserDraw(this, Standard_True, Standard_True);
+  Graphic3d_Vec4 aBndMin (myCoords[0], myCoords[1], myCoords[2], 1.0f);
+  Graphic3d_Vec4 aBndMax (myCoords[3], myCoords[4], myCoords[5], 1.0f);
+  Handle(OpenGl_Group) aGroup = Handle(OpenGl_Group)::DownCast (thePrs->NewGroup());
+  aGroup->SetMinMaxValues (aBndMin.x(), aBndMin.y(), aBndMin.z(),
+                           aBndMax.x(), aBndMax.y(), aBndMax.z());
+  aGroup->SetGroupPrimitivesAspect (myDrawer->LineAspect()->Aspect());
+  VUserDrawObj::Element* anElem = new VUserDrawObj::Element (this);
+  aGroup->AddElement(anElem);
+
+  // invalidate bounding box of the scene
+  thePrsMgr->StructureManager()->Update (thePrsMgr->StructureManager()->UpdateMode());
 }
 
 void VUserDrawObj::ComputeSelection (const Handle(SelectMgr_Selection)& theSelection,
@@ -152,42 +152,24 @@ void VUserDrawObj::ComputeSelection (const Handle(SelectMgr_Selection)& theSelec
   theSelection->Add(aSensitive);
 }
 
-void VUserDrawObj::GetBounds(Graphic3d_BndBox4f* theBounds)
-{
-  if (theBounds)
-  {
-    Graphic3d_Vec4 aMinPt (myCoords[0], myCoords[1], myCoords[2], 1.0f);
-    Graphic3d_Vec4 aMaxPt (myCoords[3], myCoords[4], myCoords[5], 1.0f);
-    if (!theBounds->IsValid())
-    {
-      theBounds->Combine (Graphic3d_BndBox4f (aMinPt, aMaxPt));
-    }
-    else
-    {
-      theBounds->CornerMin() = aMinPt;
-      theBounds->CornerMax() = aMaxPt;
-    }
-  }
-}
-
 void VUserDrawObj::Render(const Handle(OpenGl_Workspace)& theWorkspace) const
 {
+  // this sample does not use GLSL programs - make sure it is disabled
+  Handle(OpenGl_Context) aCtx = theWorkspace->GetGlContext();
+  aCtx->BindProgram (NULL);
+
   // To test linking against OpenGl_Workspace and all aspect classes
-  const OpenGl_AspectLine* aLA = theWorkspace->AspectLine(0);
-  const OpenGl_AspectMarker* aMA = theWorkspace->AspectMarker(0);
-  aMA->Type();
-  const OpenGl_AspectText* aTA = theWorkspace->AspectText(0);
-  aTA->FontName();
-  TEL_COLOUR aColor = theWorkspace->NamedStatus & OPENGL_NS_HIGHLIGHT ?
-    *(theWorkspace->HighlightColor) : aLA->Color();
-
-  // To test OpenGl_Window
-  //Handle(OpenGl_Context) aCtx = theWorkspace->GetGlContext();
+  const OpenGl_AspectMarker* aMA = theWorkspace->AspectMarker();
+  aMA->Aspect()->Type();
+  const OpenGl_AspectText* aTA = theWorkspace->AspectText();
+  aTA->Aspect()->Font();
+  OpenGl_Vec4 aColor = theWorkspace->LineColor();
 
+#if !defined(GL_ES_VERSION_2_0)
   // Finally draw something to make sure UserDraw really works
   glPushAttrib(GL_ENABLE_BIT);
   glDisable(GL_LIGHTING);
-  glColor4fv(aColor.rgb);
+  glColor4fv(aColor.GetData());
   glBegin(GL_LINE_LOOP);
   glVertex3f(myCoords[0], myCoords[1], myCoords[2]);
   glVertex3f(myCoords[3], myCoords[4], myCoords[2]);
@@ -195,18 +177,10 @@ void VUserDrawObj::Render(const Handle(OpenGl_Workspace)& theWorkspace) const
   glVertex3f(myCoords[0], myCoords[1], myCoords[5]);
   glEnd();
   glPopAttrib();
+#endif
 }
 
-OpenGl_Element* VUserDrawCallback(const CALL_DEF_USERDRAW * theUserDraw)
-{
-  Handle(VUserDrawObj) anIObj = (VUserDrawObj*)theUserDraw->Data;
-  if (anIObj.IsNull())
-  {
-    std::cout << "VUserDrawCallback error: null object passed, the custom scene element will not be rendered" << std::endl;
-  }
-
-  return new VUserDrawObj::Element(anIObj, theUserDraw->Bounds);
-}
+} // end of anonymous namespace
 
 static Standard_Integer VUserDraw (Draw_Interpretor& di,
                                     Standard_Integer argc,
@@ -235,9 +209,6 @@ static Standard_Integer VUserDraw (Draw_Interpretor& di,
   TCollection_AsciiString aName (argv[1]);
   VDisplayAISObject(aName, Handle(AIS_InteractiveObject)());
 
-  // register the custom element factory function
-  aDriver->UserDrawCallback() = VUserDrawCallback;
-
   Handle(VUserDrawObj) anIObj = new VUserDrawObj();
   VDisplayAISObject(aName, anIObj);
 
@@ -253,6 +224,7 @@ static int VFeedback (Draw_Interpretor& theDI,
                       Standard_Integer  /*theArgNb*/,
                       const char**      /*theArgVec*/)
 {
+#if !defined(GL_ES_VERSION_2_0)
   // get the active view
   Handle(V3d_View) aView = ViewerTest::CurrentView();
   if (aView.IsNull())
@@ -394,6 +366,11 @@ static int VFeedback (Draw_Interpretor& theDI,
           << "Buffer size GL_3D_COLOR: " << aLen3D_rgba * double(sizeof(GLfloat)) / double(1024 * 1024) << " MiB\n";
     return 0;
   }
+#else
+  (void )theDI;
+  std::cout << "Command is unsupported on current platform.\n";
+  return 1;
+#endif
 }
 
 //==============================================================================
@@ -427,11 +404,25 @@ static int VImmediateFront (Draw_Interpretor& /*theDI*/,
     return 1;
   }
 
-  Graphic3d_CView* aCView = (Graphic3d_CView* )(ViewerTest::CurrentView()->View()->CView());
-  aDriver->SetImmediateModeDrawToFront (*aCView, atoi(theArgVec[1]) != 0);
+  ViewerTest::CurrentView()->View()->SetImmediateModeDrawToFront (atoi(theArgVec[1]) != 0);
+
   return 0;
 }
 
+//! Search the info from the key.
+inline TCollection_AsciiString searchInfo (const TColStd_IndexedDataMapOfStringString& theDict,
+                                           const TCollection_AsciiString& theKey)
+{
+  for (TColStd_IndexedDataMapOfStringString::Iterator anIter (theDict); anIter.More(); anIter.Next())
+  {
+    if (TCollection_AsciiString::IsSameString (anIter.Key(), theKey, Standard_False))
+    {
+      return anIter.Value();
+    }
+  }
+  return TCollection_AsciiString();
+}
+
 //==============================================================================
 //function : VGlInfo
 //purpose  :
@@ -449,53 +440,76 @@ static int VGlInfo (Draw_Interpretor& theDI,
     return 1;
   }
 
-  if (theArgNb <= 1)
+  Standard_Integer anArgIter = 1;
+  Graphic3d_DiagnosticInfo anInfoLevel = Graphic3d_DiagnosticInfo_Basic;
+  if (theArgNb == 2)
   {
-    Handle(OpenGl_GraphicDriver) aDriver = Handle(OpenGl_GraphicDriver)::DownCast (aView->View()->GraphicDriver());
-    if (aDriver.IsNull())
+    TCollection_AsciiString aName (theArgVec[1]);
+    aName.LowerCase();
+    if (aName == "-short")
     {
-      std::cerr << "Error: view does not use OpenGL.\n";
-      return 1;
+      ++anArgIter;
+      anInfoLevel = Graphic3d_DiagnosticInfo_Short;
     }
-    Handle(OpenGl_Context) aCtx = aDriver->GetSharedContext();
-    Standard_CString aDebugInfo = !aCtx.IsNull() && aCtx->IsDebugContext()
-                                ? "  GLdebug     =  ON\n"
-                                : "";
+    else if (aName == "-basic")
+    {
+      ++anArgIter;
+      anInfoLevel = Graphic3d_DiagnosticInfo_Basic;
+    }
+    else if (aName == "-complete"
+          || aName == "-full")
+    {
+      ++anArgIter;
+      anInfoLevel = Graphic3d_DiagnosticInfo_Complete;
+    }
+  }
+
+  TColStd_IndexedDataMapOfStringString aDict;
+  if (anArgIter >= theArgNb)
+  {
+    aView->DiagnosticInformation (aDict, anInfoLevel);
+    TCollection_AsciiString aText;
+    for (TColStd_IndexedDataMapOfStringString::Iterator aValueIter (aDict); aValueIter.More(); aValueIter.Next())
+    {
+      if (!aText.IsEmpty())
+      {
+        aText += "\n";
+      }
+      aText += TCollection_AsciiString("  ") + aValueIter.Key() + ": " + aValueIter.Value();
+    }
+
     theDI << "OpenGL info:\n"
-          << "  GLvendor    = '" << (const char* )glGetString(GL_VENDOR)   << "'\n"
-          << "  GLdevice    = '" << (const char* )glGetString(GL_RENDERER) << "'\n"
-          << "  GLversion   = '" << (const char* )glGetString(GL_VERSION)  << "'\n"
-          << "  GLSLversion = '" << (const char* )glGetString(GL_SHADING_LANGUAGE_VERSION) << "'\n"
-          << aDebugInfo;
+          << aText;
     return 0;
   }
 
   const Standard_Boolean isList = theArgNb >= 3;
-  for (Standard_Integer anIter = 1; anIter < theArgNb; ++anIter)
+  aView->DiagnosticInformation (aDict, Graphic3d_DiagnosticInfo_Complete);
+  for (; anArgIter < theArgNb; ++anArgIter)
   {
-    TCollection_AsciiString aName (theArgVec[anIter]);
+    TCollection_AsciiString aName (theArgVec[anArgIter]);
     aName.UpperCase();
-    const char* aValue = NULL;
+    TCollection_AsciiString aValue;
     if (aName.Search ("VENDOR") != -1)
     {
-      aValue = (const char* )glGetString (GL_VENDOR);
+      aValue = searchInfo (aDict, "GLvendor");
     }
     else if (aName.Search ("RENDERER") != -1)
     {
-      aValue = (const char* )glGetString (GL_RENDERER);
+      aValue = searchInfo (aDict, "GLdevice");
     }
     else if (aName.Search ("SHADING_LANGUAGE_VERSION") != -1
           || aName.Search ("GLSL") != -1)
     {
-      aValue = (const char* )glGetString (GL_SHADING_LANGUAGE_VERSION);
+      aValue = searchInfo (aDict, "GLSLversion");
     }
     else if (aName.Search ("VERSION") != -1)
     {
-      aValue = (const char* )glGetString (GL_VERSION);
+      aValue = searchInfo (aDict, "GLversion");
     }
     else if (aName.Search ("EXTENSIONS") != -1)
     {
-      aValue = (const char* )glGetString (GL_EXTENSIONS);
+      aValue = searchInfo (aDict, "GLextensions");
     }
     else
     {
@@ -538,14 +552,40 @@ static Standard_Integer VShaderProg (Draw_Interpretor& /*theDI*/,
   }
 
   TCollection_AsciiString aLastArg (theArgVec[theArgNb - 1]);
-  aLastArg.UpperCase();
-  const Standard_Boolean toTurnOff = aLastArg == "OFF";
+  aLastArg.LowerCase();
+  const Standard_Boolean toTurnOff = aLastArg == "off";
   Standard_Integer       anArgsNb  = theArgNb - 1;
   Handle(Graphic3d_ShaderProgram) aProgram;
   if (!toTurnOff
-   && aLastArg == "PHONG")
+   && aLastArg == "phong")
   {
-    aProgram = new Graphic3d_ShaderProgram (Graphic3d_ShaderProgram::ShaderName_Phong);
+    const TCollection_AsciiString& aShadersRoot = Graphic3d_ShaderProgram::ShadersFolder();
+    if (aShadersRoot.IsEmpty())
+    {
+      std::cerr << "Both environment variables CSF_ShadersDirectory and CASROOT are undefined!\n"
+                << "At least one should be defined to load Phong program.\n";
+      return 1;
+    }
+
+    const TCollection_AsciiString aSrcVert = aShadersRoot + "/PhongShading.vs";
+    const TCollection_AsciiString aSrcFrag = aShadersRoot + "/PhongShading.fs";
+
+    if (!aSrcVert.IsEmpty()
+     && !OSD_File (aSrcVert).Exists())
+    {
+      std::cerr << "Error: PhongShading.vs is not found\n";
+      return 1;
+    }
+    if (!aSrcFrag.IsEmpty()
+      && !OSD_File (aSrcFrag).Exists())
+    {
+      std::cerr << "Error: PhongShading.fs is not found\n";
+      return 1;
+    }
+
+    aProgram = new Graphic3d_ShaderProgram();
+    aProgram->AttachShader (Graphic3d_ShaderObject::CreateFromFile (Graphic3d_TOS_VERTEX,   aSrcVert));
+    aProgram->AttachShader (Graphic3d_ShaderObject::CreateFromFile (Graphic3d_TOS_FRAGMENT, aSrcFrag));
   }
   if (!toTurnOff
    && aProgram.IsNull())
@@ -585,11 +625,24 @@ static Standard_Integer VShaderProg (Draw_Interpretor& /*theDI*/,
           anIter.More(); anIter.Next())
     {
       anIO = Handle(AIS_InteractiveObject)::DownCast (anIter.Key1());
-      if (!anIO.IsNull())
+      if (anIO.IsNull())
       {
-        anIO->Attributes()->ShadingAspect()->Aspect()->SetShaderProgram (aProgram);
+        continue;
+      }
+
+      if (!anIO->Attributes()->HasOwnShadingAspect())
+      {
+        Handle(Prs3d_ShadingAspect) aNewAspect = new Prs3d_ShadingAspect();
+        *aNewAspect->Aspect() = *anIO->Attributes()->ShadingAspect()->Aspect();
+        aNewAspect->Aspect()->SetShaderProgram (aProgram);
+        anIO->Attributes()->SetShadingAspect (aNewAspect);
         aCtx->Redisplay (anIO, Standard_False);
       }
+      else
+      {
+        anIO->Attributes()->SetShaderProgram (aProgram, Graphic3d_ASPECT_FILL_AREA);
+        anIO->SynchronizeAspects();
+      }
     }
     aCtx->UpdateCurrentViewer();
     return 0;
@@ -609,8 +662,20 @@ static Standard_Integer VShaderProg (Draw_Interpretor& /*theDI*/,
       std::cerr << "Warning: " << aName.ToCString() << " is not an AIS object\n";
       continue;
     }
-    anIO->Attributes()->ShadingAspect()->Aspect()->SetShaderProgram (aProgram);
-    aCtx->Redisplay (anIO, Standard_False);
+
+    if (!anIO->Attributes()->HasOwnShadingAspect())
+    {
+      Handle(Prs3d_ShadingAspect) aNewAspect = new Prs3d_ShadingAspect();
+      *aNewAspect->Aspect() = *anIO->Attributes()->ShadingAspect()->Aspect();
+      aNewAspect->Aspect()->SetShaderProgram (aProgram);
+      anIO->Attributes()->SetShadingAspect (aNewAspect);
+      aCtx->Redisplay (anIO, Standard_False);
+    }
+    else
+    {
+      anIO->Attributes()->SetShaderProgram (aProgram, Graphic3d_ASPECT_FILL_AREA);
+      anIO->SynchronizeAspects();
+    }
   }
 
   aCtx->UpdateCurrentViewer();
@@ -636,8 +701,10 @@ void ViewerTest::OpenGlCommands(Draw_Interpretor& theCommands)
     "vimmediatefront : render immediate mode to front buffer or to back buffer",
     __FILE__, VImmediateFront, aGroup);
   theCommands.Add("vglinfo",
-    "vglinfo [GL_VENDOR] [GL_RENDERER] [GL_VERSION] [GL_SHADING_LANGUAGE_VERSION] [GL_EXTENSIONS]"
-    " : prints GL info",
+                "vglinfo [-short|-basic|-complete]"
+        "\n\t\t:         [GL_VENDOR] [GL_RENDERER] [GL_VERSION]"
+        "\n\t\t:         [GL_SHADING_LANGUAGE_VERSION] [GL_EXTENSIONS]"
+        "\n\t\t: print OpenGL info",
     __FILE__, VGlInfo, aGroup);
   theCommands.Add("vshaderprog",
             "   'vshaderprog [name] pathToVertexShader pathToFragmentShader'"
