@@ -23,13 +23,13 @@
 #include <Precision.hxx>
 #include <gp_Ax1.hxx>
 
-#ifdef WNT
+IMPLEMENT_STANDARD_RTTIEXT(VrmlData_Group,VrmlData_Node)
+
+#ifdef _MSC_VER
 #define _CRT_SECURE_NO_DEPRECATE
 #pragma warning (disable:4996)
 #endif
 
-IMPLEMENT_STANDARD_HANDLE  (VrmlData_Group, VrmlData_Node)
-IMPLEMENT_STANDARD_RTTIEXT (VrmlData_Group, VrmlData_Node)
 
 //=======================================================================
 //function : VrmlData_Group
