@@ -44,6 +44,7 @@
 #include <TShort_Array1OfShortReal.hxx>
 #include <GeomLib.hxx>
 #include <TShort_HArray1OfShortReal.hxx>
+#include <VrmlData_Appearance.hxx>
 
 //=======================================================================
 //function : IsEqual
@@ -374,7 +375,7 @@ Handle(VrmlData_Geometry) VrmlData_ShapeConvert::triToIndexedFaceSet
       new VrmlData_Normal (myScene, 0L, nNodes, arrVec);
     myScene.AddNode (aNormalNode, Standard_False);
     aFaceSet->SetNormals (aNormalNode);
-    return aFaceSet;
+    return Handle(VrmlData_Geometry) (aFaceSet);
   }
 
   Poly_Connect PC(theTri);
@@ -448,7 +449,7 @@ Handle(VrmlData_Geometry) VrmlData_ShapeConvert::triToIndexedFaceSet
     }
   }
 
-  return aFaceSet;
+  return Handle(VrmlData_Geometry) (aFaceSet);
 }
 
 //=======================================================================
@@ -491,7 +492,7 @@ Handle(VrmlData_Geometry) VrmlData_ShapeConvert::polToIndexedLineSet
   myScene.AddNode (aCoordNode, Standard_False);
   aLineSet->SetCoordinates (aCoordNode);
 
-  return aLineSet;
+  return Handle(VrmlData_Geometry) (aLineSet);
 }
 
 //=======================================================================
