@@ -13,94 +13,87 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <XDEDRAW.ixx>
-#include <stdio.h>
 
-#include <TCollection_ExtendedString.hxx>
-#include <TCollection_AsciiString.hxx>
-#include <TColStd_HSequenceOfExtendedString.hxx>
-#include <TCollection_HAsciiString.hxx>
-#include <Quantity_Color.hxx>
-
-#include <TopoDS_Shape.hxx>
-
-#include <Draw.hxx>
-#include <DBRep.hxx>
-#include <V3d_Viewer.hxx>
-#include <V3d_View.hxx>
 #include <AIS_InteractiveContext.hxx>
-#include <ViewerTest.hxx>
-
+#include <AIS_InteractiveObject.hxx>
+#include <AIS_Trihedron.hxx>
+#include <Aspect_TypeOfLine.hxx>
+#include <DBRep.hxx>
 #include <DDF_Browser.hxx>
 #include <DDocStd.hxx>
 #include <DDocStd_DrawDocument.hxx>
-
+#include <Draw.hxx>
+#include <Draw_PluginMacro.hxx>
+#include <Geom_Axis2Placement.hxx>
+#include <Prs3d_Drawer.hxx>
+#include <Prs3d_LineAspect.hxx>
+#include <Quantity_Color.hxx>
 #include <STEPCAFControl_Controller.hxx>
-
-#include <TDF_Tool.hxx>
+#include <TCollection_AsciiString.hxx>
+#include <TCollection_ExtendedString.hxx>
+#include <TCollection_HAsciiString.hxx>
+#include <TColStd_HArray1OfInteger.hxx>
+#include <TColStd_HArray1OfReal.hxx>
+#include <TColStd_HSequenceOfExtendedString.hxx>
+#include <TDataStd_AsciiString.hxx>
+#include <TDataStd_ByteArray.hxx>
+#include <TDataStd_Comment.hxx>
+#include <TDataStd_Integer.hxx>
+#include <TDataStd_IntegerArray.hxx>
+#include <TDataStd_Name.hxx>
+#include <TDataStd_Real.hxx>
+#include <TDataStd_RealArray.hxx>
+#include <TDataStd_TreeNode.hxx>
+#include <TDataStd_UAttribute.hxx>
+#include <TDF_AttributeIterator.hxx>
 #include <TDF_Data.hxx>
 #include <TDF_LabelSequence.hxx>
-#include <TDF_AttributeIterator.hxx>
 #include <TDF_Reference.hxx>
+#include <TDF_Tool.hxx>
+#include <TDocStd_Application.hxx>
 #include <TDocStd_Document.hxx>
-#include <TDataStd_UAttribute.hxx>
-#include <TDataStd_TreeNode.hxx>
-#include <TDataStd_Integer.hxx>
-#include <TDataStd_Real.hxx>
-#include <TDataStd_Name.hxx>
-#include <TDataStd_Comment.hxx>
-#include <TDataStd_AsciiString.hxx>
+#include <TDocStd_Owner.hxx>
 #include <TNaming_NamedShape.hxx>
-#include <TDataStd_IntegerArray.hxx>
-#include <TDataStd_RealArray.hxx>
-#include <TDataStd_ByteArray.hxx>
+#include <TopoDS_Shape.hxx>
 #include <TPrsStd_AISPresentation.hxx>
-#include <TPrsStd_NamedShapeDriver.hxx>
 #include <TPrsStd_AISViewer.hxx>
-
+#include <TPrsStd_DriverTable.hxx>
+#include <TPrsStd_NamedShapeDriver.hxx>
+#include <V3d_View.hxx>
+#include <V3d_Viewer.hxx>
+#include <ViewerTest.hxx>
 #include <XCAFDoc.hxx>
-#include <XCAFDoc_Color.hxx>
-#include <XCAFDoc_Volume.hxx>
 #include <XCAFDoc_Area.hxx>
 #include <XCAFDoc_Centroid.hxx>
-#include <XCAFDoc_ShapeTool.hxx>
+#include <XCAFDoc_Color.hxx>
 #include <XCAFDoc_ColorTool.hxx>
+#include <XCAFDoc_DimTol.hxx>
+#include <XCAFDoc_Dimension.hxx>
+#include <XCAFDoc_Datum.hxx>
+#include <XCAFDoc_GeomTolerance.hxx>
 #include <XCAFDoc_DocumentTool.hxx>
 #include <XCAFDoc_GraphNode.hxx>
 #include <XCAFDoc_LayerTool.hxx>
-#include <XCAFDoc_DimTol.hxx>
 #include <XCAFDoc_Material.hxx>
+#include <XCAFDoc_ShapeTool.hxx>
+#include <XCAFDoc_Volume.hxx>
+#include <XCAFPrs.hxx>
 #include <XCAFPrs_Driver.hxx>
-#include <XCAFApp_Application.hxx>
-
-#include <XDEDRAW_Shapes.hxx>
+#include <XDEDRAW.hxx>
 #include <XDEDRAW_Colors.hxx>
+#include <XDEDRAW_Common.hxx>
 #include <XDEDRAW_Layers.hxx>
 #include <XDEDRAW_Props.hxx>
-#include <XDEDRAW_Common.hxx>
+#include <XDEDRAW_Shapes.hxx>
+#include <XDEDRAW_GDTs.hxx>
+#include <XSDRAW.hxx>
 #include <XSDRAWIGES.hxx>
 #include <XSDRAWSTEP.hxx>
-#include <XSDRAW.hxx>
-#include <XCAFPrs.hxx>
-#include <ViewerTest.hxx>
-#include <Draw_PluginMacro.hxx>
 
-#include <TColStd_HArray1OfInteger.hxx>
-#include <TColStd_HArray1OfReal.hxx>
+#include <BinXCAFDrivers.hxx>
+#include <XmlXCAFDrivers.hxx>
 
-#include <AIS_InteractiveObject.hxx>
-#include <Aspect_TypeOfLine.hxx>
-#include <Prs3d_Drawer.hxx>
-#include <Prs3d_LineAspect.hxx>
-#include <TDocStd_Owner.hxx>
-#include <Geom_Axis2Placement.hxx>
-#include <AIS_Trihedron.hxx>
-
-#define ZVIEW_SIZE 1000000.0
-// avoid warnings on 'extern "C"' functions returning C++ classes
-#ifdef WNT
-#pragma warning(4:4190)
-#endif
+#include <stdio.h>
 
 //=======================================================================
 // Section: General commands
@@ -112,23 +105,21 @@
 //=======================================================================
 static Standard_Integer newDoc (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
-  if (argc < 2) {di<<"Give document name"<<"\n";return 1;}
+  if (argc < 2) {di<<"Give document name\n";return 1;}
 
   Handle(TDocStd_Document) D;
   Handle(DDocStd_DrawDocument) DD;
-  Handle(TDocStd_Application) A;
-
-  if (!DDocStd::Find(A)) return 1;
+  Handle(TDocStd_Application) A = DDocStd::GetApplication();
 
   if (!DDocStd::GetDocument(argv[1],D,Standard_False)) {
-    A->NewDocument(  "MDTV-XCAF"  ,D);
+    A->NewDocument(  "BinXCAF"  ,D);
     DD = new DDocStd_DrawDocument(D);
     TDataStd_Name::Set(D->GetData()->Root(),argv[1]);
     Draw::Set(argv[1],DD);
-    di << "document " << argv[1] << " created" << "\n";
+    di << "document " << argv[1] << " created\n";
     //DDocStd::ReturnLabel(di,D->Main());
   }
-  else di << argv[1] << " is already a document" << "\n";
+  else di << argv[1] << " is already a document\n";
 
   return 0;
 }
@@ -141,8 +132,7 @@ static Standard_Integer newDoc (Draw_Interpretor& di, Standard_Integer argc, con
 static Standard_Integer saveDoc (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   Handle(TDocStd_Document) D;
-  Handle(TDocStd_Application) A;
-  if (!DDocStd::Find(A)) return 1;
+  Handle(TDocStd_Application) A = DDocStd::GetApplication();
 
   if (argc == 1) {
     if (A->NbDocuments() < 1) return 1;
@@ -158,7 +148,7 @@ static Standard_Integer saveDoc (Draw_Interpretor& di, Standard_Integer argc, co
     return 0;
   }
   if (!D->IsSaved()) {
-    di << "this document has never been saved" << "\n";
+    di << "this document has never been saved\n";
     return 1;
   }
   A->Save(D);
@@ -173,14 +163,11 @@ static Standard_Integer openDoc (Draw_Interpretor& di, Standard_Integer argc, co
 {
   Handle(TDocStd_Document) D;
   Handle(DDocStd_DrawDocument) DD;
-  Handle(TDocStd_Application) A;
-
-  if ( !DDocStd::Find(A) )
-    return 1;
+  Handle(TDocStd_Application) A = DDocStd::GetApplication();
 
   if ( argc != 3 )
   {
-    di << "invalid number of arguments. Usage:\t XOpen filename docname" << "\n";
+    di << "invalid number of arguments. Usage:\t XOpen filename docname\n";
     return 1;
   }
 
@@ -189,13 +176,13 @@ static Standard_Integer openDoc (Draw_Interpretor& di, Standard_Integer argc, co
 
   if ( DDocStd::GetDocument(DocName, D, Standard_False) )
   {
-    di << "document with name " << DocName << " already exists" << "\n";
+    di << "document with name " << DocName << " already exists\n";
     return 1;
   }
 
   if ( A->Open(Filename, D) != PCDM_RS_OK )
   {
-    di << "cannot open XDE document" << "\n";
+    di << "cannot open XDE document\n";
     return 1;
   }
 
@@ -203,7 +190,7 @@ static Standard_Integer openDoc (Draw_Interpretor& di, Standard_Integer argc, co
   TDataStd_Name::Set(D->GetData()->Root(), DocName);
   Draw::Set(DocName, DD);
 
-  di << "document " << DocName << " opened" << "\n";
+  di << "document " << DocName << " opened\n";
 
   return 0;
 }
@@ -215,12 +202,12 @@ static Standard_Integer openDoc (Draw_Interpretor& di, Standard_Integer argc, co
 static Standard_Integer dump (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<2) {
-    di<<"Use: "<<argv[0]<<" Doc [int deep (0/1)]"<<"\n";
+    di<<"Use: "<<argv[0]<<" Doc [int deep (0/1)]\n";
     return 1;
   }
   Handle(TDocStd_Document) Doc;
   DDocStd::GetDocument(argv[1], Doc);
-  if ( Doc.IsNull() ) { di << argv[1] << " is not a document" << "\n"; return 1; }
+  if ( Doc.IsNull() ) { di << argv[1] << " is not a document\n"; return 1; }
 
   Handle(XCAFDoc_ShapeTool) myAssembly = XCAFDoc_DocumentTool::ShapeTool(Doc->Main());
   Standard_Boolean deep = Standard_False;
@@ -310,7 +297,7 @@ static void StatAssembly(const TDF_Label L,
         if(i==1)
           di<<"\""<<Entry2.ToCString()<<"\"";
         else
-          di<<" "<<"\""<<Entry2.ToCString()<<"\"";
+          di<<" \""<<Entry2.ToCString()<<"\"";
       }
       di<<") ";
     }
@@ -337,12 +324,12 @@ static void StatAssembly(const TDF_Label L,
 static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<2) {
-    di<<"Use: "<<argv[0]<<" Doc "<<"\n";
+    di<<"Use: "<<argv[0]<<" Doc \n";
     return 1;
   }
   Handle(TDocStd_Document) Doc;   
   DDocStd::GetDocument(argv[1], Doc);
-  if ( Doc.IsNull() ) { di << argv[1] << " is not a document" << "\n"; return 1; }
+  if ( Doc.IsNull() ) { di << argv[1] << " is not a document\n"; return 1; }
 
   Standard_Boolean PrintStructMode = (argc==3);
   Handle(XCAFDoc_ShapeTool) aTool = XCAFDoc_DocumentTool::ShapeTool(Doc->Main());
@@ -350,7 +337,7 @@ static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, co
   TDF_LabelSequence SeqLabels;
   aTool->GetShapes(SeqLabels);
   if(SeqLabels.Length()<=0) return 0;
-  if(PrintStructMode) di<<"\n"<<"Structure of shapes in the document:"<<"\n";
+  if(PrintStructMode) di<<"\nStructure of shapes in the document:\n";
   Standard_Integer level=0;
   Standard_Integer NbCentroidProp=0, NbVolumeProp=0, NbAreaProp=0;
   Standard_Integer NbShapesWithName=0, NbShapesWithColor=0, NbShapesWithLayer=0;
@@ -363,7 +350,7 @@ static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, co
                  NbShapesWithLayer, Doc, PrintStructMode, di);
   }
   Standard_Integer NbLabelsShape = 0;
-  di<<"\n"<<"Statistis of shapes in the document:"<<"\n";
+  di<<"\nStatistis of shapes in the document:\n";
   for(i=0; i<=20; i++) {
     if(HAI->Value(i)==0) break;
     //di<<"level N "<<i<<" :  number of labels with shape = "<<HAI->Value(i)<<"\n";
@@ -375,7 +362,7 @@ static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, co
   di<<"Number of labels with color link = "<<NbShapesWithColor<<"\n";
   di<<"Number of labels with layer link = "<<NbShapesWithLayer<<"\n";
 
-  di<<"\n"<<"Statistis of Props in the document:"<<"\n";
+  di<<"\nStatistis of Props in the document:\n";
   di<<"Number of Centroid Props = "<<NbCentroidProp<<"\n";
   di<<"Number of Volume Props = "<<NbVolumeProp<<"\n";
   di<<"Number of Area Props = "<<NbAreaProp<<"\n";
@@ -383,7 +370,7 @@ static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, co
   Handle(XCAFDoc_ColorTool) CTool = XCAFDoc_DocumentTool::ColorTool(Doc->Main());
   TDF_LabelSequence CLabels;
   CTool->GetColors(CLabels);
-  di<<"\n"<<"Number of colors = "<<CLabels.Length()<<"\n";
+  di<<"\nNumber of colors = "<<CLabels.Length()<<"\n";
   if(CLabels.Length()>0) {
     for(i=1; i<=CLabels.Length(); i++) {
       TDF_Label aLabel = CLabels.Value(i);
@@ -397,7 +384,7 @@ static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, co
   Handle(XCAFDoc_LayerTool) LTool = XCAFDoc_DocumentTool::LayerTool(Doc->Main());
   TDF_LabelSequence LLabels;
   LTool->GetLayerLabels(LLabels);
-  di<<"\n"<<"Number of layers = "<<LLabels.Length()<<"\n";
+  di<<"\nNumber of layers = "<<LLabels.Length()<<"\n";
   if(LLabels.Length()>0) {
     for(i=1; i<=LLabels.Length(); i++) {
       TDF_Label aLabel = LLabels.Value(i);
@@ -421,13 +408,13 @@ static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, co
 static Standard_Integer setPrs (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <2) {
-    di<<"Use: "<<argv[0]<<" DocName [label1 label2 ...] "<<"\n";
+    di<<"Use: "<<argv[0]<<" DocName [label1 label2 ...] \n";
     return 1;
   }
 
   Handle(TDocStd_Document) Doc;
   DDocStd::GetDocument(argv[1], Doc);
-  if ( Doc.IsNull() ) { di << argv[1] << " is not a document" << "\n"; return 1; }
+  if ( Doc.IsNull() ) { di << argv[1] << " is not a document\n"; return 1; }
 
   // collect sequence of labels to set presentation
   Handle(XCAFDoc_ShapeTool) shapes = XCAFDoc_DocumentTool::ShapeTool(Doc->Main());
@@ -472,7 +459,7 @@ static Standard_Integer setPrs (Draw_Interpretor& di, Standard_Integer argc, con
 static Standard_Integer show (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <2) {
-    di<<"Use: "<<argv[0]<<" DocName [label1 label2 ...] "<<"\n";
+    di<<"Use: "<<argv[0]<<" DocName [label1 label2 ...] \n";
     return 1;
   }
 
@@ -494,11 +481,6 @@ static Standard_Integer show (Draw_Interpretor& di, Standard_Integer argc, const
     aDocViewer = TPrsStd_AISViewer::New (aRoot, ViewerTest::GetAISContext());
   }
 
-  //szv:CAX-TRJ7 c2-pe-214.stp was clipped
-  aDocViewer->GetInteractiveContext()->CurrentViewer()->InitActiveViews();
-  aDocViewer->GetInteractiveContext()->CurrentViewer()->ActiveView()->SetZSize(ZVIEW_SIZE);
-  //DDF::ReturnLabel(di,viewer->Label());
-
   // collect sequence of labels to display
   Handle(XCAFDoc_ShapeTool) shapes = XCAFDoc_DocumentTool::ShapeTool (aDoc->Main());
   TDF_LabelSequence seq;
@@ -544,13 +526,13 @@ static Standard_Integer show (Draw_Interpretor& di, Standard_Integer argc, const
 static Standard_Integer xwd (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <3) {
-    di<<"Use: "<<argv[0]<<" DocName filename.{xwd|gif|bmp}"<<"\n";
+    di<<"Use: "<<argv[0]<<" DocName filename.{xwd|gif|bmp}\n";
     return 1;
   }
 
   Handle(TDocStd_Document) Doc;
   DDocStd::GetDocument(argv[1], Doc);
-  if ( Doc.IsNull() ) { di << argv[1] << " is not a document" << "\n"; return 1; }
+  if ( Doc.IsNull() ) { di << argv[1] << " is not a document\n"; return 1; }
 
   Handle(AIS_InteractiveContext) IC;
   if ( ! TPrsStd_AISViewer::Find ( Doc->GetData()->Root(), IC ) ) {
@@ -558,10 +540,11 @@ static Standard_Integer xwd (Draw_Interpretor& di, Standard_Integer argc, const
     return 1;
   }
 
-  Handle(V3d_Viewer) viewer = IC->CurrentViewer();
-  viewer->InitActiveViews();
-  if ( viewer->MoreActiveViews() ) {
-    viewer->ActiveView()->Dump ( argv[2] );
+  Handle(V3d_Viewer) aViewer = IC->CurrentViewer();
+  V3d_ListOfViewIterator aViewIter = aViewer->ActiveViewIterator();
+  if (aViewIter.More())
+  {
+    aViewIter.Value()->Dump ( argv[2] );
   }
   else {
     di << "Cannot find an active view in a viewer " << argv[1] << "\n";
@@ -578,7 +561,7 @@ static Standard_Integer xwd (Draw_Interpretor& di, Standard_Integer argc, const
 //=======================================================================
 static Standard_Integer XAttributeValue (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
-  if ( argc <4 ) { di << "ERROR: Too few args" << "\n"; return 0; }
+  if ( argc <4 ) { di << "ERROR: Too few args\n"; return 0; }
   Handle(DDF_Browser) browser =
     Handle(DDF_Browser)::DownCast (Draw::Get(argv[1], Standard_True));
   if ( browser.IsNull() ) { di << "ERROR: Not a browser: " << argv[1] << "\n"; return 0; }
@@ -591,7 +574,7 @@ static Standard_Integer XAttributeValue (Draw_Interpretor& di, Standard_Integer
   TDF_AttributeIterator itr(lab,Standard_False);
   for (Standard_Integer i=1; itr.More() && i < num; i++) itr.Next();
 
-  if ( ! itr.More() ) { di << "ERROR: Attribute #" << num << " not found" << "\n"; return 0; }
+  if ( ! itr.More() ) { di << "ERROR: Attribute #" << num << " not found\n"; return 0; }
 
   const Handle(TDF_Attribute)& att = itr.Value();
   if ( att->IsKind(STANDARD_TYPE(TDataStd_TreeNode)) ) {
@@ -768,6 +751,15 @@ static Standard_Integer XAttributeValue (Draw_Interpretor& di, Standard_Integer
     else if ( att->ID() == XCAFDoc::DatumTolRefGUID() ) {
       type = "DatumToler Link";
     }
+    else if ( att->ID() == XCAFDoc::DimensionRefFirstGUID() ) {
+      type = "Dimension Link First";
+    }
+    else if ( att->ID() == XCAFDoc::DimensionRefSecondGUID() ) {
+      type = "Dimension Link Second";
+    }
+    else if ( att->ID() == XCAFDoc::GeomToleranceRefGUID() ){
+      type = "GeomTolerance Link";
+    }
     else return 0;
 
     Handle(XCAFDoc_GraphNode) DETGN = Handle(XCAFDoc_GraphNode)::DownCast(att);
@@ -805,7 +797,7 @@ static Standard_Integer XAttributeValue (Draw_Interpretor& di, Standard_Integer
 static Standard_Integer setviewName (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <2) {
-    di<<"Use: "<<argv[0]<<" (1/0)"<<"\n";
+    di<<"Use: "<<argv[0]<<" (1/0)\n";
     return 1;
   }
   Standard_Boolean mode = Standard_False;
@@ -822,8 +814,8 @@ static Standard_Integer setviewName (Draw_Interpretor& di, Standard_Integer argc
 
 static Standard_Integer getviewName (Draw_Interpretor&  di, Standard_Integer /*argc*/, const char** /*argv*/)
 {
-  if ( XCAFPrs::GetViewNameMode() ) di << "Display names ON"<< "\n";
-  else di << "Display names OFF"<< "\n";
+  if ( XCAFPrs::GetViewNameMode() ) di << "Display names ON\n";
+  else di << "Display names OFF\n";
   return 0;
 }
 
@@ -835,13 +827,13 @@ static Standard_Integer getviewName (Draw_Interpretor&  di, Standard_Integer /*a
 static Standard_Integer XSetTransparency (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 3) {
-    di<<"Use: "<<argv[0]<<" Doc Transparency [label1 label2 ...] "<<"\n";
+    di<<"Use: "<<argv[0]<<" Doc Transparency [label1 label2 ...] \n";
     return 1;
   }
 
   Handle(TDocStd_Document) Doc;
   DDocStd::GetDocument(argv[1], Doc);
-  if ( Doc.IsNull() ) { di << argv[1] << " is not a document" << "\n"; return 1; }
+  if ( Doc.IsNull() ) { di << argv[1] << " is not a document\n"; return 1; }
 
   const Standard_Real aTransparency = Draw::Atof(argv[2]);
 
@@ -913,7 +905,7 @@ static Standard_Integer XShowFaceBoundary (Draw_Interpretor& di,
   DDocStd::GetDocument (argv[1], aDoc);
   if (aDoc.IsNull())
   {
-    di << argv[1] << " is not a document" << "\n"; 
+    di << argv[1] << " is not a document\n"; 
     return 1;
   }
 
@@ -1023,10 +1015,10 @@ static Standard_Integer testDoc (Draw_Interpretor&,
   if( shape.IsNull())
     return 1;
  
-  Handle(XCAFApp_Application) A = XCAFApp_Application::GetApplication();
+  Handle(TDocStd_Application) anApp = DDocStd::GetApplication();
  
-  Handle(TDocStd_Document) aD1 = new TDocStd_Document("MDTV-XCAF");
-  aD1->Open(A);
+  Handle(TDocStd_Document) aD1 = new TDocStd_Document("BinXCAF");
+  aD1->Open(anApp);
   
   TCollection_AsciiString  aViewName ("Driver1/DummyDocument/View1");
   ViewerTest::ViewerInit (0, 0, 0, 0, aViewName.ToCString(), "");
@@ -1073,19 +1065,14 @@ void XDEDRAW::Init(Draw_Interpretor& di)
   // Load static variables for STEPCAF (ssv; 16.08.2012)
   STEPCAFControl_Controller::Init();
 
-  // OCAF *** szy: use <pload> command
+  // Initialize XCAF formats
+  Handle(TDocStd_Application) anApp = DDocStd::GetApplication();
+  BinXCAFDrivers::DefineFormat(anApp);
+  XmlXCAFDrivers::DefineFormat(anApp);
 
-//  DDF::AllCommands(di);
-//  DNaming::AllCommands(di);
-//  DDataStd::AllCommands(di);
-//  DPrsStd::AllCommands(di);
-  //DFunction::AllCommands(di);
-//  DDocStd::AllCommands(di);
-
-//  ViewerTest::Commands (di); *** szy: use <pload> command
-
-  // init XCAF application (if not yet done)
-  XCAFApp_Application::GetApplication();
+  // Register driver in global table for displaying XDE documents 
+  // in 3d viewer using OCAF mechanics
+  TPrsStd_DriverTable::Get()->AddDriver (XCAFPrs_Driver::GetID(), new XCAFPrs_Driver);
 
   //=====================================
   // General commands
@@ -1140,6 +1127,7 @@ void XDEDRAW::Init(Draw_Interpretor& di)
   XDEDRAW_Colors::InitCommands ( di );
   XDEDRAW_Layers::InitCommands ( di );
   XDEDRAW_Props::InitCommands ( di );
+  XDEDRAW_GDTs::InitCommands ( di );
   XDEDRAW_Common::InitCommands ( di );//moved from EXE
 
 }
@@ -1161,7 +1149,7 @@ void XDEDRAW::Factory(Draw_Interpretor& theDI)
   XDEDRAW::Init(theDI);
 
 #ifdef OCCT_DEBUG
-      theDI << "Draw Plugin : All TKXDEDRAW commands are loaded" << "\n";
+      theDI << "Draw Plugin : All TKXDEDRAW commands are loaded\n";
 #endif
 }
 
