@@ -13,28 +13,33 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-#include <XmlMDataStd_NamedDataDriver.ixx>
-#include <XmlObjMgt.hxx>
-#include <XmlObjMgt_Document.hxx>
-#include <LDOM_MemManager.hxx>
-#include <TCollection_ExtendedString.hxx>
+
 #include <CDM_MessageDriver.hxx>
-#include <TDataStd_NamedData.hxx>
-#include <TColStd_HArray1OfReal.hxx>
+#include <LDOM_MemManager.hxx>
+#include <Standard_Type.hxx>
+#include <TCollection_ExtendedString.hxx>
+#include <TColStd_DataMapIteratorOfDataMapOfStringInteger.hxx>
+#include <TColStd_DataMapOfStringInteger.hxx>
 #include <TColStd_HArray1OfInteger.hxx>
 #include <TColStd_HArray1OfReal.hxx>
-#include <TColStd_DataMapOfStringInteger.hxx>
-#include <TDataStd_DataMapOfStringReal.hxx>
-#include <TDataStd_DataMapOfStringString.hxx>
-#include <TDataStd_DataMapOfStringByte.hxx>
-#include <TDataStd_DataMapOfStringHArray1OfInteger.hxx>
-#include <TDataStd_DataMapOfStringHArray1OfReal.hxx>
-#include <TColStd_DataMapIteratorOfDataMapOfStringInteger.hxx>
-#include <TDataStd_DataMapIteratorOfDataMapOfStringReal.hxx>
-#include <TDataStd_DataMapIteratorOfDataMapOfStringString.hxx>
 #include <TDataStd_DataMapIteratorOfDataMapOfStringByte.hxx>
 #include <TDataStd_DataMapIteratorOfDataMapOfStringHArray1OfInteger.hxx>
 #include <TDataStd_DataMapIteratorOfDataMapOfStringHArray1OfReal.hxx>
+#include <TDataStd_DataMapIteratorOfDataMapOfStringReal.hxx>
+#include <TDataStd_DataMapIteratorOfDataMapOfStringString.hxx>
+#include <TDataStd_DataMapOfStringByte.hxx>
+#include <TDataStd_DataMapOfStringHArray1OfInteger.hxx>
+#include <TDataStd_DataMapOfStringHArray1OfReal.hxx>
+#include <TDataStd_DataMapOfStringReal.hxx>
+#include <TDataStd_DataMapOfStringString.hxx>
+#include <TDataStd_NamedData.hxx>
+#include <TDF_Attribute.hxx>
+#include <XmlMDataStd_NamedDataDriver.hxx>
+#include <XmlObjMgt.hxx>
+#include <XmlObjMgt_Document.hxx>
+#include <XmlObjMgt_Persistent.hxx>
+
+IMPLEMENT_STANDARD_RTTIEXT(XmlMDataStd_NamedDataDriver,XmlMDF_ADriver)
 IMPLEMENT_DOMSTRING (FirstIntegerIndex, "firstI")
 IMPLEMENT_DOMSTRING (LastIntegerIndex,  "lastI")
 IMPLEMENT_DOMSTRING (FirstRealIndex,    "firstR")
@@ -51,7 +56,7 @@ IMPLEMENT_DOMSTRING (LastRealArrIndex,   "lastRA")
 IMPLEMENT_DOMSTRING (ExtString, "string")
 IMPLEMENT_DOMSTRING (Value,     "value")
 
-#ifdef WNT
+#ifdef _WIN32
 #define EXCEPTION ...
 #else
 #define EXCEPTION Standard_Failure
@@ -643,7 +648,7 @@ void XmlMDataStd_NamedDataDriver::Paste(const Handle(TDF_Attribute)& theSource,
 
   Standard_Integer i=0, up;
   XmlObjMgt_Element& anElement = theTarget;
-  XmlObjMgt_Document aDoc = anElement.getOwnerDocument().Doc();
+  XmlObjMgt_Document aDoc (anElement.getOwnerDocument());
   if(S->HasIntegers() && !S->GetIntegersContainer().IsEmpty()) {
     // store a set of elements with string in each of them
     up = S->GetIntegersContainer().Extent();
@@ -747,8 +752,8 @@ void XmlMDataStd_NamedDataDriver::Paste(const Handle(TDF_Attribute)& theSource,
       for(;;) {
 	char aValueChar[32];
 	Sprintf(aValueChar, "%.15g", anArr1.Value(j));
-	TCollection_AsciiString aValueStr(aValueChar);
-	aValueStr2 += aValueStr;
+	TCollection_AsciiString aValueStr3(aValueChar);
+	aValueStr2 += aValueStr3;
 	if (j >= anArr1.Upper()) break;
 	aValueStr2 += ' ';
 	j++;
